diff --git a/RELEASE_NOTES.txt b/RELEASE_NOTES.txt
index 18f7d0e..6370e24 100644
--- a/RELEASE_NOTES.txt
+++ b/RELEASE_NOTES.txt
@@ -1,3 +1,13 @@
+==== 1.9.4.1 ====
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+] NOTE: Current Release Notes are maintained at:                                                                              [
+]                                                                                                                             [
+] http://devdocs.magento.com/guides/m1x/ce19-ee114/ce1.9_release-notes.html                                                   [
+]                                                                                                                             [
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 ==== 1.9.4.0 ====
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
diff --git a/api.php b/api.php
index c7165bb..0c75984 100644
--- a/api.php
+++ b/api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/Mage.php b/app/Mage.php
index 99bd4e5..89b63ed 100644
--- a/app/Mage.php
+++ b/app/Mage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -174,7 +174,7 @@ final class Mage
             'major'     => '1',
             'minor'     => '9',
             'revision'  => '4',
-            'patch'     => '0',
+            'patch'     => '1',
             'stability' => '',
             'number'    => '',
         );
@@ -808,16 +808,22 @@ final class Mage
         static $loggers = array();
 
         $level  = is_null($level) ? Zend_Log::DEBUG : $level;
-        $file = empty($file) ? 'system.log' : basename($file);
+        $file = empty($file) ?
+            (string) self::getConfig()->getNode('dev/log/file', Mage_Core_Model_Store::DEFAULT_CODE) : basename($file);
 
         // Validate file extension before save. Allowed file extensions: log, txt, html, csv
-        if (!self::helper('log')->isLogFileExtensionValid($file)) {
+        $_allowedFileExtensions = explode(
+            ',',
+            (string) self::getConfig()->getNode('dev/log/allowedFileExtensions', Mage_Core_Model_Store::DEFAULT_CODE)
+        );
+        $logValidator = new Zend_Validate_File_Extension($_allowedFileExtensions);
+        $logDir = self::getBaseDir('var') . DS . 'log';
+        if (!$logValidator->isValid($logDir . DS . $file)) {
             return;
         }
 
         try {
             if (!isset($loggers[$file])) {
-                $logDir  = self::getBaseDir('var') . DS . 'log';
                 $logFile = $logDir . DS . $file;
 
                 if (!is_dir($logDir)) {
diff --git a/app/bootstrap.php b/app/bootstrap.php
index 8078e5e6..dd35bec 100644
--- a/app/bootstrap.php
+++ b/app/bootstrap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Form.php b/app/code/community/Phoenix/Moneybookers/Block/Form.php
index 3789463..31ede1c 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Form.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Form.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Form extends Mage_Payment_Block_Form
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Info.php b/app/code/community/Phoenix/Moneybookers/Block/Info.php
index 9c6cddf..0c86641 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Info.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Info.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Info extends Mage_Payment_Block_Info
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Jsinit.php b/app/code/community/Phoenix/Moneybookers/Block/Jsinit.php
index 629078a..710af84 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Jsinit.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Jsinit.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Jsinit extends Mage_Adminhtml_Block_Template
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Payment.php b/app/code/community/Phoenix/Moneybookers/Block/Payment.php
index 632a26c..5f8a9a5 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Payment.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Payment.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Payment extends Mage_Core_Block_Template
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Placeform.php b/app/code/community/Phoenix/Moneybookers/Block/Placeform.php
index ce4ff1d..c520705 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Placeform.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Placeform.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Placeform extends Mage_Core_Block_Template
diff --git a/app/code/community/Phoenix/Moneybookers/Block/Redirect.php b/app/code/community/Phoenix/Moneybookers/Block/Redirect.php
index 39390bc..ccc1bbb 100644
--- a/app/code/community/Phoenix/Moneybookers/Block/Redirect.php
+++ b/app/code/community/Phoenix/Moneybookers/Block/Redirect.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Block_Redirect extends Mage_Core_Block_Template
diff --git a/app/code/community/Phoenix/Moneybookers/Helper/Data.php b/app/code/community/Phoenix/Moneybookers/Helper/Data.php
index ec4843d..0f2b760 100644
--- a/app/code/community/Phoenix/Moneybookers/Helper/Data.php
+++ b/app/code/community/Phoenix/Moneybookers/Helper/Data.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Helper_Data extends Mage_Payment_Helper_Data
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Abstract.php b/app/code/community/Phoenix/Moneybookers/Model/Abstract.php
index 0ffdc49..8984a6f 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Abstract.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Abstract.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 abstract class Phoenix_Moneybookers_Model_Abstract extends Mage_Payment_Model_Method_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Acc.php b/app/code/community/Phoenix/Moneybookers/Model/Acc.php
index a3e3f5d..16e2849 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Acc.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Acc.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Acc extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Csi.php b/app/code/community/Phoenix/Moneybookers/Model/Csi.php
index 4ed8155..b158871 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Csi.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Csi.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Csi extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Did.php b/app/code/community/Phoenix/Moneybookers/Model/Did.php
index 746e508..f15e9c8 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Did.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Did.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Did extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Dnk.php b/app/code/community/Phoenix/Moneybookers/Model/Dnk.php
index 786c2e1..73fe960 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Dnk.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Dnk.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Dnk extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Ebt.php b/app/code/community/Phoenix/Moneybookers/Model/Ebt.php
index 048e11d..e92d8b2 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Ebt.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Ebt.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Ebt extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Ent.php b/app/code/community/Phoenix/Moneybookers/Model/Ent.php
index 66068ae..44b37e1 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Ent.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Ent.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Ent extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Event.php b/app/code/community/Phoenix/Moneybookers/Model/Event.php
index bd6dd29..3f3a453 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Event.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Event.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Gcb.php b/app/code/community/Phoenix/Moneybookers/Model/Gcb.php
index 10728ea..d299493 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Gcb.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Gcb.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Gcb extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Gir.php b/app/code/community/Phoenix/Moneybookers/Model/Gir.php
index 6003204..b6b1f10 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Gir.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Gir.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Gir extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Idl.php b/app/code/community/Phoenix/Moneybookers/Model/Idl.php
index f91fb10..77c3e3b 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Idl.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Idl.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Idl extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Lsr.php b/app/code/community/Phoenix/Moneybookers/Model/Lsr.php
index 75f666f..ad815e7 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Lsr.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Lsr.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Lsr extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Mae.php b/app/code/community/Phoenix/Moneybookers/Model/Mae.php
index 78a564f..d6984a2 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Mae.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Mae.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Mae extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Npy.php b/app/code/community/Phoenix/Moneybookers/Model/Npy.php
index aff28e1..f7a4d20 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Npy.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Npy.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Npy extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Obt.php b/app/code/community/Phoenix/Moneybookers/Model/Obt.php
index 0424310..979968f 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Obt.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Obt.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Obt extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Pli.php b/app/code/community/Phoenix/Moneybookers/Model/Pli.php
index a5c0fba..e054133 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Pli.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Pli.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Pli extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Psp.php b/app/code/community/Phoenix/Moneybookers/Model/Psp.php
index 8378122..0f30419 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Psp.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Psp.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Psp extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Pwy.php b/app/code/community/Phoenix/Moneybookers/Model/Pwy.php
index e430d1b..c516223 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Pwy.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Pwy.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Pwy extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Sft.php b/app/code/community/Phoenix/Moneybookers/Model/Sft.php
index c53ebb8..11525b8 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Sft.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Sft.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Sft extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/So2.php b/app/code/community/Phoenix/Moneybookers/Model/So2.php
index 98c7aca..7526561 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/So2.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/So2.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_So2 extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/Model/Wlt.php b/app/code/community/Phoenix/Moneybookers/Model/Wlt.php
index d168182..8eb6591 100644
--- a/app/code/community/Phoenix/Moneybookers/Model/Wlt.php
+++ b/app/code/community/Phoenix/Moneybookers/Model/Wlt.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_Model_Wlt extends Phoenix_Moneybookers_Model_Abstract
diff --git a/app/code/community/Phoenix/Moneybookers/controllers/MoneybookersController.php b/app/code/community/Phoenix/Moneybookers/controllers/MoneybookersController.php
index 7b5b65b..adf99a9 100644
--- a/app/code/community/Phoenix/Moneybookers/controllers/MoneybookersController.php
+++ b/app/code/community/Phoenix/Moneybookers/controllers/MoneybookersController.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_MoneybookersController extends Mage_Adminhtml_Controller_Action
diff --git a/app/code/community/Phoenix/Moneybookers/controllers/ProcessingController.php b/app/code/community/Phoenix/Moneybookers/controllers/ProcessingController.php
index 139af5c..99809bc 100644
--- a/app/code/community/Phoenix/Moneybookers/controllers/ProcessingController.php
+++ b/app/code/community/Phoenix/Moneybookers/controllers/ProcessingController.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Phoenix_Moneybookers_ProcessingController extends Mage_Core_Controller_Front_Action
diff --git a/app/code/community/Phoenix/Moneybookers/etc/config.xml b/app/code/community/Phoenix/Moneybookers/etc/config.xml
index 188fef0..e9fd788 100644
--- a/app/code/community/Phoenix/Moneybookers/etc/config.xml
+++ b/app/code/community/Phoenix/Moneybookers/etc/config.xml
@@ -15,7 +15,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/app/code/community/Phoenix/Moneybookers/etc/system.xml b/app/code/community/Phoenix/Moneybookers/etc/system.xml
index 09ef71c..8f35dd2 100644
--- a/app/code/community/Phoenix/Moneybookers/etc/system.xml
+++ b/app/code/community/Phoenix/Moneybookers/etc/system.xml
@@ -15,7 +15,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/install-1.6.0.0.php b/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/install-1.6.0.0.php
index 13087aa..bfe5410 100644
--- a/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/install-1.6.0.0.php
+++ b/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/install-1.6.0.0.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/mysql4-upgrade-1.2-1.2.0.1.php b/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/mysql4-upgrade-1.2-1.2.0.1.php
index 79155e7..85dd44c 100644
--- a/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/mysql4-upgrade-1.2-1.2.0.1.php
+++ b/app/code/community/Phoenix/Moneybookers/sql/moneybookers_setup/mysql4-upgrade-1.2-1.2.0.1.php
@@ -14,7 +14,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Helper/Block.php b/app/code/core/Mage/Admin/Helper/Block.php
index 83ebce5..3f822dd 100644
--- a/app/code/core/Mage/Admin/Helper/Block.php
+++ b/app/code/core/Mage/Admin/Helper/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Helper/Data.php b/app/code/core/Mage/Admin/Helper/Data.php
index f5b6d02..e30fde2 100644
--- a/app/code/core/Mage/Admin/Helper/Data.php
+++ b/app/code/core/Mage/Admin/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Helper/Rules/Fallback.php b/app/code/core/Mage/Admin/Helper/Rules/Fallback.php
index 1302852..89f11e0 100644
--- a/app/code/core/Mage/Admin/Helper/Rules/Fallback.php
+++ b/app/code/core/Mage/Admin/Helper/Rules/Fallback.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Helper/Variable.php b/app/code/core/Mage/Admin/Helper/Variable.php
index 696bdf4..e88b122 100644
--- a/app/code/core/Mage/Admin/Helper/Variable.php
+++ b/app/code/core/Mage/Admin/Helper/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl.php b/app/code/core/Mage/Admin/Model/Acl.php
index 3f3250e..cb69fc7 100644
--- a/app/code/core/Mage/Admin/Model/Acl.php
+++ b/app/code/core/Mage/Admin/Model/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Assert/Ip.php b/app/code/core/Mage/Admin/Model/Acl/Assert/Ip.php
index 45565ad..81ca071 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Assert/Ip.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Assert/Ip.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Assert/Time.php b/app/code/core/Mage/Admin/Model/Acl/Assert/Time.php
index d6635bc..707f994 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Assert/Time.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Assert/Time.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Resource.php b/app/code/core/Mage/Admin/Model/Acl/Resource.php
index 0ee10d1..2065658 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Resource.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Role.php b/app/code/core/Mage/Admin/Model/Acl/Role.php
index 6bc5ddc..4238f09 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Role.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Role/Generic.php b/app/code/core/Mage/Admin/Model/Acl/Role/Generic.php
index f3f9a37..c7eea36 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Role/Generic.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Role/Generic.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Role/Group.php b/app/code/core/Mage/Admin/Model/Acl/Role/Group.php
index 534bf61..6925783 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Role/Group.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Role/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Role/Registry.php b/app/code/core/Mage/Admin/Model/Acl/Role/Registry.php
index 7db23b0..4ce6be8 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Role/Registry.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Role/Registry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Acl/Role/User.php b/app/code/core/Mage/Admin/Model/Acl/Role/User.php
index f22865b..6cee7c5 100644
--- a/app/code/core/Mage/Admin/Model/Acl/Role/User.php
+++ b/app/code/core/Mage/Admin/Model/Acl/Role/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Block.php b/app/code/core/Mage/Admin/Model/Block.php
index de63c53..ba329cb 100644
--- a/app/code/core/Mage/Admin/Model/Block.php
+++ b/app/code/core/Mage/Admin/Model/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Config.php b/app/code/core/Mage/Admin/Model/Config.php
index f6fd706..e59406d 100644
--- a/app/code/core/Mage/Admin/Model/Config.php
+++ b/app/code/core/Mage/Admin/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Acl.php b/app/code/core/Mage/Admin/Model/Mysql4/Acl.php
index d2f750d..0765add 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Acl.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role.php b/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role.php
index e01f908..cc35109 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role/Collection.php
index 526294d..3bb4932 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Acl/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Permissions/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Permissions/Collection.php
index 55c76b4..947f011 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Permissions/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Permissions/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Role.php b/app/code/core/Mage/Admin/Model/Mysql4/Role.php
index 0419589..3516844 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Role.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Role/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Role/Collection.php
index 6779742..1ddd8a8 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Role/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Roles.php b/app/code/core/Mage/Admin/Model/Mysql4/Roles.php
index 6e29c2a..ef29d74 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Roles.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Roles/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Roles/Collection.php
index bad3042..19b5e4b 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Roles/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Roles/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Roles/User/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Roles/User/Collection.php
index f375818..d7d4816 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Roles/User/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Roles/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Rules.php b/app/code/core/Mage/Admin/Model/Mysql4/Rules.php
index 8cb056c..a6469de 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Rules.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/Rules/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/Rules/Collection.php
index c393c46..81551e1 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/Rules/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/Rules/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/User.php b/app/code/core/Mage/Admin/Model/Mysql4/User.php
index 8945d30..f942694 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/User.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Mysql4/User/Collection.php b/app/code/core/Mage/Admin/Model/Mysql4/User/Collection.php
index 0adaf0c..1db7189 100644
--- a/app/code/core/Mage/Admin/Model/Mysql4/User/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Mysql4/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Observer.php b/app/code/core/Mage/Admin/Model/Observer.php
index 9a14f8d..bbd12c9 100644
--- a/app/code/core/Mage/Admin/Model/Observer.php
+++ b/app/code/core/Mage/Admin/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Redirectpolicy.php b/app/code/core/Mage/Admin/Model/Redirectpolicy.php
index e00882f..eb7bcea 100644
--- a/app/code/core/Mage/Admin/Model/Redirectpolicy.php
+++ b/app/code/core/Mage/Admin/Model/Redirectpolicy.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Acl.php b/app/code/core/Mage/Admin/Model/Resource/Acl.php
index 7a54119..21bd3c0 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Acl.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Acl/Role.php b/app/code/core/Mage/Admin/Model/Resource/Acl/Role.php
index 4f2f657..993fc96 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Acl/Role.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Acl/Role/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Acl/Role/Collection.php
index 40a0a01..3fd6d77 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Acl/Role/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Acl/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Block.php b/app/code/core/Mage/Admin/Model/Resource/Block.php
index 5aaf278..5b3b3b5 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Block.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Block/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Block/Collection.php
index b915e8c..36d6557 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Block/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Block/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Permissions/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Permissions/Collection.php
index 1930b7a..f479c20 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Permissions/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Permissions/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Role.php b/app/code/core/Mage/Admin/Model/Resource/Role.php
index 3636268..63821be 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Role.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Role/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Role/Collection.php
index 6a8e5f0..24a3517 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Role/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Roles.php b/app/code/core/Mage/Admin/Model/Resource/Roles.php
index c9df8e9..3be4377 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Roles.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Roles/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Roles/Collection.php
index 5ca09e4..92ac05f 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Roles/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Roles/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Roles/User/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Roles/User/Collection.php
index 3d45041..7dd5dd0 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Roles/User/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Roles/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Rules.php b/app/code/core/Mage/Admin/Model/Resource/Rules.php
index 110f66f..b747e33 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Rules.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Rules/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Rules/Collection.php
index d70853b..4725bbc 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Rules/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Rules/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/User.php b/app/code/core/Mage/Admin/Model/Resource/User.php
index fe90c2e..1bfa885 100644
--- a/app/code/core/Mage/Admin/Model/Resource/User.php
+++ b/app/code/core/Mage/Admin/Model/Resource/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/User/Collection.php b/app/code/core/Mage/Admin/Model/Resource/User/Collection.php
index 4c42aa7..4bda40a 100644
--- a/app/code/core/Mage/Admin/Model/Resource/User/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Variable.php b/app/code/core/Mage/Admin/Model/Resource/Variable.php
index 7c21471..f799c4b 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Variable.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Resource/Variable/Collection.php b/app/code/core/Mage/Admin/Model/Resource/Variable/Collection.php
index 907c94d..f865bdc 100644
--- a/app/code/core/Mage/Admin/Model/Resource/Variable/Collection.php
+++ b/app/code/core/Mage/Admin/Model/Resource/Variable/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Role.php b/app/code/core/Mage/Admin/Model/Role.php
index ab71090..2fec1ea 100644
--- a/app/code/core/Mage/Admin/Model/Role.php
+++ b/app/code/core/Mage/Admin/Model/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Roles.php b/app/code/core/Mage/Admin/Model/Roles.php
index 6adc55e..51ec365 100644
--- a/app/code/core/Mage/Admin/Model/Roles.php
+++ b/app/code/core/Mage/Admin/Model/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Rules.php b/app/code/core/Mage/Admin/Model/Rules.php
index 0afc1b4..f2fab3d 100644
--- a/app/code/core/Mage/Admin/Model/Rules.php
+++ b/app/code/core/Mage/Admin/Model/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Session.php b/app/code/core/Mage/Admin/Model/Session.php
index 9270eb3..c96937a 100644
--- a/app/code/core/Mage/Admin/Model/Session.php
+++ b/app/code/core/Mage/Admin/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -157,15 +157,13 @@ class Mage_Admin_Model_Session extends Mage_Core_Model_Session_Abstract
             $e->setMessage(
                 Mage::helper('adminhtml')->__('You did not sign in correctly or your account is temporarily disabled.')
             );
-            Mage::dispatchEvent('admin_session_user_login_failed',
-                array('user_name' => $username, 'exception' => $e));
-            if ($request && !$request->getParam('messageSent')) {
-                Mage::getSingleton('adminhtml/session')->addError($e->getMessage());
-                $request->setParam('messageSent', true);
-            }
+            $this->_loginFailed($e, $request, $username, $e->getMessage());
+        } catch (Exception $e) {
+            $message = Mage::helper('adminhtml')->__('An error occurred while logging in.');
+            $this->_loginFailed($e, $request, $username, $message);
         }
 
-        return $user;
+        return isset($user) ? $user : null;
     }
 
     /**
@@ -276,4 +274,29 @@ class Mage_Admin_Model_Session extends Mage_Core_Model_Session_Abstract
             return null;
         }
     }
+
+    /**
+     * Login failed process
+     *
+     * @param Exception $e
+     * @param string $username
+     * @param string $message
+     * @param Mage_Core_Controller_Request_Http $request
+     * @return void
+     */
+    protected function _loginFailed($e, $request, $username, $message)
+    {
+        try {
+            Mage::dispatchEvent('admin_session_user_login_failed', array(
+                'user_name' => $username,
+                'exception' => $e
+            ));
+        } catch (Exception $e) {
+        }
+
+        if ($request && !$request->getParam('messageSent')) {
+            Mage::getSingleton('adminhtml/session')->addError($message);
+            $request->setParam('messageSent', true);
+        }
+    }
 }
diff --git a/app/code/core/Mage/Admin/Model/User.php b/app/code/core/Mage/Admin/Model/User.php
index 6ee4e1c..eac448a 100644
--- a/app/code/core/Mage/Admin/Model/User.php
+++ b/app/code/core/Mage/Admin/Model/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/Model/Variable.php b/app/code/core/Mage/Admin/Model/Variable.php
index 7675d48..2c23e56 100644
--- a/app/code/core/Mage/Admin/Model/Variable.php
+++ b/app/code/core/Mage/Admin/Model/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/data/admin_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Admin/data/admin_setup/data-install-1.6.0.0.php
index d41a9d1..44004e4 100644
--- a/app/code/core/Mage/Admin/data/admin_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Admin/data/admin_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/etc/config.xml b/app/code/core/Mage/Admin/etc/config.xml
index cc8fa30..ad751d5 100644
--- a/app/code/core/Mage/Admin/etc/config.xml
+++ b/app/code/core/Mage/Admin/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/install-1.6.0.0.php b/app/code/core/Mage/Admin/sql/admin_setup/install-1.6.0.0.php
index 551f7d5..57c0264 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-install-0.7.0.php
index a312ad1..ac3f29c 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.0-0.7.1.php
index ec07a51..44836f1 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.1-0.7.2.php
index c35d201..d1546ae 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 1e28c1a..8e76907 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.0.0-1.6.1.0.php b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.0.0-1.6.1.0.php
index 1dacb6d..626e263 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.0.0-1.6.1.0.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.0.0-1.6.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.0-1.6.1.1.php b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.0-1.6.1.1.php
index a46dadc..d8318e4 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.0-1.6.1.1.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.0-1.6.1.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.1-1.6.1.2.php b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.1-1.6.1.2.php
index d022646..6988516 100644
--- a/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.1-1.6.1.2.php
+++ b/app/code/core/Mage/Admin/sql/admin_setup/upgrade-1.6.1.1-1.6.1.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Admin
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Helper/Data.php b/app/code/core/Mage/AdminNotification/Helper/Data.php
index c07b8c3..7f932a1 100644
--- a/app/code/core/Mage/AdminNotification/Helper/Data.php
+++ b/app/code/core/Mage/AdminNotification/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Feed.php b/app/code/core/Mage/AdminNotification/Model/Feed.php
index c46cce1..460fda0 100644
--- a/app/code/core/Mage/AdminNotification/Model/Feed.php
+++ b/app/code/core/Mage/AdminNotification/Model/Feed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Inbox.php b/app/code/core/Mage/AdminNotification/Model/Inbox.php
index b681af8..42278f2 100644
--- a/app/code/core/Mage/AdminNotification/Model/Inbox.php
+++ b/app/code/core/Mage/AdminNotification/Model/Inbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox.php b/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox.php
index ddb0050..18c07c9 100644
--- a/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox.php
+++ b/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox/Collection.php b/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox/Collection.php
index 620a681..d0b8f4f 100644
--- a/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox/Collection.php
+++ b/app/code/core/Mage/AdminNotification/Model/Mysql4/Inbox/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Observer.php b/app/code/core/Mage/AdminNotification/Model/Observer.php
index e8694f8..557ef1c 100644
--- a/app/code/core/Mage/AdminNotification/Model/Observer.php
+++ b/app/code/core/Mage/AdminNotification/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Resource/Inbox.php b/app/code/core/Mage/AdminNotification/Model/Resource/Inbox.php
index b83c0c8..c7a3882 100644
--- a/app/code/core/Mage/AdminNotification/Model/Resource/Inbox.php
+++ b/app/code/core/Mage/AdminNotification/Model/Resource/Inbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Resource/Inbox/Collection.php b/app/code/core/Mage/AdminNotification/Model/Resource/Inbox/Collection.php
index 5a01a90..1225959 100644
--- a/app/code/core/Mage/AdminNotification/Model/Resource/Inbox/Collection.php
+++ b/app/code/core/Mage/AdminNotification/Model/Resource/Inbox/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/Model/Survey.php b/app/code/core/Mage/AdminNotification/Model/Survey.php
index f980b7d..44cee05 100644
--- a/app/code/core/Mage/AdminNotification/Model/Survey.php
+++ b/app/code/core/Mage/AdminNotification/Model/Survey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/etc/adminhtml.xml b/app/code/core/Mage/AdminNotification/etc/adminhtml.xml
index b253917..fab4922 100644
--- a/app/code/core/Mage/AdminNotification/etc/adminhtml.xml
+++ b/app/code/core/Mage/AdminNotification/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/AdminNotification/etc/config.xml b/app/code/core/Mage/AdminNotification/etc/config.xml
index 49ae410..1cee6a1 100644
--- a/app/code/core/Mage/AdminNotification/etc/config.xml
+++ b/app/code/core/Mage/AdminNotification/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/AdminNotification/etc/system.xml b/app/code/core/Mage/AdminNotification/etc/system.xml
index 364702b..cd9e2b6 100644
--- a/app/code/core/Mage/AdminNotification/etc/system.xml
+++ b/app/code/core/Mage/AdminNotification/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/install-1.6.0.0.php b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/install-1.6.0.0.php
index 2f878e8..70713d3 100644
--- a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-install-1.0.0.php b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-install-1.0.0.php
index ec2ab7c..2c5fbba 100644
--- a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-install-1.0.0.php
+++ b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-install-1.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 2802498..451b9c8 100644
--- a/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/AdminNotification/sql/adminnotification_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_AdminNotification
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Abstract.php
index 5d6458a..4d296e0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Buttons.php b/app/code/core/Mage/Adminhtml/Block/Api/Buttons.php
index 406e5aa..c5a53f5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Buttons.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Buttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -71,7 +71,7 @@ class Mage_Adminhtml_Block_Api_Buttons extends Mage_Adminhtml_Block_Template
                             true
                         )
                         . '\', \''
-                        . $this->getUrl('*/*/delete', array('rid' => $this->getRequest()->getParam('rid')))
+                        . $this->getUrlSecure('*/*/delete', array('rid' => $this->getRequest()->getParam('rid')))
                         . '\')',
                     'class' => 'delete'
                 ))
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Editroles.php b/app/code/core/Mage/Adminhtml/Block/Api/Editroles.php
index 0a9ddc5..8fb58cf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Editroles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Editroles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Edituser.php b/app/code/core/Mage/Adminhtml/Block/Api/Edituser.php
index b4416de..0c034cf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Edituser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Edituser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Grid/Role.php b/app/code/core/Mage/Adminhtml/Block/Api/Grid/Role.php
index ae94e11..45d0e8f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Grid/Role.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Grid/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Role.php b/app/code/core/Mage/Adminhtml/Block/Api/Role.php
index 52529d9..a0b15ed 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Role.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php b/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
index 403431f..7fa0f72 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Roles.php b/app/code/core/Mage/Adminhtml/Block/Api/Roles.php
index 7de7162..15be275 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Roles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Roleinfo.php b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Roleinfo.php
index 51870ff..6aed0cd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Roleinfo.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Roleinfo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesedit.php b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesedit.php
index 89723dd..b2a251e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesedit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesedit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesusers.php b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesusers.php
index c7ca72b..9f58d25 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesusers.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Rolesusers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Userroles.php b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Userroles.php
index b0a2c96..a3d119b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Tab/Userroles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Tab/Userroles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Api_Tab_Userroles extends Mage_Adminhtml_Block_Widget_Tabs
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User.php b/app/code/core/Mage/Adminhtml/Block/Api/User.php
index b6756ac..0841035 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit.php
index a5397bc..095ceeb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Form.php
index 190c134..1671f3c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Main.php
index 5a69d45..8bab521 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Roles.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Roles.php
index 245dbac..ffc644d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Roles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tab/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tabs.php
index 526bfea..1a46809 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/User/Grid.php b/app/code/core/Mage/Adminhtml/Block/Api/User/Grid.php
index aafe187..b0226aa 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/User/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/User/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Users.php b/app/code/core/Mage/Adminhtml/Block/Api/Users.php
index d4309e4..671fbe8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Users.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Users.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Backup.php b/app/code/core/Mage/Adminhtml/Block/Backup.php
index 83bd454..0081b8e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Backup.php
+++ b/app/code/core/Mage/Adminhtml/Block/Backup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Backup/Dialogs.php b/app/code/core/Mage/Adminhtml/Block/Backup/Dialogs.php
index eeebae5..93eafff 100644
--- a/app/code/core/Mage/Adminhtml/Block/Backup/Dialogs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Backup/Dialogs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Backup/Grid.php b/app/code/core/Mage/Adminhtml/Block/Backup/Grid.php
index f1e7aac..b1cb27b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Backup/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Backup/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cache.php b/app/code/core/Mage/Adminhtml/Block/Cache.php
index 479ba7a..f266bab 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cache.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cache/Additional.php b/app/code/core/Mage/Adminhtml/Block/Cache/Additional.php
index 3e505d4..3d7f257 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cache/Additional.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cache/Additional.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cache/Grid.php b/app/code/core/Mage/Adminhtml/Block/Cache/Grid.php
index 44fa424..5c0cba2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cache/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cache/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cache/Notifications.php b/app/code/core/Mage/Adminhtml/Block/Cache/Notifications.php
index bdc105d..d3daac8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cache/Notifications.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cache/Notifications.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog.php b/app/code/core/Mage/Adminhtml/Block/Catalog.php
index c8c971f..8690e2d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Abstract.php
index 0609ad5..6c4c026 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Checkboxes/Tree.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Checkboxes/Tree.php
index ea17252..469fbd0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Checkboxes/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Checkboxes/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit.php
index 9fa268e..0fa228e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit/Form.php
index 43dc2a1..83ccfa9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Image.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Image.php
index 66c45d3..766e81f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Image.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Pricestep.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Pricestep.php
index ad62281..ff787e8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Pricestep.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Pricestep.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Available.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Available.php
index c573538..fe7a60c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Available.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Available.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Default.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Default.php
index 4af51a6..d8e3103 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Helper/Sortby/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Attributes.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Attributes.php
index 5a8a661..780d932 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Attributes.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Design.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Design.php
index a1ede0d..a6422bf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Design.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Catalog_Category_Tab_Design extends Mage_Adminhtml_Block_Catalog_Form
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/General.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/General.php
index 1adcaec..3bc6273 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/General.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/General.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Product.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Product.php
index 31567ee..5729244 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tab/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tabs.php
index 67817c6..9c41aa9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tree.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tree.php
index d2c7388..36c04ff 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Widget/Chooser.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Widget/Chooser.php
index 64f240d..dbb27ca 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Widget/Chooser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Category/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Form.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Form.php
index ce0236c..810abf1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Attribute/Urlkey.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Attribute/Urlkey.php
index 825d7cc..a58ce6e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Attribute/Urlkey.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Attribute/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/DateFieldsOrder.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/DateFieldsOrder.php
index 0ce0ce5..b9d9a9b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/DateFieldsOrder.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/DateFieldsOrder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/YearRange.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/YearRange.php
index d95be77..a2f371f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/YearRange.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Config/YearRange.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Fieldset/Element.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Fieldset/Element.php
index e6cad8c..11958c5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Fieldset/Element.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Form/Renderer/Fieldset/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg.php
index e1b8440..26c78ca 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg/Content.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg/Content.php
index 89dfa2c..17ac177 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg/Content.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Helper/Form/Wysiwyg/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product.php
index c1861c5..4b3392e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute.php
index 511516d..7f34472 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit.php
index c83cd0d..88a4401 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Form.php
index 7edf8e8..af21288 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Front.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Front.php
index b41e295..45b7161 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Front.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Front.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Main.php
index 1e3a8f0..d1e2944 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Options.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
index a9859a7..cefcb4b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/System.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/System.php
index 02304f1..fd94635 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/System.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tab/System.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tabs.php
index c2cd12f..510d0ff 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Grid.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Grid.php
index 73ffc93..700fa4b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Attributes.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Attributes.php
index b490565..9485f78 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Attributes.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Created.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Created.php
index 5550647..665baf5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Created.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/New/Product/Created.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Grid.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Grid.php
index d8a6b67..7b09275 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main.php
index 2064784..64011ba 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formattribute.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formattribute.php
index 8b4b14c..9e12e4a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formattribute.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formattribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formgroup.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formgroup.php
index 07fbe88..9495ca9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formgroup.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formgroup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formset.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formset.php
index 4450234..cdf7654 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formset.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Formset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Attribute.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Attribute.php
index 14ea164..b766af9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Attribute.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Group.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Group.php
index ebcc38a..1a2981d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Main/Tree/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Add.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Add.php
index 02934f8..6c6f6f5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Add.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Add.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main.php
index 3513219..270a8ac 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main/Filter.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main/Filter.php
index a9106ad..9e69ab6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main/Filter.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Attribute/Set/Toolbar/Main/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Configure.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Configure.php
index f5f218e..e2ff90e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Configure.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Configure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Error.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Error.php
index 6c6b2c4..ae52ba6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Error.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Error.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset.php
index 563978c..3da193a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Configurable.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Configurable.php
index 0b78abe..ab3e43d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Configurable.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Grouped.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Grouped.php
index f925a64..dc106ef 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Grouped.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Options.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Options.php
index 451a61b..2117b65 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Options.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Qty.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Qty.php
index 6cf8b64..1b09c7d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Qty.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Fieldset/Qty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Update/Result.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Update/Result.php
index 5fc3111..ec31a72 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Update/Result.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Composite/Update/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Created.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Created.php
index f952c47..6fae38d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Created.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Created.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit.php
index a46befa..ff561f8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -205,7 +205,7 @@ class Mage_Adminhtml_Block_Catalog_Product_Edit extends Mage_Adminhtml_Block_Wid
 
     public function getDeleteUrl()
     {
-        return $this->getUrl('*/*/delete', array('_current'=>true));
+        return $this->getUrlSecure('*/*/delete', array('_current'=>true));
     }
 
     public function getDuplicateUrl()
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute.php
index eaed592..cbf5331 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Attributes.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Attributes.php
index 561ee99..91403d7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Attributes.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Inventory.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Inventory.php
index c9b63fe..08d2684 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Inventory.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Inventory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Websites.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Websites.php
index 6e02b34..23744b6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Websites.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tab/Websites.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tabs.php
index 3813bc9..85b9883 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Action/Attribute/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Js.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Js.php
index e076f99..9d50626 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Js.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Ajax/Serializer.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Ajax/Serializer.php
index 12c23f6..c61b623 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Ajax/Serializer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Ajax/Serializer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts.php
index 8b5a2ff..f1402ab 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Price.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Price.php
index 8a606cd..ec8eb7b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Stock.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Stock.php
index 343a44f..292a12f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Stock.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Alerts/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes.php
index b7ad495..7f53fec 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes/Create.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes/Create.php
index 647f0fb4..5826ba7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Attributes/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Categories.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Categories.php
index 522e6ed..662e61d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Categories.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Categories.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Crosssell.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Crosssell.php
index ac618c4..1d9c361 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Crosssell.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Inventory.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Inventory.php
index 78b76c6..02632dd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Inventory.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Inventory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options.php
index 1e65f9f..519c3b8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Option.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Option.php
index 8426475..790a01a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Option.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Abstract.php
index 6e27dad..fa3e85a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Date.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Date.php
index 0f9ae7f..9f07c15 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Date.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/File.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/File.php
index 7da9d32..b506ec6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/File.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Select.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Select.php
index 2fb35f1..98d06f2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Select.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Text.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Text.php
index f50d578..4f68b46 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Text.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Options/Type/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price.php
index 3c2afe4..c63c0e1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group.php
index cee1707..13959d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group/Abstract.php
index 41525b7..6f18ae6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Group/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Recurring.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Recurring.php
index d6d0050..6ca3120 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Recurring.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Recurring.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Tier.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Tier.php
index 3b37eca..69b370a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Tier.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Price/Tier.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Related.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Related.php
index 0038342..0ba0535 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Related.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Related.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Reviews.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Reviews.php
index 86a4672..e691668 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Reviews.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Reviews.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Settings.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Settings.php
index ee9fab8..14f3a22 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Settings.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
index 6762bee..e1c2df9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid.php
index 12fcbaa..1e5963f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Filter/Inventory.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Filter/Inventory.php
index 4e06ad5..244cbfb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Filter/Inventory.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Filter/Inventory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Checkbox.php
index 3bc1443..6e3606d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Inventory.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Inventory.php
index 3ac359a..246af27 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Inventory.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Grid/Renderer/Inventory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Simple.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Simple.php
index fbc57da..c9f3cee 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Simple.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Group.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Group.php
index 57be540..71d0041 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Settings.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Settings.php
index 09ed583..63b5a83 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Settings.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag.php
index a93269d..6020bf9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag/Customer.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag/Customer.php
index 4af65c71..d666087 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Tag/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Upsell.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Upsell.php
index cbafa9f..e746ecc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Upsell.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Upsell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Websites.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Websites.php
index b561124..8669fc4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Websites.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Websites.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs.php
index 54addd0..7f62af1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Configurable.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Configurable.php
index 5ca332a..640c1e1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Configurable.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Grouped.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Grouped.php
index 34bc8ce..1836377 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Grouped.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tabs/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Frontend/Product/Watermark.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Frontend/Product/Watermark.php
index d931765..b4f6bba 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Frontend/Product/Watermark.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Frontend/Product/Watermark.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Grid.php
index 8a1e3f6..90a6aad 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Apply.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Apply.php
index 4b6b651..3027d36 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Apply.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Apply.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Boolean.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Boolean.php
index 8c8312d..c4dddce 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Boolean.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Config.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Config.php
index 6528915..11ce20c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Config.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery.php
index 4f69358..68a1e3f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery/Content.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery/Content.php
index 90b0461..ff633ce 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery/Content.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Gallery/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Image.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Image.php
index bfd0742..094d143 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Image.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Enabled.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Enabled.php
index 6d3f0c8..94286e6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Enabled.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Enabled.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Price.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Price.php
index f1e62ea..72832a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Msrp/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Price.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Price.php
index d692134..5e69a49 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Weight.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Weight.php
index ad373a2..2dee15f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Weight.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Helper/Form/Weight.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Price.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Price.php
index 635e46a..32849c3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser.php
index 10c5ec0..3047291 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser/Container.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser/Container.php
index 3bb4656..628d9dc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser/Container.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Widget/Chooser/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Search.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Search.php
index bde6f72..8b55fe3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Search.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit.php
index 6b3ce03..77ca984 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit/Form.php
index 3e39628..417e8cd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Grid.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Grid.php
index 31f6cb5..994af5f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement.php b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement.php
index 851d899..60f74f2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement.php
+++ b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit.php b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit.php
index b829f80..ac5ca1b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit/Form.php
index da50dba..26c5df8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Grid.php b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Grid.php
index bcd6b28..3c163f4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Checkout/Agreement/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Checkout_Agreement_Grid extends Mage_Adminhtml_Block_Widget_Grid
diff --git a/app/code/core/Mage/Adminhtml/Block/Checkout/Formkey.php b/app/code/core/Mage/Adminhtml/Block/Checkout/Formkey.php
index be94a59..2612c7f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Checkout/Formkey.php
+++ b/app/code/core/Mage/Adminhtml/Block/Checkout/Formkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Block.php b/app/code/core/Mage/Adminhtml/Block/Cms/Block.php
index f4a6715..9d83e5a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Block.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit.php b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit.php
index aa00081..511df4d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit/Form.php
index 6b6cafd..28d564c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Grid.php b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Grid.php
index 2473c41..5480e7c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Widget/Chooser.php b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Widget/Chooser.php
index 18425e8..a6515a2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Block/Widget/Chooser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Block/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page.php
index 723f0f7..aa48de9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit.php
index 90c0b5c..1d74c12 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Form.php
index 46c2b8d..e8c2307 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Content.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Content.php
index e56f61e..425fab6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Content.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Design.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Design.php
index 9e99902..825ac29 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Design.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Cms_Page_Edit_Tab_Design
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Main.php
index 88559ab..fdb1c09 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Meta.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Meta.php
index e612aa3..77a5cf9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Meta.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tab/Meta.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tabs.php
index 9a2f716..ec3f6a8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid.php
index 85cc2f2..f291cf6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid/Renderer/Action.php
index 754b8e9..75aed14 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Widget/Chooser.php b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Widget/Chooser.php
index e8b0014..2a7e1af 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Page/Widget/Chooser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Page/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content.php b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content.php
index a8c9731..27e9411 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Files.php b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Files.php
index b745764..0f90039 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Files.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Files.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Newfolder.php b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Newfolder.php
index e4a24cd..72d8fa4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Newfolder.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Newfolder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Uploader.php b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Uploader.php
index 15c7f76..7db75d0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Uploader.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Content/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Tree.php b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Tree.php
index 60b4d14..65bbcfd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/Cms/Wysiwyg/Images/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer.php b/app/code/core/Mage/Adminhtml/Block/Customer.php
index 973c627..5ff0c5c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit.php
index e22d40f..599466e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Form.php
index 4382cf7..79f6ccc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Adminpass.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Adminpass.php
index c67d2fc..44187d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Adminpass.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Adminpass.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Attribute/Group.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Attribute/Group.php
index 2426e5d..af3ae9f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Attribute/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Attribute/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Newpass.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Newpass.php
index ab32e53..5a354af 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Newpass.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Newpass.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Region.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Region.php
index f05c869..4cb9f37 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Region.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Renderer/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Account.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Account.php
index 36b1784..c9a0be0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Account.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Account.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Addresses.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Addresses.php
index a598cef..1cbe359 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Addresses.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Cart.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Cart.php
index df797b7..06c378a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Cart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Carts.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Carts.php
index 3c90645..c0c5c9e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Carts.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Carts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter.php
index 6b96409..2ab26f1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid.php
index f1f5af1..be8795a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Filter/Status.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Filter/Status.php
index 6c60c8c..3e737ec 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Filter/Status.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Filter/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Action.php
index 6e808a6..2392275 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Status.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Status.php
index c066348..ec85d22 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Status.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Newsletter/Grid/Renderer/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Orders.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Orders.php
index 407f7a4..bc39eb5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Orders.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Reviews.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Reviews.php
index 0d092b6..47d9413 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Reviews.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Reviews.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tag.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tag.php
index 5142139..f5da811 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tag.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tags.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tags.php
index 34e16b9..1c6cea7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tags.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Tags.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View.php
index a8d64de..dc83d26 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Accordion.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Accordion.php
index f63721a..40f019d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Accordion.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Accordion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Cart.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Cart.php
index 112b560..11a8788 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Cart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Grid/Renderer/Item.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Grid/Renderer/Item.php
index 05d06fa..0e3feaa 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Grid/Renderer/Item.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Grid/Renderer/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Orders.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Orders.php
index e5d6596..f73cc57 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Orders.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Sales.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Sales.php
index e0a1c49..66b6647 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Sales.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Sales.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Wishlist.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Wishlist.php
index 51cf256..aadaf7d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Wishlist.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/View/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist.php
index 63b1772..07203b6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist/Grid/Renderer/Description.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist/Grid/Renderer/Description.php
index 35c23a0..a953a32 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist/Grid/Renderer/Description.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tab/Wishlist/Grid/Renderer/Description.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tabs.php
index 50b6172..6bfac6d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Boolean.php b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Boolean.php
index ca21ea6..9c2b73e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Boolean.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/File.php b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/File.php
index 62101ac..9fcb859 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/File.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Image.php b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Image.php
index 385de97..01b96f9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Image.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Form/Element/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Customer/Grid.php
index aa13faf..d12dc22 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Filter/Country.php b/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Filter/Country.php
index 99d7a42..c6fd8a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Filter/Country.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Filter/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Renderer/Multiaction.php b/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Renderer/Multiaction.php
index add8ff9..fb15058 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Renderer/Multiaction.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Grid/Renderer/Multiaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Group.php b/app/code/core/Mage/Adminhtml/Block/Customer/Group.php
index a9ccd15..3aa70b5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit.php b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit.php
index 8d3c526..1b7e8b8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -57,7 +57,7 @@ class Mage_Adminhtml_Block_Customer_Group_Edit extends Mage_Adminhtml_Block_Widg
                 'form_key' => Mage::getSingleton('core/session')->getFormKey()
             ));
         } else {
-            parent::getDeleteUrl();
+            return parent::getDeleteUrl();
         }
     }
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit/Form.php
index cd98bc6..6d6d931 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Grid.php b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Grid.php
index bd74ec3..f6f9f8e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Group/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Group/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online.php
index d852627..b53f903 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Filter.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Filter.php
index 59bbe42..2ceef01 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Filter.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid.php
index 2ba8d74..7f292b4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Ip.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Ip.php
index 3942cb4..005c35a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Ip.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Ip.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Type.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Type.php
index b44b53e..a3ca8b1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Type.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Url.php b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Url.php
index 562d0e5..e5a2c71 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Url.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Online/Grid/Renderer/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/Sales/Order/Address/Form/Renderer/Vat.php b/app/code/core/Mage/Adminhtml/Block/Customer/Sales/Order/Address/Form/Renderer/Vat.php
index fd4f71e..9037423 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/Sales/Order/Address/Form/Renderer/Vat.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/Sales/Order/Address/Form/Renderer/Vat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Customer/System/Config/Validatevat.php b/app/code/core/Mage/Adminhtml/Block/Customer/System/Config/Validatevat.php
index c51853f..27fc42c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Customer/System/Config/Validatevat.php
+++ b/app/code/core/Mage/Adminhtml/Block/Customer/System/Config/Validatevat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard.php b/app/code/core/Mage/Adminhtml/Block/Dashboard.php
index 2c61697..022f686 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Abstract.php
index ef039fe..5ea3c3c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Bar.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Bar.php
index 1c919f3..d10a9fd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Bar.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Bar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Diagrams.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Diagrams.php
index 3aa2768..f4b1012 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Diagrams.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Diagrams.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Graph.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Graph.php
index 6a39562..e3ceac0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Graph.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Graph.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -37,7 +37,7 @@ class Mage_Adminhtml_Block_Dashboard_Graph extends Mage_Adminhtml_Block_Dashboar
     /**
      * Api URL
      */
-    const API_URL = 'http://chart.apis.google.com/chart';
+    const API_URL = 'https://image-charts.com/chart';
 
     /**
      * All series
@@ -98,6 +98,8 @@ class Mage_Adminhtml_Block_Dashboard_Graph extends Mage_Adminhtml_Block_Dashboar
     /**
      * Google chart api data encoding
      *
+     * @deprecated since the Google Image Charts API not accessible from March 14, 2019
+     *
      * @var string
      */
     protected $_encoding = 'e';
@@ -190,7 +192,9 @@ class Mage_Adminhtml_Block_Dashboard_Graph extends Mage_Adminhtml_Block_Dashboar
             'cht'  => 'lc',
             'chf'  => 'bg,s,f4f4f4|c,lg,90,ffffff,0.1,ededed,0',
             'chm'  => 'B,f4d4b2,0,0,0',
-            'chco' => 'db4814'
+            'chco' => 'db4814',
+            'chxs' => '0,0,11|1,0,11',
+            'chma' => '15,15,15,15'
         );
 
         $this->_allSeries = $this->getRowsData($this->_dataRows);
@@ -264,20 +268,11 @@ class Mage_Adminhtml_Block_Dashboard_Graph extends Mage_Adminhtml_Block_Dashboar
         $this->_axisLabels['x'] = $dates;
         $this->_allSeries = $datas;
 
-        //Google encoding values
-        if ($this->_encoding == "s") {
-            // simple encoding
-            $params['chd'] = "s:";
-            $dataDelimiter = "";
-            $dataSetdelimiter = ",";
-            $dataMissing = "_";
-        } else {
-            // extended encoding
-            $params['chd'] = "e:";
-            $dataDelimiter = "";
-            $dataSetdelimiter = ",";
-            $dataMissing = "__";
-        }
+        // Image-Charts Awesome data format values
+        $params['chd'] = "a:";
+        $dataDelimiter = ",";
+        $dataSetdelimiter = "|";
+        $dataMissing = "_";
 
         // process each string in the array, and find the max length
         foreach ($this->getAllSeries() as $index => $serie) {
@@ -323,38 +318,14 @@ class Mage_Adminhtml_Block_Dashboard_Graph extends Mage_Adminhtml_Block_Dashboar
 
         foreach ($this->getAllSeries() as $index => $serie) {
             $thisdataarray = $serie;
-            if ($this->_encoding == "s") {
-                // SIMPLE ENCODING
-                for ($j = 0; $j < sizeof($thisdataarray); $j++) {
-                    $currentvalue = $thisdataarray[$j];
-                    if (is_numeric($currentvalue)) {
-                        $ylocation = round((strlen($this->_simpleEncoding)-1) * ($yorigin + $currentvalue) / $yrange);
-                        array_push($chartdata, substr($this->_simpleEncoding, $ylocation, 1) . $dataDelimiter);
-                    } else {
-                        array_push($chartdata, $dataMissing . $dataDelimiter);
-                    }
-                }
-                // END SIMPLE ENCODING
-            } else {
-                // EXTENDED ENCODING
-                for ($j = 0; $j < sizeof($thisdataarray); $j++) {
-                    $currentvalue = $thisdataarray[$j];
-                    if (is_numeric($currentvalue)) {
-                        if ($yrange) {
-                         $ylocation = (4095 * ($yorigin + $currentvalue) / $yrange);
-                        } else {
-                          $ylocation = 0;
-                        }
-                        $firstchar = floor($ylocation / 64);
-                        $secondchar = $ylocation % 64;
-                        $mappedchar = substr($this->_extendedEncoding, $firstchar, 1)
-                            . substr($this->_extendedEncoding, $secondchar, 1);
-                        array_push($chartdata, $mappedchar . $dataDelimiter);
-                    } else {
-                        array_push($chartdata, $dataMissing . $dataDelimiter);
-                    }
+            for ($j = 0; $j < sizeof($thisdataarray); $j++) {
+                $currentvalue = $thisdataarray[$j];
+                if (is_numeric($currentvalue)) {
+                    $ylocation = $yorigin + $currentvalue;
+                    array_push($chartdata, $ylocation . $dataDelimiter);
+                } else {
+                    array_push($chartdata, $dataMissing . $dataDelimiter);
                 }
-                // ============= END EXTENDED ENCODING =============
             }
             array_push($chartdata, $dataSetdelimiter);
         }
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Grid.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Grid.php
index 2a0d832..5734c54 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Grids.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Grids.php
index cb02842..19feb4e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Grids.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Grids.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Orders/Grid.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Orders/Grid.php
index 7298c06..bbdb2cb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Orders/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Orders/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Sales.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Sales.php
index 4424be0..6aa3e2c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Sales.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Sales.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Last.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Last.php
index a93677c..d5ef085 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Last.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Last.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Renderer/Searchquery.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Renderer/Searchquery.php
index 9df3509..5477b1d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Renderer/Searchquery.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Renderer/Searchquery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Top.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Top.php
index e591ccc..d756379 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Top.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Searches/Top.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Amounts.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Amounts.php
index 3644698..ab37764 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Amounts.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Amounts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Most.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Most.php
index 91f0630..2f574ef 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Most.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Most.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Newest.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Newest.php
index 7a240b4..6209490 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Newest.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Customers/Newest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Orders.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Orders.php
index 0bfb3c5..6f1e25b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Orders.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Ordered.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Ordered.php
index 9af1e08..1513ecb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Ordered.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Ordered.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Viewed.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Viewed.php
index a8adebf..1ec732b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Viewed.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Tab/Products/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Dashboard/Totals.php b/app/code/core/Mage/Adminhtml/Block/Dashboard/Totals.php
index be61677..b8046f4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Dashboard/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Dashboard/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Denied.php b/app/code/core/Mage/Adminhtml/Block/Denied.php
index 1e30c68..4420d79 100644
--- a/app/code/core/Mage/Adminhtml/Block/Denied.php
+++ b/app/code/core/Mage/Adminhtml/Block/Denied.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Html/Date.php b/app/code/core/Mage/Adminhtml/Block/Html/Date.php
index 0a5f7ba..8da38d1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Html/Date.php
+++ b/app/code/core/Mage/Adminhtml/Block/Html/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Html/Select.php b/app/code/core/Mage/Adminhtml/Block/Html/Select.php
index 9fd8c38..03264a1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Html/Select.php
+++ b/app/code/core/Mage/Adminhtml/Block/Html/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Media/Editor.php b/app/code/core/Mage/Adminhtml/Block/Media/Editor.php
index 3f51cb8..2bb66f1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Media/Editor.php
+++ b/app/code/core/Mage/Adminhtml/Block/Media/Editor.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Media/Uploader.php b/app/code/core/Mage/Adminhtml/Block/Media/Uploader.php
index 6caa894..1739fd6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Media/Uploader.php
+++ b/app/code/core/Mage/Adminhtml/Block/Media/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Messages.php b/app/code/core/Mage/Adminhtml/Block/Messages.php
index d90e467..a1e705c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Messages.php
+++ b/app/code/core/Mage/Adminhtml/Block/Messages.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem.php
index ca7ef81..21e4e7c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid.php
index 0d78e66..a2c9cb7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Filter/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Filter/Checkbox.php
index d3a47d7..6beadc2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Filter/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Filter/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Renderer/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Renderer/Checkbox.php
index c815020..fa61207 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Renderer/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Problem/Grid/Renderer/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue.php
index cd92918..fe0dea2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit.php
index be9f292..0ce2f91 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit/Form.php
index caf90ca..2725764 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid.php
index 91a63f9..1afae9b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid/Renderer/Action.php
index 811fcdf..4549dee 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
index 826f3d9..ea78d54 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview/Form.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview/Form.php
index 7ecffc2..2559cfe 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber.php
index 26e9830..7158f7a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid.php
index fe43c08..e631ab8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Checkbox.php
index 86b9b39..d675688 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Website.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Website.php
index 268c858..165fb05 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Website.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Filter/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Renderer/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Renderer/Checkbox.php
index 149ee1a..e9d49d4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Renderer/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Subscriber/Grid/Renderer/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template.php
index 2f17ce9..9683f28 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit.php
index 8283ade..fae5a1a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit/Form.php
index 8a30ab7..ba64b9b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid.php
index f0ce776..e0f04d0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Action.php
index dfdfc13..b1784af 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Sender.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Sender.php
index be36905..f8d69e5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Sender.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Grid/Renderer/Sender.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
index c6416fd..2eeda67 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview/Form.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview/Form.php
index 0fd43cb..df4dc34 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Baseurl.php b/app/code/core/Mage/Adminhtml/Block/Notification/Baseurl.php
index fddad0b..d59cab0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Baseurl.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Baseurl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Curl.php b/app/code/core/Mage/Adminhtml/Block/Notification/Curl.php
index 8c9e82c..803a572 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Curl.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Grid.php b/app/code/core/Mage/Adminhtml/Block/Notification/Grid.php
index 56bcf47..960568a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Actions.php b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Actions.php
index 3827ca0..c824973 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Actions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Notice.php b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Notice.php
index baad83a..9cf5856 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Notice.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Notice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Severity.php b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Severity.php
index d2821ca..2cf9065 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Severity.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Grid/Renderer/Severity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Inbox.php b/app/code/core/Mage/Adminhtml/Block/Notification/Inbox.php
index 0319aed..25e6b0d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Inbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Inbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Security.php b/app/code/core/Mage/Adminhtml/Block/Notification/Security.php
index ccd7cdd..5034fdc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Security.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Security.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Survey.php b/app/code/core/Mage/Adminhtml/Block/Notification/Survey.php
index d9b0a6c..33950c8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Survey.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Survey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Symlink.php b/app/code/core/Mage/Adminhtml/Block/Notification/Symlink.php
index ba53754..b2b2e79 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Symlink.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Symlink.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Toolbar.php b/app/code/core/Mage/Adminhtml/Block/Notification/Toolbar.php
index 1f7613d..87ddee4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Toolbar.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Toolbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Notification/Window.php b/app/code/core/Mage/Adminhtml/Block/Notification/Window.php
index 63bd4bd..53e1214 100644
--- a/app/code/core/Mage/Adminhtml/Block/Notification/Window.php
+++ b/app/code/core/Mage/Adminhtml/Block/Notification/Window.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page.php b/app/code/core/Mage/Adminhtml/Block/Page.php
index 0baef6e..4000dd7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page/Footer.php b/app/code/core/Mage/Adminhtml/Block/Page/Footer.php
index f4cf146..2a26e54 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page/Footer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page/Footer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page/Head.php b/app/code/core/Mage/Adminhtml/Block/Page/Head.php
index f5479d5..acf6494 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page/Head.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page/Head.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page/Header.php b/app/code/core/Mage/Adminhtml/Block/Page/Header.php
index 25e6aff..09e0d38 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page/Header.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page/Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page/Menu.php b/app/code/core/Mage/Adminhtml/Block/Page/Menu.php
index 3b2e133..06e444b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page/Menu.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page/Menu.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Page/Notices.php b/app/code/core/Mage/Adminhtml/Block/Page/Notices.php
index 99eb461..aac87bf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Page/Notices.php
+++ b/app/code/core/Mage/Adminhtml/Block/Page/Notices.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Block.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Block.php
index 1b37094..6f649ea 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Block.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit.php
index d230829..574584a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit/Form.php
index 31bfb35..ef7328d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Grid.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Grid.php
index 609d4e8..c4bd894 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Block/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Buttons.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Buttons.php
index f581d60..306387a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Buttons.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Buttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -70,7 +70,7 @@ class Mage_Adminhtml_Block_Permissions_Buttons extends Mage_Adminhtml_Block_Temp
                             Mage::helper('adminhtml')->__('Are you sure you want to do this?')
                         )
                         . '\', \''
-                        . $this->getUrl('*/*/delete', array('rid' => $this->getRequest()->getParam('rid')))
+                        . $this->getUrlSecure('*/*/delete', array('rid' => $this->getRequest()->getParam('rid')))
                         . '\')',
                     'class' => 'delete'
                 ))
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Editroles.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Editroles.php
index 1cdb134..ae1a936 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Editroles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Editroles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Edituser.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Edituser.php
index ab6cd2d..e8bdc42 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Edituser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Edituser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/Role.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/Role.php
index c6814a3..5cb7819 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/Role.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/User.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/User.php
index 9fd19eb..1384341 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Grid/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Role.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Role.php
index e1e9d4d..cf191f6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Role.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
index 7922946..159773d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Roles.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Roles.php
index 5907d7e..6db08c1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Roles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Roleinfo.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Roleinfo.php
index fe105ff..de9dc0f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Roleinfo.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Roleinfo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesedit.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesedit.php
index 9d8d391..b89d18b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesedit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesedit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesusers.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesusers.php
index 2da14bf..7fb7cb8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesusers.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Rolesusers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Useredit.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Useredit.php
index 8ed3135..fc3cef8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Useredit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Useredit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Permissions_Tab_Useredit extends Mage_Adminhtml_Block_Widget_Form
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Userroles.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Userroles.php
index b91cd20..25238a3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Userroles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Tab/Userroles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Permissions_Tab_Userroles extends Mage_Adminhtml_Block_Widget_Tabs
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User.php
index d1dd96a..0ac7837 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit.php
index caf0cd5..88c02ac 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Form.php
index b1ab571..bcb4b1a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Main.php
index 90953d0..5edc53f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Roles.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Roles.php
index a6a7fb7..82d9658 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Roles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tab/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tabs.php
index c2f439a..2175de2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Grid.php b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Grid.php
index b0720c7..3f95289 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/User/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/User/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Usernroles.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Usernroles.php
index cf612f3..6319667 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Usernroles.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Usernroles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Permissions_UsernRoles extends Mage_Adminhtml_Block_Template
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Users.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Users.php
index 13ea50d..4643fc7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Users.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Users.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable.php
index 9f24719..f345a33 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit.php
index d0cf918..6a99d93 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit/Form.php
index 538e495..9690799 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Grid.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Grid.php
index 2dda549..a996960 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Variable/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit.php b/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit.php
index 9c2a988..964a8ae 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit/Form.php
index 4a387f1..322c1fc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Answer/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit.php
index f00cd7b..26111a0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Form.php
index 4f4245a..aadad01 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers.php
index 9c4fc71..d454a30 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Form.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Form.php
index 7dba0a7..ee57596 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Grid.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Grid.php
index dd6d5ad..8d326ab 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/List.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/List.php
index aa51c0f..5a01b2d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/List.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Answers/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Form.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Form.php
index 4a85b26..55af41d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tab/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tabs.php
index 9decb9b..d67a4e6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Grid.php b/app/code/core/Mage/Adminhtml/Block/Poll/Grid.php
index 1564607..29f7033 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Poll/Poll.php b/app/code/core/Mage/Adminhtml/Block/Poll/Poll.php
index b888194..8da5e75 100644
--- a/app/code/core/Mage/Adminhtml/Block/Poll/Poll.php
+++ b/app/code/core/Mage/Adminhtml/Block/Poll/Poll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog.php
index f74a686..f8272a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit.php
index e4ca231..297525f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Form.php
index e92fc08..1ee82c5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Js.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Js.php
index 5d08645..0307a94 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Js.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Actions.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Actions.php
index 436cdc4..74c627f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Actions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Conditions.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Conditions.php
index ce554ef..3f1d8a4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Conditions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Conditions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Main.php
index f95b102..de9588b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tabs.php
index 3b02af3..e30f263 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Grid.php b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Grid.php
index ef346bc..064915e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Catalog/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote.php
index 38e23f9..03f9093 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit.php
index 6ab3d89..2b0ef77 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Form.php
index b9d00f1..87a0112 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Actions.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Actions.php
index 9f33759..cb5e2be 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Actions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Conditions.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Conditions.php
index 5f13bbe..4c5e997 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Conditions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Conditions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons.php
index 76a5e47..fada2b5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Form.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Form.php
index 58aff50..f8bb081 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid.php
index 3b4d438..bd350ad 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid/Column/Renderer/Used.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid/Column/Renderer/Used.php
index 4b12277..8751dc2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid/Column/Renderer/Used.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Coupons/Grid/Column/Renderer/Used.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Labels.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Labels.php
index 8ea246a..a71a154 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Labels.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Labels.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main.php
index a3c066d..35dd748 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main/Renderer/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main/Renderer/Checkbox.php
index 8b9cc46..84ce011 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main/Renderer/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tab/Main/Renderer/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tabs.php
index af327ff..761953f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Grid.php b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Grid.php
index af67104..83d847a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Quote/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser.php b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser.php
index 77aa5d1..f64afc4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Daterange.php b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Daterange.php
index 4d666fb..b3a7b68 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Daterange.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Daterange.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Sku.php b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Sku.php
index fbe6d36..69fab80 100644
--- a/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Sku.php
+++ b/app/code/core/Mage/Adminhtml/Block/Promo/Widget/Chooser/Sku.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Edit.php b/app/code/core/Mage/Adminhtml/Block/Rating/Edit.php
index 9125bbc..9037efd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Form.php
index 827e9a8..362349a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Form.php b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Form.php
index 8ab1b31..8ebf341 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Options.php b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Options.php
index 69fcd76..93b8351 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Options.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tab/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tabs.php
index 31ddd69..b4d22ef 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Grid.php b/app/code/core/Mage/Adminhtml/Block/Rating/Grid.php
index 2f1fd7d..7ce11e4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Rating/Rating.php b/app/code/core/Mage/Adminhtml/Block/Rating/Rating.php
index 3c7d48d..f472eff 100644
--- a/app/code/core/Mage/Adminhtml/Block/Rating/Rating.php
+++ b/app/code/core/Mage/Adminhtml/Block/Rating/Rating.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/MtdStart.php b/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/MtdStart.php
index 3b8faca..36cec06 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/MtdStart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/MtdStart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/YtdStart.php b/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/YtdStart.php
index fe0033f..999d215 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/YtdStart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Config/Form/Field/YtdStart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts.php
index 5a7661f..dfc37fa 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts/Grid.php
index 800c0d2..6156315 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Accounts/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders.php
index 96c1289..f180267 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders/Grid.php
index 1805adf..f7f7f97 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Orders/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals.php
index e2096d4..0504861 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals/Grid.php
index 17965d0..574cde7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Customer/Totals/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Filter/Form.php b/app/code/core/Mage/Adminhtml/Block/Report/Filter/Form.php
index c0df9df..f20c411 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Filter/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Filter/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid.php
index 9119cc2..25f8d61 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Abstract.php
index 1254508..f99de17 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Blanknumber.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Blanknumber.php
index a2c404d..5f6ae11 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Blanknumber.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Blanknumber.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Currency.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Currency.php
index 5fbd260..5231553 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Currency.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Customer.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Customer.php
index 9f19949b..1ce6396 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Product.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Product.php
index 7da8366..3783cf0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Column/Renderer/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Shopcart.php b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Shopcart.php
index f0eb3a9..1235914 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Grid/Shopcart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Grid/Shopcart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product.php b/app/code/core/Mage/Adminhtml/Block/Report/Product.php
index 9a95a24..d5f3ed6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads.php
index e95b696..9cd58df 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Grid.php
index 1e97e58..8bffe67 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Renderer/Purchases.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Renderer/Purchases.php
index 0b5bb7f..fd8826d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Renderer/Purchases.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Downloads/Renderer/Purchases.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Grid.php
index 00a6464..7e46f0d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock.php
index ab959ec..0d5d4dc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock/Grid.php
index 4c938cd..6cae072 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Lowstock/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered.php
index 72e3b8a..9415c97 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered/Grid.php
index 11d8a5d..8532490 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Ordered/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold.php
index 1325ee4..03efd19 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold/Grid.php
index 10f9b64..6ede3d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Sold/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed.php
index c699fda..98d79f3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed/Grid.php
index 76e01c5..a0cfdd0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Product/Viewed/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics.php b/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics.php
index 3909044..0e1f488 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics/Grid.php
index 499b913..8af958c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Refresh/Statistics/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer.php
index ab16252..16cd4d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer/Grid.php
index 081e52a..b7a1577 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail.php
index ad14c86..f6359c7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail/Grid.php
index 0bd2c3a..24dbc16 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Detail/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Product.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Product.php
index 3bea86d..b2e4101 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Review/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Review/Product/Grid.php
index d6cc9ff..61db83e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Review/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Review/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers.php
index 5e24a57..081cfe0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers/Grid.php
index 54d5a18..0e87a31 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Bestsellers/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons.php
index 8510538..fc740dc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons/Grid.php
index ca22699..97799c5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Coupons/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Grid/Column/Renderer/Date.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Grid/Column/Renderer/Date.php
index d63c9aa..362fd0b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Grid/Column/Renderer/Date.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Grid/Column/Renderer/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced.php
index 2feffbd..76ba6a0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced/Grid.php
index 26a4eb4..6901470 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Invoiced/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded.php
index b6fc8b5..29e6c9c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded/Grid.php
index 3330ec2..2244b67 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Refunded/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales.php
index 1789bbe..163f778 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales/Grid.php
index d605a2e..069c246 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Sales/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping.php
index eb59e8a..f176115 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping/Grid.php
index d02e78c..3f6f30e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Shipping/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax.php
index 374a8a7..c7abcde 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax/Grid.php
index 4561a28..5fefe07 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Sales/Tax/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Search.php b/app/code/core/Mage/Adminhtml/Block/Report/Search.php
index 2015283..bcb37f6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Search.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Search/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Search/Grid.php
index b158c64..f2a4f6f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Search/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned.php
index 077ab69..533394a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned/Grid.php
index 834a444..710d0ad 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Abandoned/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer.php
index 9dbae37..e0d5230 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer/Grid.php
index 647f0bd..25de431 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product.php
index 7d01c61..c4704e0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product/Grid.php
index 20cb489..5a4a6fa 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Shopcart/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer.php
index 41a5b03..8ebabdf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail.php
index 77cce53..80fb57d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail/Grid.php
index 3ec44ab..caab81e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Detail/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Grid.php
index a498f2c..bc9dbc1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular.php
index ec6c9cc..55cd88d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail.php
index 251abd3..8a30489 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail/Grid.php
index 9378d5a..f45a370 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Detail/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Grid.php
index 0197dfc..fb25756 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Popular/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product.php
index 79d5ed0..a89ab07 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail.php
index e99a8e6..5e56ea79 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail/Grid.php
index 4a2b416..d0d6d1d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Detail/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Grid.php
index 9016f33..340bf3e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Tag/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Wishlist.php b/app/code/core/Mage/Adminhtml/Block/Report/Wishlist.php
index d3fc987..cf7f205 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Wishlist.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Report/Wishlist/Grid.php b/app/code/core/Mage/Adminhtml/Block/Report/Wishlist/Grid.php
index aede5df..feeaded 100644
--- a/app/code/core/Mage/Adminhtml/Block/Report/Wishlist/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Report/Wishlist/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Add.php b/app/code/core/Mage/Adminhtml/Block/Review/Add.php
index ba628e8..6a1390c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Add.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Add.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Add/Form.php b/app/code/core/Mage/Adminhtml/Block/Review/Add/Form.php
index c0a95c6..2dbeaee 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Add/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Add/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Edit.php b/app/code/core/Mage/Adminhtml/Block/Review/Edit.php
index b94ff29..e2cc79c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Review/Edit/Form.php
index 525cdb1..ddf32c8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Grid.php b/app/code/core/Mage/Adminhtml/Block/Review/Grid.php
index 133c83f..0bfa587 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Grid/Filter/Type.php b/app/code/core/Mage/Adminhtml/Block/Review/Grid/Filter/Type.php
index c5b2cbe..fba60bc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Grid/Filter/Type.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Grid/Filter/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Grid/Renderer/Type.php b/app/code/core/Mage/Adminhtml/Block/Review/Grid/Renderer/Type.php
index b109dbb..8ac48fe 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Grid/Renderer/Type.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Grid/Renderer/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Main.php b/app/code/core/Mage/Adminhtml/Block/Review/Main.php
index ccb3109..fb67ed1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Review/Product/Grid.php
index 3e2fd11..8b0c19b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Rating/Detailed.php b/app/code/core/Mage/Adminhtml/Block/Review/Rating/Detailed.php
index e3a758a..769a33e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Rating/Detailed.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Rating/Detailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Review/Rating/Summary.php b/app/code/core/Mage/Adminhtml/Block/Review/Rating/Summary.php
index 3e97409..2d6d87d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Review/Rating/Summary.php
+++ b/app/code/core/Mage/Adminhtml/Block/Review/Rating/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales.php b/app/code/core/Mage/Adminhtml/Block/Sales.php
index 0d41622..2f5af94 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo.php b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo.php
index 49d17c8..ebdc163 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
index a5cfc1a..d81c515 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice.php b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice.php
index c8234bf..bb946e5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
index 7f50f5d..c8a6598 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Abstract.php
index 1afd284..eb41102 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Default.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Default.php
index 357f12b..9cbb68dc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name.php
index 4faac84..e47ec3d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name/Grouped.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name/Grouped.php
index b84155e..29214dd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name/Grouped.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Name/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Qty.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Qty.php
index 0b00241..f8e1931 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Qty.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Column/Qty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Configurable.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Configurable.php
index 4217204..b8c1e90 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Configurable.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Default.php b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Default.php
index 155c7b1..80dd7dd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Items/Renderer/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order.php
index eca6c52..77789f05 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Abstract.php
index 780d4ce..2d31adc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address.php
index 7eec50b..839191d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address/Form.php
index 4fc2e90..814bdd2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Address/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Comments/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Comments/View.php
index 9f93326..de61755 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Comments/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Comments/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create.php
index a4c2e69..a88cc3c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Abstract.php
index e552cea..fa2de07 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Address.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Address.php
index d04004b..d57cbcd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Address.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method.php
index a31d4b6..4a867e2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method/Form.php
index f0e4820..b28b533 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Billing/Method/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Comment.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Comment.php
index c8a343b..c914008 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Comment.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons.php
index 0a3a14c..b6e89fa 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons/Form.php
index d2945e4..cbb978d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Coupons/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer.php
index 596249b..43f2a1d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer/Grid.php
index 1c4cafb..8031eba 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Data.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Data.php
index f3bcc02..76a522a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Data.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form.php
index 8a05c13..b925e3c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Abstract.php
index 0d1b0c4..ef9318e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Account.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Account.php
index 8cd5fad..69f076c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Account.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Account.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Address.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Address.php
index 904541c..e0af9d1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Address.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Form/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage.php
index 7d4b406..f146382 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage/Form.php
index 4994a0e..5fe7be3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Giftmessage/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
index 632b6e8..9b18cba 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items.php
index 505d1e7..b088e27 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items/Grid.php
index a334274..554a961 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Items/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Load.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Load.php
index 4b4ef20..3bb26d4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Load.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Load.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Messages.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Messages.php
index 279effa..5e46903 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Messages.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Messages.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter.php
index dc99aba..9585f0a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter/Form.php
index 29cf2d0..2250709 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Newsletter/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search.php
index dd83d35..59e8027 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid.php
index ad28f3f..5593b24 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Giftmessage.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Giftmessage.php
index 98e2834..faf3d4b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Giftmessage.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Giftmessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Price.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Price.php
index 8f1fc14..434453a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Product.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Product.php
index 2304067..0bee4c7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Qty.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Qty.php
index c467e7a..8e9ade7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Qty.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Search/Grid/Renderer/Qty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Address.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Address.php
index 09982c0..a406132 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Address.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method.php
index 445466a..6ec4b77 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method/Form.php
index 03a3765..e501d40 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Shipping/Method/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar.php
index afa40d5..a426f47 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Abstract.php
index 23ec975..266103d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Cart.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Cart.php
index 43c68bb..e26ca63 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Cart.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Compared.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Compared.php
index 2b553b0..fd68eb2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Compared.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pcompared.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pcompared.php
index 56e6fbf..b63c8d5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pcompared.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pcompared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pviewed.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pviewed.php
index f3c850d..0ede85c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pviewed.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Pviewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Reorder.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Reorder.php
index f6b6870..01aadd5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Reorder.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Reorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Viewed.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Viewed.php
index 5028997..d2c6d6e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Viewed.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Wishlist.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Wishlist.php
index f59ab10..f8a476e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Wishlist.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Sidebar/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store.php
index ff01674..045352f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store/Select.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store/Select.php
index c75f47b..24ad441 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store/Select.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Store/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals.php
index 0ae2308..77b3613 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Default.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Default.php
index 8114c67..50aa577 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Discount.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Discount.php
index 5b6ddf1..80245dc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Discount.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Grandtotal.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Grandtotal.php
index 6590dd4..0c83057 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Grandtotal.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Grandtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Shipping.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Shipping.php
index 2d8afe3..4e5a10c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Shipping.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Subtotal.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Subtotal.php
index 0c17337..f21b654 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Subtotal.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Table.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Table.php
index 63cb2d4..9582590 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Table.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Tax.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Tax.php
index 97c0cb0..0e43dd4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Tax.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Totals/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
index 346c02d..e1e1c5b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Adjustments.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Adjustments.php
index 3fe5f4a..d54945f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Adjustments.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Adjustments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Sales_Order_Creditmemo_Create_Adjustments extends Mage_Adminhtml_Block_Template
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Form.php
index 7c216a9..30f80de 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Items.php
index 2e36142..a0323f9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Totals.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Totals.php
index ebaee5b..e47cc5c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View.php
index a0d66f4..b21eecc 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Comments.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Comments.php
index bb5d6ea..984182a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Comments.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Comments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Form.php
index f55c5a1..7e409f4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Items.php
index 42be8b1..099162c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
index 9c935ce..43ba9cd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
index 1f6e911..b3a152d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Form.php
index f0fc1e9..ff91128 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Items.php
index 87fb4a4..fda3310 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Tracking.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Tracking.php
index 734af71..d45afd9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Tracking.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create/Tracking.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Totals.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Totals.php
index 4450431..23cb589 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View.php
index ac2e6cc..7bed940 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Comments.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Comments.php
index d7a4f75..1751fe9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Comments.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Comments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Form.php
index cecf857..8fac73d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Items.php
index 46053cc..a6e0032 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Payment.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Payment.php
index aa37d2a..de365eb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Payment.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
index 5763ba4..e39ee02 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Form.php
index 510b9d2..0ff0a94 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Items.php
index 138b593..9665dae 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Tracking.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Tracking.php
index 77d9331..c6cb9c0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Tracking.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create/Tracking.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging.php
index 16be58c..5b89f23 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging/Grid.php
index c261ead..453cc90 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Packaging/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Tracking/Info.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Tracking/Info.php
index d5634ea..2076102 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Tracking/Info.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Tracking/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View.php
index 00be414..0a7deeb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Comments.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Comments.php
index 4ba3ee2..af6ae64 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Comments.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Comments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Form.php
index e647ac0..3d96278 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Items.php
index 9facdeb..2f546c0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Tracking.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Tracking.php
index e27e0bd..6501853 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Tracking.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/View/Tracking.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status.php
index 7d5766f..9698c8f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign.php
index d75859b..9e9ec12 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign/Form.php
index b837e92..414391f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Assign/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit.php
index 00b53bf..b1c5729 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit/Form.php
index 8477bf5..73552d1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Grid.php
index b0171ee..94b8c54 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New.php
index bbc8879..fb8c5eb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New/Form.php
index a8c80cd..190be47 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Status/New/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totalbar.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totalbar.php
index 32f25a5..0961b11 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totalbar.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totalbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals.php
index bc795c1..0e72952 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Item.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Item.php
index cd0b24f..9837377 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Item.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Tax.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Tax.php
index a45db0e..efdbd37 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Tax.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Totals/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
index bb57bba..0af75c7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Form.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Form.php
index 766cb45..ce23842 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Giftmessage.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Giftmessage.php
index 6c1e0c0..9f82820 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Giftmessage.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Giftmessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/History.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/History.php
index ab3eeb3..26671a9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/History.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Info.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Info.php
index 85f18fb..2ec98fb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Info.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items.php
index b77858a..d347d16 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items/Renderer/Default.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items/Renderer/Default.php
index 831493a..fb9c383 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items/Renderer/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Items/Renderer/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Messages.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Messages.php
index e569b7a..dcc9caf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Messages.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Messages.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Creditmemos.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Creditmemos.php
index 173d614..e44f927 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Creditmemos.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Creditmemos.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/History.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/History.php
index e74c124..5ecf9d0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/History.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Info.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Info.php
index 4819fa3..141be9f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Info.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Invoices.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Invoices.php
index e01961c..ba0a681 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Invoices.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Invoices.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Shipments.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Shipments.php
index 96f4a8c..6507b17 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Shipments.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Shipments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Transactions.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Transactions.php
index eeb2428..3fb11f4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Transactions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tab/Transactions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tabs.php
index b6252f1..c4ab4f9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Reorder/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Sales/Reorder/Renderer/Action.php
index b52a807..eeca6a2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Reorder/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Reorder/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment.php b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment.php
index 673fc3c..31533da 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
index e66e710..0676cb1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Totals.php b/app/code/core/Mage/Adminhtml/Block/Sales/Totals.php
index 12a8cca..34742e4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Totals.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions.php
index dee9f3c..015d82c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Child/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Child/Grid.php
index b2e438d..12f6da9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Child/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Child/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail.php
index 2227e87..3c6941c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail/Grid.php
index b133249..2ed2ec6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Detail/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
index 6a7d28a..cc107f6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Shipping/Carrier/Tablerate/Grid.php b/app/code/core/Mage/Adminhtml/Block/Shipping/Carrier/Tablerate/Grid.php
index edf5963..07936ca 100644
--- a/app/code/core/Mage/Adminhtml/Block/Shipping/Carrier/Tablerate/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Shipping/Carrier/Tablerate/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap.php b/app/code/core/Mage/Adminhtml/Block/Sitemap.php
index 84d06c4..25a848c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit.php
index c67a6fa..f404ab9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit/Form.php
index 832234c..b3e02c8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid.php
index 7a291ef..f68fc01 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Action.php
index 310cab1..d65c45d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Link.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Link.php
index 8b56924..c51c469 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Link.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Time.php b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Time.php
index 2aae77e..4ddc989 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Time.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sitemap/Grid/Renderer/Time.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Store/Switcher.php b/app/code/core/Mage/Adminhtml/Block/Store/Switcher.php
index 94ad7aa..edc67d3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Store/Switcher.php
+++ b/app/code/core/Mage/Adminhtml/Block/Store/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset.php b/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset.php
index 3583cee..8a566c9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset.php
+++ b/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset/Element.php b/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset/Element.php
index 825eec5..666ae3d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset/Element.php
+++ b/app/code/core/Mage/Adminhtml/Block/Store/Switcher/Form/Renderer/Fieldset/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Account/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Account/Edit.php
index df1022a..af09dc9 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Account/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Account/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Account/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Account/Edit/Form.php
index becb4ef..509cc82 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Account/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Account/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Cache/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Cache/Edit.php
index 959f4d9..424b913 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Cache/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Cache/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Cache/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Cache/Form.php
index ca1fef8..187deed 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Cache/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Cache/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Dwstree.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Dwstree.php
index 2278e12..fb101e5 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Dwstree.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Dwstree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Edit.php
index 51963ee..1e40dca 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form.php
index fbed52c..c52b220 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field.php
index 4a27643..b813c58 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Array/Abstract.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Array/Abstract.php
index c761309..7790afe 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Array/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Array/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Datetime.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Datetime.php
index d8989a0..5446414 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Datetime.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Export.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Export.php
index 0286c4f..0605de2 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Export.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Export.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/File.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/File.php
index d247eec..7fddfd2 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/File.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Heading.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Heading.php
index 0805bd3..01738ae 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Heading.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Heading.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Image.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Image.php
index c51efdd..c2ea70d 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Image.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Import.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Import.php
index 56db9aa..3a1bb62 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Import.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Notification.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Notification.php
index 6d7e9d6..75824e4 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Notification.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Notification.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Regexceptions.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Regexceptions.php
index d1faf07..ad42dc0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Regexceptions.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Regexceptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Allowspecific.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Allowspecific.php
index 1287550..025456e 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Allowspecific.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Allowspecific.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatcatalog.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatcatalog.php
index ebcdd58..b731536 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatcatalog.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatcatalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatproduct.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatproduct.php
index e1996c0..4ab4c95 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatproduct.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Field/Select/Flatproduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset.php
index 485561c..4678148 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Modules/DisableOutput.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Modules/DisableOutput.php
index cb44743..d31c90d 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Modules/DisableOutput.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Modules/DisableOutput.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Order/Statuses.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Order/Statuses.php
index 6ca21f6..c35b430 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Order/Statuses.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Form/Fieldset/Order/Statuses.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Switcher.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Switcher.php
index 67b91e4..e13b40b 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Switcher.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/System/Storage/Media/Synchronize.php b/app/code/core/Mage/Adminhtml/Block/System/Config/System/Storage/Media/Synchronize.php
index 662fff6..b0f72c1 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/System/Storage/Media/Synchronize.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/System/Storage/Media/Synchronize.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Config/Tabs.php b/app/code/core/Mage/Adminhtml/Block/System/Config/Tabs.php
index ec959a0..7ddcd52 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Config/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Config/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui.php
index 2145d5d..d8473b0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit.php
index 5dc8435..d74996d 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Form.php
index b6377f9..55d53bf 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Upload.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Upload.php
index 80dd6a9..c9f56c0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Upload.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Upload.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/View.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/View.php
index 75e691e..7727f52 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Wizard.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Wizard.php
index eb4fec1..c93490c 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Wizard.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tab/Wizard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tabs.php
index 083616a..a90c909 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Grid.php
index ee71d37..50df290 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Gui/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile.php
index 7ca8cfa..0601d53 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit.php
index cbfd046..99092a0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Filter/Action.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Filter/Action.php
index 245eee2..4deb882 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Filter/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Filter/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Form.php
index 778ce5b..5f7283f 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Renderer/Action.php
index df79ca4..db86499 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Edit.php
index 0541afc..9d59dd0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/History.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/History.php
index fbc4de8..10ed031 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/History.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Run.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Run.php
index 035bc54..603d995 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Run.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tab/Run.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tabs.php
index 900e8cd..9e7d35b 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Grid.php
index 885ff6c..397dd0f 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Run.php b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Run.php
index 559a61e..d89b46a 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Run.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Convert/Profile/Run.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency.php b/app/code/core/Mage/Adminhtml/Block/System/Currency.php
index 8ee05fd..f561662 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Form.php
index 67e51c5..bc74a9f 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Main.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Main.php
index 3558e2c..1f8260b 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Rates.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Rates.php
index 30504c3..be30c88 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Rates.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tab/Rates.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tabs.php
index f74fcbe..8e6c9f2 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Matrix.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Matrix.php
index 034cec1..7051fda 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Matrix.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Matrix.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Services.php b/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Services.php
index 1801ff5..de9b8aa 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Services.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Currency/Rate/Services.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Design.php b/app/code/core/Mage/Adminhtml/Block/System/Design.php
index 4f1db6e..d98f962 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Design.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit.php
index 78ecb2d..d3ef1d1 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -75,7 +75,10 @@ class Mage_Adminhtml_Block_System_Design_Edit extends Mage_Adminhtml_Block_Widge
 
     public function getDeleteUrl()
     {
-        return $this->getUrl('*/*/delete', array('_current'=>true));
+        return $this->getUrlSecure('*/*/delete', array(
+            'id' => $this->getDesignChangeId(),
+            Mage_Core_Model_Url::FORM_KEY => $this->getFormKey()
+        ));
     }
 
     public function getSaveUrl()
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tab/General.php b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tab/General.php
index 0387839..69d9b65 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tab/General.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tab/General.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_System_Design_Edit_Tab_General extends Mage_Adminhtml_Block_Widget_Form
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tabs.php b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tabs.php
index f35841a..d8c49a0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Design/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Design/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Design/Grid.php
index c7d1d5d..1cd4609 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Design/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Design/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template.php
index 7b5f74a..55badc0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit.php
index 1fd580e..b55cef9 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit/Form.php
index a4caa63..2b1225d 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid.php
index 35955ce..7faaa82 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Filter/Type.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Filter/Type.php
index feb6f87..b35e250 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Filter/Type.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Filter/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Action.php
index 9b2b1e7..e825a67 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Sender.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Sender.php
index 1bf9f9a..f57f6d5 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Sender.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Sender.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Type.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Type.php
index 5face1e..94372cf 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Type.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Grid/Renderer/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
index 3d169ef..4b02ec0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete.php
index 0b133f6..8ba4f21 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Form.php
index 3a76c73..d11dab9 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Group.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Group.php
index 72ff20e..d009cbd 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Website.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Website.php
index b39734f..830c0b9 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Website.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Delete/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Edit.php
index 2ae3b2e..ba6f3b0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -40,24 +40,28 @@ class Mage_Adminhtml_Block_System_Store_Edit extends Mage_Adminhtml_Block_Widget
      */
     public function __construct()
     {
+        $backupAvailable =
+            Mage::getSingleton('admin/session')->isAllowed('system/tools/backup')
+            && Mage::helper('core')->isModuleEnabled('Mage_Backup')
+            && !Mage::getStoreConfigFlag('advanced/modules_disable_output/Mage_Backup');
         switch (Mage::registry('store_type')) {
             case 'website':
                 $this->_objectId = 'website_id';
                 $saveLabel   = Mage::helper('core')->__('Save Website');
                 $deleteLabel = Mage::helper('core')->__('Delete Website');
-                $deleteUrl   = $this->getUrl('*/*/deleteWebsite', array('item_id' => Mage::registry('store_data')->getId()));
+                $deleteUrl   = $this->_getDeleteUrl(Mage::registry('store_type'), $backupAvailable);
                 break;
             case 'group':
                 $this->_objectId = 'group_id';
                 $saveLabel   = Mage::helper('core')->__('Save Store');
                 $deleteLabel = Mage::helper('core')->__('Delete Store');
-                $deleteUrl   = $this->getUrl('*/*/deleteGroup', array('item_id' => Mage::registry('store_data')->getId()));
+                $deleteUrl   = $this->_getDeleteUrl(Mage::registry('store_type'), $backupAvailable);
                 break;
             case 'store':
                 $this->_objectId = 'store_id';
                 $saveLabel   = Mage::helper('core')->__('Save Store View');
                 $deleteLabel = Mage::helper('core')->__('Delete Store View');
-                $deleteUrl   = $this->getUrl('*/*/deleteStore', array('item_id' => Mage::registry('store_data')->getId()));
+                $deleteUrl   = $this->_getDeleteUrl(Mage::registry('store_type'), $backupAvailable);
                 break;
         }
         $this->_controller = 'system_store';
@@ -100,4 +104,29 @@ class Mage_Adminhtml_Block_System_Store_Edit extends Mage_Adminhtml_Block_Widget
 
         return Mage::registry('store_action') == 'add' ? $addLabel : $editLabel;
     }
+
+    /**
+     * Create URL depending on backups
+     *
+     * @param string $storeType
+     * @param bool $backupAvailable
+     * @return string
+     */
+    public function _getDeleteUrl($storeType, $backupAvailable = false)
+    {
+        $storeType = uc_words($storeType);
+        if ($backupAvailable) {
+            $deleteUrl   = $this->getUrl('*/*/delete' . $storeType, array('item_id' => Mage::registry('store_data')->getId()));
+        } else {
+            $deleteUrl   = $this->getUrl(
+                '*/*/delete' . $storeType . 'Post',
+                array(
+                    'item_id' => Mage::registry('store_data')->getId(),
+                    'form_key' => Mage::getSingleton('core/session')->getFormKey()
+                )
+            );
+        }
+
+        return $deleteUrl;
+    }
 }
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Edit/Form.php
index b24f011..7b13c8e 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid.php
index b4ca481..4015198 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Group.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Group.php
index 7eade97..7ed2f41 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Group.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Store.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Store.php
index ae4e93c..d89b6a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Store.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Website.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Website.php
index 817654b..ddd2aac 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Website.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Grid/Render/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Store.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Store.php
index efb8c21..cef2244 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Store.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Store/Tree.php b/app/code/core/Mage/Adminhtml/Block/System/Store/Tree.php
index 714153a..7d74386 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Store/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Store/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Variable.php b/app/code/core/Mage/Adminhtml/Block/System/Variable.php
index aa28b2d..9ed0e43 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Variable.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit.php b/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit.php
index 5e894ab..a4341b0 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit/Form.php
index 2a8c05a..9939d77 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Variable/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Variable/Grid.php b/app/code/core/Mage/Adminhtml/Block/System/Variable/Grid.php
index db2627c..e273aec 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Variable/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Variable/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag.php b/app/code/core/Mage/Adminhtml/Block/Tag.php
index d924e21..0d80797 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Assigned/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tag/Assigned/Grid.php
index a865a8d..181f608 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Assigned/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Assigned/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Customer.php b/app/code/core/Mage/Adminhtml/Block/Tag/Customer.php
index 13f76b5..8513d81 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Customer/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tag/Customer/Grid.php
index ba95782..7a65426 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Customer/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Customer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Edit.php b/app/code/core/Mage/Adminhtml/Block/Tag/Edit.php
index c762c59..075876b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Accordion.php b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Accordion.php
index 2275fe9..a6dc06b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Accordion.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Accordion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Assigned.php b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Assigned.php
index c421b9d..ddc7d08 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Assigned.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Assigned.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Form.php
index ae3c39d..93bb99b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/All.php b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/All.php
index 1886e50..2f8aaad 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/All.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/All.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Customers.php b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Customers.php
index d6a9a41..575c2ba 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Customers.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Customers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Pending.php b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Pending.php
index dac2d9e..e98a989 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Pending.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Pending.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Products.php b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Products.php
index 85d8f28..b3b1ff0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Products.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Grid/Products.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Pending.php b/app/code/core/Mage/Adminhtml/Block/Tag/Pending.php
index 5637268..1e18437 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Pending.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Pending.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Product.php b/app/code/core/Mage/Adminhtml/Block/Tag/Product.php
index 727ee8f..11cddf4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Product.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tag/Product/Grid.php
index a8cdb82..7ef864d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Store/Switcher.php b/app/code/core/Mage/Adminhtml/Block/Tag/Store/Switcher.php
index 1bcd3e7..2d2f7c9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Store/Switcher.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Store/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Tag.php b/app/code/core/Mage/Adminhtml/Block/Tag/Tag.php
index 5cc33b9..8f266d6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Tag.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit.php b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit.php
index 4f79d8d..e482d32 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit/Form.php
index 1fe8269..63a438c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Grid.php
index cf46518..b250a5a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tag/Tag/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Class.php b/app/code/core/Mage/Adminhtml/Block/Tax/Class.php
index c4a2a62..334a159 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Class.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Class.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit.php b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit.php
index 63a1bf6..b8ca361 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit/Form.php
index 3955d69..a5b4f19 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Grid.php
index 812e9ac..5d9ccd5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Class/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Class/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Form.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Form.php
index ab56dc9..6d3bd38 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid.php
index e7652d6..a98b7c3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Tax_Rate_Grid extends Mage_Adminhtml_Block_Widget_Grid
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Country.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Country.php
index 0144277..f6fe601 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Country.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Data.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Data.php
index bd644bb..8dec231 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Data.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Grid/Renderer/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/ImportExport.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/ImportExport.php
index 38bddf7..53e4166 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/ImportExport.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/ImportExport.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title.php
index 704d9ed..7e4b9c7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title/Fieldset.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title/Fieldset.php
index a317d3b..479cac6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title/Fieldset.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Title/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Add.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Add.php
index 086142e..8d6c848 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Add.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Add.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Save.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Save.php
index 8760354..38be093 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Save.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rate/Toolbar/Save.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rule.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rule.php
index bfff649..2b215b4 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rule.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit.php
index 9fdb8d9..b735950 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit/Form.php
index f2fbee8..9ddb447 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Grid.php b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Grid.php
index 2fb5f13..f2942f2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Tax/Rule/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Block_Tax_Rule_Grid extends Mage_Adminhtml_Block_Widget_Grid
diff --git a/app/code/core/Mage/Adminhtml/Block/Template.php b/app/code/core/Mage/Adminhtml/Block/Template.php
index 0cd5e63..08201f1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Template.php
+++ b/app/code/core/Mage/Adminhtml/Block/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Text/List.php b/app/code/core/Mage/Adminhtml/Block/Text/List.php
index 0d2bf99..a4a23e2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Text/List.php
+++ b/app/code/core/Mage/Adminhtml/Block/Text/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite.php
index ce176b5..c6acb41 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Category/Tree.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Category/Tree.php
index c670aa2..0c53045 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Category/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Category/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit.php
index ad3a486..5635eb7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit/Form.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit/Form.php
index a55d8d4..d82eba5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Grid.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Grid.php
index a96e1cc..eadb994 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Link.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Link.php
index b099db9..337e8a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Link.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Product/Grid.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Product/Grid.php
index aff1b76..6e6b401 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Product/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Selector.php b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Selector.php
index d12a8ff..2241789 100644
--- a/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Selector.php
+++ b/app/code/core/Mage/Adminhtml/Block/Urlrewrite/Selector.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget.php b/app/code/core/Mage/Adminhtml/Block/Widget.php
index e6cb95d..6c0bfee 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Accordion.php b/app/code/core/Mage/Adminhtml/Block/Widget/Accordion.php
index 59a341f..a7c1753 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Accordion.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Accordion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Accordion/Item.php b/app/code/core/Mage/Adminhtml/Block/Widget/Accordion/Item.php
index be4b06e..106962d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Accordion/Item.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Accordion/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Breadcrumbs.php b/app/code/core/Mage/Adminhtml/Block/Widget/Breadcrumbs.php
index 3f1e90d..6ef4939 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Breadcrumbs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Breadcrumbs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Button.php b/app/code/core/Mage/Adminhtml/Block/Widget/Button.php
index 1ffdfea..10400f8 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Button.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Button.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Container.php b/app/code/core/Mage/Adminhtml/Block/Widget/Container.php
index 7c810a5..63cd488 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Container.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form.php
index 0c40f74..855438e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Container.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Container.php
index 73aaebc..df6ce67 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Container.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element.php
index eda9956..cb52bd2 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Dependence.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Dependence.php
index 117e870..e94d371 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Dependence.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Dependence.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Gallery.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Gallery.php
index c3e24d1..df31775 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Gallery.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Element/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Element.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Element.php
index 040a19b..2d15158 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Element.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset.php
index 4baaf5f..9f23df1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset/Element.php b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset/Element.php
index fe03f1e..daa7525 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset/Element.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Form/Renderer/Fieldset/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid.php
index 2c8f162..57b25a3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Block.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Block.php
index 53a8fb8..583c7fe 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Block.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column.php
index 038602b..c735068 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Abstract.php
index 71ea863..de75f0f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Checkbox.php
index b0e4251..4fcdf1c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Country.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Country.php
index ba3d72d..31d2b2c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Country.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Date.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Date.php
index dde4ea2..96e9ad7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Date.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Datetime.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Datetime.php
index 339c480..818a7d7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Datetime.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Interface.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Interface.php
index 5e6b035..02e80b9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Interface.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Massaction.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Massaction.php
index 3fa83e4..df53f5b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Massaction.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Massaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Price.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Price.php
index 70e3bff..eb6f91f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Radio.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Radio.php
index 27227b6..ae05bf0 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Radio.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Radio.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Range.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Range.php
index 0d84c5f..a30dc57 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Range.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Range.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Select.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Select.php
index a4d836c..563e975 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Select.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Store.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Store.php
index 8752b32..853da91 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Store.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Text.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Text.php
index f1753da..49eae5e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Text.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Theme.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Theme.php
index 363cc66..39cf9e7 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Theme.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Filter/Theme.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
index 3f09507..e884e05 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Action.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Action.php
index f0edf56..c80133a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Action.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Checkbox.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Checkbox.php
index fe6d518..2885c0f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Checkbox.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Concat.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Concat.php
index b034912..76bc67c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Concat.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Concat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Country.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Country.php
index df0f232..65943e6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Country.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Currency.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Currency.php
index 1e0d8f5..32303a5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Currency.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Date.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Date.php
index 3399075..e7a9c7b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Date.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Datetime.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Datetime.php
index 3c245a6..7c130eb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Datetime.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Input.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Input.php
index 921f0aa..4a3c4fe 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Input.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Input.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Interface.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Interface.php
index 726d2b0..ba5ab9c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Interface.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Ip.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Ip.php
index 8d276d4..9c6209b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Ip.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Ip.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Longtext.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Longtext.php
index 5d926b9..253c70b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Longtext.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Longtext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Massaction.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Massaction.php
index 658c0f0..473f97e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Massaction.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Massaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Number.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Number.php
index 2ae3643..bff268e 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Number.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Number.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Options.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Options.php
index 46c7013..7d0ab43 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Options.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Price.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Price.php
index 0cf0dcb..fe5eb94 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Price.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Radio.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Radio.php
index cee9524..d9d1beb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Radio.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Radio.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Select.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Select.php
index 4f6582e..d4befa9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Select.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Store.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Store.php
index 18dc5dc..cace859 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Store.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Text.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Text.php
index 286bc8f..b313897 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Text.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Theme.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Theme.php
index 7c0b925..c8ebede 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Theme.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Theme.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Wrapline.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Wrapline.php
index f16b16b..a66b356 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Wrapline.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Wrapline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Container.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Container.php
index cbfc0cf..73d361d 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Container.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction.php
index 509dd98..1d36162 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Abstract.php
index 0b205b1..3794abb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item.php
index ac8e7a2..070bf65 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Default.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Default.php
index 1d3b3ec..046e806 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Default.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Interface.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Interface.php
index 8569d64..c1981d9 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Interface.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Massaction/Item/Additional/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Serializer.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Serializer.php
index 43a5225..f79430c 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Serializer.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Serializer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Tab/Interface.php b/app/code/core/Mage/Adminhtml/Block/Widget/Tab/Interface.php
index 6565fdf..a831ebb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Tab/Interface.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Tab/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Tabs.php b/app/code/core/Mage/Adminhtml/Block/Widget/Tabs.php
index 9fcfd09..c6a0c77 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Tabs.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Tree.php b/app/code/core/Mage/Adminhtml/Block/Widget/Tree.php
index 00105c7..e9964ce 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Tree.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/View/Container.php b/app/code/core/Mage/Adminhtml/Block/Widget/View/Container.php
index 9fdf3f2..1deaaaf 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/View/Container.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/View/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Controller/Action.php b/app/code/core/Mage/Adminhtml/Controller/Action.php
index 8fe6d66..b9de23d 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Action.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -415,19 +415,59 @@ class Mage_Adminhtml_Controller_Action extends Mage_Core_Controller_Varien_Actio
      */
     protected function _checkIsForcedFormKeyAction()
     {
-        return in_array($this->getRequest()->getActionName(), $this->_forcedFormKeyActions);
+        return in_array(
+            strtolower($this->getRequest()->getActionName()),
+            array_map('strtolower', $this->_forcedFormKeyActions)
+        );
     }
 
     /**
-     * Set actions name for forced use form key
+     * Set actions name for forced use form key if "Secret Key to URLs" disabled
      *
      * @param array | string $actionNames - action names for forced use form key
      */
     protected function _setForcedFormKeyActions($actionNames)
     {
-        $actionNames = (is_array($actionNames)) ? $actionNames: (array)$actionNames;
-        $actionNames = array_merge($this->_forcedFormKeyActions, $actionNames);
-        $actionNames = array_unique($actionNames);
-        $this->_forcedFormKeyActions = $actionNames;
+        if (!Mage::helper('adminhtml')->isEnabledSecurityKeyUrl()) {
+            $actionNames = (is_array($actionNames)) ? $actionNames: (array)$actionNames;
+            $actionNames = array_merge($this->_forcedFormKeyActions, $actionNames);
+            $actionNames = array_unique($actionNames);
+            $this->_forcedFormKeyActions = $actionNames;
+        }
+    }
+
+    /**
+     * Validate request parameter
+     *
+     * @param string $param - request parameter
+     * @param string $pattern - pattern that should be contained in parameter
+     *
+     * @return bool
+     */
+    protected function _validateRequestParam($param, $pattern = '')
+    {
+        $pattern = empty($pattern) ? '/^[a-z0-9\-\_\/]*$/si' : $pattern;
+        if (preg_match($pattern, $param)) {
+            return true;
+        }
+        return false;
+    }
+
+    /**
+     * Validate request parameters
+     *
+     * @param array $params - array of request parameters
+     * @param string $pattern - pattern that should be contained in parameter
+     *
+     * @return bool
+     */
+    protected function _validateRequestParams($params, $pattern = '')
+    {
+        foreach ($params as $param) {
+            if (!$this->_validateRequestParam($param, $pattern)) {
+                return false;
+            }
+        }
+        return true;
     }
 }
diff --git a/app/code/core/Mage/Adminhtml/Controller/Report/Abstract.php b/app/code/core/Mage/Adminhtml/Controller/Report/Abstract.php
index ab4d906..59be714 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Report/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Report/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Controller/Rss/Abstract.php b/app/code/core/Mage/Adminhtml/Controller/Rss/Abstract.php
index 6e8664c..d2f2441 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Rss/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Rss/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Controller/Sales/Creditmemo.php b/app/code/core/Mage/Adminhtml/Controller/Sales/Creditmemo.php
index 15ae018..f73e515 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Sales/Creditmemo.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Sales/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Controller/Sales/Invoice.php b/app/code/core/Mage/Adminhtml/Controller/Sales/Invoice.php
index dc39969..74dffe7 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Sales/Invoice.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Sales/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Controller/Sales/Shipment.php b/app/code/core/Mage/Adminhtml/Controller/Sales/Shipment.php
index a5415f5..8d3519a 100644
--- a/app/code/core/Mage/Adminhtml/Controller/Sales/Shipment.php
+++ b/app/code/core/Mage/Adminhtml/Controller/Sales/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Exception.php b/app/code/core/Mage/Adminhtml/Exception.php
index fd2e7dd..786d60d 100644
--- a/app/code/core/Mage/Adminhtml/Exception.php
+++ b/app/code/core/Mage/Adminhtml/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Addresses.php b/app/code/core/Mage/Adminhtml/Helper/Addresses.php
index e68a9af..5d8e324 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Addresses.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Catalog.php b/app/code/core/Mage/Adminhtml/Helper/Catalog.php
index 2de4e64..951d7d1 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Catalog.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Composite.php b/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Composite.php
index 9fcbd4e..b00ba14 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Composite.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Composite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Edit/Action/Attribute.php b/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Edit/Action/Attribute.php
index 2503a77..bb850d2 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Edit/Action/Attribute.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Catalog/Product/Edit/Action/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Abstract.php b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Abstract.php
index 1788e6d..078914d 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Data.php b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Data.php
index 9167993..2b5cdfc 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Data.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Order.php b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Order.php
index 3b46476..ec66673 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Dashboard/Order.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Dashboard/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Data.php b/app/code/core/Mage/Adminhtml/Helper/Data.php
index 0918f9a..d36d689 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Data.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -37,6 +37,7 @@ class Mage_Adminhtml_Helper_Data extends Mage_Adminhtml_Helper_Help_Mapping
     const XML_PATH_USE_CUSTOM_ADMIN_URL         = 'default/admin/url/use_custom';
     const XML_PATH_USE_CUSTOM_ADMIN_PATH        = 'default/admin/url/use_custom_path';
     const XML_PATH_CUSTOM_ADMIN_PATH            = 'default/admin/url/custom_path';
+    const XML_PATH_ADMINHTML_SECURITY_USE_FORM_KEY = 'admin/security/use_form_key';
 
     protected $_pageHelpUrl;
 
@@ -148,4 +149,14 @@ class Mage_Adminhtml_Helper_Data extends Mage_Adminhtml_Helper_Help_Mapping
     {
         $value = trim(rawurldecode($value));
     }
+
+    /**
+     * Check if enabled "Add Secret Key to URLs" functionality
+     *
+     * @return bool
+     */
+    public function isEnabledSecurityKeyUrl()
+    {
+        return Mage::getStoreConfigFlag(self::XML_PATH_ADMINHTML_SECURITY_USE_FORM_KEY);
+    }
 }
diff --git a/app/code/core/Mage/Adminhtml/Helper/Help/Mapping.php b/app/code/core/Mage/Adminhtml/Helper/Help/Mapping.php
index 53d8fdf..4ea9d0c 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Help/Mapping.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Help/Mapping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Js.php b/app/code/core/Mage/Adminhtml/Helper/Js.php
index 6bb619a..f3fbf7d 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Js.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Media/Js.php b/app/code/core/Mage/Adminhtml/Helper/Media/Js.php
index d2ebc21..56cc339 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Media/Js.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Media/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Rss.php b/app/code/core/Mage/Adminhtml/Helper/Rss.php
index c03fcc2..45ed184 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Rss.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Rss.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Helper/Sales.php b/app/code/core/Mage/Adminhtml/Helper/Sales.php
index 029d64e..941b847 100644
--- a/app/code/core/Mage/Adminhtml/Helper/Sales.php
+++ b/app/code/core/Mage/Adminhtml/Helper/Sales.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Config.php b/app/code/core/Mage/Adminhtml/Model/Config.php
index 95ce40e..467ad85 100644
--- a/app/code/core/Mage/Adminhtml/Model/Config.php
+++ b/app/code/core/Mage/Adminhtml/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Config/Data.php b/app/code/core/Mage/Adminhtml/Model/Config/Data.php
index f8f31a1..90ab946 100644
--- a/app/code/core/Mage/Adminhtml/Model/Config/Data.php
+++ b/app/code/core/Mage/Adminhtml/Model/Config/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Customer/Renderer/Region.php b/app/code/core/Mage/Adminhtml/Model/Customer/Renderer/Region.php
index 452ebcd..27a817c 100644
--- a/app/code/core/Mage/Adminhtml/Model/Customer/Renderer/Region.php
+++ b/app/code/core/Mage/Adminhtml/Model/Customer/Renderer/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Email/PathValidator.php b/app/code/core/Mage/Adminhtml/Model/Email/PathValidator.php
new file mode 100644
index 0000000..4ee60a2
--- /dev/null
+++ b/app/code/core/Mage/Adminhtml/Model/Email/PathValidator.php
@@ -0,0 +1,63 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Mage
+ * @package     Mage_Adminhtml
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+/**
+ * Validator for Email Template
+ *
+ * @category   Mage
+ * @package    Mage_Adminhtml
+ * @author     Magento Core Team <core@magentocommerce.com>
+ */
+class Mage_Adminhtml_Model_Email_PathValidator extends Zend_Validate_Abstract
+{
+    /**
+     * Returns true if and only if $value meets the validation requirements
+     * If $value fails validation, then this method returns false
+     *
+     * @param  mixed $value
+     * @return boolean
+     */
+    public function isValid($value)
+    {
+        $pathNode = is_array($value) ? array_shift($value) : $value;
+
+        return $this->isEncryptedNodePath($pathNode);
+    }
+
+    /**
+     * Return bool after checking the encrypted model in the path to config node
+     *
+     * @param string $path
+     * @return bool
+     */
+    protected function isEncryptedNodePath($path)
+    {
+        /** @var $configModel Mage_Adminhtml_Model_Config */
+        $configModel = Mage::getSingleton('adminhtml/config');
+
+        return in_array((string)$path, $configModel->getEncryptedNodeEntriesPaths());
+    }
+}
diff --git a/app/code/core/Mage/Adminhtml/Model/Email/Template.php b/app/code/core/Mage/Adminhtml/Model/Email/Template.php
index da1f4ec..e5fcb9f 100644
--- a/app/code/core/Mage/Adminhtml/Model/Email/Template.php
+++ b/app/code/core/Mage/Adminhtml/Model/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Extension.php b/app/code/core/Mage/Adminhtml/Model/Extension.php
index 2c9232a..966fcdf 100644
--- a/app/code/core/Mage/Adminhtml/Model/Extension.php
+++ b/app/code/core/Mage/Adminhtml/Model/Extension.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Giftmessage/Save.php b/app/code/core/Mage/Adminhtml/Model/Giftmessage/Save.php
index 7bd0830..ec47aec 100644
--- a/app/code/core/Mage/Adminhtml/Model/Giftmessage/Save.php
+++ b/app/code/core/Mage/Adminhtml/Model/Giftmessage/Save.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php b/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
index f0bd5c9..513fc9c 100644
--- a/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
+++ b/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -69,6 +69,7 @@ class Mage_Adminhtml_Model_LayoutUpdate_Validator extends Zend_Validate_Abstract
     protected $_disallowedBlock = array(
         'Mage_Install_Block_End',
         'Mage_Rss_Block_Order_New',
+        'Mage_Core_Block_Template_Zend',
     );
 
     /**
diff --git a/app/code/core/Mage/Adminhtml/Model/Newsletter/Renderer/Text.php b/app/code/core/Mage/Adminhtml/Model/Newsletter/Renderer/Text.php
index cc9fe67..6c09120 100644
--- a/app/code/core/Mage/Adminhtml/Model/Newsletter/Renderer/Text.php
+++ b/app/code/core/Mage/Adminhtml/Model/Newsletter/Renderer/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Observer.php b/app/code/core/Mage/Adminhtml/Model/Observer.php
index f4eb4d6..935ee47 100644
--- a/app/code/core/Mage/Adminhtml/Model/Observer.php
+++ b/app/code/core/Mage/Adminhtml/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Report/Item.php b/app/code/core/Mage/Adminhtml/Model/Report/Item.php
index 172e06f..6eb2979 100644
--- a/app/code/core/Mage/Adminhtml/Model/Report/Item.php
+++ b/app/code/core/Mage/Adminhtml/Model/Report/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_Report_Item extends Varien_Object
diff --git a/app/code/core/Mage/Adminhtml/Model/Sales/Order.php b/app/code/core/Mage/Adminhtml/Model/Sales/Order.php
index 1f868f0..249ae72 100644
--- a/app/code/core/Mage/Adminhtml/Model/Sales/Order.php
+++ b/app/code/core/Mage/Adminhtml/Model/Sales/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Sales/Order/Create.php b/app/code/core/Mage/Adminhtml/Model/Sales/Order/Create.php
index 07d2541..9faffae7 100644
--- a/app/code/core/Mage/Adminhtml/Model/Sales/Order/Create.php
+++ b/app/code/core/Mage/Adminhtml/Model/Sales/Order/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Sales/Order/Random.php b/app/code/core/Mage/Adminhtml/Model/Sales/Order/Random.php
index 0358f49..03ae76e 100644
--- a/app/code/core/Mage/Adminhtml/Model/Sales/Order/Random.php
+++ b/app/code/core/Mage/Adminhtml/Model/Sales/Order/Random.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Search/Catalog.php b/app/code/core/Mage/Adminhtml/Model/Search/Catalog.php
index edcaf7f..e78a7c7 100644
--- a/app/code/core/Mage/Adminhtml/Model/Search/Catalog.php
+++ b/app/code/core/Mage/Adminhtml/Model/Search/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Search/Customer.php b/app/code/core/Mage/Adminhtml/Model/Search/Customer.php
index 4e84662..482da4f 100644
--- a/app/code/core/Mage/Adminhtml/Model/Search/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Model/Search/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Search/Order.php b/app/code/core/Mage/Adminhtml/Model/Search/Order.php
index 5a666b0..2c48edb 100644
--- a/app/code/core/Mage/Adminhtml/Model/Search/Order.php
+++ b/app/code/core/Mage/Adminhtml/Model/Search/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Session.php b/app/code/core/Mage/Adminhtml/Model/Session.php
index d93e204..fb69df4 100644
--- a/app/code/core/Mage/Adminhtml/Model/Session.php
+++ b/app/code/core/Mage/Adminhtml/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Session/Quote.php b/app/code/core/Mage/Adminhtml/Model/Session/Quote.php
index 1d786a1..986759c 100644
--- a/app/code/core/Mage/Adminhtml/Model/Session/Quote.php
+++ b/app/code/core/Mage/Adminhtml/Model/Session/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custom.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custom.php
index 9781de5..b98425c 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custom.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custom.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custompath.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custompath.php
index 7c2ae16..8bcffd1 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custompath.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Custompath.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Observer.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Observer.php
index f10d8b8..3373b8f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Observer.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Password/Link/Expirationperiod.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Password/Link/Expirationperiod.php
index c9f0d3d..dedf541 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Password/Link/Expirationperiod.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Password/Link/Expirationperiod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustom.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustom.php
index 11badad..8e32b08 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustom.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustom.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustompath.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustompath.php
index 77c526f..0ad44f0 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustompath.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usecustompath.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usesecretkey.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usesecretkey.php
index f469c93..156a77b 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usesecretkey.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Admin/Usesecretkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
index c7bc6bf..55537c2 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cache.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cache.php
index f89548d..d9015e5 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cache.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Inventory/Managestock.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Inventory/Managestock.php
index c4e35cf..9f58c25 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Inventory/Managestock.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Inventory/Managestock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Search/Type.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Search/Type.php
index 7ed05c3..8e3914b 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Search/Type.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Catalog/Search/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Category.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Category.php
index 6c1fc92..9148ead 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Category.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cookie.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cookie.php
index 5a49a2b..1fe1b1d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cookie.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Cookie.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Abstract.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Abstract.php
index f52252c..e8c4bd6 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Allow.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Allow.php
index 8f9aac9..59abf81 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Allow.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Allow.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Base.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Base.php
index 4ea7cde..537a67e 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Base.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Base.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Cron.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Cron.php
index beb9946..1b8398a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Cron.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Default.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Default.php
index 74a2168..fbab750 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Default.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Currency/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Address/Street.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Address/Street.php
index 536ea48..1afefab 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Address/Street.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Address/Street.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Password/Link/Expirationperiod.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Password/Link/Expirationperiod.php
index d037e9f..5a7fbcb 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Password/Link/Expirationperiod.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Password/Link/Expirationperiod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Address.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Address.php
index ff09d9f..b3f4674 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Address.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Customer.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Customer.php
index 45d4fb6..bc0f541 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Customer.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Customer/Show/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Datashare.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Datashare.php
index 0795205..4ff8140 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Datashare.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Datashare.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Exception.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Exception.php
index bd40e29..33149ef 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Exception.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Package.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Package.php
index 446c7b7..e12ca93 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Package.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Design/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Address.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Address.php
index 254945f..aa57a91 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Address.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Logo.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Logo.php
index 15bdcaf..3cddd56 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Logo.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Logo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Sender.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Sender.php
index 3deddf7..a9a9636 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Sender.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Email/Sender.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Encrypted.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Encrypted.php
index 6b5fc04..c52f571 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Encrypted.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Encrypted.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/File.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/File.php
index f4cb455..8208f4a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/File.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Filename.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Filename.php
index 475bc22..ea72511 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Filename.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Filename.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Gatewayurl.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Gatewayurl.php
new file mode 100644
index 0000000..bba131d
--- /dev/null
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Gatewayurl.php
@@ -0,0 +1,53 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Mage
+ * @package     Mage_Adminhtml
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+/**
+ * Gateway URL config field backend model
+ *
+ * @category    Mage
+ * @package     Mage_Adminhtml
+ * @author      Magento Core Team <core@magentocommerce.com>
+ */
+class Mage_Adminhtml_Model_System_Config_Backend_Gatewayurl extends  Mage_Core_Model_Config_Data
+{
+    /**
+     * Before save processing
+     *
+     * @throws Mage_Core_Exception
+     * @return Mage_Adminhtml_Model_System_Config_Backend_Gatewayurl
+     */
+    protected function _beforeSave()
+    {
+        if ($this->getValue()) {
+            $parsed = parse_url($this->getValue());
+            if (!isset($parsed['scheme']) || (('https' != $parsed['scheme']) && ('http' != $parsed['scheme']))) {
+                Mage::throwException(Mage::helper('core')->__('Invalid URL scheme.'));
+            }
+        }
+
+        return $this;
+    }
+}
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image.php
index a9b80be..c84a198 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Favicon.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Favicon.php
index c69d1c8..30fd347 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Favicon.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Favicon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Pdf.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Pdf.php
index 83441c0..dfd680d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Pdf.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Image/Pdf.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Layer/Children.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Layer/Children.php
index 5cd5d35..65af32f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Layer/Children.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Layer/Children.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
index 56c2892..9ec0be2 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale/Timezone.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale/Timezone.php
index 17a1c1e..cb22661 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale/Timezone.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale/Timezone.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Log/Cron.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Log/Cron.php
index 5b6ccc4..02dc9f9 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Log/Cron.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Log/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Price/Scope.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Price/Scope.php
index 774701f..502e229 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Price/Scope.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Price/Scope.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Product/Alert/Cron.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Product/Alert/Cron.php
index 09dd472..3550de1 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Product/Alert/Cron.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Product/Alert/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Protected.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Protected.php
new file mode 100644
index 0000000..41eff7c
--- /dev/null
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Protected.php
@@ -0,0 +1,35 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Mage
+ * @package     Mage_Adminhtml
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+/**
+ * System config protected fields backend model
+ *
+ * @category Mage
+ * @package  Mage_Adminhtml
+ */
+class Mage_Adminhtml_Model_System_Config_Backend_Protected extends Mage_Adminhtml_Model_System_Config_Backend_Symlink
+{
+}
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Secure.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Secure.php
index f6799d3..fcc4103 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Secure.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Secure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Seo/Product.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Seo/Product.php
index b13fd15..bab961d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Seo/Product.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Seo/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized.php
index 9ea0e5e..18ff149 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
index cc96ddf..fef80ea 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Shipping/Tablerate.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Shipping/Tablerate.php
index baf9d38..ea912bd 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Shipping/Tablerate.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Shipping/Tablerate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap.php
index 1ada827..b580d52 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap/Cron.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap/Cron.php
index 740d051..0c79d47 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap/Cron.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Sitemap/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Storage/Media/Database.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Storage/Media/Database.php
index 95aeec9..3ab3c43 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Storage/Media/Database.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Storage/Media/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Store.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Store.php
index 77f973f..fe004d8 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Store.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Symlink.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Symlink.php
index cac65f6..0d3b843 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Symlink.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Symlink.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Translate.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Translate.php
index 8d34a82..76ca335 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Translate.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Web/Secure/Offloaderheader.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Web/Secure/Offloaderheader.php
index f0ef39f..a46470d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Web/Secure/Offloaderheader.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Web/Secure/Offloaderheader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Clone/Media/Image.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Clone/Media/Image.php
index a441448..b5a8861 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Clone/Media/Image.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Clone/Media/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Admin/Page.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Admin/Page.php
index bb11983..ce53f06 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Admin/Page.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Admin/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Allregion.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Allregion.php
index 0f82611..5068f9f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Allregion.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Allregion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/GridPerPage.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/GridPerPage.php
index ea7746c..872525f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/GridPerPage.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/GridPerPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListMode.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListMode.php
index 95059d2..2285c3e 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListMode.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListMode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListPerPage.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListPerPage.php
index 4432549..dbdb4c9 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListPerPage.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListPerPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListSort.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListSort.php
index 8660f55..e12febe 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListSort.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/ListSort.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/Search/Type.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/Search/Type.php
index 3300d74..0f7ecea 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/Search/Type.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/Search/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/TimeFormat.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/TimeFormat.php
index 603cb85..44f1070 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/TimeFormat.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Catalog/TimeFormat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Category.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Category.php
index 7a3879b..c7ba927 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Category.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Checktype.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Checktype.php
index b4ce84a..e460c32 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Checktype.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Checktype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Page.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Page.php
index b5ce170..5fec34d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Page.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Cms_Page
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Wysiwyg/Enabled.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Wysiwyg/Enabled.php
index 610a981..3a1cc37 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Wysiwyg/Enabled.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cms/Wysiwyg/Enabled.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country.php
index ddc0a73..6412c8e 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country/Full.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country/Full.php
index ba93ad7..500a609 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country/Full.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Country/Full.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cron/Frequency.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cron/Frequency.php
index a397b74..601a14a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cron/Frequency.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Cron/Frequency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency.php
index a0c23f6..e0bd58c 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency/Service.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency/Service.php
index 0642ce0..f8d2aa9 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency/Service.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Currency/Service.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Address/Type.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Address/Type.php
index eebb2c3..1f9e655 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Address/Type.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Address/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Forgotpassword.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Forgotpassword.php
index 02b6a6d..c8a8741 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Forgotpassword.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Forgotpassword.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group.php
index 22c2e22..adaad76 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group/Multiselect.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group/Multiselect.php
index c5ec038..5034dcf 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group/Multiselect.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Customer/Group/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Date/Short.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Date/Short.php
index 2f928c3..002216b 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Date/Short.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Date/Short.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Package.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Package.php
index 8468e4b..97713de 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Package.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Package
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Robots.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Robots.php
index c78c570..1721b66 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Robots.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Design/Robots.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Dev/Dbautoup.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Dev/Dbautoup.php
index fee877a..0ad3eed 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Dev/Dbautoup.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Dev/Dbautoup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Dev_Dbautoup
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Identity.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Identity.php
index ed50070..709e0df 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Identity.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Identity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Method.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Method.php
index 3609285..6fdb398 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Method.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Smtpauth.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Smtpauth.php
index f9ab385..713c5a8 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Smtpauth.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Smtpauth.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Template.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Template.php
index 58f1fa0..650cef3 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Template.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Enabledisable.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Enabledisable.php
index 15779aa..4ea29a5 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Enabledisable.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Enabledisable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Frequency.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Frequency.php
index 91baefd..eb1768d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Frequency.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Frequency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Language.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Language.php
index e9bcc12..c7e469c 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Language.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Language.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale.php
index bf4ee72..ace173e 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Country.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Country.php
index 65a868c..6c0714a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Country.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency.php
index ab111eb..161bbf4 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency/All.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency/All.php
index e6a5f01..bdb8e64 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency/All.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Currency/All.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Timezone.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Timezone.php
index d33698c..92810ae 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Timezone.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Timezone.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdaycodes.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdaycodes.php
index a14e89b..cb650ea 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdaycodes.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdaycodes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdays.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdays.php
index a13d4e8..f49477b 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdays.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Locale/Weekdays.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Nooptreq.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Nooptreq.php
index 81435dd..c9cb02b 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Nooptreq.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Nooptreq.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Nooptreq
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Notification/Frequency.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Notification/Frequency.php
index 3959158..2dfc1a9 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Notification/Frequency.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Notification/Frequency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status.php
index 550dc43..d03cea0 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/New.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/New.php
index 809b998..516d009 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/New.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Newprocessing.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Newprocessing.php
index 184fd25..1c26cb6 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Newprocessing.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Newprocessing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Processing.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Processing.php
index a18eb79..5938810 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Processing.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Order/Status/Processing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allmethods.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allmethods.php
index 4004241..c46dad5 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allmethods.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allmethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allowedmethods.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allowedmethods.php
index a543d03..80a87c5 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allowedmethods.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allowedmethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allspecificcountries.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allspecificcountries.php
index 5c0f988..5e9be35 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allspecificcountries.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Allspecificcountries.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Cctype.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Cctype.php
index 2080b93..c841a2f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Cctype.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Payment/Cctype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Scope.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Scope.php
index 140c619..e0fa02d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Scope.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Scope.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Step.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Step.php
index 20bfec8..32ead6f 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Step.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Price/Step.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Price.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Price.php
index adffc9c..32fb7a3 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Price.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Type.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Type.php
index 838e8d1..ff6ecf3 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Type.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Options/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Thumbnail.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Thumbnail.php
index aa6edca..270729d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Thumbnail.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Product/Thumbnail.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Reports/Scope.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Reports/Scope.php
index 61b4ca3..7375392 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Reports/Scope.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Reports/Scope.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Security/Domainpolicy.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Security/Domainpolicy.php
index a5bd2cc..285a920 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Security/Domainpolicy.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Security/Domainpolicy.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allmethods.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allmethods.php
index 4a9062b..89f0508 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allmethods.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allmethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allowedmethods.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allowedmethods.php
index 3244b3f..f51ca0a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allowedmethods.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allowedmethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allspecificcountries.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allspecificcountries.php
index 0981cda..d082a62 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allspecificcountries.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Allspecificcountries.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Flatrate.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Flatrate.php
index 8685f9e..4e60004 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Flatrate.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Flatrate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Tablerate.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Tablerate.php
index b0d10fd..bbd4645 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Tablerate.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Tablerate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Taxclass.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Taxclass.php
index 2033565..25e8a84 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Taxclass.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Shipping/Taxclass.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Shipping_Taxclass
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Database.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Database.php
index 4850384..81b2d20 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Database.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Storage.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Storage.php
index a6da25b..fb51f02 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Storage.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Storage/Media/Storage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Store.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Store.php
index cfccc13..5b5ed3a 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Store.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Apply/On.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Apply/On.php
index 4b9a462..76294ab 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Apply/On.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Apply/On.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Tax_Apply_On
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Basedon.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Basedon.php
index ed58355..42b5cc0 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Basedon.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Basedon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Tax_Basedon
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Catalog.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Catalog.php
index 11e212d..3f453e7 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Catalog.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Tax/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Tax_Catalog
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Watermark/Position.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Watermark/Position.php
index a7093d3..3c353d0 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Watermark/Position.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Watermark/Position.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Protocol.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Protocol.php
index e23ef54..59a8829 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Protocol.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Protocol.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Web_Protocol
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Redirect.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Redirect.php
index 79b178f..2e4112d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Redirect.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Web/Redirect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_System_Config_Source_Web_Redirect
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Website.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Website.php
index a4e0774..9908f62 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Website.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesno.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesno.php
index d02e82f..7122d6d 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesno.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesno.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesnocustom.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesnocustom.php
index 9c1cb55..1717de1 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesnocustom.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Source/Yesnocustom.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Store.php b/app/code/core/Mage/Adminhtml/Model/System/Store.php
index 26694fd..1a0541e 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Store.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/Model/Url.php b/app/code/core/Mage/Adminhtml/Model/Url.php
index 83636eb..8aad6c3 100644
--- a/app/code/core/Mage/Adminhtml/Model/Url.php
+++ b/app/code/core/Mage/Adminhtml/Model/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Model_Url extends Mage_Core_Model_Url
diff --git a/app/code/core/Mage/Adminhtml/controllers/AjaxController.php b/app/code/core/Mage/Adminhtml/controllers/AjaxController.php
index 2f8d853..df48ead 100644
--- a/app/code/core/Mage/Adminhtml/controllers/AjaxController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/AjaxController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Api/RoleController.php b/app/code/core/Mage/Adminhtml/controllers/Api/RoleController.php
index e332798..fbeaf44 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Api/RoleController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Api/RoleController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -33,6 +33,16 @@
  */
 class Mage_Adminhtml_Api_RoleController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions(array('delete', 'save'));
+        return parent::preDispatch();
+    }
 
     protected function _initAction()
     {
diff --git a/app/code/core/Mage/Adminhtml/controllers/Api/UserController.php b/app/code/core/Mage/Adminhtml/controllers/Api/UserController.php
index 7d9401c..a6d4757 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Api/UserController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Api/UserController.php
@@ -20,11 +20,21 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Api_UserController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
 
     protected function _initAction()
     {
diff --git a/app/code/core/Mage/Adminhtml/controllers/CacheController.php b/app/code/core/Mage/Adminhtml/controllers/CacheController.php
index 548b10b..b114612 100644
--- a/app/code/core/Mage/Adminhtml/controllers/CacheController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/CacheController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Category/WidgetController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Category/WidgetController.php
index 267c1d4..55cccd5 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Category/WidgetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Category/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/CategoryController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/CategoryController.php
index c27c2fc..d22cff8 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/CategoryController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/CategoryController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/Action/AttributeController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/Action/AttributeController.php
index 2fec086..6bde536 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/Action/AttributeController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/Action/AttributeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -65,6 +65,7 @@ class Mage_Adminhtml_Catalog_Product_Action_AttributeController extends Mage_Adm
         $attributesData     = $this->getRequest()->getParam('attributes', array());
         $websiteRemoveData  = $this->getRequest()->getParam('remove_website_ids', array());
         $websiteAddData     = $this->getRequest()->getParam('add_website_ids', array());
+        $attributeName      = '';
 
         /* Prepare inventory data item options (use config settings) */
         foreach (Mage::helper('cataloginventory')->getConfigItemOptions() as $option) {
@@ -77,6 +78,7 @@ class Mage_Adminhtml_Catalog_Product_Action_AttributeController extends Mage_Adm
             if ($attributesData) {
                 $dateFormat = Mage::app()->getLocale()->getDateFormat(Mage_Core_Model_Locale::FORMAT_TYPE_SHORT);
                 $storeId    = $this->_getHelper()->getSelectedStoreId();
+                $data       = new Varien_Object();
 
                 foreach ($attributesData as $attributeCode => $value) {
                     $attribute = Mage::getSingleton('eav/config')
@@ -85,6 +87,9 @@ class Mage_Adminhtml_Catalog_Product_Action_AttributeController extends Mage_Adm
                         unset($attributesData[$attributeCode]);
                         continue;
                     }
+                    $data->setData($attributeCode, $value);
+                    $attributeName = $attribute->getFrontendLabel();
+                    $attribute->getBackend()->validate($data);
                     if ($attribute->getBackendType() == 'datetime') {
                         if (!empty($value)) {
                             $filterInput    = new Zend_Filter_LocalizedToNormalized(array(
@@ -179,6 +184,9 @@ class Mage_Adminhtml_Catalog_Product_Action_AttributeController extends Mage_Adm
                 $this->__('Total of %d record(s) were updated', count($this->_getHelper()->getProductIds()))
             );
         }
+        catch (Mage_Eav_Model_Entity_Attribute_Exception $e) {
+            $this->_getSession()->addError($attributeName . ': ' . $e->getMessage());
+        }
         catch (Mage_Core_Exception $e) {
             $this->_getSession()->addError($e->getMessage());
         }
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
index 0510fd9..43cf415 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -54,6 +54,7 @@ class Mage_Adminhtml_Catalog_Product_AttributeController extends Mage_Adminhtml_
 
     public function preDispatch()
     {
+        $this->_setForcedFormKeyActions('delete');
         parent::preDispatch();
         $this->_entityTypeId = Mage::getModel('eav/entity')->setType(Mage_Catalog_Model_Product::ENTITY)->getTypeId();
     }
@@ -208,7 +209,7 @@ class Mage_Adminhtml_Catalog_Product_AttributeController extends Mage_Adminhtml_
 
             //validate attribute_code
             if (isset($data['attribute_code'])) {
-                $validatorAttrCode = new Zend_Validate_Regex(array('pattern' => '/[a-z][a-z_0-9]{1,254}[^event]/'));
+                $validatorAttrCode = new Zend_Validate_Regex(array('pattern' => '/^(?!event$)[a-z][a-z_0-9]{1,254}$/'));
                 if (!$validatorAttrCode->isValid($data['attribute_code'])) {
                     $session->addError(
                         Mage::helper('catalog')->__('Attribute code is invalid. Please use only letters (a-z), numbers (0-9) or underscore(_) in this field, first character should be a letter. Do not use "event" for an attribute code.')
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/DatafeedsController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/DatafeedsController.php
index 4600116..3b21e08 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/DatafeedsController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/DatafeedsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GalleryController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GalleryController.php
index 98c581b..cb274fe 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GalleryController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GalleryController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GroupController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GroupController.php
index ef4f6eb..6501c93 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GroupController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/GroupController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
index b742af7..4e5a97a 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/SetController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/SetController.php
index 073ffec..40ef549 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/SetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/SetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/WidgetController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/WidgetController.php
index d59ead4..ef18890 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/WidgetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -36,6 +36,9 @@ class Mage_Adminhtml_Catalog_Product_WidgetController extends Mage_Adminhtml_Con
 {
     /**
      * Chooser Source action
+     *
+     * @throws Mage_Core_Exception
+     * @return void
      */
     public function chooserAction()
     {
@@ -43,6 +46,10 @@ class Mage_Adminhtml_Catalog_Product_WidgetController extends Mage_Adminhtml_Con
         $massAction = $this->getRequest()->getParam('use_massaction', false);
         $productTypeId = $this->getRequest()->getParam('product_type_id', null);
 
+        if (!$this->_validateRequestParam($uniqId)) {
+            Mage::throwException(Mage::helper('adminhtml')->__('An error occurred while adding condition.'));
+        }
+
         $productsGrid = $this->getLayout()->createBlock('adminhtml/catalog_product_widget_chooser', '', array(
             'id'                => $uniqId,
             'use_massaction' => $massAction,
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
index fda1497..a38dd91 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -45,6 +45,17 @@ class Mage_Adminhtml_Catalog_ProductController extends Mage_Adminhtml_Controller
      */
     protected $_publicActions = array('edit');
 
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions(array('delete', 'massDelete'));
+        return parent::preDispatch();
+    }
+
     protected function _construct()
     {
         // Define module dependent translate
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/SearchController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/SearchController.php
index c07b1d1..8a36bc8 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/SearchController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/SearchController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/CatalogController.php b/app/code/core/Mage/Adminhtml/controllers/CatalogController.php
index 2ad7f49..bf562be 100644
--- a/app/code/core/Mage/Adminhtml/controllers/CatalogController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/CatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php b/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
index 8df6b34..98afaa2 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/Block/WidgetController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/Block/WidgetController.php
index 4125861..7f9efb7 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/Block/WidgetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/Block/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/BlockController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/BlockController.php
index fe56e01..73de52c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/BlockController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/BlockController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/Page/WidgetController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/Page/WidgetController.php
index d924218..26f055b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/Page/WidgetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/Page/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/PageController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/PageController.php
index 2545fbf..d217477 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/PageController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/PageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/Wysiwyg/ImagesController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/Wysiwyg/ImagesController.php
index 8d27fad..863de4f 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/Wysiwyg/ImagesController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/Wysiwyg/ImagesController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Cms/WysiwygController.php b/app/code/core/Mage/Adminhtml/controllers/Cms/WysiwygController.php
index fe44dc8..108dffc 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Cms/WysiwygController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Cms/WysiwygController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -44,6 +44,10 @@ class Mage_Adminhtml_Cms_WysiwygController extends Mage_Adminhtml_Controller_Act
         $directive = Mage::helper('core')->urlDecode($directive);
         $url = Mage::getModel('cms/adminhtml_template_filter')->filter($directive);
         try {
+            $allowedStreamWrappers = Mage::helper('cms')->getAllowedStreamWrappers();
+            if (!Mage::getModel('core/file_validator_streamWrapper', $allowedStreamWrappers)->validate($url)) {
+                Mage::throwException(Mage::helper('core')->__('Invalid stream.'));
+            }
             $image = Varien_Image_Adapter::factory('GD2');
             $image->open($url);
         } catch (Exception $e) {
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/Cart/Product/Composite/CartController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/Cart/Product/Composite/CartController.php
index 33d1d9b..714c9ea 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/Cart/Product/Composite/CartController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/Cart/Product/Composite/CartController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/ConfigController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/ConfigController.php
index d1da17b..b5ce013 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/ConfigController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/ConfigController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/GroupController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/GroupController.php
index 7d9177e..86e6d0e 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/GroupController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/GroupController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/OnlineController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/OnlineController.php
index 5b795f2..d369928 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/OnlineController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/OnlineController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Customer_OnlineController extends Mage_Adminhtml_Controller_Action
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/System/Config/ValidatevatController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/System/Config/ValidatevatController.php
index 6191ff6..2b53192 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/System/Config/ValidatevatController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/System/Config/ValidatevatController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Customer/Wishlist/Product/Composite/WishlistController.php b/app/code/core/Mage/Adminhtml/controllers/Customer/Wishlist/Product/Composite/WishlistController.php
index 79c0300..8ad524e 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Customer/Wishlist/Product/Composite/WishlistController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Customer/Wishlist/Product/Composite/WishlistController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/CustomerController.php b/app/code/core/Mage/Adminhtml/controllers/CustomerController.php
index c7ef678..0e6e126 100644
--- a/app/code/core/Mage/Adminhtml/controllers/CustomerController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -40,7 +40,7 @@ class Mage_Adminhtml_CustomerController extends Mage_Adminhtml_Controller_Action
      */
     public function preDispatch()
     {
-        $this->_setForcedFormKeyActions('delete');
+        $this->_setForcedFormKeyActions(array('delete', 'massDelete'));
         return parent::preDispatch();
     }
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/DashboardController.php b/app/code/core/Mage/Adminhtml/controllers/DashboardController.php
index a11413f..d0dd27b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/DashboardController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/DashboardController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/IndexController.php b/app/code/core/Mage/Adminhtml/controllers/IndexController.php
index 624813a..3e730f8 100644
--- a/app/code/core/Mage/Adminhtml/controllers/IndexController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/JsonController.php b/app/code/core/Mage/Adminhtml/controllers/JsonController.php
index 442396f..c79a31c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/JsonController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/JsonController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Media/EditorController.php b/app/code/core/Mage/Adminhtml/controllers/Media/EditorController.php
index 1404459..9239721 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Media/EditorController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Media/EditorController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Media/UploaderController.php b/app/code/core/Mage/Adminhtml/controllers/Media/UploaderController.php
index 1f2c9d4..e7c8627 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Media/UploaderController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Media/UploaderController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Newsletter/ProblemController.php b/app/code/core/Mage/Adminhtml/controllers/Newsletter/ProblemController.php
index 1cc9818..6cc608b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Newsletter/ProblemController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Newsletter/ProblemController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Newsletter/QueueController.php b/app/code/core/Mage/Adminhtml/controllers/Newsletter/QueueController.php
index 87de463..f8b564a 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Newsletter/QueueController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Newsletter/QueueController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Newsletter/SubscriberController.php b/app/code/core/Mage/Adminhtml/controllers/Newsletter/SubscriberController.php
index d88718f..17ed870 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Newsletter/SubscriberController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Newsletter/SubscriberController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php b/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
index 1b16772..ed546c5 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/app/code/core/Mage/Adminhtml/controllers/NotificationController.php b/app/code/core/Mage/Adminhtml/controllers/NotificationController.php
index ebc571f..8c8d9b6 100644
--- a/app/code/core/Mage/Adminhtml/controllers/NotificationController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/NotificationController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Permissions/BlockController.php b/app/code/core/Mage/Adminhtml/controllers/Permissions/BlockController.php
index 9a92ce9..3162e35 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Permissions/BlockController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Permissions/BlockController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Permissions/RoleController.php b/app/code/core/Mage/Adminhtml/controllers/Permissions/RoleController.php
index b98b464..93f1928 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Permissions/RoleController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Permissions/RoleController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -35,6 +35,17 @@ class Mage_Adminhtml_Permissions_RoleController extends Mage_Adminhtml_Controlle
 {
 
     /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
+
+    /**
      * Preparing layout for output
      *
      * @return Mage_Adminhtml_Permissions_RoleController
@@ -138,6 +149,13 @@ class Mage_Adminhtml_Permissions_RoleController extends Mage_Adminhtml_Controlle
     {
         $rid = $this->getRequest()->getParam('rid', false);
 
+        $role = $this->_initRole();
+        if (!$role->getId()) {
+            Mage::getSingleton('adminhtml/session')->addError($this->__('This Role no longer exists.'));
+            $this->_redirect('*/*/');
+            return;
+        }
+
         $currentUser = Mage::getModel('admin/user')->setId(Mage::getSingleton('admin/session')->getUser()->getId());
 
         if (in_array($rid, $currentUser->getRoles()) ) {
@@ -147,7 +165,7 @@ class Mage_Adminhtml_Permissions_RoleController extends Mage_Adminhtml_Controlle
         }
 
         try {
-            $role = $this->_initRole()->delete();
+            $role->delete();
 
             Mage::getSingleton('adminhtml/session')->addSuccess($this->__('The role has been deleted.'));
         } catch (Exception $e) {
diff --git a/app/code/core/Mage/Adminhtml/controllers/Permissions/UserController.php b/app/code/core/Mage/Adminhtml/controllers/Permissions/UserController.php
index 721bf0e..e92f1cc 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Permissions/UserController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Permissions/UserController.php
@@ -20,11 +20,21 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Adminhtml_Permissions_UserController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
 
     protected function _initAction()
     {
diff --git a/app/code/core/Mage/Adminhtml/controllers/Permissions/VariableController.php b/app/code/core/Mage/Adminhtml/controllers/Permissions/VariableController.php
index f508941..5a4ca4c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Permissions/VariableController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Permissions/VariableController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Poll/AnswerController.php b/app/code/core/Mage/Adminhtml/controllers/Poll/AnswerController.php
index 4f219cc..f7912dd 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Poll/AnswerController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Poll/AnswerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/PollController.php b/app/code/core/Mage/Adminhtml/controllers/PollController.php
index 0b1f801..2e727eb 100644
--- a/app/code/core/Mage/Adminhtml/controllers/PollController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/PollController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php b/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
index 174d126..9962530 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -40,6 +40,17 @@ class Mage_Adminhtml_Promo_CatalogController extends Mage_Adminhtml_Controller_A
      */
     protected $_dirtyRulesNoticeMessage;
 
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
+
     protected function _initAction()
     {
         $this->loadLayout()
@@ -194,6 +205,13 @@ class Mage_Adminhtml_Promo_CatalogController extends Mage_Adminhtml_Controller_A
             try {
                 $model = Mage::getModel('catalogrule/rule');
                 $model->load($id);
+                if (!$model->getRuleId()) {
+                    Mage::getSingleton('adminhtml/session')->addError(
+                        Mage::helper('catalogrule')->__('Unable to find a rule to delete.')
+                    );
+                    $this->_redirect('*/*/');
+                    return;
+                }
                 $model->delete();
                 Mage::getModel('catalogrule/flag')->loadSelf()
                     ->setState(1)
diff --git a/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php b/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
index f5e0dfd..e9b61cb 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
@@ -20,13 +20,25 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
 
 class Mage_Adminhtml_Promo_QuoteController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+    * Controller predispatch method
+    *
+    * @return Mage_Adminhtml_Controller_Action
+    */
+
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
+
     protected function _initRule()
     {
         $this->_title($this->__('Promotions'))->_title($this->__('Shopping Cart Price Rules'));
@@ -197,6 +209,15 @@ class Mage_Adminhtml_Promo_QuoteController extends Mage_Adminhtml_Controller_Act
             try {
                 $model = Mage::getModel('salesrule/rule');
                 $model->load($id);
+
+                if (!$model->getRuleId()) {
+                    Mage::getSingleton('adminhtml/session')->addError(
+                        Mage::helper('catalogrule')->__('Unable to find a rule to delete.')
+                    );
+                    $this->_redirect('*/*/');
+                    return;
+                }
+
                 $model->delete();
                 Mage::getSingleton('adminhtml/session')->addSuccess(
                     Mage::helper('salesrule')->__('The rule has been deleted.'));
@@ -217,12 +238,25 @@ class Mage_Adminhtml_Promo_QuoteController extends Mage_Adminhtml_Controller_Act
         $this->_redirect('*/*/');
     }
 
+    /**
+     * New condition HTML action
+     *
+     * @throws Mage_Core_Exception
+     * @return void
+     */
     public function newConditionHtmlAction()
     {
         $id = $this->getRequest()->getParam('id');
         $typeArr = explode('|', str_replace('-', '/', $this->getRequest()->getParam('type')));
         $type = $typeArr[0];
 
+        if (!$this->_validateRequestParams(array($id, $type))) {
+            if ($this->getRequest()->getQuery('id')) {
+                $this->getRequest()->setQuery('id', '');
+            }
+            Mage::throwException(Mage::helper('adminhtml')->__('An error occurred while adding condition.'));
+        }
+
         $model = Mage::getModel($type)
             ->setId($id)
             ->setType($type)
diff --git a/app/code/core/Mage/Adminhtml/controllers/Promo/WidgetController.php b/app/code/core/Mage/Adminhtml/controllers/Promo/WidgetController.php
index f361a63..acb5bd3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Promo/WidgetController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Promo/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/PromoController.php b/app/code/core/Mage/Adminhtml/controllers/PromoController.php
index e0a0fe8..93774a8 100644
--- a/app/code/core/Mage/Adminhtml/controllers/PromoController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/PromoController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/RatingController.php b/app/code/core/Mage/Adminhtml/controllers/RatingController.php
index c75d562..e575645 100644
--- a/app/code/core/Mage/Adminhtml/controllers/RatingController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/RatingController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/CustomerController.php b/app/code/core/Mage/Adminhtml/controllers/Report/CustomerController.php
index afa5294..ca6dccb 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/CustomerController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/ProductController.php b/app/code/core/Mage/Adminhtml/controllers/Report/ProductController.php
index a562e3e..57647c5 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/ProductController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/ReviewController.php b/app/code/core/Mage/Adminhtml/controllers/Report/ReviewController.php
index 609cc22..bc85abf 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/ReviewController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/ReviewController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/SalesController.php b/app/code/core/Mage/Adminhtml/controllers/Report/SalesController.php
index d840ef6..9f08b60 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/SalesController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/SalesController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/ShopcartController.php b/app/code/core/Mage/Adminhtml/controllers/Report/ShopcartController.php
index 8045558..758b2ee 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/ShopcartController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/ShopcartController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/StatisticsController.php b/app/code/core/Mage/Adminhtml/controllers/Report/StatisticsController.php
index 45f772a..1498ea3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/StatisticsController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/StatisticsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Report/TagController.php b/app/code/core/Mage/Adminhtml/controllers/Report/TagController.php
index fdfb6b1..32ad67b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Report/TagController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Report/TagController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/ReportController.php b/app/code/core/Mage/Adminhtml/controllers/ReportController.php
index 3640a42..211deb9 100644
--- a/app/code/core/Mage/Adminhtml/controllers/ReportController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/ReportController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Rss/CatalogController.php b/app/code/core/Mage/Adminhtml/controllers/Rss/CatalogController.php
index 4a02d6c..48b7f71 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Rss/CatalogController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Rss/CatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Rss/OrderController.php b/app/code/core/Mage/Adminhtml/controllers/Rss/OrderController.php
index d9e950a..8325777 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Rss/OrderController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Rss/OrderController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Billing/AgreementController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Billing/AgreementController.php
index 8d84fad..c0893f6 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Billing/AgreementController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Billing/AgreementController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/CreditmemoController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/CreditmemoController.php
index 25eade7..10906ad 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/CreditmemoController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/CreditmemoController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/InvoiceController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/InvoiceController.php
index 424c6d0..3d2d402 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/InvoiceController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/InvoiceController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
index 6b1567c..5ac3079 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreditmemoController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreditmemoController.php
index 567e70e..ef741ea 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreditmemoController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreditmemoController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/EditController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/EditController.php
index 6da9360..402177d 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/EditController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/EditController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/InvoiceController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/InvoiceController.php
index d249588..a2c1017 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/InvoiceController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/InvoiceController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/ShipmentController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/ShipmentController.php
index d15f60e..b2e5149 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/ShipmentController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/ShipmentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/StatusController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/StatusController.php
index f8fb33a..cdf1d0e 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/StatusController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/StatusController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/View/GiftmessageController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/View/GiftmessageController.php
index dc1bb99..8fd2806 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/View/GiftmessageController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/View/GiftmessageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/OrderController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/OrderController.php
index 2ae790c..7bdbbce 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/OrderController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/OrderController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Recurring/ProfileController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Recurring/ProfileController.php
index 5bfc9a0..244a732 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Recurring/ProfileController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Recurring/ProfileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/ShipmentController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/ShipmentController.php
index b3b2a56..5181981 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/ShipmentController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/ShipmentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/TransactionsController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/TransactionsController.php
index 9d76033..f9576c1 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/TransactionsController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/TransactionsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/SalesController.php b/app/code/core/Mage/Adminhtml/controllers/SalesController.php
index ce4b90b..8d5518f 100644
--- a/app/code/core/Mage/Adminhtml/controllers/SalesController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/SalesController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/SitemapController.php b/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
index 4bb55c8..9aba874 100644
--- a/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/SurveyController.php b/app/code/core/Mage/Adminhtml/controllers/SurveyController.php
index 10aea12..a10f16b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/SurveyController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/SurveyController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/AccountController.php b/app/code/core/Mage/Adminhtml/controllers/System/AccountController.php
index a5f2118..a50173b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/AccountController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/AccountController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/BackupController.php b/app/code/core/Mage/Adminhtml/controllers/System/BackupController.php
index 0f2dad0..86c01b8 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/BackupController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/BackupController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -40,7 +40,7 @@ class Mage_Adminhtml_System_BackupController extends Mage_Adminhtml_Controller_A
      */
     public function preDispatch()
     {
-        $this->_setForcedFormKeyActions('create');
+        $this->_setForcedFormKeyActions(array('create', 'massDelete'));
         return parent::preDispatch();
     }
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/CacheController.php b/app/code/core/Mage/Adminhtml/controllers/System/CacheController.php
index 3ae3241..a2da5f4 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/CacheController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/CacheController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/Config/System/StorageController.php b/app/code/core/Mage/Adminhtml/controllers/System/Config/System/StorageController.php
index 4f3b5cf..562504c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/Config/System/StorageController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/Config/System/StorageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/ConfigController.php b/app/code/core/Mage/Adminhtml/controllers/System/ConfigController.php
index b9f65dc..4951e6b 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/ConfigController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/ConfigController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/Convert/GuiController.php b/app/code/core/Mage/Adminhtml/controllers/System/Convert/GuiController.php
index 4ee2ce0..0c40ec3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/Convert/GuiController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/Convert/GuiController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/Convert/ProfileController.php b/app/code/core/Mage/Adminhtml/controllers/System/Convert/ProfileController.php
index 2074554..d8c021e 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/Convert/ProfileController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/Convert/ProfileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/CurrencyController.php b/app/code/core/Mage/Adminhtml/controllers/System/CurrencyController.php
index 16eb2d9..9ab7dce 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/CurrencyController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/CurrencyController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/DesignController.php b/app/code/core/Mage/Adminhtml/controllers/System/DesignController.php
index e90b4e1..c8ac0a3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/DesignController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/DesignController.php
@@ -20,13 +20,24 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
 
 class Mage_Adminhtml_System_DesignController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
+
     public function indexAction()
     {
         $this->_title($this->__('System'))->_title($this->__('Design'));
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php b/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
index ec636d2..2bd9f96 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/StoreController.php b/app/code/core/Mage/Adminhtml/controllers/System/StoreController.php
index b628a97..eb7a9e3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/StoreController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/StoreController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/VariableController.php b/app/code/core/Mage/Adminhtml/controllers/System/VariableController.php
index aeb99d6..dcb615a 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/VariableController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/VariableController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/SystemController.php b/app/code/core/Mage/Adminhtml/controllers/SystemController.php
index 45d18a8..eb91cba 100644
--- a/app/code/core/Mage/Adminhtml/controllers/SystemController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/SystemController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/TagController.php b/app/code/core/Mage/Adminhtml/controllers/TagController.php
index 9074aef..3bc78ff 100644
--- a/app/code/core/Mage/Adminhtml/controllers/TagController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/TagController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Tax/Class/CustomerController.php b/app/code/core/Mage/Adminhtml/controllers/Tax/Class/CustomerController.php
index 46e47d1..1fb09bf 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Tax/Class/CustomerController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Tax/Class/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Tax/Class/ProductController.php b/app/code/core/Mage/Adminhtml/controllers/Tax/Class/ProductController.php
index 6a43a1b..3a86caf 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Tax/Class/ProductController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Tax/Class/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Tax/ClassController.php b/app/code/core/Mage/Adminhtml/controllers/Tax/ClassController.php
index 513ef20..edcf797 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Tax/ClassController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Tax/ClassController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Tax/RateController.php b/app/code/core/Mage/Adminhtml/controllers/Tax/RateController.php
index 7b1eb89..e75ccb5 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Tax/RateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Tax/RateController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/Tax/RuleController.php b/app/code/core/Mage/Adminhtml/controllers/Tax/RuleController.php
index 4c900be..765d277 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Tax/RuleController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Tax/RuleController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/TaxController.php b/app/code/core/Mage/Adminhtml/controllers/TaxController.php
index 29eef1b..c431824 100644
--- a/app/code/core/Mage/Adminhtml/controllers/TaxController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/TaxController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/controllers/UrlrewriteController.php b/app/code/core/Mage/Adminhtml/controllers/UrlrewriteController.php
index 0867f78..ffde3f2 100644
--- a/app/code/core/Mage/Adminhtml/controllers/UrlrewriteController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/UrlrewriteController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Adminhtml/etc/adminhtml.xml b/app/code/core/Mage/Adminhtml/etc/adminhtml.xml
index 7d07093..3627b4b 100644
--- a/app/code/core/Mage/Adminhtml/etc/adminhtml.xml
+++ b/app/code/core/Mage/Adminhtml/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Adminhtml/etc/config.xml b/app/code/core/Mage/Adminhtml/etc/config.xml
index 9a414de..3a0aa4a 100644
--- a/app/code/core/Mage/Adminhtml/etc/config.xml
+++ b/app/code/core/Mage/Adminhtml/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Adminhtml/etc/jstranslator.xml b/app/code/core/Mage/Adminhtml/etc/jstranslator.xml
index 84f83f1..e8232e8 100644
--- a/app/code/core/Mage/Adminhtml/etc/jstranslator.xml
+++ b/app/code/core/Mage/Adminhtml/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api/Controller/Action.php b/app/code/core/Mage/Api/Controller/Action.php
index d2da4e7..53a2d14 100644
--- a/app/code/core/Mage/Api/Controller/Action.php
+++ b/app/code/core/Mage/Api/Controller/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Exception.php b/app/code/core/Mage/Api/Exception.php
index 390e98a..63d0618 100644
--- a/app/code/core/Mage/Api/Exception.php
+++ b/app/code/core/Mage/Api/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Helper/Data.php b/app/code/core/Mage/Api/Helper/Data.php
index 2c58af6..416c12c 100644
--- a/app/code/core/Mage/Api/Helper/Data.php
+++ b/app/code/core/Mage/Api/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl.php b/app/code/core/Mage/Api/Model/Acl.php
index 63eec29..4f451f3 100644
--- a/app/code/core/Mage/Api/Model/Acl.php
+++ b/app/code/core/Mage/Api/Model/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Assert/Ip.php b/app/code/core/Mage/Api/Model/Acl/Assert/Ip.php
index 6c7ef72..5ee6ddf 100644
--- a/app/code/core/Mage/Api/Model/Acl/Assert/Ip.php
+++ b/app/code/core/Mage/Api/Model/Acl/Assert/Ip.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Assert/Time.php b/app/code/core/Mage/Api/Model/Acl/Assert/Time.php
index 71fec82..65275a7 100644
--- a/app/code/core/Mage/Api/Model/Acl/Assert/Time.php
+++ b/app/code/core/Mage/Api/Model/Acl/Assert/Time.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Resource.php b/app/code/core/Mage/Api/Model/Acl/Resource.php
index 6d8663a..0666709 100644
--- a/app/code/core/Mage/Api/Model/Acl/Resource.php
+++ b/app/code/core/Mage/Api/Model/Acl/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Role.php b/app/code/core/Mage/Api/Model/Acl/Role.php
index 6f002fe..bae3247 100644
--- a/app/code/core/Mage/Api/Model/Acl/Role.php
+++ b/app/code/core/Mage/Api/Model/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Role/Generic.php b/app/code/core/Mage/Api/Model/Acl/Role/Generic.php
index 696847d..d8a8a24 100644
--- a/app/code/core/Mage/Api/Model/Acl/Role/Generic.php
+++ b/app/code/core/Mage/Api/Model/Acl/Role/Generic.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Role/Group.php b/app/code/core/Mage/Api/Model/Acl/Role/Group.php
index ec96f4b..ca1c9f5 100644
--- a/app/code/core/Mage/Api/Model/Acl/Role/Group.php
+++ b/app/code/core/Mage/Api/Model/Acl/Role/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Role/Registry.php b/app/code/core/Mage/Api/Model/Acl/Role/Registry.php
index daf4f21..b771379 100644
--- a/app/code/core/Mage/Api/Model/Acl/Role/Registry.php
+++ b/app/code/core/Mage/Api/Model/Acl/Role/Registry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Acl/Role/User.php b/app/code/core/Mage/Api/Model/Acl/Role/User.php
index 6c98a98..ef50239 100644
--- a/app/code/core/Mage/Api/Model/Acl/Role/User.php
+++ b/app/code/core/Mage/Api/Model/Acl/Role/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Config.php b/app/code/core/Mage/Api/Model/Config.php
index 9450ee4..ced0c02 100644
--- a/app/code/core/Mage/Api/Model/Config.php
+++ b/app/code/core/Mage/Api/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Acl.php b/app/code/core/Mage/Api/Model/Mysql4/Acl.php
index efbb68d..c79cbdc 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Acl.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Acl/Role.php b/app/code/core/Mage/Api/Model/Mysql4/Acl/Role.php
index 5dffd5b..f8413bc 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Acl/Role.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Acl/Role/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Acl/Role/Collection.php
index f76b836..757e5b1 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Acl/Role/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Acl/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Permissions/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Permissions/Collection.php
index 09f468b..4adbb09 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Permissions/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Permissions/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Role.php b/app/code/core/Mage/Api/Model/Mysql4/Role.php
index 506b566..35dba18 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Role.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Role/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Role/Collection.php
index e9122b1..3b6d132 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Role/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Roles.php b/app/code/core/Mage/Api/Model/Mysql4/Roles.php
index 8de7a61..4c2a724 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Roles.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Roles/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Roles/Collection.php
index 8ff9780..4067f3e 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Roles/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Roles/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Roles/User/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Roles/User/Collection.php
index b30b33c..67aa16b 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Roles/User/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Roles/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Rules.php b/app/code/core/Mage/Api/Model/Mysql4/Rules.php
index d1e3c7e..34da478 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Rules.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/Rules/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/Rules/Collection.php
index 85904cd..c26d7c5 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/Rules/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/Rules/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/User.php b/app/code/core/Mage/Api/Model/Mysql4/User.php
index 7386069..72e6a95 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/User.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Mysql4/User/Collection.php b/app/code/core/Mage/Api/Model/Mysql4/User/Collection.php
index d4d2355..e2e91ca 100644
--- a/app/code/core/Mage/Api/Model/Mysql4/User/Collection.php
+++ b/app/code/core/Mage/Api/Model/Mysql4/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Abstract.php b/app/code/core/Mage/Api/Model/Resource/Abstract.php
index 868a073..7b18980 100644
--- a/app/code/core/Mage/Api/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Api/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Acl.php b/app/code/core/Mage/Api/Model/Resource/Acl.php
index b1705f5..b68e544 100644
--- a/app/code/core/Mage/Api/Model/Resource/Acl.php
+++ b/app/code/core/Mage/Api/Model/Resource/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Acl/Role.php b/app/code/core/Mage/Api/Model/Resource/Acl/Role.php
index e798751..fc9d5f5 100644
--- a/app/code/core/Mage/Api/Model/Resource/Acl/Role.php
+++ b/app/code/core/Mage/Api/Model/Resource/Acl/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Acl/Role/Collection.php b/app/code/core/Mage/Api/Model/Resource/Acl/Role/Collection.php
index 890ed65..7f238bc 100644
--- a/app/code/core/Mage/Api/Model/Resource/Acl/Role/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Acl/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Permissions/Collection.php b/app/code/core/Mage/Api/Model/Resource/Permissions/Collection.php
index 98d216d..de04215 100644
--- a/app/code/core/Mage/Api/Model/Resource/Permissions/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Permissions/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Role.php b/app/code/core/Mage/Api/Model/Resource/Role.php
index 0219c45..72179f4 100644
--- a/app/code/core/Mage/Api/Model/Resource/Role.php
+++ b/app/code/core/Mage/Api/Model/Resource/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Role/Collection.php b/app/code/core/Mage/Api/Model/Resource/Role/Collection.php
index 7089f66..7cd1535 100644
--- a/app/code/core/Mage/Api/Model/Resource/Role/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Roles.php b/app/code/core/Mage/Api/Model/Resource/Roles.php
index 76d1db3..7bd0345 100644
--- a/app/code/core/Mage/Api/Model/Resource/Roles.php
+++ b/app/code/core/Mage/Api/Model/Resource/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Roles/Collection.php b/app/code/core/Mage/Api/Model/Resource/Roles/Collection.php
index 07c8ca1..bc6a91e 100644
--- a/app/code/core/Mage/Api/Model/Resource/Roles/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Roles/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Roles/User/Collection.php b/app/code/core/Mage/Api/Model/Resource/Roles/User/Collection.php
index 435cb8b..13d2532 100644
--- a/app/code/core/Mage/Api/Model/Resource/Roles/User/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Roles/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Rules.php b/app/code/core/Mage/Api/Model/Resource/Rules.php
index 740b48d..3668b16 100644
--- a/app/code/core/Mage/Api/Model/Resource/Rules.php
+++ b/app/code/core/Mage/Api/Model/Resource/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/Rules/Collection.php b/app/code/core/Mage/Api/Model/Resource/Rules/Collection.php
index 176b6b8..8f92b8e 100644
--- a/app/code/core/Mage/Api/Model/Resource/Rules/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/Rules/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/User.php b/app/code/core/Mage/Api/Model/Resource/User.php
index a2761d2..f6e9278 100644
--- a/app/code/core/Mage/Api/Model/Resource/User.php
+++ b/app/code/core/Mage/Api/Model/Resource/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Resource/User/Collection.php b/app/code/core/Mage/Api/Model/Resource/User/Collection.php
index 1bc14fe..fa4968e 100644
--- a/app/code/core/Mage/Api/Model/Resource/User/Collection.php
+++ b/app/code/core/Mage/Api/Model/Resource/User/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Role.php b/app/code/core/Mage/Api/Model/Role.php
index 1c2890d..5a1323d 100644
--- a/app/code/core/Mage/Api/Model/Role.php
+++ b/app/code/core/Mage/Api/Model/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Roles.php b/app/code/core/Mage/Api/Model/Roles.php
index a389d24..3ae38d0 100644
--- a/app/code/core/Mage/Api/Model/Roles.php
+++ b/app/code/core/Mage/Api/Model/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Rules.php b/app/code/core/Mage/Api/Model/Rules.php
index 9f5d35e..c5ff981 100644
--- a/app/code/core/Mage/Api/Model/Rules.php
+++ b/app/code/core/Mage/Api/Model/Rules.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server.php b/app/code/core/Mage/Api/Model/Server.php
index d7fac4d..165f0d8 100644
--- a/app/code/core/Mage/Api/Model/Server.php
+++ b/app/code/core/Mage/Api/Model/Server.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Adapter/Interface.php b/app/code/core/Mage/Api/Model/Server/Adapter/Interface.php
index d9cf82e..3551bff 100644
--- a/app/code/core/Mage/Api/Model/Server/Adapter/Interface.php
+++ b/app/code/core/Mage/Api/Model/Server/Adapter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Adapter/Soap.php b/app/code/core/Mage/Api/Model/Server/Adapter/Soap.php
index 0292463..e3874ce 100644
--- a/app/code/core/Mage/Api/Model/Server/Adapter/Soap.php
+++ b/app/code/core/Mage/Api/Model/Server/Adapter/Soap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Adapter/Xmlrpc.php b/app/code/core/Mage/Api/Model/Server/Adapter/Xmlrpc.php
index b4a0241..cbca092 100644
--- a/app/code/core/Mage/Api/Model/Server/Adapter/Xmlrpc.php
+++ b/app/code/core/Mage/Api/Model/Server/Adapter/Xmlrpc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Handler.php b/app/code/core/Mage/Api/Model/Server/Handler.php
index 6d8d418..35640bc 100644
--- a/app/code/core/Mage/Api/Model/Server/Handler.php
+++ b/app/code/core/Mage/Api/Model/Server/Handler.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Handler/Abstract.php b/app/code/core/Mage/Api/Model/Server/Handler/Abstract.php
index e67220f..2d38e80 100644
--- a/app/code/core/Mage/Api/Model/Server/Handler/Abstract.php
+++ b/app/code/core/Mage/Api/Model/Server/Handler/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/V2/Adapter/Soap.php b/app/code/core/Mage/Api/Model/Server/V2/Adapter/Soap.php
index d30c7ee..ac64c7a 100644
--- a/app/code/core/Mage/Api/Model/Server/V2/Adapter/Soap.php
+++ b/app/code/core/Mage/Api/Model/Server/V2/Adapter/Soap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/V2/Handler.php b/app/code/core/Mage/Api/Model/Server/V2/Handler.php
index c8f322c..34f1183 100644
--- a/app/code/core/Mage/Api/Model/Server/V2/Handler.php
+++ b/app/code/core/Mage/Api/Model/Server/V2/Handler.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Wsi/Adapter/Soap.php b/app/code/core/Mage/Api/Model/Server/Wsi/Adapter/Soap.php
index dcbd861..f8d1a9b 100644
--- a/app/code/core/Mage/Api/Model/Server/Wsi/Adapter/Soap.php
+++ b/app/code/core/Mage/Api/Model/Server/Wsi/Adapter/Soap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Server/Wsi/Handler.php b/app/code/core/Mage/Api/Model/Server/Wsi/Handler.php
index 67d5bbf..7937be0 100644
--- a/app/code/core/Mage/Api/Model/Server/Wsi/Handler.php
+++ b/app/code/core/Mage/Api/Model/Server/Wsi/Handler.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Session.php b/app/code/core/Mage/Api/Model/Session.php
index 39c9739..39131d2 100644
--- a/app/code/core/Mage/Api/Model/Session.php
+++ b/app/code/core/Mage/Api/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/User.php b/app/code/core/Mage/Api/Model/User.php
index 2bc6320..954e8c2 100644
--- a/app/code/core/Mage/Api/Model/User.php
+++ b/app/code/core/Mage/Api/Model/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Wsdl/Config.php b/app/code/core/Mage/Api/Model/Wsdl/Config.php
index 6f1894e..b1bdd3f 100644
--- a/app/code/core/Mage/Api/Model/Wsdl/Config.php
+++ b/app/code/core/Mage/Api/Model/Wsdl/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Wsdl/Config/Base.php b/app/code/core/Mage/Api/Model/Wsdl/Config/Base.php
index 5056d44..4089698 100644
--- a/app/code/core/Mage/Api/Model/Wsdl/Config/Base.php
+++ b/app/code/core/Mage/Api/Model/Wsdl/Config/Base.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/Model/Wsdl/Config/Element.php b/app/code/core/Mage/Api/Model/Wsdl/Config/Element.php
index 84ad757..c9f4eb3 100644
--- a/app/code/core/Mage/Api/Model/Wsdl/Config/Element.php
+++ b/app/code/core/Mage/Api/Model/Wsdl/Config/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/controllers/IndexController.php b/app/code/core/Mage/Api/controllers/IndexController.php
index 562a205..d0a74fc 100644
--- a/app/code/core/Mage/Api/controllers/IndexController.php
+++ b/app/code/core/Mage/Api/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/controllers/SoapController.php b/app/code/core/Mage/Api/controllers/SoapController.php
index 4396878..3067f88 100644
--- a/app/code/core/Mage/Api/controllers/SoapController.php
+++ b/app/code/core/Mage/Api/controllers/SoapController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/controllers/V2/SoapController.php b/app/code/core/Mage/Api/controllers/V2/SoapController.php
index 849d403..fa6ddd0 100644
--- a/app/code/core/Mage/Api/controllers/V2/SoapController.php
+++ b/app/code/core/Mage/Api/controllers/V2/SoapController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/controllers/XmlrpcController.php b/app/code/core/Mage/Api/controllers/XmlrpcController.php
index 19cd44e..33079af 100644
--- a/app/code/core/Mage/Api/controllers/XmlrpcController.php
+++ b/app/code/core/Mage/Api/controllers/XmlrpcController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/etc/adminhtml.xml b/app/code/core/Mage/Api/etc/adminhtml.xml
index 730d5a2..b3a82cc 100644
--- a/app/code/core/Mage/Api/etc/adminhtml.xml
+++ b/app/code/core/Mage/Api/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api/etc/api.xml b/app/code/core/Mage/Api/etc/api.xml
index 16f8717..6123a8a 100644
--- a/app/code/core/Mage/Api/etc/api.xml
+++ b/app/code/core/Mage/Api/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api/etc/config.xml b/app/code/core/Mage/Api/etc/config.xml
index 147c51d..a69229b 100644
--- a/app/code/core/Mage/Api/etc/config.xml
+++ b/app/code/core/Mage/Api/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api/etc/system.xml b/app/code/core/Mage/Api/etc/system.xml
index cb9db86..c079d0e 100644
--- a/app/code/core/Mage/Api/etc/system.xml
+++ b/app/code/core/Mage/Api/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api/sql/api_setup/install-1.6.0.0.php b/app/code/core/Mage/Api/sql/api_setup/install-1.6.0.0.php
index f98c6c2..87ddb20 100644
--- a/app/code/core/Mage/Api/sql/api_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Api/sql/api_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/sql/api_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Api/sql/api_setup/mysql4-install-0.7.0.php
index 77f9909..56d5e4d 100644
--- a/app/code/core/Mage/Api/sql/api_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Api/sql/api_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 5d7e8cc..aeb8861 100644
--- a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.8.0-0.8.1.php
index 1a9cd4d..2c9842f 100644
--- a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 0cec201..a5b0610 100644
--- a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
index 6e4753f..c756fd7 100644
--- a/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Api/sql/api_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute.php
index 703bc2b..c89f8fd 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Buttons.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Buttons.php
index ecb44d3..b720be8 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Buttons.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Buttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit.php
index 50ca1e7..b8db261 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit/Form.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit/Form.php
index c97cbd5..42e1632 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit/Form.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Grid.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Grid.php
index 46907fa..f622e82 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Grid.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tab/Resource.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tab/Resource.php
index bff4701..97ead88 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tab/Resource.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tab/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tabs.php b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tabs.php
index d7cb2a8..bb3f942 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tabs.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Attribute/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Permissions/User/Edit/Tab/Roles.php b/app/code/core/Mage/Api2/Block/Adminhtml/Permissions/User/Edit/Tab/Roles.php
index 42f1cd4..e24fa37 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Permissions/User/Edit/Tab/Roles.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Permissions/User/Edit/Tab/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles.php
index 73df528..0f6b630 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Buttons.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Buttons.php
index 4b90dfd..891eac6 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Buttons.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Buttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -126,7 +126,7 @@ class Mage_Api2_Block_Adminhtml_Roles_Buttons extends Mage_Adminhtml_Block_Templ
 
         $this->getChild('deleteButton')->setData('onclick', sprintf("deleteConfirm('%s', '%s')",
             Mage::helper('core')->jsQuoteEscape(Mage::helper('adminhtml')->__('Are you sure you want to do this?')),
-            $this->getUrl('*/*/delete', array('id' => $this->getRole()->getId()))
+            $this->getUrlSecure('*/*/delete', array('id' => $this->getRole()->getId()))
         ));
 
         return $this->getChildHtml('deleteButton');
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Grid.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Grid.php
index 6605c15..b0b6153 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Grid.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Info.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Info.php
index 9913ecb..cca480d 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Info.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Resources.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Resources.php
index 86637af..6452029 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Resources.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Resources.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Users.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Users.php
index 9667622..12e9e9c 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Users.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tab/Users.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tabs.php b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tabs.php
index 168aac2..4dcf38e 100644
--- a/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tabs.php
+++ b/app/code/core/Mage/Api2/Block/Adminhtml/Roles/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Exception.php b/app/code/core/Mage/Api2/Exception.php
index 36e2a63..79eb625 100644
--- a/app/code/core/Mage/Api2/Exception.php
+++ b/app/code/core/Mage/Api2/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Helper/Data.php b/app/code/core/Mage/Api2/Helper/Data.php
index 708bbab..0340851 100644
--- a/app/code/core/Mage/Api2/Helper/Data.php
+++ b/app/code/core/Mage/Api2/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl.php b/app/code/core/Mage/Api2/Model/Acl.php
index efe782b..fc03233 100644
--- a/app/code/core/Mage/Api2/Model/Acl.php
+++ b/app/code/core/Mage/Api2/Model/Acl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Filter.php b/app/code/core/Mage/Api2/Model/Acl/Filter.php
index dd07c0c..f570f69 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Filter.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute.php b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute.php
index 2d86be9..ae6b9a0 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/Operation.php b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/Operation.php
index 1a4e583..1f8235d 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/Operation.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/Operation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/ResourcePermission.php b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/ResourcePermission.php
index bdb46b5..3cd2d00 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/ResourcePermission.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Filter/Attribute/ResourcePermission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global.php b/app/code/core/Mage/Api2/Model/Acl/Global.php
index a4ae371..88a5ee8 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Role.php b/app/code/core/Mage/Api2/Model/Acl/Global/Role.php
index 6c1e505..4c5ac3d 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Role.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Rule.php b/app/code/core/Mage/Api2/Model/Acl/Global/Rule.php
index 4c6df96..dbb32ec 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Rule.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Permission.php b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Permission.php
index 1df20ff..517d44d 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Permission.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Permission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Privilege.php b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Privilege.php
index 7757da8..bac0f43 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Privilege.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Privilege.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/ResourcePermission.php b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/ResourcePermission.php
index d829953..8cad06b 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/ResourcePermission.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/ResourcePermission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Tree.php b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Tree.php
index 40e948b..d8cc891 100644
--- a/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Tree.php
+++ b/app/code/core/Mage/Api2/Model/Acl/Global/Rule/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Acl/PermissionInterface.php b/app/code/core/Mage/Api2/Model/Acl/PermissionInterface.php
index b52fe82..4716729 100644
--- a/app/code/core/Mage/Api2/Model/Acl/PermissionInterface.php
+++ b/app/code/core/Mage/Api2/Model/Acl/PermissionInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth.php b/app/code/core/Mage/Api2/Model/Auth.php
index 420504a..56650e9 100644
--- a/app/code/core/Mage/Api2/Model/Auth.php
+++ b/app/code/core/Mage/Api2/Model/Auth.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/Adapter.php b/app/code/core/Mage/Api2/Model/Auth/Adapter.php
index ce5d653..f191c90 100644
--- a/app/code/core/Mage/Api2/Model/Auth/Adapter.php
+++ b/app/code/core/Mage/Api2/Model/Auth/Adapter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/Adapter/Abstract.php b/app/code/core/Mage/Api2/Model/Auth/Adapter/Abstract.php
index 5f5ac7b..452ec3a 100644
--- a/app/code/core/Mage/Api2/Model/Auth/Adapter/Abstract.php
+++ b/app/code/core/Mage/Api2/Model/Auth/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/Adapter/Oauth.php b/app/code/core/Mage/Api2/Model/Auth/Adapter/Oauth.php
index 4703020..c7b7888 100644
--- a/app/code/core/Mage/Api2/Model/Auth/Adapter/Oauth.php
+++ b/app/code/core/Mage/Api2/Model/Auth/Adapter/Oauth.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/User.php b/app/code/core/Mage/Api2/Model/Auth/User.php
index a579950..0dfcdeb 100644
--- a/app/code/core/Mage/Api2/Model/Auth/User.php
+++ b/app/code/core/Mage/Api2/Model/Auth/User.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/User/Abstract.php b/app/code/core/Mage/Api2/Model/Auth/User/Abstract.php
index 2f1b906..4fcfcc1 100644
--- a/app/code/core/Mage/Api2/Model/Auth/User/Abstract.php
+++ b/app/code/core/Mage/Api2/Model/Auth/User/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/User/Admin.php b/app/code/core/Mage/Api2/Model/Auth/User/Admin.php
index c5db332..e383c73 100644
--- a/app/code/core/Mage/Api2/Model/Auth/User/Admin.php
+++ b/app/code/core/Mage/Api2/Model/Auth/User/Admin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/User/Customer.php b/app/code/core/Mage/Api2/Model/Auth/User/Customer.php
index b035790..10fb232 100644
--- a/app/code/core/Mage/Api2/Model/Auth/User/Customer.php
+++ b/app/code/core/Mage/Api2/Model/Auth/User/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Auth/User/Guest.php b/app/code/core/Mage/Api2/Model/Auth/User/Guest.php
index 2ca0c21..81e8cda 100644
--- a/app/code/core/Mage/Api2/Model/Auth/User/Guest.php
+++ b/app/code/core/Mage/Api2/Model/Auth/User/Guest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Config.php b/app/code/core/Mage/Api2/Model/Config.php
index 1828ead..c0db199 100644
--- a/app/code/core/Mage/Api2/Model/Config.php
+++ b/app/code/core/Mage/Api2/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Dispatcher.php b/app/code/core/Mage/Api2/Model/Dispatcher.php
index d0e2f01..b6addc1 100644
--- a/app/code/core/Mage/Api2/Model/Dispatcher.php
+++ b/app/code/core/Mage/Api2/Model/Dispatcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Multicall.php b/app/code/core/Mage/Api2/Model/Multicall.php
index 2ba33d1..f2f3e5e 100644
--- a/app/code/core/Mage/Api2/Model/Multicall.php
+++ b/app/code/core/Mage/Api2/Model/Multicall.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Observer.php b/app/code/core/Mage/Api2/Model/Observer.php
index 37d8c32..16ec398 100644
--- a/app/code/core/Mage/Api2/Model/Observer.php
+++ b/app/code/core/Mage/Api2/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer.php b/app/code/core/Mage/Api2/Model/Renderer.php
index 5fedc44..7870722 100644
--- a/app/code/core/Mage/Api2/Model/Renderer.php
+++ b/app/code/core/Mage/Api2/Model/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer/Interface.php b/app/code/core/Mage/Api2/Model/Renderer/Interface.php
index 6874426..26e344a 100644
--- a/app/code/core/Mage/Api2/Model/Renderer/Interface.php
+++ b/app/code/core/Mage/Api2/Model/Renderer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer/Json.php b/app/code/core/Mage/Api2/Model/Renderer/Json.php
index 545ab39..3483e13 100644
--- a/app/code/core/Mage/Api2/Model/Renderer/Json.php
+++ b/app/code/core/Mage/Api2/Model/Renderer/Json.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer/Query.php b/app/code/core/Mage/Api2/Model/Renderer/Query.php
index 5d359a5..fe31aff 100644
--- a/app/code/core/Mage/Api2/Model/Renderer/Query.php
+++ b/app/code/core/Mage/Api2/Model/Renderer/Query.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer/Xml.php b/app/code/core/Mage/Api2/Model/Renderer/Xml.php
index 4466826..4c36b91 100644
--- a/app/code/core/Mage/Api2/Model/Renderer/Xml.php
+++ b/app/code/core/Mage/Api2/Model/Renderer/Xml.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Renderer/Xml/Writer.php b/app/code/core/Mage/Api2/Model/Renderer/Xml/Writer.php
index f29b6bb..2567dc4 100644
--- a/app/code/core/Mage/Api2/Model/Renderer/Xml/Writer.php
+++ b/app/code/core/Mage/Api2/Model/Renderer/Xml/Writer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request.php b/app/code/core/Mage/Api2/Model/Request.php
index bce6e47..1694f04 100644
--- a/app/code/core/Mage/Api2/Model/Request.php
+++ b/app/code/core/Mage/Api2/Model/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Internal.php b/app/code/core/Mage/Api2/Model/Request/Internal.php
index 57f699e..59d0ddd3 100644
--- a/app/code/core/Mage/Api2/Model/Request/Internal.php
+++ b/app/code/core/Mage/Api2/Model/Request/Internal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Interpreter.php b/app/code/core/Mage/Api2/Model/Request/Interpreter.php
index 440e410..b6a3e23 100644
--- a/app/code/core/Mage/Api2/Model/Request/Interpreter.php
+++ b/app/code/core/Mage/Api2/Model/Request/Interpreter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Interpreter/Interface.php b/app/code/core/Mage/Api2/Model/Request/Interpreter/Interface.php
index 48897f3..fce216c 100644
--- a/app/code/core/Mage/Api2/Model/Request/Interpreter/Interface.php
+++ b/app/code/core/Mage/Api2/Model/Request/Interpreter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Interpreter/Json.php b/app/code/core/Mage/Api2/Model/Request/Interpreter/Json.php
index 7a75414..6349192 100644
--- a/app/code/core/Mage/Api2/Model/Request/Interpreter/Json.php
+++ b/app/code/core/Mage/Api2/Model/Request/Interpreter/Json.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Interpreter/Query.php b/app/code/core/Mage/Api2/Model/Request/Interpreter/Query.php
index 583d111..2cc87f0 100644
--- a/app/code/core/Mage/Api2/Model/Request/Interpreter/Query.php
+++ b/app/code/core/Mage/Api2/Model/Request/Interpreter/Query.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Request/Interpreter/Xml.php b/app/code/core/Mage/Api2/Model/Request/Interpreter/Xml.php
index d64c018..2b88ec8 100644
--- a/app/code/core/Mage/Api2/Model/Request/Interpreter/Xml.php
+++ b/app/code/core/Mage/Api2/Model/Request/Interpreter/Xml.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource.php b/app/code/core/Mage/Api2/Model/Resource.php
index 1816c19..58d8750 100644
--- a/app/code/core/Mage/Api2/Model/Resource.php
+++ b/app/code/core/Mage/Api2/Model/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute.php
index 191598a..03c7300 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute/Collection.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute/Collection.php
index 4999ea8..b281189 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute/Collection.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Filter/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role.php
index e547505..4d2a60b 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role/Collection.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role/Collection.php
index 4074a82..812646f 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role/Collection.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Role/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule.php
index 0ca08a5..624e20b 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule/Collection.php b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule/Collection.php
index 8c548e0..d1da918 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule/Collection.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Acl/Global/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Setup.php b/app/code/core/Mage/Api2/Model/Resource/Setup.php
index 102df78..f55ea84 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Validator.php b/app/code/core/Mage/Api2/Model/Resource/Validator.php
index efbe02a..a26f76b 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Validator.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Validator/Eav.php b/app/code/core/Mage/Api2/Model/Resource/Validator/Eav.php
index 5b59c4a..5453a64 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Validator/Eav.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Validator/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Resource/Validator/Fields.php b/app/code/core/Mage/Api2/Model/Resource/Validator/Fields.php
index fd71e17..7dfab1f 100644
--- a/app/code/core/Mage/Api2/Model/Resource/Validator/Fields.php
+++ b/app/code/core/Mage/Api2/Model/Resource/Validator/Fields.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Response.php b/app/code/core/Mage/Api2/Model/Response.php
index 09eb98e..05b9895 100644
--- a/app/code/core/Mage/Api2/Model/Response.php
+++ b/app/code/core/Mage/Api2/Model/Response.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Route/Abstract.php b/app/code/core/Mage/Api2/Model/Route/Abstract.php
index c56d8fa..08d516f 100644
--- a/app/code/core/Mage/Api2/Model/Route/Abstract.php
+++ b/app/code/core/Mage/Api2/Model/Route/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Route/ApiType.php b/app/code/core/Mage/Api2/Model/Route/ApiType.php
index 2ee1162..4a810ed 100644
--- a/app/code/core/Mage/Api2/Model/Route/ApiType.php
+++ b/app/code/core/Mage/Api2/Model/Route/ApiType.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Route/Interface.php b/app/code/core/Mage/Api2/Model/Route/Interface.php
index 842fde7..933fbda 100644
--- a/app/code/core/Mage/Api2/Model/Route/Interface.php
+++ b/app/code/core/Mage/Api2/Model/Route/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Route/Rest.php b/app/code/core/Mage/Api2/Model/Route/Rest.php
index 3f7df39..d3f5a8e 100644
--- a/app/code/core/Mage/Api2/Model/Route/Rest.php
+++ b/app/code/core/Mage/Api2/Model/Route/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Router.php b/app/code/core/Mage/Api2/Model/Router.php
index ffe124f..0c50c39 100644
--- a/app/code/core/Mage/Api2/Model/Router.php
+++ b/app/code/core/Mage/Api2/Model/Router.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/Model/Server.php b/app/code/core/Mage/Api2/Model/Server.php
index d426b56..8ab1c73 100644
--- a/app/code/core/Mage/Api2/Model/Server.php
+++ b/app/code/core/Mage/Api2/Model/Server.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/AttributeController.php b/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/AttributeController.php
index 2f6ff30..4c00028 100644
--- a/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/AttributeController.php
+++ b/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/AttributeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -34,6 +34,17 @@
 class Mage_Api2_Adminhtml_Api2_AttributeController extends Mage_Adminhtml_Controller_Action
 {
     /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions(array('save'));
+        return parent::preDispatch();
+    }
+
+    /**
      * Show user types grid
      */
     public function indexAction()
diff --git a/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/RoleController.php b/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/RoleController.php
index 2c6f485..995da3f 100644
--- a/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/RoleController.php
+++ b/app/code/core/Mage/Api2/controllers/Adminhtml/Api2/RoleController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -34,6 +34,17 @@
 class Mage_Api2_Adminhtml_Api2_RoleController extends Mage_Adminhtml_Controller_Action
 {
     /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions(array('delete', 'save'));
+        return parent::preDispatch();
+    }
+
+    /**
      * Show grid
      */
     public function indexAction()
diff --git a/app/code/core/Mage/Api2/etc/adminhtml.xml b/app/code/core/Mage/Api2/etc/adminhtml.xml
index 7185500..ecf8488 100644
--- a/app/code/core/Mage/Api2/etc/adminhtml.xml
+++ b/app/code/core/Mage/Api2/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api2/etc/config.xml b/app/code/core/Mage/Api2/etc/config.xml
index 5e1345a..6c602c9 100644
--- a/app/code/core/Mage/Api2/etc/config.xml
+++ b/app/code/core/Mage/Api2/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Api2/sql/api2_setup/install-1.0.0.0.php b/app/code/core/Mage/Api2/sql/api2_setup/install-1.0.0.0.php
index a8eac5b..39c493b 100644
--- a/app/code/core/Mage/Api2/sql/api2_setup/install-1.0.0.0.php
+++ b/app/code/core/Mage/Api2/sql/api2_setup/install-1.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/app/code/core/Mage/Authorizenet/Block/Directpost/Form.php b/app/code/core/Mage/Authorizenet/Block/Directpost/Form.php
index e1df055..8d21a36 100644
--- a/app/code/core/Mage/Authorizenet/Block/Directpost/Form.php
+++ b/app/code/core/Mage/Authorizenet/Block/Directpost/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Block/Directpost/Iframe.php b/app/code/core/Mage/Authorizenet/Block/Directpost/Iframe.php
index 7fe83e7..78a19f8 100644
--- a/app/code/core/Mage/Authorizenet/Block/Directpost/Iframe.php
+++ b/app/code/core/Mage/Authorizenet/Block/Directpost/Iframe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Helper/Admin.php b/app/code/core/Mage/Authorizenet/Helper/Admin.php
index 2c6d397..64a6662 100644
--- a/app/code/core/Mage/Authorizenet/Helper/Admin.php
+++ b/app/code/core/Mage/Authorizenet/Helper/Admin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Helper/Data.php b/app/code/core/Mage/Authorizenet/Helper/Data.php
index ffacc3b..ce81154 100644
--- a/app/code/core/Mage/Authorizenet/Helper/Data.php
+++ b/app/code/core/Mage/Authorizenet/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost.php b/app/code/core/Mage/Authorizenet/Model/Directpost.php
index 5a879cd..5db0add 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Observer.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Observer.php
index 3a2db93..cea94d2 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Observer.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
index 205583b..a8f85f9 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
index ee35290..00cc05e 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Session.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Session.php
index e1c00e8..7cbfb26 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Session.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/controllers/Adminhtml/Authorizenet/Directpost/PaymentController.php b/app/code/core/Mage/Authorizenet/controllers/Adminhtml/Authorizenet/Directpost/PaymentController.php
index 5b5630a..6386799 100644
--- a/app/code/core/Mage/Authorizenet/controllers/Adminhtml/Authorizenet/Directpost/PaymentController.php
+++ b/app/code/core/Mage/Authorizenet/controllers/Adminhtml/Authorizenet/Directpost/PaymentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/controllers/Directpost/PaymentController.php b/app/code/core/Mage/Authorizenet/controllers/Directpost/PaymentController.php
index 8330cfe..732d060 100644
--- a/app/code/core/Mage/Authorizenet/controllers/Directpost/PaymentController.php
+++ b/app/code/core/Mage/Authorizenet/controllers/Directpost/PaymentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Authorizenet/etc/config.xml b/app/code/core/Mage/Authorizenet/etc/config.xml
index b5037b1..33f9834 100644
--- a/app/code/core/Mage/Authorizenet/etc/config.xml
+++ b/app/code/core/Mage/Authorizenet/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Authorizenet/etc/system.xml b/app/code/core/Mage/Authorizenet/etc/system.xml
index 9032c76..369b25a 100644
--- a/app/code/core/Mage/Authorizenet/etc/system.xml
+++ b/app/code/core/Mage/Authorizenet/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Backup/Exception.php b/app/code/core/Mage/Backup/Exception.php
index 8aab96c..c5d0510 100644
--- a/app/code/core/Mage/Backup/Exception.php
+++ b/app/code/core/Mage/Backup/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Helper/Data.php b/app/code/core/Mage/Backup/Helper/Data.php
index 77d90ae..d5eeb77 100644
--- a/app/code/core/Mage/Backup/Helper/Data.php
+++ b/app/code/core/Mage/Backup/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Backup.php b/app/code/core/Mage/Backup/Model/Backup.php
index 1a42c91..ad49848 100644
--- a/app/code/core/Mage/Backup/Model/Backup.php
+++ b/app/code/core/Mage/Backup/Model/Backup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Config/Backend/Cron.php b/app/code/core/Mage/Backup/Model/Config/Backend/Cron.php
index 69adc17..73cbbd8 100644
--- a/app/code/core/Mage/Backup/Model/Config/Backend/Cron.php
+++ b/app/code/core/Mage/Backup/Model/Config/Backend/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Config/Source/Type.php b/app/code/core/Mage/Backup/Model/Config/Source/Type.php
index b18a9be..6f2736e 100644
--- a/app/code/core/Mage/Backup/Model/Config/Source/Type.php
+++ b/app/code/core/Mage/Backup/Model/Config/Source/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Db.php b/app/code/core/Mage/Backup/Model/Db.php
index 848c0b4..2d2fb40 100644
--- a/app/code/core/Mage/Backup/Model/Db.php
+++ b/app/code/core/Mage/Backup/Model/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Fs/Collection.php b/app/code/core/Mage/Backup/Model/Fs/Collection.php
index f5a8062..adec5d6 100644
--- a/app/code/core/Mage/Backup/Model/Fs/Collection.php
+++ b/app/code/core/Mage/Backup/Model/Fs/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Mysql4/Db.php b/app/code/core/Mage/Backup/Model/Mysql4/Db.php
index 3ad0257..0183861 100644
--- a/app/code/core/Mage/Backup/Model/Mysql4/Db.php
+++ b/app/code/core/Mage/Backup/Model/Mysql4/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Observer.php b/app/code/core/Mage/Backup/Model/Observer.php
index 4795419..5a8a980 100644
--- a/app/code/core/Mage/Backup/Model/Observer.php
+++ b/app/code/core/Mage/Backup/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Resource/Db.php b/app/code/core/Mage/Backup/Model/Resource/Db.php
index 6ebcbe0..203bca2 100644
--- a/app/code/core/Mage/Backup/Model/Resource/Db.php
+++ b/app/code/core/Mage/Backup/Model/Resource/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Backup/Model/Resource/Helper/Mysql4.php
index 58260fe..c0e3957 100644
--- a/app/code/core/Mage/Backup/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Backup/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Backup/etc/adminhtml.xml b/app/code/core/Mage/Backup/etc/adminhtml.xml
index 1919e67..2d3553a 100644
--- a/app/code/core/Mage/Backup/etc/adminhtml.xml
+++ b/app/code/core/Mage/Backup/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Backup/etc/config.xml b/app/code/core/Mage/Backup/etc/config.xml
index 8dedf26..aa1d046 100644
--- a/app/code/core/Mage/Backup/etc/config.xml
+++ b/app/code/core/Mage/Backup/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Backup/etc/system.xml b/app/code/core/Mage/Backup/etc/system.xml
index ac57821..eb8d059 100644
--- a/app/code/core/Mage/Backup/etc/system.xml
+++ b/app/code/core/Mage/Backup/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Bundle.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Bundle.php
index 0d8bd2a..fb9a4ba 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Bundle.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Checkbox.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Checkbox.php
index 3d064c7..805d86d 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Checkbox.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Multi.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Multi.php
index 0f00860..ca40cd0 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Multi.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Multi.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Radio.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Radio.php
index ea4438f..a9587b8 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Radio.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Radio.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Select.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Select.php
index 255732f..8d136ac 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Select.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Options/Type/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes.php
index d697cf0..9cbecf5 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Extend.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Extend.php
index a11f2bd..ab85d84 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Extend.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Extend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Special.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Special.php
index 0390802..7d92988 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Special.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Attributes/Special.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
index 83350d1..079322b 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
index 55d1f86..2ee2cdd 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search.php
index 72b492c..8c73532 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
index 1cda1a7..f9f26cd 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
index 0882625..191ac44 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tabs.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tabs.php
index 232419b..a1476d3 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tabs.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Catalog/Product/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/Items/Renderer.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/Items/Renderer.php
index 40c7566..6fe1ac6 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/Items/Renderer.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/Items/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/View/Items/Renderer.php b/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/View/Items/Renderer.php
index bd742f2..4a0d9ba 100644
--- a/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/View/Items/Renderer.php
+++ b/app/code/core/Mage/Bundle/Block/Adminhtml/Sales/Order/View/Items/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/List/Partof.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/List/Partof.php
index 08a4cdd..b82ae7f 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/List/Partof.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/List/Partof.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/Price.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/Price.php
index 91b9b97..2b7c08b 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/Price.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View.php
index b6cbdea..f48919c 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle.php
index d4721c3..a37dd3e 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option.php
index 3484cfd..e33b65d 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Checkbox.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Checkbox.php
index a3fbf7c..c49b1ec 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Checkbox.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Multi.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Multi.php
index 890845f..5a074c2 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Multi.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Multi.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Radio.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Radio.php
index 5431a9e..9b1263e 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Radio.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Radio.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Select.php b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Select.php
index a059109..079fa84 100644
--- a/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Select.php
+++ b/app/code/core/Mage/Bundle/Block/Catalog/Product/View/Type/Bundle/Option/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Checkout/Cart/Item/Renderer.php b/app/code/core/Mage/Bundle/Block/Checkout/Cart/Item/Renderer.php
index 89865d8..84ccc5a 100644
--- a/app/code/core/Mage/Bundle/Block/Checkout/Cart/Item/Renderer.php
+++ b/app/code/core/Mage/Bundle/Block/Checkout/Cart/Item/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Block/Sales/Order/Items/Renderer.php b/app/code/core/Mage/Bundle/Block/Sales/Order/Items/Renderer.php
index c9f0e8e..57351d9 100644
--- a/app/code/core/Mage/Bundle/Block/Sales/Order/Items/Renderer.php
+++ b/app/code/core/Mage/Bundle/Block/Sales/Order/Items/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Helper/Catalog/Product/Configuration.php b/app/code/core/Mage/Bundle/Helper/Catalog/Product/Configuration.php
index d3398c8..9e0b5ba 100644
--- a/app/code/core/Mage/Bundle/Helper/Catalog/Product/Configuration.php
+++ b/app/code/core/Mage/Bundle/Helper/Catalog/Product/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Helper/Data.php b/app/code/core/Mage/Bundle/Helper/Data.php
index e111c89..9b2332b 100644
--- a/app/code/core/Mage/Bundle/Helper/Data.php
+++ b/app/code/core/Mage/Bundle/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/CatalogIndex/Data/Bundle.php b/app/code/core/Mage/Bundle/Model/CatalogIndex/Data/Bundle.php
index d135836..9784f44 100644
--- a/app/code/core/Mage/Bundle/Model/CatalogIndex/Data/Bundle.php
+++ b/app/code/core/Mage/Bundle/Model/CatalogIndex/Data/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Bundle.php b/app/code/core/Mage/Bundle/Model/Mysql4/Bundle.php
index 5028d16..bcd75f5 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Bundle.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Price.php b/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Price.php
index d253279..dc70938 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Price.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Stock.php b/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Stock.php
index 64c4f13..63c4e61 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Stock.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Indexer/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Option.php b/app/code/core/Mage/Bundle/Model/Mysql4/Option.php
index 75e9660..f9d551d 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Option.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Option/Collection.php b/app/code/core/Mage/Bundle/Model/Mysql4/Option/Collection.php
index d4ce90f..2af6abd 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Option/Collection.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Price/Index.php b/app/code/core/Mage/Bundle/Model/Mysql4/Price/Index.php
index 5e32e7b..bc50610 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Price/Index.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Price/Index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Selection.php b/app/code/core/Mage/Bundle/Model/Mysql4/Selection.php
index 4e12591..e5ff362 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Selection.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Selection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Mysql4/Selection/Collection.php b/app/code/core/Mage/Bundle/Model/Mysql4/Selection/Collection.php
index 54c00bc..ab144c9 100644
--- a/app/code/core/Mage/Bundle/Model/Mysql4/Selection/Collection.php
+++ b/app/code/core/Mage/Bundle/Model/Mysql4/Selection/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Observer.php b/app/code/core/Mage/Bundle/Model/Observer.php
index a60f6a1..a122e82 100644
--- a/app/code/core/Mage/Bundle/Model/Observer.php
+++ b/app/code/core/Mage/Bundle/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Option.php b/app/code/core/Mage/Bundle/Model/Option.php
index c06d76b..573fabc 100644
--- a/app/code/core/Mage/Bundle/Model/Option.php
+++ b/app/code/core/Mage/Bundle/Model/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Price/Index.php b/app/code/core/Mage/Bundle/Model/Price/Index.php
index d59fcb0..120fc56 100644
--- a/app/code/core/Mage/Bundle/Model/Price/Index.php
+++ b/app/code/core/Mage/Bundle/Model/Price/Index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Product/Attribute/Source/Price/View.php b/app/code/core/Mage/Bundle/Model/Product/Attribute/Source/Price/View.php
index 131b3f3..8d7bc59 100644
--- a/app/code/core/Mage/Bundle/Model/Product/Attribute/Source/Price/View.php
+++ b/app/code/core/Mage/Bundle/Model/Product/Attribute/Source/Price/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Product/Price.php b/app/code/core/Mage/Bundle/Model/Product/Price.php
index 8c8df29..b16f6f7 100644
--- a/app/code/core/Mage/Bundle/Model/Product/Price.php
+++ b/app/code/core/Mage/Bundle/Model/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Product/Type.php b/app/code/core/Mage/Bundle/Model/Product/Type.php
index 8234db4..6278a21 100644
--- a/app/code/core/Mage/Bundle/Model/Product/Type.php
+++ b/app/code/core/Mage/Bundle/Model/Product/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Bundle.php b/app/code/core/Mage/Bundle/Model/Resource/Bundle.php
index 153347f..a3728da 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Bundle.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Indexer/Price.php b/app/code/core/Mage/Bundle/Model/Resource/Indexer/Price.php
index 40638ad..c7e5149 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Indexer/Price.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Indexer/Stock.php b/app/code/core/Mage/Bundle/Model/Resource/Indexer/Stock.php
index 642d239..b5c5287 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Indexer/Stock.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Indexer/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Option.php b/app/code/core/Mage/Bundle/Model/Resource/Option.php
index e858f6b..30a823c 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Option.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Option/Collection.php b/app/code/core/Mage/Bundle/Model/Resource/Option/Collection.php
index 33a342d..445a261 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Option/Collection.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Price/Index.php b/app/code/core/Mage/Bundle/Model/Resource/Price/Index.php
index 243640d..e1cd3d2 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Price/Index.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Price/Index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Selection.php b/app/code/core/Mage/Bundle/Model/Resource/Selection.php
index 10e977a..43fa9a3 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Selection.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Selection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Resource/Selection/Collection.php b/app/code/core/Mage/Bundle/Model/Resource/Selection/Collection.php
index 33df8b2..0731163 100644
--- a/app/code/core/Mage/Bundle/Model/Resource/Selection/Collection.php
+++ b/app/code/core/Mage/Bundle/Model/Resource/Selection/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Abstract.php b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Abstract.php
index 3a8f015..3e07426 100644
--- a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Abstract.php
+++ b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Creditmemo.php b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Creditmemo.php
index 2aa50d5..fc31f47 100644
--- a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Creditmemo.php
+++ b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Invoice.php b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Invoice.php
index 405507e..d876219 100644
--- a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Invoice.php
+++ b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Shipment.php b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Shipment.php
index f95004c..edf8b8c 100644
--- a/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Shipment.php
+++ b/app/code/core/Mage/Bundle/Model/Sales/Order/Pdf/Items/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Selection.php b/app/code/core/Mage/Bundle/Model/Selection.php
index 9188f39..683b958 100644
--- a/app/code/core/Mage/Bundle/Model/Selection.php
+++ b/app/code/core/Mage/Bundle/Model/Selection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Source/Option/Selection/Price/Type.php b/app/code/core/Mage/Bundle/Model/Source/Option/Selection/Price/Type.php
index 265131a..11f1f14 100644
--- a/app/code/core/Mage/Bundle/Model/Source/Option/Selection/Price/Type.php
+++ b/app/code/core/Mage/Bundle/Model/Source/Option/Selection/Price/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/Model/Source/Option/Type.php b/app/code/core/Mage/Bundle/Model/Source/Option/Type.php
index 142000e..2026929 100644
--- a/app/code/core/Mage/Bundle/Model/Source/Option/Type.php
+++ b/app/code/core/Mage/Bundle/Model/Source/Option/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/Product/EditController.php b/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/Product/EditController.php
index 24c9397..d0d2d91 100644
--- a/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/Product/EditController.php
+++ b/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/Product/EditController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/SelectionController.php b/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/SelectionController.php
index 826f967..bf00303 100644
--- a/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/SelectionController.php
+++ b/app/code/core/Mage/Bundle/controllers/Adminhtml/Bundle/SelectionController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/controllers/Product/EditController.php b/app/code/core/Mage/Bundle/controllers/Product/EditController.php
index 36ef10c..79c8d3d 100644
--- a/app/code/core/Mage/Bundle/controllers/Product/EditController.php
+++ b/app/code/core/Mage/Bundle/controllers/Product/EditController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/controllers/SelectionController.php b/app/code/core/Mage/Bundle/controllers/SelectionController.php
index a09d90d..309a1f2 100644
--- a/app/code/core/Mage/Bundle/controllers/SelectionController.php
+++ b/app/code/core/Mage/Bundle/controllers/SelectionController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/data/bundle_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Bundle/data/bundle_setup/data-install-1.6.0.0.php
index f603e16..a74a6d9 100644
--- a/app/code/core/Mage/Bundle/data/bundle_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Bundle/data/bundle_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/etc/config.xml b/app/code/core/Mage/Bundle/etc/config.xml
index 6831755..9aac196 100644
--- a/app/code/core/Mage/Bundle/etc/config.xml
+++ b/app/code/core/Mage/Bundle/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/install-1.6.0.0.php b/app/code/core/Mage/Bundle/sql/bundle_setup/install-1.6.0.0.php
index 58e3de7..6390dde 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-data-upgrade-0.1.13-0.1.14.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-data-upgrade-0.1.13-0.1.14.php
index 4b07152..9d68f27 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-data-upgrade-0.1.13-0.1.14.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-data-upgrade-0.1.13-0.1.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-install-0.1.0.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-install-0.1.0.php
index df71f05..d50ebed 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-install-0.1.0.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-install-0.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.0-0.1.1.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.0-0.1.1.php
index 1c90049..56ca7fb 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.0-0.1.1.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.0-0.1.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.1-0.1.2.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.1-0.1.2.php
index e30d4f6..b67a9c5 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.1-0.1.2.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.1-0.1.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.10-0.1.11.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.10-0.1.11.php
index f4e8207..5689dcf 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.10-0.1.11.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.10-0.1.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.11-0.1.12.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.11-0.1.12.php
index 13e3442..6a4c230 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.11-0.1.12.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.11-0.1.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.12-0.1.13.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.12-0.1.13.php
index 585e0a9..cb2ff74 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.12-0.1.13.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.12-0.1.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.2-0.1.3.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.2-0.1.3.php
index 74ffbec..20d5b7d 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.2-0.1.3.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.2-0.1.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.3-0.1.4.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.3-0.1.4.php
index d054ee5..2101c33 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.3-0.1.4.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.3-0.1.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.4-0.1.5.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.4-0.1.5.php
index 5f76e1f..653533d 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.4-0.1.5.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.4-0.1.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.5-0.1.6.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.5-0.1.6.php
index 5d27598..97f2084 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.5-0.1.6.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.5-0.1.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.6-0.1.7.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.6-0.1.7.php
index 7c1e118..b9a71fd 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.6-0.1.7.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.6-0.1.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.7-0.1.8.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.7-0.1.8.php
index 206ff56..2d6a4cb 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.7-0.1.8.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.7-0.1.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.8-0.1.9.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.8-0.1.9.php
index 3e46cca..36be56e 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.8-0.1.9.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.8-0.1.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.9-0.1.10.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.9-0.1.10.php
index 4393a1c..0fac449 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.9-0.1.10.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-0.1.9-0.1.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 55096db..6213a34 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
index 4577b7e..8834255 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Bundle/sql/bundle_setup/upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/Bundle/sql/bundle_setup/upgrade-1.6.0.0-1.6.0.0.1.php
index 0e48a5b..e3a63c1 100644
--- a/app/code/core/Mage/Bundle/sql/bundle_setup/upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Bundle/sql/bundle_setup/upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Block/Captcha.php b/app/code/core/Mage/Captcha/Block/Captcha.php
index f67960d..368ba9b 100644
--- a/app/code/core/Mage/Captcha/Block/Captcha.php
+++ b/app/code/core/Mage/Captcha/Block/Captcha.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Block/Captcha/Zend.php b/app/code/core/Mage/Captcha/Block/Captcha/Zend.php
index 079f52c..2f126c1 100644
--- a/app/code/core/Mage/Captcha/Block/Captcha/Zend.php
+++ b/app/code/core/Mage/Captcha/Block/Captcha/Zend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Helper/Data.php b/app/code/core/Mage/Captcha/Helper/Data.php
index 26016e7..bb6e483 100644
--- a/app/code/core/Mage/Captcha/Helper/Data.php
+++ b/app/code/core/Mage/Captcha/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Config/Font.php b/app/code/core/Mage/Captcha/Model/Config/Font.php
index b8f8c26..7504380 100644
--- a/app/code/core/Mage/Captcha/Model/Config/Font.php
+++ b/app/code/core/Mage/Captcha/Model/Config/Font.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Config/Form/Abstract.php b/app/code/core/Mage/Captcha/Model/Config/Form/Abstract.php
index 829976b..9a29d89 100644
--- a/app/code/core/Mage/Captcha/Model/Config/Form/Abstract.php
+++ b/app/code/core/Mage/Captcha/Model/Config/Form/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Config/Form/Backend.php b/app/code/core/Mage/Captcha/Model/Config/Form/Backend.php
index 1d4b6d4..202a82a 100644
--- a/app/code/core/Mage/Captcha/Model/Config/Form/Backend.php
+++ b/app/code/core/Mage/Captcha/Model/Config/Form/Backend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Config/Form/Frontend.php b/app/code/core/Mage/Captcha/Model/Config/Form/Frontend.php
index d9e273a..e006e1b 100644
--- a/app/code/core/Mage/Captcha/Model/Config/Form/Frontend.php
+++ b/app/code/core/Mage/Captcha/Model/Config/Form/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Config/Mode.php b/app/code/core/Mage/Captcha/Model/Config/Mode.php
index 87b2712..6e5e87d 100644
--- a/app/code/core/Mage/Captcha/Model/Config/Mode.php
+++ b/app/code/core/Mage/Captcha/Model/Config/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Interface.php b/app/code/core/Mage/Captcha/Model/Interface.php
index 866d260..e9f3585 100644
--- a/app/code/core/Mage/Captcha/Model/Interface.php
+++ b/app/code/core/Mage/Captcha/Model/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Observer.php b/app/code/core/Mage/Captcha/Model/Observer.php
index a42db5c..faadd6e 100644
--- a/app/code/core/Mage/Captcha/Model/Observer.php
+++ b/app/code/core/Mage/Captcha/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Resource/Log.php b/app/code/core/Mage/Captcha/Model/Resource/Log.php
index 0db0ed4..adbde6f 100644
--- a/app/code/core/Mage/Captcha/Model/Resource/Log.php
+++ b/app/code/core/Mage/Captcha/Model/Resource/Log.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/Model/Zend.php b/app/code/core/Mage/Captcha/Model/Zend.php
index 02dedfc..e0ed9e3 100644
--- a/app/code/core/Mage/Captcha/Model/Zend.php
+++ b/app/code/core/Mage/Captcha/Model/Zend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/controllers/Adminhtml/RefreshController.php b/app/code/core/Mage/Captcha/controllers/Adminhtml/RefreshController.php
index 9a78018..14b8107 100644
--- a/app/code/core/Mage/Captcha/controllers/Adminhtml/RefreshController.php
+++ b/app/code/core/Mage/Captcha/controllers/Adminhtml/RefreshController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/controllers/RefreshController.php b/app/code/core/Mage/Captcha/controllers/RefreshController.php
index e47e85a..5baba21 100644
--- a/app/code/core/Mage/Captcha/controllers/RefreshController.php
+++ b/app/code/core/Mage/Captcha/controllers/RefreshController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Captcha/etc/config.xml b/app/code/core/Mage/Captcha/etc/config.xml
index 8c2ed50..da3cc84 100644
--- a/app/code/core/Mage/Captcha/etc/config.xml
+++ b/app/code/core/Mage/Captcha/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Captcha/etc/system.xml b/app/code/core/Mage/Captcha/etc/system.xml
index f6e94c0..26c211a 100644
--- a/app/code/core/Mage/Captcha/etc/system.xml
+++ b/app/code/core/Mage/Captcha/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Captcha/sql/captcha_setup/install-1.7.0.0.0.php b/app/code/core/Mage/Captcha/sql/captcha_setup/install-1.7.0.0.0.php
index f1f63c9..0f79cd2 100644
--- a/app/code/core/Mage/Captcha/sql/captcha_setup/install-1.7.0.0.0.php
+++ b/app/code/core/Mage/Captcha/sql/captcha_setup/install-1.7.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /* @var $installer Mage_Core_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Catalog/Block/Breadcrumbs.php b/app/code/core/Mage/Catalog/Block/Breadcrumbs.php
index f1ea9b1..fe45105 100644
--- a/app/code/core/Mage/Catalog/Block/Breadcrumbs.php
+++ b/app/code/core/Mage/Catalog/Block/Breadcrumbs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Catalog/Block/Category/View.php b/app/code/core/Mage/Catalog/Block/Category/View.php
index 735c606..900eacd 100644
--- a/app/code/core/Mage/Catalog/Block/Category/View.php
+++ b/app/code/core/Mage/Catalog/Block/Category/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Category/Widget/Link.php b/app/code/core/Mage/Catalog/Block/Category/Widget/Link.php
index 4b90a78..05859e7 100644
--- a/app/code/core/Mage/Catalog/Block/Category/Widget/Link.php
+++ b/app/code/core/Mage/Catalog/Block/Category/Widget/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/Filter/Abstract.php b/app/code/core/Mage/Catalog/Block/Layer/Filter/Abstract.php
index d34c3f2..fffbabd 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/Filter/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/Filter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/Filter/Attribute.php b/app/code/core/Mage/Catalog/Block/Layer/Filter/Attribute.php
index c24ccaa..5e56b2d 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/Filter/Category.php b/app/code/core/Mage/Catalog/Block/Layer/Filter/Category.php
index 89d81cd..05725ad 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/Filter/Category.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/Filter/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/Filter/Decimal.php b/app/code/core/Mage/Catalog/Block/Layer/Filter/Decimal.php
index 3ca768f..a824a0d 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/Filter/Decimal.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/Filter/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/Filter/Price.php b/app/code/core/Mage/Catalog/Block/Layer/Filter/Price.php
index 529c55d..ea90be2 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/Filter/Price.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/Filter/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/State.php b/app/code/core/Mage/Catalog/Block/Layer/State.php
index 538d603..5c559c9 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/State.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/State.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Layer/View.php b/app/code/core/Mage/Catalog/Block/Layer/View.php
index 1ba818c..2db8c37 100644
--- a/app/code/core/Mage/Catalog/Block/Layer/View.php
+++ b/app/code/core/Mage/Catalog/Block/Layer/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Navigation.php b/app/code/core/Mage/Catalog/Block/Navigation.php
index 87318b7..08a553f 100644
--- a/app/code/core/Mage/Catalog/Block/Navigation.php
+++ b/app/code/core/Mage/Catalog/Block/Navigation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product.php b/app/code/core/Mage/Catalog/Block/Product.php
index 518b1bb..5da1743 100644
--- a/app/code/core/Mage/Catalog/Block/Product.php
+++ b/app/code/core/Mage/Catalog/Block/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Abstract.php b/app/code/core/Mage/Catalog/Block/Product/Abstract.php
index 1a73235..3cbb1e6 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Compare/Abstract.php b/app/code/core/Mage/Catalog/Block/Product/Compare/Abstract.php
index 149b763..0e9d2b4 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Compare/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Compare/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Compare/List.php b/app/code/core/Mage/Catalog/Block/Product/Compare/List.php
index 53668c1..e347dd5 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Compare/List.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Compare/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Compare/Sidebar.php b/app/code/core/Mage/Catalog/Block/Product/Compare/Sidebar.php
index 585a8cf..0d7439f 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Compare/Sidebar.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Compare/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Gallery.php b/app/code/core/Mage/Catalog/Block/Product/Gallery.php
index 6468d04..a9757ac 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Gallery.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List.php b/app/code/core/Mage/Catalog/Block/Product/List.php
index 23f0da4..d6616cc 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Crosssell.php b/app/code/core/Mage/Catalog/Block/Product/List/Crosssell.php
index 8be3a3d..19fcf31 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Crosssell.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Promotion.php b/app/code/core/Mage/Catalog/Block/Product/List/Promotion.php
index d399d47..bf2b3cd 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Promotion.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Promotion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Catalog_Block_Product_List_Promotion extends Mage_Catalog_Block_Product_List
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Random.php b/app/code/core/Mage/Catalog/Block/Product/List/Random.php
index b7cefe0..4669bfc 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Random.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Random.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Related.php b/app/code/core/Mage/Catalog/Block/Product/List/Related.php
index a586589..f5fa14a 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Related.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Related.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Toolbar.php b/app/code/core/Mage/Catalog/Block/Product/List/Toolbar.php
index 6cbed87..0788acc 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Toolbar.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Toolbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/List/Upsell.php b/app/code/core/Mage/Catalog/Block/Product/List/Upsell.php
index a68331e..7532bd4 100644
--- a/app/code/core/Mage/Catalog/Block/Product/List/Upsell.php
+++ b/app/code/core/Mage/Catalog/Block/Product/List/Upsell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/New.php b/app/code/core/Mage/Catalog/Block/Product/New.php
index fc7625e..cdb7968 100644
--- a/app/code/core/Mage/Catalog/Block/Product/New.php
+++ b/app/code/core/Mage/Catalog/Block/Product/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Price.php b/app/code/core/Mage/Catalog/Block/Product/Price.php
index 81405d2..fe31dcd 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Price.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Price/Template.php b/app/code/core/Mage/Catalog/Block/Product/Price/Template.php
index 9deac50..ff4ae23 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Price/Template.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Price/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Send.php b/app/code/core/Mage/Catalog/Block/Product/Send.php
index 9a6d7b0..45abdad 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Send.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Send.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View.php b/app/code/core/Mage/Catalog/Block/Product/View.php
index 04c1013..14b44e6 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Abstract.php b/app/code/core/Mage/Catalog/Block/Product/View/Abstract.php
index 6d45022..3e59811 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Additional.php b/app/code/core/Mage/Catalog/Block/Product/View/Additional.php
index b29d198..368d6a6 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Additional.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Additional.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Attributes.php b/app/code/core/Mage/Catalog/Block/Product/View/Attributes.php
index aa7026e..a6c65fd 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Attributes.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Description.php b/app/code/core/Mage/Catalog/Block/Product/View/Description.php
index 1b32c6d..d2b2c81 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Description.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Description.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Media.php b/app/code/core/Mage/Catalog/Block/Product/View/Media.php
index 4a87eb5..f4764f2 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Media.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options.php b/app/code/core/Mage/Catalog/Block/Product/View/Options.php
index 02994b7..d21c932 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Abstract.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Abstract.php
index 3600289..8912e20 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Date.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Date.php
index 5850dae..ea817e9 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Date.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Default.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Default.php
index c0ec571..a54262b 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Default.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/File.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/File.php
index 3390e4a..4db11ce 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/File.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Select.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Select.php
index 646b7b9..4d85b3c 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Select.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Text.php b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Text.php
index 05fab85..56d53c2 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Text.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Options/Type/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Price.php b/app/code/core/Mage/Catalog/Block/Product/View/Price.php
index 93e272d..3643743 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Price.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Tabs.php b/app/code/core/Mage/Catalog/Block/Product/View/Tabs.php
index 864ad21..b909a99 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Tabs.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Type/Configurable.php b/app/code/core/Mage/Catalog/Block/Product/View/Type/Configurable.php
index 40cdef2..a40fb3f 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Type/Configurable.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Type/Grouped.php b/app/code/core/Mage/Catalog/Block/Product/View/Type/Grouped.php
index 456e8cb..e0fcf81 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Type/Grouped.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Type/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Type/Simple.php b/app/code/core/Mage/Catalog/Block/Product/View/Type/Simple.php
index dd40034..936ad62 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Type/Simple.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Type/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/View/Type/Virtual.php b/app/code/core/Mage/Catalog/Block/Product/View/Type/Virtual.php
index 3f3b6fe..89615c4 100644
--- a/app/code/core/Mage/Catalog/Block/Product/View/Type/Virtual.php
+++ b/app/code/core/Mage/Catalog/Block/Product/View/Type/Virtual.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Widget/Html/Pager.php b/app/code/core/Mage/Catalog/Block/Product/Widget/Html/Pager.php
index 3ac8745..37ec9a4 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Widget/Html/Pager.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Widget/Html/Pager.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Widget/Link.php b/app/code/core/Mage/Catalog/Block/Product/Widget/Link.php
index 0b8eb4d..013aff1 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Widget/Link.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Widget/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Product/Widget/New.php b/app/code/core/Mage/Catalog/Block/Product/Widget/New.php
index 2a16250..3f06397 100644
--- a/app/code/core/Mage/Catalog/Block/Product/Widget/New.php
+++ b/app/code/core/Mage/Catalog/Block/Product/Widget/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Abstract.php b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Abstract.php
index 226e0bd..1c7c0e1 100644
--- a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Abstract.php
+++ b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Category.php b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Category.php
index 44ef927..3a284aa 100644
--- a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Category.php
+++ b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Product.php b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Product.php
index ae2dd54..8848d2c 100644
--- a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Product.php
+++ b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Category.php b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Category.php
index 56345d2..1250a6c 100644
--- a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Category.php
+++ b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Pager.php b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Pager.php
index 28f893b..f86d73e 100644
--- a/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Pager.php
+++ b/app/code/core/Mage/Catalog/Block/Seo/Sitemap/Tree/Pager.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Block/Widget/Link.php b/app/code/core/Mage/Catalog/Block/Widget/Link.php
index 92997d5..abee4db 100644
--- a/app/code/core/Mage/Catalog/Block/Widget/Link.php
+++ b/app/code/core/Mage/Catalog/Block/Widget/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Exception.php b/app/code/core/Mage/Catalog/Exception.php
index 4ad0d29..22aed3d 100644
--- a/app/code/core/Mage/Catalog/Exception.php
+++ b/app/code/core/Mage/Catalog/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Category.php b/app/code/core/Mage/Catalog/Helper/Category.php
index dc97bd7..b0f3630 100644
--- a/app/code/core/Mage/Catalog/Helper/Category.php
+++ b/app/code/core/Mage/Catalog/Helper/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Category/Flat.php b/app/code/core/Mage/Catalog/Helper/Category/Flat.php
index e61ac28..86e41ec 100644
--- a/app/code/core/Mage/Catalog/Helper/Category/Flat.php
+++ b/app/code/core/Mage/Catalog/Helper/Category/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite.php b/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite.php
index 9c5ef47..24f6a51 100644
--- a/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite.php
+++ b/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite/Interface.php b/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite/Interface.php
index fa6f54b..92b8e6a 100644
--- a/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite/Interface.php
+++ b/app/code/core/Mage/Catalog/Helper/Category/Url/Rewrite/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Data.php b/app/code/core/Mage/Catalog/Helper/Data.php
index 0d65dd7..fbb58fa 100644
--- a/app/code/core/Mage/Catalog/Helper/Data.php
+++ b/app/code/core/Mage/Catalog/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Flat/Abstract.php b/app/code/core/Mage/Catalog/Helper/Flat/Abstract.php
index 00df159..dc014a4 100644
--- a/app/code/core/Mage/Catalog/Helper/Flat/Abstract.php
+++ b/app/code/core/Mage/Catalog/Helper/Flat/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Image.php b/app/code/core/Mage/Catalog/Helper/Image.php
index c7bf360..4f0b272 100644
--- a/app/code/core/Mage/Catalog/Helper/Image.php
+++ b/app/code/core/Mage/Catalog/Helper/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Map.php b/app/code/core/Mage/Catalog/Helper/Map.php
index b0dcc60..0881631 100644
--- a/app/code/core/Mage/Catalog/Helper/Map.php
+++ b/app/code/core/Mage/Catalog/Helper/Map.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Output.php b/app/code/core/Mage/Catalog/Helper/Output.php
index e170849..6d5db22 100644
--- a/app/code/core/Mage/Catalog/Helper/Output.php
+++ b/app/code/core/Mage/Catalog/Helper/Output.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product.php b/app/code/core/Mage/Catalog/Helper/Product.php
index e36c79c..e9c0146 100644
--- a/app/code/core/Mage/Catalog/Helper/Product.php
+++ b/app/code/core/Mage/Catalog/Helper/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Compare.php b/app/code/core/Mage/Catalog/Helper/Product/Compare.php
index a45f30f..8347774 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Compare.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Compare.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Configuration.php b/app/code/core/Mage/Catalog/Helper/Product/Configuration.php
index b4bd63e..adfc3ef 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Configuration.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Configuration/Interface.php b/app/code/core/Mage/Catalog/Helper/Product/Configuration/Interface.php
index 7c93703..5e163c2 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Configuration/Interface.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Configuration/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Flat.php b/app/code/core/Mage/Catalog/Helper/Product/Flat.php
index d461b56..30bee87 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Flat.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Options.php b/app/code/core/Mage/Catalog/Helper/Product/Options.php
index ce414ff..5ee80fc 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Options.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Type/Composite.php b/app/code/core/Mage/Catalog/Helper/Product/Type/Composite.php
index 4fd121c..d67699b 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Type/Composite.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Type/Composite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Url.php b/app/code/core/Mage/Catalog/Helper/Product/Url.php
index 34e0c97..6d7e9f5 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Url.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite.php b/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite.php
index 97f71bc..251058a 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite/Interface.php b/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite/Interface.php
index 8dde2d9..b7d0f18 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite/Interface.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/Url/Rewrite/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Helper/Product/View.php b/app/code/core/Mage/Catalog/Helper/Product/View.php
index 578be4f..f39e73f 100644
--- a/app/code/core/Mage/Catalog/Helper/Product/View.php
+++ b/app/code/core/Mage/Catalog/Helper/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Abstract.php b/app/code/core/Mage/Catalog/Model/Abstract.php
index 7625d25..5a489d0 100644
--- a/app/code/core/Mage/Catalog/Model/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api/Resource.php b/app/code/core/Mage/Catalog/Model/Api/Resource.php
index 0aa3860..10824a7 100644
--- a/app/code/core/Mage/Catalog/Model/Api/Resource.php
+++ b/app/code/core/Mage/Catalog/Model/Api/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product.php b/app/code/core/Mage/Catalog/Model/Api2/Product.php
index d225d69..b24b5e4 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Category.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Category.php
index b0a528e..777d7e2 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Category.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest.php
index 4a97e32..4fca054 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Admin/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Admin/V1.php
index d86588a..195a6fa 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Customer/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Customer/V1.php
index 09399d0..eb2897d 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Guest/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Guest/V1.php
index ed798c0..5b24f05 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Guest/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Category/Rest/Guest/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image.php
index 23eacb5..b72d1a8 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest.php
index d9c0dfd..05b54d1 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Admin/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Admin/V1.php
index 465b6ab..762b1ed 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Customer/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Customer/V1.php
index 5580abf..d2f8600 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Guest/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Guest/V1.php
index 19de638..576d023 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Guest/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Rest/Guest/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Validator/Image.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Validator/Image.php
index 50d69ac..3a5395c 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Validator/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Image/Validator/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest.php
index 51b71c2..8898032 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Admin/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Admin/V1.php
index 5ca0ae9..e8704e1 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Customer/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Customer/V1.php
index 192db80..3104902 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Guest/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Guest/V1.php
index d3bba54..b5bd76a 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Guest/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Rest/Guest/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Validator/Product.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Validator/Product.php
index d814503..db1fa1f 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Validator/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Validator/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Website.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Website.php
index 1e84d0e..b4d00c3 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Website.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest.php
index 36c436c..1adccc4 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest/Admin/V1.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest/Admin/V1.php
index c4e174d..79d79ec 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Validator/Admin/Website.php b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Validator/Admin/Website.php
index 5a76cf5..2cc6aa6 100644
--- a/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Validator/Admin/Website.php
+++ b/app/code/core/Mage/Catalog/Model/Api2/Product/Website/Validator/Admin/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Attribute/Backend/Customlayoutupdate.php b/app/code/core/Mage/Catalog/Model/Attribute/Backend/Customlayoutupdate.php
index 3b24c0a..1dc133d 100644
--- a/app/code/core/Mage/Catalog/Model/Attribute/Backend/Customlayoutupdate.php
+++ b/app/code/core/Mage/Catalog/Model/Attribute/Backend/Customlayoutupdate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Attribute/Backend/Urlkey/Abstract.php b/app/code/core/Mage/Catalog/Model/Attribute/Backend/Urlkey/Abstract.php
index 5915aba..0cb954c 100644
--- a/app/code/core/Mage/Catalog/Model/Attribute/Backend/Urlkey/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Attribute/Backend/Urlkey/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category.php b/app/code/core/Mage/Catalog/Model/Category.php
index 9613b90..6e59038 100644
--- a/app/code/core/Mage/Catalog/Model/Category.php
+++ b/app/code/core/Mage/Catalog/Model/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Api.php b/app/code/core/Mage/Catalog/Model/Category/Api.php
index 79ab012..671c593 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Api/V2.php b/app/code/core/Mage/Catalog/Model/Category/Api/V2.php
index 6b12355..75e668b 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Api.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Api.php
index 40948fb..18c1e0f 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Api/V2.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Api/V2.php
index a59e22c..466037c 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Image.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Image.php
index b11bc84..29a3c5e 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Sortby.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Sortby.php
index c8ee795..52bb0af 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Sortby.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Sortby.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Urlkey.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Urlkey.php
index a319a9b..1cb6439 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Urlkey.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Backend/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Layout.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Layout.php
index d7dd08d..b9eb97c 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Layout.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Mode.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Mode.php
index a90ca48..68e97b8 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Mode.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Page.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Page.php
index d1be69b..fc4d5cb 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Page.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Sortby.php b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Sortby.php
index ed8b1be..b130433 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Sortby.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Attribute/Source/Sortby.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Indexer/Flat.php b/app/code/core/Mage/Catalog/Model/Category/Indexer/Flat.php
index 682ff1f..4932824 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Indexer/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Indexer/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Indexer/Product.php b/app/code/core/Mage/Catalog/Model/Category/Indexer/Product.php
index 7928c7a..350a0c4 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Indexer/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Indexer/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Category/Url.php b/app/code/core/Mage/Catalog/Model/Category/Url.php
index 3a74b58..f3eecd2 100644
--- a/app/code/core/Mage/Catalog/Model/Category/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Category/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Config.php b/app/code/core/Mage/Catalog/Model/Config.php
index 6701ca9..3e3cba1 100644
--- a/app/code/core/Mage/Catalog/Model/Config.php
+++ b/app/code/core/Mage/Catalog/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Convert.php b/app/code/core/Mage/Catalog/Model/Convert.php
index c71a150..5a302f9 100644
--- a/app/code/core/Mage/Catalog/Model/Convert.php
+++ b/app/code/core/Mage/Catalog/Model/Convert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Convert/Adapter/Catalog.php b/app/code/core/Mage/Catalog/Model/Convert/Adapter/Catalog.php
index 8c847f6..13a9103 100644
--- a/app/code/core/Mage/Catalog/Model/Convert/Adapter/Catalog.php
+++ b/app/code/core/Mage/Catalog/Model/Convert/Adapter/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Convert/Adapter/Product.php b/app/code/core/Mage/Catalog/Model/Convert/Adapter/Product.php
index 7d842c9..c29a1e1 100644
--- a/app/code/core/Mage/Catalog/Model/Convert/Adapter/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Convert/Adapter/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Convert/Parser/Product.php b/app/code/core/Mage/Catalog/Model/Convert/Parser/Product.php
index d2cfae4..44b5533 100644
--- a/app/code/core/Mage/Catalog/Model/Convert/Parser/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Convert/Parser/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Design.php b/app/code/core/Mage/Catalog/Model/Design.php
index df00d22..8a6bdc8 100644
--- a/app/code/core/Mage/Catalog/Model/Design.php
+++ b/app/code/core/Mage/Catalog/Model/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Entity/Attribute.php b/app/code/core/Mage/Catalog/Model/Entity/Attribute.php
index c4d9dd3..dbcf1a7 100644
--- a/app/code/core/Mage/Catalog/Model/Entity/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Entity/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Design/Options/Container.php b/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Design/Options/Container.php
index 7a6cce2..d5678fe 100644
--- a/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Design/Options/Container.php
+++ b/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Design/Options/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Frontend/Image.php
index 8c4787b..36b9bf1 100644
--- a/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Entity/Product/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Factory.php b/app/code/core/Mage/Catalog/Model/Factory.php
index e2b836e..3304029 100644
--- a/app/code/core/Mage/Catalog/Model/Factory.php
+++ b/app/code/core/Mage/Catalog/Model/Factory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Index.php b/app/code/core/Mage/Catalog/Model/Index.php
index b50c06b..fe0ee84 100644
--- a/app/code/core/Mage/Catalog/Model/Index.php
+++ b/app/code/core/Mage/Catalog/Model/Index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Indexer/Url.php b/app/code/core/Mage/Catalog/Model/Indexer/Url.php
index 65a9bb8..42e795e 100644
--- a/app/code/core/Mage/Catalog/Model/Indexer/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Indexer/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer.php b/app/code/core/Mage/Catalog/Model/Layer.php
index ea4fa1d..9fe668e 100644
--- a/app/code/core/Mage/Catalog/Model/Layer.php
+++ b/app/code/core/Mage/Catalog/Model/Layer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Abstract.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Abstract.php
index 2fb101c..0069c79 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Attribute.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Attribute.php
index 812cb2d..dd816f3 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Category.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Category.php
index 81bbe21..023c96a 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Category.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Decimal.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Decimal.php
index bb3a54f..f2a638a 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Decimal.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Item.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Item.php
index 3a064ff..416cceb 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Item.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Price.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Price.php
index bc5fa7a..19463ab4 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/Filter/Price/Algorithm.php b/app/code/core/Mage/Catalog/Model/Layer/Filter/Price/Algorithm.php
index d35bf5f..e367d89 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/Filter/Price/Algorithm.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/Filter/Price/Algorithm.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Layer/State.php b/app/code/core/Mage/Catalog/Model/Layer/State.php
index b0fef2e..770642f 100644
--- a/app/code/core/Mage/Catalog/Model/Layer/State.php
+++ b/app/code/core/Mage/Catalog/Model/Layer/State.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Observer.php b/app/code/core/Mage/Catalog/Model/Observer.php
index 14d5f38..21d96fe 100644
--- a/app/code/core/Mage/Catalog/Model/Observer.php
+++ b/app/code/core/Mage/Catalog/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product.php b/app/code/core/Mage/Catalog/Model/Product.php
index 294323c..7a0cf6a 100644
--- a/app/code/core/Mage/Catalog/Model/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Action.php b/app/code/core/Mage/Catalog/Model/Product/Action.php
index c24a8fc..4e69186 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Action.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Api.php b/app/code/core/Mage/Catalog/Model/Product/Api.php
index 593e855..d3b5087 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Api/V2.php
index 4436cb2..2c49187 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Api.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Api.php
index 96ad854..a5a024f 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Api/V2.php
index b9a999a..0d2ddba 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Boolean.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Boolean.php
index 75cd319..848b99d 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Boolean.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice.php
index 2febe38..9880336 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice/Abstract.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice/Abstract.php
index ebeefc8..f0a4619 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Groupprice/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Media.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Media.php
index 8593913..dcc7b93 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Media.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Msrp.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Msrp.php
index cc1a262..a41f7cc 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Msrp.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Msrp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Price.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Price.php
index 1466827..5c2383b 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Recurring.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Recurring.php
index 163e8ff..f470345 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Recurring.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Recurring.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Sku.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Sku.php
index d3e8de2..a3ce9a8 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Sku.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Sku.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate.php
index ae74ea7..fe42615 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate/Specialprice.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate/Specialprice.php
index 9672ddf..98462c7 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate/Specialprice.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Startdate/Specialprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Tierprice.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Tierprice.php
index ae12dc7..0de6f2a 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Tierprice.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Urlkey.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Urlkey.php
index 50cd846..52f4771 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Urlkey.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Backend/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Frontend/Image.php
index cc674b7..7079a10 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Group.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Group.php
index 71d1ddc..d23a10b 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Group.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api.php
index c40cf54..4035389 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api/V2.php
index 438db64..4da1ef1 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Media/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api.php
index fc6df81..d35e71e 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api/V2.php
index 0221f18..5aea908 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Set/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Boolean.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Boolean.php
index 5892df9..23c93cd 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Boolean.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Countryofmanufacture.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Countryofmanufacture.php
index d8ab78c..227306f 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Countryofmanufacture.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Countryofmanufacture.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Inputtype.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Inputtype.php
index e3a64aa..ed69194 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Inputtype.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Inputtype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Layout.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Layout.php
index cb8370c..8871122 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Layout.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type.php
index 80b9cbd..83c4935 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Enabled.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Enabled.php
index 4b64fec..68673e8 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Enabled.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Enabled.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Price.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Price.php
index f4f21a0..335fded 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Source/Msrp/Type/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api.php
index d69da6c..b61deca 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api/V2.php
index b00f09f..55bc427 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Attribute/Tierprice/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Compare/Item.php b/app/code/core/Mage/Catalog/Model/Product/Compare/Item.php
index e62c611..0686e30 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Compare/Item.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Compare/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Compare/List.php b/app/code/core/Mage/Catalog/Model/Product/Compare/List.php
index 0be4c0f..8a30085 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Compare/List.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Compare/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Condition.php b/app/code/core/Mage/Catalog/Model/Product/Condition.php
index 120cf2c..5660eb8 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Condition.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Condition.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Condition/Interface.php b/app/code/core/Mage/Catalog/Model/Product/Condition/Interface.php
index 800250a..2173551 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Condition/Interface.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Condition/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Interface.php b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Interface.php
index 18edc0c..87a19e3 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Interface.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option.php b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option.php
index 0cb0d59..1bd5e77 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option/Interface.php b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option/Interface.php
index c08b552..56995df 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option/Interface.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Configuration/Item/Option/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Flat/Flag.php b/app/code/core/Mage/Catalog/Model/Product/Flat/Flag.php
index 86e1cf8..e2194d0 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Flat/Flag.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Flat/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Flat/Indexer.php b/app/code/core/Mage/Catalog/Model/Product/Flat/Indexer.php
index a0ae16d..bf1a7bc 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Flat/Indexer.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Flat/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Flat/Observer.php b/app/code/core/Mage/Catalog/Model/Product/Flat/Observer.php
index 565188c..ed9e6ba 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Flat/Observer.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Flat/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Image.php b/app/code/core/Mage/Catalog/Model/Product/Image.php
index 0cbcd8f..9475a60 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Indexer/Eav.php b/app/code/core/Mage/Catalog/Model/Product/Indexer/Eav.php
index dacfb84..c512638 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Indexer/Eav.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Indexer/Flat.php b/app/code/core/Mage/Catalog/Model/Product/Indexer/Flat.php
index f393646..7b1f4ff 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Indexer/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Indexer/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Catalog_Model_Product_Indexer_Flat extends Mage_Index_Model_Indexer_Abstract
diff --git a/app/code/core/Mage/Catalog/Model/Product/Indexer/Price.php b/app/code/core/Mage/Catalog/Model/Product/Indexer/Price.php
index e49f00c..eb19dee 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Indexer/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/app/code/core/Mage/Catalog/Model/Product/Link.php b/app/code/core/Mage/Catalog/Model/Product/Link.php
index 730d528..99dd949 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Link.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Link/Api.php b/app/code/core/Mage/Catalog/Model/Product/Link/Api.php
index 4157694..4d42fcc 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Link/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Link/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Link/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Link/Api/V2.php
index 505d7c6..65e913a 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Link/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Link/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Media/Config.php b/app/code/core/Mage/Catalog/Model/Product/Media/Config.php
index 0ef2b9e..d27d3d8 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Media/Config.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Media/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option.php b/app/code/core/Mage/Catalog/Model/Product/Option.php
index 77adce5..3d1c463 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Api.php b/app/code/core/Mage/Catalog/Model/Product/Option/Api.php
index d76bbeb..2a64e4b 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Option/Api/V2.php
index e62b5af..58e8870 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Observer.php b/app/code/core/Mage/Catalog/Model/Product/Option/Observer.php
index 31e7ff4..4ef9207 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Observer.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Date.php b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Date.php
index 276efb7..ae32836 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Date.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Default.php b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Default.php
index 3dfc2a1..39b270d 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Default.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Type/File.php b/app/code/core/Mage/Catalog/Model/Product/Option/Type/File.php
index aa86dca..17de30d 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Type/File.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Type/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Select.php b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Select.php
index dfc2a7b..4b55870 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Select.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -54,7 +54,8 @@ class Mage_Catalog_Model_Product_Option_Type_Select extends Mage_Catalog_Model_P
         if (!$this->_isSingleSelection()) {
             $valuesCollection = $option->getOptionValuesByOptionId($value, $this->getProduct()->getStoreId())
                 ->load();
-            if ($valuesCollection->count() != count($value)) {
+            $valueCount = empty($value) ? 0 : count($value);
+            if ($valuesCollection->count() != $valueCount) {
                 $this->setIsValid(false);
                 Mage::throwException(Mage::helper('catalog')->__('Please specify the product required option(s).'));
             }
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Text.php b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Text.php
index e44ac29..4b8a9e8 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Type/Text.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Type/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Value.php b/app/code/core/Mage/Catalog/Model/Product/Option/Value.php
index 26dbadb..b4e36fa 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Value.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Value.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api.php b/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api.php
index 4a02a06..3c0c6be 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api/V2.php
index 6868e26..d4332dc 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Option/Value/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Status.php b/app/code/core/Mage/Catalog/Model/Product/Status.php
index 3e36f73..e9705e0 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Status.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type.php b/app/code/core/Mage/Catalog/Model/Product/Type.php
index 2df36f4..6ed8a10 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Abstract.php b/app/code/core/Mage/Catalog/Model/Product/Type/Abstract.php
index 0b365e5..829dc16 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Api.php b/app/code/core/Mage/Catalog/Model/Product/Type/Api.php
index 38153cd..87fd083 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Api.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Api/V2.php b/app/code/core/Mage/Catalog/Model/Product/Type/Api/V2.php
index 3c1bd63..f35ed63 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Api/V2.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable.php b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable.php
index 41ffc87..e45bf59 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Attribute.php b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Attribute.php
index 7ce8290..fb17a5e 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Price.php b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Price.php
index e7bef65..fcd1384 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Configurable/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Grouped.php b/app/code/core/Mage/Catalog/Model/Product/Type/Grouped.php
index 22ba5d9..e3e1831 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Grouped.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Grouped/Price.php b/app/code/core/Mage/Catalog/Model/Product/Type/Grouped/Price.php
index 712f672..cd10a30 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Grouped/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Grouped/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Price.php b/app/code/core/Mage/Catalog/Model/Product/Type/Price.php
index d1bca79..28ab36d 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Simple.php b/app/code/core/Mage/Catalog/Model/Product/Type/Simple.php
index 483f84c..b9712b0 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Simple.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Type/Virtual.php b/app/code/core/Mage/Catalog/Model/Product/Type/Virtual.php
index 765a875..7a9a5d1 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Type/Virtual.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Type/Virtual.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Url.php b/app/code/core/Mage/Catalog/Model/Product/Url.php
index c4c73cb..65a83e2 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Visibility.php b/app/code/core/Mage/Catalog/Model/Product/Visibility.php
index f7bf8ca..6e59dfd 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Visibility.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Visibility.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Product/Website.php b/app/code/core/Mage/Catalog/Model/Product/Website.php
index fc07410..7f188a2 100644
--- a/app/code/core/Mage/Catalog/Model/Product/Website.php
+++ b/app/code/core/Mage/Catalog/Model/Product/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Abstract.php
index 9d91684..079b736 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Attribute.php
index bdf016c..8cf91fe 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category.php b/app/code/core/Mage/Catalog/Model/Resource/Category.php
index 444ee76..9343f83 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Collection.php
index 98c3cbb..3f4818a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Frontend/Image.php
index ce402fb..0c13f07 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Layout.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Layout.php
index 20b1180..1e94d1a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Layout.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Mode.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Mode.php
index 8414cad..4672710 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Mode.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Page.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Page.php
index a750ecf..defb55e 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Page.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Attribute/Source/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Collection.php
index ab9221c..2649a3d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Flat.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Flat.php
index e6ae20f..b1f85aa 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Flat/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Flat/Collection.php
index 330343a..0fc9985 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Flat/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Flat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Indexer/Product.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Indexer/Product.php
index 30ffa50..0869546 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Indexer/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Indexer/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Category/Tree.php b/app/code/core/Mage/Catalog/Model/Resource/Category/Tree.php
index 43c9e33..5f60e79 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Category/Tree.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Category/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Collection/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Collection/Abstract.php
index 3bb6156..af8cf79 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Collection/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Config.php b/app/code/core/Mage/Catalog/Model/Resource/Config.php
index 42c89ea..ddff53a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Config.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Attribute.php
index 914326e..3002099 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Abstract.php
index 5f5541b..c507da7 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Attribute.php
index 387e963..de8ffab 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category.php
index f5008df..202b6f0 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Collection.php
index c1318c4..48fda3c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Frontend/Image.php
index b97e342..190d7a0 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Layout.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Layout.php
index 20e23ae..0772c6c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Layout.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Mode.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Mode.php
index 6b9cbd2..3f473f4 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Mode.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Page.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Page.php
index ba3bed6..a261bb5 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Page.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Attribute/Source/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Collection.php
index 0866f64..e25c02a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat.php
index ad687f8..357cd6b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat/Collection.php
index 6d3fa88..75e7345 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Flat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Indexer/Product.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Indexer/Product.php
index c1af068..7230dc6 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Indexer/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Indexer/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Tree.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Tree.php
index 16e49c7..e360e79 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Tree.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Category/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Collection/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Collection/Abstract.php
index 661d8bf..c53918b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Collection/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Config.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Config.php
index 393c77f..dc24c1c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Config.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Attribute.php
index 6f8bb94..b733dc7 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Decimal.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Decimal.php
index 5eef71f..de4eb27 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Decimal.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Price.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Price.php
index a348f75..1b54dc7 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Layer/Filter/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product.php
index eaa6961..a978c7d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Action.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Action.php
index f55ec0d..ac7db2d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Action.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Image.php
index cc49fd0..6563814 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Media.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Media.php
index 539f1d6..7ec3bfe 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Media.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Tierprice.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Tierprice.php
index e3b6279..8ad2d57 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Tierprice.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Urlkey.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Urlkey.php
index b83432b..a2902c4 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Urlkey.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Backend/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Collection.php
index f18589c..606a2c5 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Image.php
index fbeef0f..ff67529 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Tierprice.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Tierprice.php
index ebfb367..8cf476f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Tierprice.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Attribute/Frontend/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Collection.php
index 2cd72c4..01ee85b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item.php
index f4025ea..88e1397 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item/Collection.php
index 9b3bb3a..c355c03 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Compare/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat.php
index a91c38e..e3b7424 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat/Indexer.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat/Indexer.php
index 6b800bd..525ccdf 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat/Indexer.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Flat/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Abstract.php
index 86c5233..5c381e2 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav.php
index 4671131..4b57c6b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Abstract.php
index cc318a8..498ce7b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Decimal.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Decimal.php
index 793d28c..bcced16 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Decimal.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Source.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Source.php
index c502c40..c03571e 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Source.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Eav/Source.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price.php
index 9a7d7a1..f57e5ba 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Configurable.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Configurable.php
index dbdaa01..5a3dd1f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Configurable.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Default.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Default.php
index aa29bcc..6eb5911 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Default.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Grouped.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Grouped.php
index 530d7be..469078d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Grouped.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Interface.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Interface.php
index 574e9ee..4fbe87a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Interface.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Indexer/Price/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link.php
index 94137c1..9488e4d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Collection.php
index 37a5596..4174e3b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Product/Collection.php
index b5e43b1..c68d908 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Link/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option.php
index d67d7b0..78025fa 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Collection.php
index c91b7ab..2d5916c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value.php
index cb52aea..5a91a88 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value/Collection.php
index a215a5f..c4f665e 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Option/Value/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Relation.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Relation.php
index 3d20ed3..71ca25a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Relation.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Relation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Status.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Status.php
index a9d524d..274b8ef 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Status.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable.php
index 57c5248..68964c6 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute.php
index 6fe74b1..5f07fea 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute/Collection.php
index d35cd4f..d98be50 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Product/Collection.php
index 6cfe84c..c9b5516 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Type/Configurable/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Website.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Website.php
index 674efa3..aa41b4f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Website.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Product/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend.php
index 8bc6a07..2ef08e7 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend/Collection.php
index 4796f7c..36c77da 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Sendfriend/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Setup.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Setup.php
index 27ecefc..722ca5c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Setup.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Url.php b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Url.php
index 78af469..1adab48 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Eav/Mysql4/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Catalog/Model/Resource/Helper/Mysql4.php
index c5b4ccd..c2bdcae 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Attribute.php
index 4255da8..f8e1b8b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Decimal.php b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Decimal.php
index f1bbbc0..b64b018 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Decimal.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Price.php b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Price.php
index c58c234..272315c 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Layer/Filter/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product.php b/app/code/core/Mage/Catalog/Model/Resource/Product.php
index f10a045..e8463ef 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Action.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Action.php
index ebe68ea..af9c8b3 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Action.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice.php
index f030b19..2f3cd9a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice/Abstract.php
index a48afc6..1d3e350 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Groupprice/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Image.php
index b6af306..183536f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Media.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Media.php
index 02724f9..025d5ea 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Media.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Tierprice.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Tierprice.php
index 8308420..d30b3a6 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Tierprice.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Urlkey.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Urlkey.php
index 91f9531..a455285 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Urlkey.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Backend/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Collection.php
index 332ae8a..70bcd85 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Image.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Image.php
index 2b931cb..934c702 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Image.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Tierprice.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Tierprice.php
index 7d69346..d8023dd 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Tierprice.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Attribute/Frontend/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Collection.php
index d995707..1418eff 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item.php
index 892ef58..3dfdaef 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item/Collection.php
index 328f3c1..b717274 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Compare/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Flat.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Flat.php
index afb6945..a565f2b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Flat/Indexer.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Flat/Indexer.php
index fcf2de9..9930fa2 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Flat/Indexer.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Flat/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Abstract.php
index 76ddee2..43070de 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav.php
index 92b2b09..f49e580 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Abstract.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Abstract.php
index 302a1a9..b9fb491 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Abstract.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Decimal.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Decimal.php
index dec119f..92abc0d 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Decimal.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Decimal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Source.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Source.php
index e0280f6..4c2eee9 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Source.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Eav/Source.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price.php
index bc788c8..63228a5 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Configurable.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Configurable.php
index d6c9b08..2d6c88b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Configurable.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Default.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Default.php
index 40dd17e..6941523 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Default.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Grouped.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Grouped.php
index 2b82241..5fe2448 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Grouped.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Interface.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Interface.php
index ca09c1d..f35efa9 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Interface.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Indexer/Price/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Link.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Link.php
index b06924e..b0bee6e 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Link.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Collection.php
index fa5d17d..69b500f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Product/Collection.php
index 9cc585a..5f80535 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Link/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Option.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Option.php
index 91d24e2..200c80a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Option.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Collection.php
index e953f8a..1fa8ec8 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value.php
index 125101a..cab638a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value/Collection.php
index dad15b6..e982bc7 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Option/Value/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Relation.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Relation.php
index 2851f53..a36aa1f 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Relation.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Relation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Status.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Status.php
index 638188f..ad97423 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Status.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable.php
index 80edbda..c56fdec 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute.php
index a54fa4a..122e30a 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute/Collection.php
index 6e5ee01..d5c1849 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Product/Collection.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Product/Collection.php
index cfaeb62..b84fb9b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Product/Collection.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Type/Configurable/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Product/Website.php b/app/code/core/Mage/Catalog/Model/Resource/Product/Website.php
index aa0e306..beae8ae 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Product/Website.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Product/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Setup.php b/app/code/core/Mage/Catalog/Model/Resource/Setup.php
index e626674..f69e10b 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Resource/Url.php b/app/code/core/Mage/Catalog/Model/Resource/Url.php
index 9818911..930b739 100644
--- a/app/code/core/Mage/Catalog/Model/Resource/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Resource/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Session.php b/app/code/core/Mage/Catalog/Model/Session.php
index d0e3815..828c9b5 100644
--- a/app/code/core/Mage/Catalog/Model/Session.php
+++ b/app/code/core/Mage/Catalog/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Category/Flat.php b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Category/Flat.php
index 6ce4559..7afbc52 100644
--- a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Category/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Category/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Product/Flat.php b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Product/Flat.php
index d8896ba..7c281dc 100644
--- a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Product/Flat.php
+++ b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Product/Flat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Url/Rewrite/Suffix.php b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Url/Rewrite/Suffix.php
index 41a69042..5dc718a 100644
--- a/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Url/Rewrite/Suffix.php
+++ b/app/code/core/Mage/Catalog/Model/System/Config/Backend/Catalog/Url/Rewrite/Suffix.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Template/Filter.php b/app/code/core/Mage/Catalog/Model/Template/Filter.php
index 0715a4f..13df38b 100644
--- a/app/code/core/Mage/Catalog/Model/Template/Filter.php
+++ b/app/code/core/Mage/Catalog/Model/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/Model/Url.php b/app/code/core/Mage/Catalog/Model/Url.php
index 98fef1a..6ee82bb 100644
--- a/app/code/core/Mage/Catalog/Model/Url.php
+++ b/app/code/core/Mage/Catalog/Model/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/controllers/CategoryController.php b/app/code/core/Mage/Catalog/controllers/CategoryController.php
index fa5959b..0b6e5a1 100644
--- a/app/code/core/Mage/Catalog/controllers/CategoryController.php
+++ b/app/code/core/Mage/Catalog/controllers/CategoryController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/controllers/IndexController.php b/app/code/core/Mage/Catalog/controllers/IndexController.php
index 9a1f930..6b422c1 100644
--- a/app/code/core/Mage/Catalog/controllers/IndexController.php
+++ b/app/code/core/Mage/Catalog/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/controllers/Product/CompareController.php b/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
index 18b2309..2be9c52 100644
--- a/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
+++ b/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/controllers/ProductController.php b/app/code/core/Mage/Catalog/controllers/ProductController.php
index 316a125..1a66812 100644
--- a/app/code/core/Mage/Catalog/controllers/ProductController.php
+++ b/app/code/core/Mage/Catalog/controllers/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/controllers/Seo/SitemapController.php b/app/code/core/Mage/Catalog/controllers/Seo/SitemapController.php
index 2acde31..3b0a096 100644
--- a/app/code/core/Mage/Catalog/controllers/Seo/SitemapController.php
+++ b/app/code/core/Mage/Catalog/controllers/Seo/SitemapController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-install-1.6.0.0.php
index a95ca34..da5462f 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.12-1.6.0.0.13.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.12-1.6.0.0.13.php
index 36b48a5..bf1d727 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.12-1.6.0.0.13.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.12-1.6.0.0.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.13-1.6.0.0.14.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.13-1.6.0.0.14.php
index b99c340..c85a16c 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.13-1.6.0.0.14.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.13-1.6.0.0.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /** @var $installer Mage_Catalog_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php
index 5050203..46f1d8f 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /** @var $installer Mage_Catalog_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.4-1.6.0.0.5.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.4-1.6.0.0.5.php
index 921dfe0..80c3b93 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.4-1.6.0.0.5.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.4-1.6.0.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.8-1.6.0.0.9.php b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.8-1.6.0.0.9.php
index 7b111f4..bc62c7d 100644
--- a/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.8-1.6.0.0.9.php
+++ b/app/code/core/Mage/Catalog/data/catalog_setup/data-upgrade-1.6.0.0.8-1.6.0.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/etc/adminhtml.xml b/app/code/core/Mage/Catalog/etc/adminhtml.xml
index 945f7ec..0ba43e5 100644
--- a/app/code/core/Mage/Catalog/etc/adminhtml.xml
+++ b/app/code/core/Mage/Catalog/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/api.xml b/app/code/core/Mage/Catalog/etc/api.xml
index f9f5287..c244ecd 100644
--- a/app/code/core/Mage/Catalog/etc/api.xml
+++ b/app/code/core/Mage/Catalog/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/api2.xml b/app/code/core/Mage/Catalog/etc/api2.xml
index b1422f2..a099fed 100644
--- a/app/code/core/Mage/Catalog/etc/api2.xml
+++ b/app/code/core/Mage/Catalog/etc/api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/config.xml b/app/code/core/Mage/Catalog/etc/config.xml
index 087ad77..f038fc0 100644
--- a/app/code/core/Mage/Catalog/etc/config.xml
+++ b/app/code/core/Mage/Catalog/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/convert.xml b/app/code/core/Mage/Catalog/etc/convert.xml
index 8bc29d6..00c4369 100644
--- a/app/code/core/Mage/Catalog/etc/convert.xml
+++ b/app/code/core/Mage/Catalog/etc/convert.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/system.xml b/app/code/core/Mage/Catalog/etc/system.xml
index c79dd71..cd5c822 100644
--- a/app/code/core/Mage/Catalog/etc/system.xml
+++ b/app/code/core/Mage/Catalog/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/etc/widget.xml b/app/code/core/Mage/Catalog/etc/widget.xml
index 5a1b12c..e7590f0 100644
--- a/app/code/core/Mage/Catalog/etc/widget.xml
+++ b/app/code/core/Mage/Catalog/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/install-1.6.0.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/install-1.6.0.0.php
index 3465493..b7736aa 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.57-0.7.58.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.57-0.7.58.php
index 68b66c7..7dbe121 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.57-0.7.58.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.57-0.7.58.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.63-0.7.64.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.63-0.7.64.php
index dd237da..766fe76 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.63-0.7.64.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-0.7.63-0.7.64.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php
index a1d3515..93dbc7e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php
index e80a24b..c214a24 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-0.7.0.php
index d4d3e2f..a9a3206 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-1.4.0.0.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-1.4.0.0.0.php
index 7460075..8091c11 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-1.4.0.0.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-install-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.6.40-0.7.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.6.40-0.7.0.php
index 569a63f..fbb4267 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.6.40-0.7.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.6.40-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.0-0.7.1.php
index fb99155..6d8d9cf 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 4001566..3e7c7aa 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.11-0.7.12.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.11-0.7.12.php
index 3e76e27..8c38204 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.11-0.7.12.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.11-0.7.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.12-0.7.13.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.12-0.7.13.php
index 03b4142..6ecf0fd 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.12-0.7.13.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.12-0.7.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.13-0.7.14.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.13-0.7.14.php
index 99e6b4f..84fb337 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.13-0.7.14.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.13-0.7.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.14-0.7.15.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.14-0.7.15.php
index 15108ae..13e4fbc 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.14-0.7.15.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.14-0.7.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $this->startSetup()->run("
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.15-0.7.16.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.15-0.7.16.php
index 987d1f9..036676a 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.15-0.7.16.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.15-0.7.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.16-0.7.17.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.16-0.7.17.php
index 03b4142..6ecf0fd 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.16-0.7.17.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.16-0.7.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.17-0.7.18.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.17-0.7.18.php
index 57bcf71..eb045b5 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.17-0.7.18.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.17-0.7.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.18-0.7.19.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.18-0.7.19.php
index c28d8e1..e58dd3d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.18-0.7.19.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.18-0.7.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.19-0.7.20.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.19-0.7.20.php
index 3e76e27..8c38204 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.19-0.7.20.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.19-0.7.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 1447ce4..aefc87f 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.20-0.7.21.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.20-0.7.21.php
index 556f294..2cbb026 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.20-0.7.21.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.20-0.7.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.21-0.7.22.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.21-0.7.22.php
index 9947fd3..50682f8 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.21-0.7.22.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.21-0.7.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.22-0.7.23.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.22-0.7.23.php
index 071cb52..3794036 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.22-0.7.23.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.22-0.7.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.23-0.7.24.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.23-0.7.24.php
index 4b37737..0c50f3c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.23-0.7.24.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.23-0.7.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.24-0.7.25.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.24-0.7.25.php
index a0b0be6..0995203 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.24-0.7.25.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.24-0.7.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.25-0.7.26.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.25-0.7.26.php
index a0b0be6..0995203 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.25-0.7.26.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.25-0.7.26.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.26-0.7.27.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.26-0.7.27.php
index 2f15199..6e72635 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.26-0.7.27.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.26-0.7.27.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.27-0.7.28.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.27-0.7.28.php
index 0e18d28..1723b9a 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.27-0.7.28.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.27-0.7.28.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.28-0.7.29.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.28-0.7.29.php
index dcfcd1f..134eb9d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.28-0.7.29.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.28-0.7.29.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.29-0.7.30.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.29-0.7.30.php
index 6c94727..b518cae 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.29-0.7.30.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.29-0.7.30.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.30-0.7.31.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.30-0.7.31.php
index 89cf103..8bfb8ee 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.30-0.7.31.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.30-0.7.31.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.31-0.7.32.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.31-0.7.32.php
index abaadbc..acb777c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.31-0.7.32.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.31-0.7.32.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.32-0.7.33.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.32-0.7.33.php
index 324598b..d0abe4e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.32-0.7.33.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.32-0.7.33.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.33-0.7.34.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.33-0.7.34.php
index baed5bf..a83e38d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.33-0.7.34.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.33-0.7.34.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.34-0.7.35.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.34-0.7.35.php
index 339fb0d..4b4cf80 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.34-0.7.35.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.34-0.7.35.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.35-0.7.36.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.35-0.7.36.php
index e0b9339..4a16939 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.35-0.7.36.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.35-0.7.36.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.36-0.7.37.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.36-0.7.37.php
index 5618fed..445d25c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.36-0.7.37.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.36-0.7.37.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.37-0.7.38.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.37-0.7.38.php
index 970dec8..f27c6f5 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.37-0.7.38.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.37-0.7.38.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.38-0.7.39.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.38-0.7.39.php
index 8e88c5e..636309e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.38-0.7.39.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.38-0.7.39.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.39-0.7.40.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.39-0.7.40.php
index 9e28be6..69167a3 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.39-0.7.40.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.39-0.7.40.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 5343a20..d04d65d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.40-0.7.41.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.40-0.7.41.php
index cb707fa..d1a9806 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.40-0.7.41.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.40-0.7.41.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.41-0.7.42.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.41-0.7.42.php
index c2f4c23..a0b77b3 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.41-0.7.42.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.41-0.7.42.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.43-0.7.44.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.43-0.7.44.php
index 4bc7cd0..c172b5e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.43-0.7.44.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.43-0.7.44.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.44-0.7.45.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.44-0.7.45.php
index 5fd5a15..b744014 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.44-0.7.45.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.44-0.7.45.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.45-0.7.46.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.45-0.7.46.php
index 128b4a8..3505e4a 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.45-0.7.46.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.45-0.7.46.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.46-0.7.47.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.46-0.7.47.php
index a854062..63b8999 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.46-0.7.47.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.46-0.7.47.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.47-0.7.48.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.47-0.7.48.php
index 387d022..986edc0 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.47-0.7.48.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.47-0.7.48.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.48-0.7.49.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.48-0.7.49.php
index ba6463a..74d5df4 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.48-0.7.49.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.48-0.7.49.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.49-0.7.50.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.49-0.7.50.php
index 480f704..32bbaec 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.49-0.7.50.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.49-0.7.50.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 81b9137..9d50cdc 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.50-0.7.51.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.50-0.7.51.php
index 0a484ea..91279ce 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.50-0.7.51.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.50-0.7.51.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.51-0.7.52.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.51-0.7.52.php
index 52afc1b..653cd56 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.51-0.7.52.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.51-0.7.52.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.52-0.7.53.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.52-0.7.53.php
index fe6ca67..4bdf4fe 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.52-0.7.53.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.52-0.7.53.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.53-0.7.54.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.53-0.7.54.php
index f2fe5af..a37cd89 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.53-0.7.54.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.53-0.7.54.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.54-0.7.55.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.54-0.7.55.php
index dc7c67a..480c96d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.54-0.7.55.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.54-0.7.55.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.55-0.7.56.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.55-0.7.56.php
index a5047f0..3bd0e66 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.55-0.7.56.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.55-0.7.56.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.56-0.7.57.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.56-0.7.57.php
index 9d1ae42..071bcbf 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.56-0.7.57.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.56-0.7.57.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.57-0.7.58.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.57-0.7.58.php
index 5ce94dd..ed4591c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.57-0.7.58.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.57-0.7.58.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.58-0.7.59.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.58-0.7.59.php
index e7c2aba..f7b0b35 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.58-0.7.59.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.58-0.7.59.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.59-0.7.60.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.59-0.7.60.php
index fde2724..6f6edda 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.59-0.7.60.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.59-0.7.60.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 3e76e27..8c38204 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.60-0.7.61.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.60-0.7.61.php
index 0b641a6..a1ee90f 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.60-0.7.61.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.60-0.7.61.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.61-0.7.62.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.61-0.7.62.php
index 3a7310b..56bb87f 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.61-0.7.62.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.61-0.7.62.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.62-0.7.63.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.62-0.7.63.php
index a2969e6..7ee9d0c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.62-0.7.63.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.62-0.7.63.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.63-0.7.64.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.63-0.7.64.php
index 26c02af..35f4b5f 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.63-0.7.64.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.63-0.7.64.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.64-0.7.65.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.64-0.7.65.php
index 447f2ea..a766d52 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.64-0.7.65.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.64-0.7.65.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.65-0.7.66.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.65-0.7.66.php
index 77d733c..0e2690e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.65-0.7.66.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.65-0.7.66.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.66-0.7.67.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.66-0.7.67.php
index b6d7f9a..060b6b9 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.66-0.7.67.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.66-0.7.67.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.67-0.7.68.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.67-0.7.68.php
index 67ddb38..3c46881 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.67-0.7.68.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.67-0.7.68.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.68-0.7.69.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.68-0.7.69.php
index 11d9b63..fa93093 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.68-0.7.69.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.68-0.7.69.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.69-0.7.70.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.69-0.7.70.php
index 4e18eb0..daf65d7 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.69-0.7.70.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.69-0.7.70.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.7-0.7.8.php
index c0ea7df..9d45178 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.70-0.7.71.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.70-0.7.71.php
index 69ba93b..8645968 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.70-0.7.71.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.70-0.7.71.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.71-0.7.72.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.71-0.7.72.php
index 08702b6..aa1036f 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.71-0.7.72.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.71-0.7.72.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.72-0.7.73.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.72-0.7.73.php
index 29ad0f3..bc6c8da 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.72-0.7.73.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.72-0.7.73.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.73-1.4.0.0.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.73-1.4.0.0.0.php
index fa16722..af147e6 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.73-1.4.0.0.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.73-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 2672b9e..d529ce5 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
index b0f474c..ff95562 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
index 0c1b55e..279a377 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
index db775a5..34c68ed 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php
index 6f74718..fa93bca 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
index a82f93f..5f5549c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php
index 7ab2b3e..5db45ff 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php
index 77b7925..edd0297 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php
index 048caeb..3ac22f9 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php
index fd7a6f8..5d04a8b 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php
index 5504e78..d166e4e 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php
index 453443d..6e44160 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php
index 977f16d..d4c02f7 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
index d06cb05..316d5f3 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php
index 9dc0bdb..e89795b 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php
index ad0f7ce..57aa988 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php
index 080c7ca..2d96573 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php
index cb69aac..4c802aa 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php
index 263ab0f..ecb0829 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php
index 52d87ab..f5e1880 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php
index 1d813b9..4227caf 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php
index 29e7c10..64d5e87 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php
index 14c8019..937da23 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
index 1397f72..de7053c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php
index 9986851..aae860d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php
index 7986f37..559bce1 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php
index bcd4553..e30b6e2 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php
index d13a038..7d0baab 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php
index e820006..1d2d553 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php
index b122cf3..ff6f5e2 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php
index af5d3f5..13e5e28 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php
index b8e6cec..903cc37 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php
index 1dd2a2b..dad0330 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php
index 1f600eb..6ea79f0 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
index d0d2275..e34aea0 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php
index c0e09c7..87ee545 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php
index 410917a..efebbf3 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php
index cfd90ed..36c33b8 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
index 9a4c16b..6207f42 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
index 2623864..321ce0c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
index 2a30da7..e9d7535 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
index 7e8a7ed..bef9eff 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
index 3e55076..1ae049d 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 3c74e08..6e962dc 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php
index b18b46c..4886e53 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0-1.6.0.0.1.php
index 59cdc3a..9bb691b 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
index c3ba474..5a22023 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.10-1.6.0.0.11.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.10-1.6.0.0.11.php
index 1cdcbe4..dd1c591 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.10-1.6.0.0.11.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.10-1.6.0.0.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.11-1.6.0.0.12.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.11-1.6.0.0.12.php
index 5136b31..59f1133 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.11-1.6.0.0.12.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.11-1.6.0.0.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.14-1.6.0.0.15.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.14-1.6.0.0.15.php
index 1c2aea7..be67c34 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.14-1.6.0.0.15.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.14-1.6.0.0.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.15-1.6.0.0.18.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.15-1.6.0.0.18.php
index 6671287..0e604db 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.15-1.6.0.0.18.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.15-1.6.0.0.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.18-1.6.0.0.19.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.18-1.6.0.0.19.php
index a7fb18a..2791cf7 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.18-1.6.0.0.19.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.18-1.6.0.0.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php
index 86c3956..52f7e96 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php
index 23721ce..deaa498 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php
index cc5290f..699659a 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
index 7750e69..cb598b0 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.3-1.6.0.0.4.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.3-1.6.0.0.4.php
index 386489e..bb2a27a 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.3-1.6.0.0.4.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.3-1.6.0.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.4-1.6.0.0.5.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.4-1.6.0.0.5.php
index 94f122f..64f7647 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.4-1.6.0.0.5.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.4-1.6.0.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.5-1.6.0.0.6.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.5-1.6.0.0.6.php
index 11b2ee1..ec59897 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.5-1.6.0.0.6.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.5-1.6.0.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.6-1.6.0.0.7.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.6-1.6.0.0.7.php
index 46e7b0e..39e5e5c 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.6-1.6.0.0.7.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.6-1.6.0.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.7-1.6.0.0.8.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.7-1.6.0.0.8.php
index 4a1d67c..eaab890 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.7-1.6.0.0.8.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.7-1.6.0.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.9-1.6.0.0.10.php b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.9-1.6.0.0.10.php
index 5d1f824..0913f61 100644
--- a/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.9-1.6.0.0.10.php
+++ b/app/code/core/Mage/Catalog/sql/catalog_setup/upgrade-1.6.0.0.9-1.6.0.0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Catalog
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Aggregation.php b/app/code/core/Mage/CatalogIndex/Model/Aggregation.php
index 16251b9..050d499 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Aggregation.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Attribute.php b/app/code/core/Mage/CatalogIndex/Model/Attribute.php
index 732ef93..33715e2 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Attribute.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Flag.php b/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Flag.php
index cee63b9..cb91d52 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Flag.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Kill/Flag.php b/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Kill/Flag.php
index f120e58..765df8a 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Kill/Flag.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Catalog/Index/Kill/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Data/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Data/Abstract.php
index e279c74..a066b62 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Data/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Data/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Data/Configurable.php b/app/code/core/Mage/CatalogIndex/Model/Data/Configurable.php
index b863c5e..67ee572 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Data/Configurable.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Data/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Data/Grouped.php b/app/code/core/Mage/CatalogIndex/Model/Data/Grouped.php
index 567fe31..748074a 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Data/Grouped.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Data/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Data/Simple.php b/app/code/core/Mage/CatalogIndex/Model/Data/Simple.php
index a5b2c33..b9e93c2 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Data/Simple.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Data/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Data/Virtual.php b/app/code/core/Mage/CatalogIndex/Model/Data/Virtual.php
index 8722858..fe957af 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Data/Virtual.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Data/Virtual.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer.php b/app/code/core/Mage/CatalogIndex/Model/Indexer.php
index 1e3c2ce..f95dc27 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Abstract.php
index 29e6b94..26fe36f 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Eav.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Eav.php
index 2d84d4a..d72729d 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Eav.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Interface.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Interface.php
index 47eea81..7f15f39 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Interface.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Minimalprice.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Minimalprice.php
index 0ee8fba..734a178 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Minimalprice.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Minimalprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Price.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Price.php
index a537e45..db3bffa 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Indexer/Tierprice.php b/app/code/core/Mage/CatalogIndex/Model/Indexer/Tierprice.php
index a2983fa..5438800 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Indexer/Tierprice.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Indexer/Tierprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Abstract.php
index 23cd020..bdfee33 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Aggregation.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Aggregation.php
index 2af5ae7..4263b86 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Aggregation.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Attribute.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Attribute.php
index 2116adb..d53b230 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Attribute.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Abstract.php
index 1b75523..e76a2e5 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Configurable.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Configurable.php
index d4300cf..360f66b 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Configurable.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Grouped.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Grouped.php
index 0c0f03b..72a8e21 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Grouped.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Data/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer.php
index 6d853cb..6e0e638 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Abstract.php
index 102348c..cb13fdb 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Eav.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Eav.php
index 4ec858c..ddaa16a 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Eav.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Minimalprice.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Minimalprice.php
index a679c27..672aa43 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Minimalprice.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Minimalprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Price.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Price.php
index 9926eb8..1cf1162 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Price.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Price.php
index 91922bf..8088fbd 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Retreiver.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Retreiver.php
index 3ff5be3..7de4969 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Retreiver.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Retreiver.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Setup.php b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Setup.php
index 2ea01cc..431e40b 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Observer.php b/app/code/core/Mage/CatalogIndex/Model/Observer.php
index 156015f..dd17279 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Observer.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Price.php b/app/code/core/Mage/CatalogIndex/Model/Price.php
index 2c73a8f..7dbb37b 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Abstract.php
index 510e9d9..9be5bb0 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Aggregation.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Aggregation.php
index 2e6734a..0a51e05 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Aggregation.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Attribute.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Attribute.php
index dfa3a10..499cabc 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Attribute.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Abstract.php
index b8fea6f..24842f5 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Configurable.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Configurable.php
index 79a1d68..f3f5967 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Configurable.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Grouped.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Grouped.php
index 287ed0c..9b8773a 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Grouped.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Data/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer.php
index b28d78c..98ab5cb 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Abstract.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Abstract.php
index e021e64..aff52c8 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Abstract.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Eav.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Eav.php
index eb281bb..0317f32 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Eav.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Eav.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Minimalprice.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Minimalprice.php
index 7fc9ef2..f2cd0bc 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Minimalprice.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Minimalprice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Price.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Price.php
index a9a8045..6223766 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Price.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Price.php
index 62025c5..cee042e 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Price.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Retreiver.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Retreiver.php
index 848ca72..3291eab 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Retreiver.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Retreiver.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Resource/Setup.php b/app/code/core/Mage/CatalogIndex/Model/Resource/Setup.php
index e532fc8..c01f3dd 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Resource/Setup.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/Model/Retreiver.php b/app/code/core/Mage/CatalogIndex/Model/Retreiver.php
index 3ba4126..c725844 100644
--- a/app/code/core/Mage/CatalogIndex/Model/Retreiver.php
+++ b/app/code/core/Mage/CatalogIndex/Model/Retreiver.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/etc/config.xml b/app/code/core/Mage/CatalogIndex/etc/config.xml
index 01c1027..9b9471a 100644
--- a/app/code/core/Mage/CatalogIndex/etc/config.xml
+++ b/app/code/core/Mage/CatalogIndex/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/install-1.6.0.0.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/install-1.6.0.0.php
index 625a129..cacd281 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-install-0.7.0.php
index 850118e..362c5e5 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.0-0.7.1.php
index f41c66b..58889e1 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 5050551..4d13600 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.2-0.7.3.php
index ca4bf51..b24b547 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 54b4aff..33d01e6 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 007a6a2..3a3a179 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.5-0.7.6.php
index c94d758..c48c47f 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 23cdf8f..b4beee3 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 796e801..5c0c6cb 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 562f4fd..d48cb2a 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 2a42a38..7695518 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 918d1b7..af48ce0 100644
--- a/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogIndex/sql/catalogindex_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogIndex
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Customergroup.php b/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Customergroup.php
index f90706f..bc47e7d 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Customergroup.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Customergroup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Minsaleqty.php b/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Minsaleqty.php
index 313d749..2cfc19c 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Minsaleqty.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Adminhtml/Form/Field/Minsaleqty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Qtyincrements.php b/app/code/core/Mage/CatalogInventory/Block/Qtyincrements.php
index 67b285d..e0cde15 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Qtyincrements.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Qtyincrements.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Abstract.php b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Abstract.php
index b713409..db0fe8a 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Abstract.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Composite.php b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Composite.php
index 93f514b..38285df 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Composite.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Composite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Default.php b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Default.php
index c0e9a52..f275969 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Default.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Configurable.php b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Configurable.php
index 49d1bf3..764f5a5 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Configurable.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Grouped.php b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Grouped.php
index 687a003..2498e81 100644
--- a/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Grouped.php
+++ b/app/code/core/Mage/CatalogInventory/Block/Stockqty/Type/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Helper/Data.php b/app/code/core/Mage/CatalogInventory/Helper/Data.php
index a7933b5..f8a53d9 100644
--- a/app/code/core/Mage/CatalogInventory/Helper/Data.php
+++ b/app/code/core/Mage/CatalogInventory/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Helper/Minsaleqty.php b/app/code/core/Mage/CatalogInventory/Helper/Minsaleqty.php
index 71ca012..8fcb1e0 100644
--- a/app/code/core/Mage/CatalogInventory/Helper/Minsaleqty.php
+++ b/app/code/core/Mage/CatalogInventory/Helper/Minsaleqty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item.php b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item.php
index 105dfed..1914f9b 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest.php b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest.php
index e556eb2..d71bec6 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest/Admin/V1.php b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest/Admin/V1.php
index b00ea5b..3031b9f 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest/Admin/V1.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Validator/Item.php b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Validator/Item.php
index 0d67be3..55d09f1 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Validator/Item.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Api2/Stock/Item/Validator/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Indexer/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Indexer/Stock.php
index 4dd63cb..dec4086 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Indexer/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Indexer/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock.php
index b0a9eea..279b2d3 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Configurable.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Configurable.php
index 473bc82..2d6e4b7 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Configurable.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Default.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Default.php
index fd94182..47e2c9a 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Default.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Grouped.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Grouped.php
index 959fdee..d93aec9 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Grouped.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Interface.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Interface.php
index 42fb57c..b17da0b 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Interface.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Indexer/Stock/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock.php
index d778c45..50d710b 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item.php
index 3739705..9d998c7 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item/Collection.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item/Collection.php
index 3161932..e8fe283 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item/Collection.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Status.php b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Status.php
index a217f2d..1d1d848 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Status.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Mysql4/Stock/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Observer.php b/app/code/core/Mage/CatalogInventory/Model/Observer.php
index deaf923..d62cb25 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Observer.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock.php
index f7c1fca..7b5c4c0 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Configurable.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Configurable.php
index 0d799dd..24666df 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Configurable.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Default.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Default.php
index bcbfd72..c9794f7 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Default.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Grouped.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Grouped.php
index 8456262..33d6e4f 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Grouped.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Interface.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Interface.php
index c3f0538..868fb62 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Interface.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Indexer/Stock/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock.php
index 15faa23..6f265f8 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item.php
index 4698fcd..5113f99 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item/Collection.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item/Collection.php
index 9e4cf0d..3a51ebf 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item/Collection.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Status.php b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Status.php
index 1fa2962..fdd48e1 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Status.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Resource/Stock/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Source/Backorders.php b/app/code/core/Mage/CatalogInventory/Model/Source/Backorders.php
index 56e6b56..23e68af 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Source/Backorders.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Source/Backorders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Source/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Source/Stock.php
index c5934b2..db61635 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Source/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Source/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Stock.php b/app/code/core/Mage/CatalogInventory/Model/Stock.php
index 15916b0..fb14ae4 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Stock.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Stock/Item.php b/app/code/core/Mage/CatalogInventory/Model/Stock/Item.php
index 21f7a71..a728b73 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Stock/Item.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Stock/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api.php b/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api.php
index 7f859bf..55d7417 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api/V2.php b/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api/V2.php
index 57a65b1..7eaefb6 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api/V2.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Stock/Item/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/Stock/Status.php b/app/code/core/Mage/CatalogInventory/Model/Stock/Status.php
index 5623658..bf5d475 100644
--- a/app/code/core/Mage/CatalogInventory/Model/Stock/Status.php
+++ b/app/code/core/Mage/CatalogInventory/Model/Stock/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minqty.php b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minqty.php
index 7722315..344e12b 100644
--- a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minqty.php
+++ b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minqty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minsaleqty.php b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minsaleqty.php
index 3935079..3e17ab8 100644
--- a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minsaleqty.php
+++ b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Minsaleqty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Qtyincrements.php b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Qtyincrements.php
index 73836db..7ee7225 100644
--- a/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Qtyincrements.php
+++ b/app/code/core/Mage/CatalogInventory/Model/System/Config/Backend/Qtyincrements.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/etc/adminhtml.xml b/app/code/core/Mage/CatalogInventory/etc/adminhtml.xml
index 4566bb5..2d040fe 100644
--- a/app/code/core/Mage/CatalogInventory/etc/adminhtml.xml
+++ b/app/code/core/Mage/CatalogInventory/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogInventory/etc/api.xml b/app/code/core/Mage/CatalogInventory/etc/api.xml
index e6ca1cb..d94f4ad 100644
--- a/app/code/core/Mage/CatalogInventory/etc/api.xml
+++ b/app/code/core/Mage/CatalogInventory/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogInventory/etc/api2.xml b/app/code/core/Mage/CatalogInventory/etc/api2.xml
index 294d7d4..9cc2295 100644
--- a/app/code/core/Mage/CatalogInventory/etc/api2.xml
+++ b/app/code/core/Mage/CatalogInventory/etc/api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogInventory/etc/config.xml b/app/code/core/Mage/CatalogInventory/etc/config.xml
index 301e7a9..1f6549d 100644
--- a/app/code/core/Mage/CatalogInventory/etc/config.xml
+++ b/app/code/core/Mage/CatalogInventory/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogInventory/etc/system.xml b/app/code/core/Mage/CatalogInventory/etc/system.xml
index c3033e0..dd139c9 100644
--- a/app/code/core/Mage/CatalogInventory/etc/system.xml
+++ b/app/code/core/Mage/CatalogInventory/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/install-1.6.0.0.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/install-1.6.0.0.php
index 268b8b2..76168c8 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-install-0.7.0.php
index b486762..a34379f 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 74c4ce1..366a03d 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 4b5ad9e..ca94418 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 041fc93..ea9b163 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.3-0.7.4.php
index d6e52c0..298df3d 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 13e3877..e05b71d 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 84f03d7..b574985 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.6-0.7.7.php
index e5a9d8d..633cd48 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.7-0.7.8.php
index d1c7c31..38f60a8 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 7e40dc6..e48d160 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
index 775bed3..54411f9 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/mysql4-upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
index 4e99c7f..a6d454f 100644
--- a/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
+++ b/app/code/core/Mage/CatalogInventory/sql/cataloginventory_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogInventory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Helper/Data.php b/app/code/core/Mage/CatalogRule/Helper/Data.php
index f57696c..545dc50 100644
--- a/app/code/core/Mage/CatalogRule/Helper/Data.php
+++ b/app/code/core/Mage/CatalogRule/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh.php b/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh.php
index 60e274c..85b9a19 100644
--- a/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh.php
+++ b/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh/Row.php b/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh/Row.php
index dfc1fb3..733d176 100644
--- a/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh/Row.php
+++ b/app/code/core/Mage/CatalogRule/Model/Action/Index/Refresh/Row.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Flag.php b/app/code/core/Mage/CatalogRule/Model/Flag.php
index 5066b69..4eccc0e 100644
--- a/app/code/core/Mage/CatalogRule/Model/Flag.php
+++ b/app/code/core/Mage/CatalogRule/Model/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule.php b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule.php
index 317682f..086703b 100644
--- a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule.php
+++ b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Collection.php b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Collection.php
index 217d54f..0506fdc 100644
--- a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Collection.php
+++ b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price.php b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price.php
index 1d2eb28..fda152b 100644
--- a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price.php
+++ b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price/Collection.php b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price/Collection.php
index 0c8ee18..7ac2043 100644
--- a/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price/Collection.php
+++ b/app/code/core/Mage/CatalogRule/Model/Mysql4/Rule/Product/Price/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Observer.php b/app/code/core/Mage/CatalogRule/Model/Observer.php
index fde8769..e6a1f2e 100644
--- a/app/code/core/Mage/CatalogRule/Model/Observer.php
+++ b/app/code/core/Mage/CatalogRule/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Resource/Rule.php b/app/code/core/Mage/CatalogRule/Model/Resource/Rule.php
index b67bd3c..a893566 100644
--- a/app/code/core/Mage/CatalogRule/Model/Resource/Rule.php
+++ b/app/code/core/Mage/CatalogRule/Model/Resource/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Collection.php b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Collection.php
index 849eb2a..7a95cd9 100644
--- a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Collection.php
+++ b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price.php b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price.php
index cffb505..96542c5 100644
--- a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price.php
+++ b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price/Collection.php b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price/Collection.php
index b0fdb6e..68c1e1e 100644
--- a/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price/Collection.php
+++ b/app/code/core/Mage/CatalogRule/Model/Resource/Rule/Product/Price/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule.php b/app/code/core/Mage/CatalogRule/Model/Rule.php
index 1ff8d93..e386aaa 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule/Action/Collection.php b/app/code/core/Mage/CatalogRule/Model/Rule/Action/Collection.php
index b9584b7..ba1a087 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule/Action/Collection.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule/Action/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule/Action/Product.php b/app/code/core/Mage/CatalogRule/Model/Rule/Action/Product.php
index b090ec9..ae1a961 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule/Action/Product.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule/Action/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Combine.php b/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Combine.php
index c4d98ba..32b7a9d 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Combine.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Combine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Product.php b/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Product.php
index 3e07a76..2fbb1bf 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Product.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule/Condition/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/Model/Rule/Product/Price.php b/app/code/core/Mage/CatalogRule/Model/Rule/Product/Price.php
index a81d04e..fb50e5b 100644
--- a/app/code/core/Mage/CatalogRule/Model/Rule/Product/Price.php
+++ b/app/code/core/Mage/CatalogRule/Model/Rule/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/etc/adminhtml.xml b/app/code/core/Mage/CatalogRule/etc/adminhtml.xml
index 0ff6b03..4429156 100644
--- a/app/code/core/Mage/CatalogRule/etc/adminhtml.xml
+++ b/app/code/core/Mage/CatalogRule/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogRule/etc/config.xml b/app/code/core/Mage/CatalogRule/etc/config.xml
index ae55ab4..21128f4 100644
--- a/app/code/core/Mage/CatalogRule/etc/config.xml
+++ b/app/code/core/Mage/CatalogRule/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/install-1.6.0.0.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/install-1.6.0.0.php
index 3d2af1c..eb7feb9 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-install-0.7.0.php
index 95413b7..cd9286a 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
index a0720c7..564449f 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 36cc263..68e7a4f 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 36a2b75..11510e9 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 79eacd5..be52dff 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
index dd7348f..81a04fe 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
index ae022ac..9d4dedf 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 980e727..1c53fca 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
index a960280..02aed95 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 8ec23de..9158419 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
index fb31ba4..761e59a 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 48d617d..f0f4405 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.0-1.6.0.1.php
index 3b61e94..078918f 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.1-1.6.0.2.php
index 4a6baba..d9dcca9 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.2-1.6.0.3.php
index d0356dd..d063b45 100644
--- a/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/CatalogRule/sql/catalogrule_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Advanced/Form.php b/app/code/core/Mage/CatalogSearch/Block/Advanced/Form.php
index b6078a9..f69becb 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Advanced/Form.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Advanced/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Advanced/Result.php b/app/code/core/Mage/CatalogSearch/Block/Advanced/Result.php
index f221fef..3df4101 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Advanced/Result.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Advanced/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Autocomplete.php b/app/code/core/Mage/CatalogSearch/Block/Autocomplete.php
index a2f6d4d..a783d5f 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Autocomplete.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Autocomplete.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Layer.php b/app/code/core/Mage/CatalogSearch/Block/Layer.php
index 3a36348..e10733c 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Layer.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Layer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Layer/Filter/Attribute.php b/app/code/core/Mage/CatalogSearch/Block/Layer/Filter/Attribute.php
index 5424647..45ca108 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Result.php b/app/code/core/Mage/CatalogSearch/Block/Result.php
index d05a6b1..ddb2802 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Result.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Block/Term.php b/app/code/core/Mage/CatalogSearch/Block/Term.php
index b650f7f..0da074a 100644
--- a/app/code/core/Mage/CatalogSearch/Block/Term.php
+++ b/app/code/core/Mage/CatalogSearch/Block/Term.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Helper/Data.php b/app/code/core/Mage/CatalogSearch/Helper/Data.php
index 1e71864..32e2b89 100644
--- a/app/code/core/Mage/CatalogSearch/Helper/Data.php
+++ b/app/code/core/Mage/CatalogSearch/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Advanced.php b/app/code/core/Mage/CatalogSearch/Model/Advanced.php
index b88bfba..0e4b62f 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Advanced.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Advanced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Fulltext.php
index 5358c82..85acc91 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Fulltext/Observer.php b/app/code/core/Mage/CatalogSearch/Model/Fulltext/Observer.php
index fcdddb3..8fcec0d 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Fulltext/Observer.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Fulltext/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Indexer/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Indexer/Fulltext.php
index 661bbde..606a5c6 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Indexer/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Indexer/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Layer.php b/app/code/core/Mage/CatalogSearch/Model/Layer.php
index d751663..38a6681 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Layer.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Layer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Layer/Filter/Attribute.php b/app/code/core/Mage/CatalogSearch/Model/Layer/Filter/Attribute.php
index 287aac8..5b26a1a 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Layer/Filter/Attribute.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Layer/Filter/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced.php
index f676ff4..5529680 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced/Collection.php
index 112e925..f98f0b2 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Advanced/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext.php
index 3562ddb..e4acf24 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Collection.php
index e17fe62..e89d045 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Engine.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Engine.php
index d86847a..cecb9bb 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Engine.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Fulltext/Engine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Indexer/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Indexer/Fulltext.php
index 6c9cbe5..26b2359 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Indexer/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Indexer/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query.php
index 240cce5..58b0d95 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query/Collection.php
index 12823db..f777e0a 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Query/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Search/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Search/Collection.php
index e7ce150..9ea6605 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Mysql4/Search/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Mysql4/Search/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Query.php b/app/code/core/Mage/CatalogSearch/Model/Query.php
index c9ba7e4..5c67618 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Query.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Query.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced.php
index 440e6bf..180e911 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced/Collection.php
index dc46302..8bea37f 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Advanced/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext.php
index e81b0c6..ffa46c7 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Collection.php
index e887f93..f772897 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Engine.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Engine.php
index 86733a5..be089a9 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Engine.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Fulltext/Engine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Helper/Mysql4.php
index 33f4eb0..132d9e2 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Indexer/Fulltext.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Indexer/Fulltext.php
index b1c1176..414a29f 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Indexer/Fulltext.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Indexer/Fulltext.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Query.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Query.php
index 77f53f5..6fcdcdc 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Query.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Query.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Query/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Query/Collection.php
index 7685da9..dc7e93b 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Query/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Query/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Resource/Search/Collection.php b/app/code/core/Mage/CatalogSearch/Model/Resource/Search/Collection.php
index 2df4daf..b5d8d27 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Resource/Search/Collection.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Resource/Search/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/Session.php b/app/code/core/Mage/CatalogSearch/Model/Session.php
index 2aeab03..5ecc4ac 100644
--- a/app/code/core/Mage/CatalogSearch/Model/Session.php
+++ b/app/code/core/Mage/CatalogSearch/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/Model/System/Config/Backend/Sitemap.php b/app/code/core/Mage/CatalogSearch/Model/System/Config/Backend/Sitemap.php
index 7af720c..3fdf947 100644
--- a/app/code/core/Mage/CatalogSearch/Model/System/Config/Backend/Sitemap.php
+++ b/app/code/core/Mage/CatalogSearch/Model/System/Config/Backend/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/controllers/AdvancedController.php b/app/code/core/Mage/CatalogSearch/controllers/AdvancedController.php
index 0a6b378..ba09c8d 100644
--- a/app/code/core/Mage/CatalogSearch/controllers/AdvancedController.php
+++ b/app/code/core/Mage/CatalogSearch/controllers/AdvancedController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/controllers/AjaxController.php b/app/code/core/Mage/CatalogSearch/controllers/AjaxController.php
index 4a61005..461feb0 100644
--- a/app/code/core/Mage/CatalogSearch/controllers/AjaxController.php
+++ b/app/code/core/Mage/CatalogSearch/controllers/AjaxController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/controllers/ResultController.php b/app/code/core/Mage/CatalogSearch/controllers/ResultController.php
index 9ab1fa1..9b11b9d 100644
--- a/app/code/core/Mage/CatalogSearch/controllers/ResultController.php
+++ b/app/code/core/Mage/CatalogSearch/controllers/ResultController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/controllers/TermController.php b/app/code/core/Mage/CatalogSearch/controllers/TermController.php
index 13a8e0d..e341b47 100644
--- a/app/code/core/Mage/CatalogSearch/controllers/TermController.php
+++ b/app/code/core/Mage/CatalogSearch/controllers/TermController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/etc/adminhtml.xml b/app/code/core/Mage/CatalogSearch/etc/adminhtml.xml
index f17dd43..41e87b8 100644
--- a/app/code/core/Mage/CatalogSearch/etc/adminhtml.xml
+++ b/app/code/core/Mage/CatalogSearch/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogSearch/etc/config.xml b/app/code/core/Mage/CatalogSearch/etc/config.xml
index 5571cf0..b13e9ef 100644
--- a/app/code/core/Mage/CatalogSearch/etc/config.xml
+++ b/app/code/core/Mage/CatalogSearch/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogSearch/etc/system.xml b/app/code/core/Mage/CatalogSearch/etc/system.xml
index 534ce9f..fb1595f 100644
--- a/app/code/core/Mage/CatalogSearch/etc/system.xml
+++ b/app/code/core/Mage/CatalogSearch/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/install-1.6.0.0.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/install-1.6.0.0.php
index ad4db17..51e2ee3 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-install-0.7.0.php
index 5770d7f..7991a75 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.1-0.7.2.php
index ee8900d..627a4c8 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 12da401..f441c0a 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 5969298..2ac25e1 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.4-0.7.5.php
index c3f45ff..fddbf0f 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 8e387a1..f09eec9 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.6-0.7.7.php
index ee4c3fa..224729d 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 0bb3f1c..e11e979 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/upgrade-1.6.0.0-1.8.2.0.php b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/upgrade-1.6.0.0-1.8.2.0.php
index 6c0217a..3ae3ed0 100644
--- a/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/upgrade-1.6.0.0-1.8.2.0.php
+++ b/app/code/core/Mage/CatalogSearch/sql/catalogsearch_setup/upgrade-1.6.0.0-1.8.2.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CatalogSearch
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Adminhtml/Validation.php b/app/code/core/Mage/Centinel/Block/Adminhtml/Validation.php
index 8033540..78afb9d 100644
--- a/app/code/core/Mage/Centinel/Block/Adminhtml/Validation.php
+++ b/app/code/core/Mage/Centinel/Block/Adminhtml/Validation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Adminhtml/Validation/Form.php b/app/code/core/Mage/Centinel/Block/Adminhtml/Validation/Form.php
index c6594a5..f40ed73 100644
--- a/app/code/core/Mage/Centinel/Block/Adminhtml/Validation/Form.php
+++ b/app/code/core/Mage/Centinel/Block/Adminhtml/Validation/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Authentication.php b/app/code/core/Mage/Centinel/Block/Authentication.php
index 3c820e6..cbe385a 100644
--- a/app/code/core/Mage/Centinel/Block/Authentication.php
+++ b/app/code/core/Mage/Centinel/Block/Authentication.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Authentication/Complete.php b/app/code/core/Mage/Centinel/Block/Authentication/Complete.php
index 5af8897..7bcb8ad 100644
--- a/app/code/core/Mage/Centinel/Block/Authentication/Complete.php
+++ b/app/code/core/Mage/Centinel/Block/Authentication/Complete.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Authentication/Start.php b/app/code/core/Mage/Centinel/Block/Authentication/Start.php
index 06ebe48..c9cbfb0 100644
--- a/app/code/core/Mage/Centinel/Block/Authentication/Start.php
+++ b/app/code/core/Mage/Centinel/Block/Authentication/Start.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Block/Logo.php b/app/code/core/Mage/Centinel/Block/Logo.php
index a5ccd54..07910cf 100644
--- a/app/code/core/Mage/Centinel/Block/Logo.php
+++ b/app/code/core/Mage/Centinel/Block/Logo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Helper/Data.php b/app/code/core/Mage/Centinel/Helper/Data.php
index 9b50a63..159b1f6 100644
--- a/app/code/core/Mage/Centinel/Helper/Data.php
+++ b/app/code/core/Mage/Centinel/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Api.php b/app/code/core/Mage/Centinel/Model/Api.php
index 53ffa44..7862b90 100644
--- a/app/code/core/Mage/Centinel/Model/Api.php
+++ b/app/code/core/Mage/Centinel/Model/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Api/Client.php b/app/code/core/Mage/Centinel/Model/Api/Client.php
index db6c194..cc08193 100644
--- a/app/code/core/Mage/Centinel/Model/Api/Client.php
+++ b/app/code/core/Mage/Centinel/Model/Api/Client.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Config.php b/app/code/core/Mage/Centinel/Model/Config.php
index 9e921ff..80615c2 100644
--- a/app/code/core/Mage/Centinel/Model/Config.php
+++ b/app/code/core/Mage/Centinel/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Observer.php b/app/code/core/Mage/Centinel/Model/Observer.php
index dedd90e..8557f47 100644
--- a/app/code/core/Mage/Centinel/Model/Observer.php
+++ b/app/code/core/Mage/Centinel/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Service.php b/app/code/core/Mage/Centinel/Model/Service.php
index 0e33481..c1784b8 100644
--- a/app/code/core/Mage/Centinel/Model/Service.php
+++ b/app/code/core/Mage/Centinel/Model/Service.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/Session.php b/app/code/core/Mage/Centinel/Model/Session.php
index d2363ee..5d8f519 100644
--- a/app/code/core/Mage/Centinel/Model/Session.php
+++ b/app/code/core/Mage/Centinel/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/State/Jcb.php b/app/code/core/Mage/Centinel/Model/State/Jcb.php
index d2ef9fe..14c8fe1 100644
--- a/app/code/core/Mage/Centinel/Model/State/Jcb.php
+++ b/app/code/core/Mage/Centinel/Model/State/Jcb.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/State/Mastercard.php b/app/code/core/Mage/Centinel/Model/State/Mastercard.php
index c78e9b0..4a7dc75 100644
--- a/app/code/core/Mage/Centinel/Model/State/Mastercard.php
+++ b/app/code/core/Mage/Centinel/Model/State/Mastercard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/State/Visa.php b/app/code/core/Mage/Centinel/Model/State/Visa.php
index 9bfbb63..c279195 100644
--- a/app/code/core/Mage/Centinel/Model/State/Visa.php
+++ b/app/code/core/Mage/Centinel/Model/State/Visa.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/Model/StateAbstract.php b/app/code/core/Mage/Centinel/Model/StateAbstract.php
index 5bfab3f..46d099a 100644
--- a/app/code/core/Mage/Centinel/Model/StateAbstract.php
+++ b/app/code/core/Mage/Centinel/Model/StateAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/controllers/Adminhtml/Centinel/IndexController.php b/app/code/core/Mage/Centinel/controllers/Adminhtml/Centinel/IndexController.php
index 1201b04..eae2555 100644
--- a/app/code/core/Mage/Centinel/controllers/Adminhtml/Centinel/IndexController.php
+++ b/app/code/core/Mage/Centinel/controllers/Adminhtml/Centinel/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/controllers/IndexController.php b/app/code/core/Mage/Centinel/controllers/IndexController.php
index 9cd3896..fcbdb88 100644
--- a/app/code/core/Mage/Centinel/controllers/IndexController.php
+++ b/app/code/core/Mage/Centinel/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Centinel/etc/config.xml b/app/code/core/Mage/Centinel/etc/config.xml
index 1d5eb6b..a512f9c 100644
--- a/app/code/core/Mage/Centinel/etc/config.xml
+++ b/app/code/core/Mage/Centinel/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Centinel/etc/system.xml b/app/code/core/Mage/Centinel/etc/system.xml
index c89cd7c..ddc80c8 100644
--- a/app/code/core/Mage/Centinel/etc/system.xml
+++ b/app/code/core/Mage/Centinel/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/Block/Agreements.php b/app/code/core/Mage/Checkout/Block/Agreements.php
index dcb5cd5..5dd62d5 100644
--- a/app/code/core/Mage/Checkout/Block/Agreements.php
+++ b/app/code/core/Mage/Checkout/Block/Agreements.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Checkout_Block_Agreements extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/Checkout/Block/Cart.php b/app/code/core/Mage/Checkout/Block/Cart.php
index cf6d75f..7edb827 100644
--- a/app/code/core/Mage/Checkout/Block/Cart.php
+++ b/app/code/core/Mage/Checkout/Block/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Abstract.php b/app/code/core/Mage/Checkout/Block/Cart/Abstract.php
index b43a244..31d9106 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Abstract.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Coupon.php b/app/code/core/Mage/Checkout/Block/Cart/Coupon.php
index 7847d77..b6ab3c5 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Coupon.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Crosssell.php b/app/code/core/Mage/Checkout/Block/Cart/Crosssell.php
index a39c48d..9530634 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Crosssell.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Item/Configure.php b/app/code/core/Mage/Checkout/Block/Cart/Item/Configure.php
index 31f152d..29d7eb2 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Item/Configure.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Item/Configure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer.php b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer.php
index 21b94b0..3478b4e 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Configurable.php b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Configurable.php
index c857c5d..2c9fa90 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Configurable.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Grouped.php b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Grouped.php
index 264b2d0..81403d0 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Grouped.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Item/Renderer/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Minicart.php b/app/code/core/Mage/Checkout/Block/Cart/Minicart.php
index 52c4bc6..9b6aabb 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Minicart.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Minicart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Shipping.php b/app/code/core/Mage/Checkout/Block/Cart/Shipping.php
index 08fe4fe..50935d6 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Shipping.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Sidebar.php b/app/code/core/Mage/Checkout/Block/Cart/Sidebar.php
index 27b2d59..d6db805 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Sidebar.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Cart/Totals.php b/app/code/core/Mage/Checkout/Block/Cart/Totals.php
index ac1aa1a..8eb04c9 100644
--- a/app/code/core/Mage/Checkout/Block/Cart/Totals.php
+++ b/app/code/core/Mage/Checkout/Block/Cart/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Links.php b/app/code/core/Mage/Checkout/Block/Links.php
index 84179e7..ef236ca 100644
--- a/app/code/core/Mage/Checkout/Block/Links.php
+++ b/app/code/core/Mage/Checkout/Block/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Abstract.php b/app/code/core/Mage/Checkout/Block/Multishipping/Abstract.php
index fc8c8a2..0036a2e 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Abstract.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Address/Select.php b/app/code/core/Mage/Checkout/Block/Multishipping/Address/Select.php
index 994cb11..5051213 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Address/Select.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Address/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Addresses.php b/app/code/core/Mage/Checkout/Block/Multishipping/Addresses.php
index 7178f0f..8f9e951 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Addresses.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Billing.php b/app/code/core/Mage/Checkout/Block/Multishipping/Billing.php
index f9a0d88..edd2ee6 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Billing.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Billing/Items.php b/app/code/core/Mage/Checkout/Block/Multishipping/Billing/Items.php
index 98a191e..1b003ac 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Billing/Items.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Billing/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Link.php b/app/code/core/Mage/Checkout/Block/Multishipping/Link.php
index adfa9da..6224224 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Link.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Overview.php b/app/code/core/Mage/Checkout/Block/Multishipping/Overview.php
index 48e5c62..e8b81a5 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Overview.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Overview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Payment/Info.php b/app/code/core/Mage/Checkout/Block/Multishipping/Payment/Info.php
index 3094d23..db59813 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Payment/Info.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Payment/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Shipping.php b/app/code/core/Mage/Checkout/Block/Multishipping/Shipping.php
index 9071b06..763efdf 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Shipping.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/State.php b/app/code/core/Mage/Checkout/Block/Multishipping/State.php
index fc0537a..6c9690a 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/State.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/State.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Multishipping/Success.php b/app/code/core/Mage/Checkout/Block/Multishipping/Success.php
index e5743c4..fcfe49c 100644
--- a/app/code/core/Mage/Checkout/Block/Multishipping/Success.php
+++ b/app/code/core/Mage/Checkout/Block/Multishipping/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage.php b/app/code/core/Mage/Checkout/Block/Onepage.php
index 8f9a5f0..c0517c3 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Abstract.php b/app/code/core/Mage/Checkout/Block/Onepage/Abstract.php
index 81dd29b..60a9d90 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Abstract.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Billing.php b/app/code/core/Mage/Checkout/Block/Onepage/Billing.php
index e1505b7..6918035 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Billing.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Failure.php b/app/code/core/Mage/Checkout/Block/Onepage/Failure.php
index 9f3342b..204f79b 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Failure.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Failure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Link.php b/app/code/core/Mage/Checkout/Block/Onepage/Link.php
index 85df670..bbc93de 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Link.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Login.php b/app/code/core/Mage/Checkout/Block/Onepage/Login.php
index 0d265b3..80aeca1 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Login.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Payment.php b/app/code/core/Mage/Checkout/Block/Onepage/Payment.php
index 4872019..3a5d195 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Payment.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Payment/Info.php b/app/code/core/Mage/Checkout/Block/Onepage/Payment/Info.php
index e9af910..c5b804d 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Payment/Info.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Payment/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Payment/Methods.php b/app/code/core/Mage/Checkout/Block/Onepage/Payment/Methods.php
index 3de20f1..c3b738e 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Payment/Methods.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Payment/Methods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Progress.php b/app/code/core/Mage/Checkout/Block/Onepage/Progress.php
index 1f35d47..e310947 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Progress.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Progress.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Review.php b/app/code/core/Mage/Checkout/Block/Onepage/Review.php
index 7418016..b6ebb02 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Review.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Review/Info.php b/app/code/core/Mage/Checkout/Block/Onepage/Review/Info.php
index 0e53617..0641e41 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Review/Info.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Review/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Shipping.php b/app/code/core/Mage/Checkout/Block/Onepage/Shipping.php
index 90693b3..1f49d05 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Shipping.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method.php b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method.php
index 3b823f4..34bf43e 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Additional.php b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Additional.php
index 8b9198f..ced504e 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Additional.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Additional.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Available.php b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Available.php
index 3b18b4f..60694cb 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Available.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Shipping/Method/Available.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Onepage/Success.php b/app/code/core/Mage/Checkout/Block/Onepage/Success.php
index 456db1a..0982904 100644
--- a/app/code/core/Mage/Checkout/Block/Onepage/Success.php
+++ b/app/code/core/Mage/Checkout/Block/Onepage/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Success.php b/app/code/core/Mage/Checkout/Block/Success.php
index 39582d2..40fc2ee 100644
--- a/app/code/core/Mage/Checkout/Block/Success.php
+++ b/app/code/core/Mage/Checkout/Block/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Total/Default.php b/app/code/core/Mage/Checkout/Block/Total/Default.php
index b46f13e..534aac9 100644
--- a/app/code/core/Mage/Checkout/Block/Total/Default.php
+++ b/app/code/core/Mage/Checkout/Block/Total/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Total/Nominal.php b/app/code/core/Mage/Checkout/Block/Total/Nominal.php
index d38063f..58216b9 100644
--- a/app/code/core/Mage/Checkout/Block/Total/Nominal.php
+++ b/app/code/core/Mage/Checkout/Block/Total/Nominal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Block/Total/Tax.php b/app/code/core/Mage/Checkout/Block/Total/Tax.php
index 859b780..91a77f4 100644
--- a/app/code/core/Mage/Checkout/Block/Total/Tax.php
+++ b/app/code/core/Mage/Checkout/Block/Total/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Controller/Action.php b/app/code/core/Mage/Checkout/Controller/Action.php
index d6fde40..8995e08 100644
--- a/app/code/core/Mage/Checkout/Controller/Action.php
+++ b/app/code/core/Mage/Checkout/Controller/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Exception.php b/app/code/core/Mage/Checkout/Exception.php
index 11a8643..81a9a2f 100644
--- a/app/code/core/Mage/Checkout/Exception.php
+++ b/app/code/core/Mage/Checkout/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Helper/Cart.php b/app/code/core/Mage/Checkout/Helper/Cart.php
index 566f460..0a1e68c 100644
--- a/app/code/core/Mage/Checkout/Helper/Cart.php
+++ b/app/code/core/Mage/Checkout/Helper/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Helper/Data.php b/app/code/core/Mage/Checkout/Helper/Data.php
index 3230d76..4129cf4 100644
--- a/app/code/core/Mage/Checkout/Helper/Data.php
+++ b/app/code/core/Mage/Checkout/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Helper/Url.php b/app/code/core/Mage/Checkout/Helper/Url.php
index 091f882..8199cea 100644
--- a/app/code/core/Mage/Checkout/Helper/Url.php
+++ b/app/code/core/Mage/Checkout/Helper/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Agreement.php b/app/code/core/Mage/Checkout/Model/Agreement.php
index 48ed34e..8de6d2e 100644
--- a/app/code/core/Mage/Checkout/Model/Agreement.php
+++ b/app/code/core/Mage/Checkout/Model/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Api/Resource.php b/app/code/core/Mage/Checkout/Model/Api/Resource.php
index 4e36141..a5bc09e 100644
--- a/app/code/core/Mage/Checkout/Model/Api/Resource.php
+++ b/app/code/core/Mage/Checkout/Model/Api/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Api/Resource/Customer.php b/app/code/core/Mage/Checkout/Model/Api/Resource/Customer.php
index c8f3f4f..b46938e 100644
--- a/app/code/core/Mage/Checkout/Model/Api/Resource/Customer.php
+++ b/app/code/core/Mage/Checkout/Model/Api/Resource/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Api/Resource/Product.php b/app/code/core/Mage/Checkout/Model/Api/Resource/Product.php
index d0f58f6..eee8f1c 100644
--- a/app/code/core/Mage/Checkout/Model/Api/Resource/Product.php
+++ b/app/code/core/Mage/Checkout/Model/Api/Resource/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart.php b/app/code/core/Mage/Checkout/Model/Cart.php
index 87d092b..3b77bc6 100644
--- a/app/code/core/Mage/Checkout/Model/Cart.php
+++ b/app/code/core/Mage/Checkout/Model/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Api.php
index 40c57cb..2de8078 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Api/V2.php
index b25e021..88eea14 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api.php
index 34e5603..f41a8dd 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api/V2.php
index da252bb..516d7ee 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Coupon/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Customer/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Customer/Api.php
index 9eadace..a8d9682 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Customer/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Customer/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Customer/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Customer/Api/V2.php
index 62ea26b..ea759b7 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Customer/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Customer/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Interface.php b/app/code/core/Mage/Checkout/Model/Cart/Interface.php
index ee74aed..711f9e1 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Interface.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Payment/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Payment/Api.php
index 36ac0df..78eeb58 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Payment/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Payment/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Payment/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Payment/Api/V2.php
index b5b9c55..c992eb0 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Payment/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Payment/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Product/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Product/Api.php
index 889496f..2ab463e 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Product/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Product/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Product/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Product/Api/V2.php
index ca4c041..a462434 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Product/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Product/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api.php b/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api.php
index a5a169a..41362fc 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api/V2.php b/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api/V2.php
index 5491600..652a3e7 100644
--- a/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api/V2.php
+++ b/app/code/core/Mage/Checkout/Model/Cart/Shipping/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Config/Source/Cart/Summary.php b/app/code/core/Mage/Checkout/Model/Config/Source/Cart/Summary.php
index fd6b5bc..b829e4a 100644
--- a/app/code/core/Mage/Checkout/Model/Config/Source/Cart/Summary.php
+++ b/app/code/core/Mage/Checkout/Model/Config/Source/Cart/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Checkout_Model_Config_Source_Cart_Summary
diff --git a/app/code/core/Mage/Checkout/Model/Mysql4/Agreement.php b/app/code/core/Mage/Checkout/Model/Mysql4/Agreement.php
index 52f8539..b6148cf 100644
--- a/app/code/core/Mage/Checkout/Model/Mysql4/Agreement.php
+++ b/app/code/core/Mage/Checkout/Model/Mysql4/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Mysql4/Agreement/Collection.php b/app/code/core/Mage/Checkout/Model/Mysql4/Agreement/Collection.php
index f2b3fad..2b16ec2 100644
--- a/app/code/core/Mage/Checkout/Model/Mysql4/Agreement/Collection.php
+++ b/app/code/core/Mage/Checkout/Model/Mysql4/Agreement/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Mysql4/Cart.php b/app/code/core/Mage/Checkout/Model/Mysql4/Cart.php
index 410c099..7eb3bc5 100644
--- a/app/code/core/Mage/Checkout/Model/Mysql4/Cart.php
+++ b/app/code/core/Mage/Checkout/Model/Mysql4/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Mysql4/Setup.php b/app/code/core/Mage/Checkout/Model/Mysql4/Setup.php
index 8cbe4e9..1059fbb 100644
--- a/app/code/core/Mage/Checkout/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Checkout/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Observer.php b/app/code/core/Mage/Checkout/Model/Observer.php
index 27cb63f..b594645 100644
--- a/app/code/core/Mage/Checkout/Model/Observer.php
+++ b/app/code/core/Mage/Checkout/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Resource/Agreement.php b/app/code/core/Mage/Checkout/Model/Resource/Agreement.php
index d1b7076..1342e89 100644
--- a/app/code/core/Mage/Checkout/Model/Resource/Agreement.php
+++ b/app/code/core/Mage/Checkout/Model/Resource/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Resource/Agreement/Collection.php b/app/code/core/Mage/Checkout/Model/Resource/Agreement/Collection.php
index 0111946..b2d346c 100644
--- a/app/code/core/Mage/Checkout/Model/Resource/Agreement/Collection.php
+++ b/app/code/core/Mage/Checkout/Model/Resource/Agreement/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Resource/Cart.php b/app/code/core/Mage/Checkout/Model/Resource/Cart.php
index 6374319..b966e87 100644
--- a/app/code/core/Mage/Checkout/Model/Resource/Cart.php
+++ b/app/code/core/Mage/Checkout/Model/Resource/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Resource/Setup.php b/app/code/core/Mage/Checkout/Model/Resource/Setup.php
index 6e729aa..e140a4b 100644
--- a/app/code/core/Mage/Checkout/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Checkout/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Session.php b/app/code/core/Mage/Checkout/Model/Session.php
index d07dabe..fc99aa6 100644
--- a/app/code/core/Mage/Checkout/Model/Session.php
+++ b/app/code/core/Mage/Checkout/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Type/Abstract.php b/app/code/core/Mage/Checkout/Model/Type/Abstract.php
index b838ea7..319e7fb 100644
--- a/app/code/core/Mage/Checkout/Model/Type/Abstract.php
+++ b/app/code/core/Mage/Checkout/Model/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Type/Multishipping.php b/app/code/core/Mage/Checkout/Model/Type/Multishipping.php
index 9a456ca..22047b5 100644
--- a/app/code/core/Mage/Checkout/Model/Type/Multishipping.php
+++ b/app/code/core/Mage/Checkout/Model/Type/Multishipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Type/Multishipping/State.php b/app/code/core/Mage/Checkout/Model/Type/Multishipping/State.php
index 72c27c5..9cd7a32 100644
--- a/app/code/core/Mage/Checkout/Model/Type/Multishipping/State.php
+++ b/app/code/core/Mage/Checkout/Model/Type/Multishipping/State.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/Model/Type/Onepage.php b/app/code/core/Mage/Checkout/Model/Type/Onepage.php
index 922f1732..d534ac7 100644
--- a/app/code/core/Mage/Checkout/Model/Type/Onepage.php
+++ b/app/code/core/Mage/Checkout/Model/Type/Onepage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/controllers/CartController.php b/app/code/core/Mage/Checkout/controllers/CartController.php
index 28a2647..12abf85 100644
--- a/app/code/core/Mage/Checkout/controllers/CartController.php
+++ b/app/code/core/Mage/Checkout/controllers/CartController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/controllers/IndexController.php b/app/code/core/Mage/Checkout/controllers/IndexController.php
index e2f4fa7..f2ceb3e 100644
--- a/app/code/core/Mage/Checkout/controllers/IndexController.php
+++ b/app/code/core/Mage/Checkout/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/controllers/Multishipping/AddressController.php b/app/code/core/Mage/Checkout/controllers/Multishipping/AddressController.php
index 0ef943b..d349d6c 100644
--- a/app/code/core/Mage/Checkout/controllers/Multishipping/AddressController.php
+++ b/app/code/core/Mage/Checkout/controllers/Multishipping/AddressController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/controllers/MultishippingController.php b/app/code/core/Mage/Checkout/controllers/MultishippingController.php
index 3095782..26e66fa 100644
--- a/app/code/core/Mage/Checkout/controllers/MultishippingController.php
+++ b/app/code/core/Mage/Checkout/controllers/MultishippingController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/controllers/OnepageController.php b/app/code/core/Mage/Checkout/controllers/OnepageController.php
index 97f6252..1e122fa 100644
--- a/app/code/core/Mage/Checkout/controllers/OnepageController.php
+++ b/app/code/core/Mage/Checkout/controllers/OnepageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/etc/adminhtml.xml b/app/code/core/Mage/Checkout/etc/adminhtml.xml
index 054424b..1a11ccc 100644
--- a/app/code/core/Mage/Checkout/etc/adminhtml.xml
+++ b/app/code/core/Mage/Checkout/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/etc/api.xml b/app/code/core/Mage/Checkout/etc/api.xml
index 530dd48..252e295 100644
--- a/app/code/core/Mage/Checkout/etc/api.xml
+++ b/app/code/core/Mage/Checkout/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/etc/config.xml b/app/code/core/Mage/Checkout/etc/config.xml
index 39fc7f7..23ce66a 100644
--- a/app/code/core/Mage/Checkout/etc/config.xml
+++ b/app/code/core/Mage/Checkout/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/etc/jstranslator.xml b/app/code/core/Mage/Checkout/etc/jstranslator.xml
index 825e157..7c53e54 100644
--- a/app/code/core/Mage/Checkout/etc/jstranslator.xml
+++ b/app/code/core/Mage/Checkout/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/etc/system.xml b/app/code/core/Mage/Checkout/etc/system.xml
index 7c6ad35..2106a92 100644
--- a/app/code/core/Mage/Checkout/etc/system.xml
+++ b/app/code/core/Mage/Checkout/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/install-1.6.0.0.php b/app/code/core/Mage/Checkout/sql/checkout_setup/install-1.6.0.0.php
index 22ce0c4..f67f7a5 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-install-0.9.1.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-install-0.9.1.php
index 3f63966..1db9e2b 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-install-0.9.1.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-install-0.9.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.0-0.9.1.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.0-0.9.1.php
index cad5336..87be9a5 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.0-0.9.1.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.0-0.9.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.1-0.9.2.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.1-0.9.2.php
index 4b11543..04b24b5 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.1-0.9.2.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.1-0.9.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.2-0.9.3.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.2-0.9.3.php
index 29a7e2c..f4bc861 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.2-0.9.3.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.2-0.9.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.3-0.9.4.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.3-0.9.4.php
index 852c892..2eb7772 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.3-0.9.4.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.3-0.9.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.4-0.9.5.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.4-0.9.5.php
index b6f21f2..48ae92c 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.4-0.9.5.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-0.9.4-0.9.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index d425324..b206eed 100644
--- a/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Checkout/sql/checkout_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Checkout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Block/Block.php b/app/code/core/Mage/Cms/Block/Block.php
index e8db7c6..74f21ab 100644
--- a/app/code/core/Mage/Cms/Block/Block.php
+++ b/app/code/core/Mage/Cms/Block/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Block/Page.php b/app/code/core/Mage/Cms/Block/Page.php
index 55c31ca..22974cf 100644
--- a/app/code/core/Mage/Cms/Block/Page.php
+++ b/app/code/core/Mage/Cms/Block/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Block/Widget/Block.php b/app/code/core/Mage/Cms/Block/Widget/Block.php
index 4fc7424..4ebfffa 100644
--- a/app/code/core/Mage/Cms/Block/Widget/Block.php
+++ b/app/code/core/Mage/Cms/Block/Widget/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Block/Widget/Page/Link.php b/app/code/core/Mage/Cms/Block/Widget/Page/Link.php
index 05bad15..42f15cc 100644
--- a/app/code/core/Mage/Cms/Block/Widget/Page/Link.php
+++ b/app/code/core/Mage/Cms/Block/Widget/Page/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Controller/Router.php b/app/code/core/Mage/Cms/Controller/Router.php
index 703b2a8..13f092e 100644
--- a/app/code/core/Mage/Cms/Controller/Router.php
+++ b/app/code/core/Mage/Cms/Controller/Router.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Helper/Data.php b/app/code/core/Mage/Cms/Helper/Data.php
index 39b3107..42b3b18 100644
--- a/app/code/core/Mage/Cms/Helper/Data.php
+++ b/app/code/core/Mage/Cms/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -36,6 +36,7 @@ class Mage_Cms_Helper_Data extends Mage_Core_Helper_Abstract
 {
     const XML_NODE_PAGE_TEMPLATE_FILTER     = 'global/cms/page/tempate_filter';
     const XML_NODE_BLOCK_TEMPLATE_FILTER    = 'global/cms/block/tempate_filter';
+    const XML_NODE_ALLOWED_STREAM_WRAPPERS  = 'global/cms/allowed_stream_wrappers';
 
     /**
      * Retrieve Template processor for Page Content
@@ -58,4 +59,19 @@ class Mage_Cms_Helper_Data extends Mage_Core_Helper_Abstract
         $model = (string)Mage::getConfig()->getNode(self::XML_NODE_BLOCK_TEMPLATE_FILTER);
         return Mage::getModel($model);
     }
+
+    /**
+     * Return list with allowed stream wrappers
+     *
+     * @return array
+     */
+    public function getAllowedStreamWrappers()
+    {
+        $allowedStreamWrappers = Mage::getConfig()->getNode(self::XML_NODE_ALLOWED_STREAM_WRAPPERS);
+        if ($allowedStreamWrappers instanceof Mage_Core_Model_Config_Element) {
+            $allowedStreamWrappers = $allowedStreamWrappers->asArray();
+        }
+
+        return is_array($allowedStreamWrappers) ? $allowedStreamWrappers : array();
+    }
 }
diff --git a/app/code/core/Mage/Cms/Helper/Page.php b/app/code/core/Mage/Cms/Helper/Page.php
index c590996..57cfeda 100644
--- a/app/code/core/Mage/Cms/Helper/Page.php
+++ b/app/code/core/Mage/Cms/Helper/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Helper/Wysiwyg/Images.php b/app/code/core/Mage/Cms/Helper/Wysiwyg/Images.php
index 2295608..787b03c 100644
--- a/app/code/core/Mage/Cms/Helper/Wysiwyg/Images.php
+++ b/app/code/core/Mage/Cms/Helper/Wysiwyg/Images.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Adminhtml/Template/Filter.php b/app/code/core/Mage/Cms/Model/Adminhtml/Template/Filter.php
index ba098de..a911fd7 100644
--- a/app/code/core/Mage/Cms/Model/Adminhtml/Template/Filter.php
+++ b/app/code/core/Mage/Cms/Model/Adminhtml/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Block.php b/app/code/core/Mage/Cms/Model/Block.php
index 646dd98..3332bf5 100644
--- a/app/code/core/Mage/Cms/Model/Block.php
+++ b/app/code/core/Mage/Cms/Model/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Mysql4/Block.php b/app/code/core/Mage/Cms/Model/Mysql4/Block.php
index de9fbb5..c6f1e0e 100644
--- a/app/code/core/Mage/Cms/Model/Mysql4/Block.php
+++ b/app/code/core/Mage/Cms/Model/Mysql4/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Mysql4/Block/Collection.php b/app/code/core/Mage/Cms/Model/Mysql4/Block/Collection.php
index c6317ba..0117758 100644
--- a/app/code/core/Mage/Cms/Model/Mysql4/Block/Collection.php
+++ b/app/code/core/Mage/Cms/Model/Mysql4/Block/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Mysql4/Page.php b/app/code/core/Mage/Cms/Model/Mysql4/Page.php
index e627135..6cf2b0c 100644
--- a/app/code/core/Mage/Cms/Model/Mysql4/Page.php
+++ b/app/code/core/Mage/Cms/Model/Mysql4/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Mysql4/Page/Collection.php b/app/code/core/Mage/Cms/Model/Mysql4/Page/Collection.php
index 44b34de..9c40db9 100644
--- a/app/code/core/Mage/Cms/Model/Mysql4/Page/Collection.php
+++ b/app/code/core/Mage/Cms/Model/Mysql4/Page/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Mysql4/Page/Service.php b/app/code/core/Mage/Cms/Model/Mysql4/Page/Service.php
index f50d073..f47e88a 100644
--- a/app/code/core/Mage/Cms/Model/Mysql4/Page/Service.php
+++ b/app/code/core/Mage/Cms/Model/Mysql4/Page/Service.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Observer.php b/app/code/core/Mage/Cms/Model/Observer.php
index 95b1bb7..1c5bc4c 100644
--- a/app/code/core/Mage/Cms/Model/Observer.php
+++ b/app/code/core/Mage/Cms/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Page.php b/app/code/core/Mage/Cms/Model/Page.php
index f6e3719..ee4a87c 100644
--- a/app/code/core/Mage/Cms/Model/Page.php
+++ b/app/code/core/Mage/Cms/Model/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Resource/Block.php b/app/code/core/Mage/Cms/Model/Resource/Block.php
index 3283b40..819b740 100644
--- a/app/code/core/Mage/Cms/Model/Resource/Block.php
+++ b/app/code/core/Mage/Cms/Model/Resource/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Resource/Block/Collection.php b/app/code/core/Mage/Cms/Model/Resource/Block/Collection.php
index 792f8f7..d436458 100644
--- a/app/code/core/Mage/Cms/Model/Resource/Block/Collection.php
+++ b/app/code/core/Mage/Cms/Model/Resource/Block/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Resource/Page.php b/app/code/core/Mage/Cms/Model/Resource/Page.php
index 3bd3719..b431ab9 100644
--- a/app/code/core/Mage/Cms/Model/Resource/Page.php
+++ b/app/code/core/Mage/Cms/Model/Resource/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Resource/Page/Collection.php b/app/code/core/Mage/Cms/Model/Resource/Page/Collection.php
index e375851..f7a94c8 100644
--- a/app/code/core/Mage/Cms/Model/Resource/Page/Collection.php
+++ b/app/code/core/Mage/Cms/Model/Resource/Page/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Resource/Page/Service.php b/app/code/core/Mage/Cms/Model/Resource/Page/Service.php
index df33c89..4fe239e 100644
--- a/app/code/core/Mage/Cms/Model/Resource/Page/Service.php
+++ b/app/code/core/Mage/Cms/Model/Resource/Page/Service.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Template/Filter.php b/app/code/core/Mage/Cms/Model/Template/Filter.php
index b0c3109..f990938 100644
--- a/app/code/core/Mage/Cms/Model/Template/Filter.php
+++ b/app/code/core/Mage/Cms/Model/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php b/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
index 54f352c..471f10f 100644
--- a/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
+++ b/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage.php b/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage.php
index 8e0ad13..0ad0c1c 100644
--- a/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage.php
+++ b/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage/Collection.php b/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage/Collection.php
index 46c1a73..4ddfb87 100644
--- a/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage/Collection.php
+++ b/app/code/core/Mage/Cms/Model/Wysiwyg/Images/Storage/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/controllers/IndexController.php b/app/code/core/Mage/Cms/controllers/IndexController.php
index 77f9db2..dd91cdb 100644
--- a/app/code/core/Mage/Cms/controllers/IndexController.php
+++ b/app/code/core/Mage/Cms/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/controllers/PageController.php b/app/code/core/Mage/Cms/controllers/PageController.php
index 4b048d8..2ea1672 100644
--- a/app/code/core/Mage/Cms/controllers/PageController.php
+++ b/app/code/core/Mage/Cms/controllers/PageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/data/cms_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Cms/data/cms_setup/data-install-1.6.0.0.php
index d785bb7..0505e43 100644
--- a/app/code/core/Mage/Cms/data/cms_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Cms/data/cms_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.0-1.6.0.0.1.php b/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.0-1.6.0.0.1.php
index cfadfdb..f6801d9 100644
--- a/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.1-1.6.0.0.2.php b/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.1-1.6.0.0.2.php
index bee7a91..72b77e1 100644
--- a/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.1-1.6.0.0.2.php
+++ b/app/code/core/Mage/Cms/data/cms_setup/data-upgrade-1.6.0.0.1-1.6.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $content = "<p>This website requires cookies to provide all of its features. For more " .
diff --git a/app/code/core/Mage/Cms/etc/adminhtml.xml b/app/code/core/Mage/Cms/etc/adminhtml.xml
index 1dc90d1..6b03280 100644
--- a/app/code/core/Mage/Cms/etc/adminhtml.xml
+++ b/app/code/core/Mage/Cms/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Cms/etc/config.xml b/app/code/core/Mage/Cms/etc/config.xml
index f155123..a75a7fb 100644
--- a/app/code/core/Mage/Cms/etc/config.xml
+++ b/app/code/core/Mage/Cms/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -190,6 +190,10 @@
             <block>
                 <tempate_filter>cms/template_filter</tempate_filter>
             </block>
+            <allowed_stream_wrappers>
+                <http>http</http>
+                <https>https</https>
+            </allowed_stream_wrappers>
         </cms>
     </global>
     <default>
diff --git a/app/code/core/Mage/Cms/etc/system.xml b/app/code/core/Mage/Cms/etc/system.xml
index 7c2edec..0d29c2f 100644
--- a/app/code/core/Mage/Cms/etc/system.xml
+++ b/app/code/core/Mage/Cms/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Cms/etc/widget.xml b/app/code/core/Mage/Cms/etc/widget.xml
index 9b889aa..73f8786 100644
--- a/app/code/core/Mage/Cms/etc/widget.xml
+++ b/app/code/core/Mage/Cms/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/install-1.6.0.0.php b/app/code/core/Mage/Cms/sql/cms_setup/install-1.6.0.0.php
index 6ff369c..3b44f10 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-install-0.7.0.php
index 8ed0c5b..e4b9920 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 0250d75..cc26f2c 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.1-0.7.2.php
index c17eeaf..6d9cbb8 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.10-0.7.11.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.10-0.7.11.php
index 387103d..844f619 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.10-0.7.11.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.10-0.7.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.11-0.7.12.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.11-0.7.12.php
index 95f8e47..de3d5c3 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.11-0.7.12.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.11-0.7.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.12-0.7.13.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.12-0.7.13.php
index ddae0a5..5e4ad20 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.12-0.7.13.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.12-0.7.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 774169b..2e38ade 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 1a46a37..37ebb3c 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 4876ba7..248e288 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 09443ee..61ba0cc 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 7d0bda9..50c9a59 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 25c7757..7a98fb4 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 51e8e56..f9698d0 100644
--- a/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Cms/sql/cms_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cms
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/Block/Process.php b/app/code/core/Mage/Compiler/Block/Process.php
index 6b4cf32..133f24f 100644
--- a/app/code/core/Mage/Compiler/Block/Process.php
+++ b/app/code/core/Mage/Compiler/Block/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/Helper/Data.php b/app/code/core/Mage/Compiler/Helper/Data.php
index 336ab68..c586e78 100644
--- a/app/code/core/Mage/Compiler/Helper/Data.php
+++ b/app/code/core/Mage/Compiler/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/Model/Process.php b/app/code/core/Mage/Compiler/Model/Process.php
index d7b85be..1f7994e 100644
--- a/app/code/core/Mage/Compiler/Model/Process.php
+++ b/app/code/core/Mage/Compiler/Model/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/controllers/Adminhtml/Compiler/ProcessController.php b/app/code/core/Mage/Compiler/controllers/Adminhtml/Compiler/ProcessController.php
index 2e295cf..a8d51be 100644
--- a/app/code/core/Mage/Compiler/controllers/Adminhtml/Compiler/ProcessController.php
+++ b/app/code/core/Mage/Compiler/controllers/Adminhtml/Compiler/ProcessController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/controllers/ProcessController.php b/app/code/core/Mage/Compiler/controllers/ProcessController.php
index a46efaf..5319819 100644
--- a/app/code/core/Mage/Compiler/controllers/ProcessController.php
+++ b/app/code/core/Mage/Compiler/controllers/ProcessController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Compiler/etc/adminhtml.xml b/app/code/core/Mage/Compiler/etc/adminhtml.xml
index 547d7bf..f2793d3 100644
--- a/app/code/core/Mage/Compiler/etc/adminhtml.xml
+++ b/app/code/core/Mage/Compiler/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Compiler/etc/compilation.xml b/app/code/core/Mage/Compiler/etc/compilation.xml
index 0447907..af924e5 100644
--- a/app/code/core/Mage/Compiler/etc/compilation.xml
+++ b/app/code/core/Mage/Compiler/etc/compilation.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Compiler/etc/config.xml b/app/code/core/Mage/Compiler/etc/config.xml
index 5c380e6..c6f1ab8 100644
--- a/app/code/core/Mage/Compiler/etc/config.xml
+++ b/app/code/core/Mage/Compiler/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Layer/State/Swatch.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Layer/State/Swatch.php
index 139e435..ee87da1 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Layer/State/Swatch.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Layer/State/Swatch.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Block_Catalog_Layer_State_Swatch extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Abstract.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Abstract.php
index 07bd1f3..b5c65ad 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Abstract.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 abstract class Mage_ConfigurableSwatches_Block_Catalog_Media_Js_Abstract extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/List.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/List.php
index d00184a..0a215e9 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/List.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Block_Catalog_Media_Js_List
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Product.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Product.php
index bb05227..352f57d 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Product.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Media/Js/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Block_Catalog_Media_Js_Product
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/List/Price.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/List/Price.php
index 5f78682..f60628f 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/List/Price.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/List/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/View/Type/Configurable/Swatches.php b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/View/Type/Configurable/Swatches.php
index 493f032..62610f7 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/View/Type/Configurable/Swatches.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Block/Catalog/Product/View/Type/Configurable/Swatches.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Block_Catalog_Product_View_Type_Configurable_Swatches extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/Data.php b/app/code/core/Mage/ConfigurableSwatches/Helper/Data.php
index d420db1..2a1057e 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/Data.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Helper_Data extends Mage_Core_Helper_Abstract
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/List/Price.php b/app/code/core/Mage/ConfigurableSwatches/Helper/List/Price.php
index 31a2fe9..47b3e0b 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/List/Price.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/List/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/Mediafallback.php b/app/code/core/Mage/ConfigurableSwatches/Helper/Mediafallback.php
index 76c73e6..49d70ee 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/Mediafallback.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/Mediafallback.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/Productimg.php b/app/code/core/Mage/ConfigurableSwatches/Helper/Productimg.php
index 4db2c44..9839e96 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/Productimg.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/Productimg.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/Productlist.php b/app/code/core/Mage/ConfigurableSwatches/Helper/Productlist.php
index 3ecfab5..c2a2797 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/Productlist.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/Productlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Helper/Swatchdimensions.php b/app/code/core/Mage/ConfigurableSwatches/Helper/Swatchdimensions.php
index b363d26..e405d1f 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Helper/Swatchdimensions.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Helper/Swatchdimensions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/Observer.php b/app/code/core/Mage/ConfigurableSwatches/Model/Observer.php
index 987e5bd..490c34e 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/Observer.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_Observer extends Mage_Core_Model_Abstract
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Attribute/Super/Collection.php b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Attribute/Super/Collection.php
index 4807a28..6005a4c 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Attribute/Super/Collection.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Attribute/Super/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_Resource_Catalog_Product_Attribute_Super_Collection
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable.php b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable.php
index 3f89eb7..75f1f4d 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_Resource_Catalog_Product_Type_Configurable
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable/Product/Collection.php b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable/Product/Collection.php
index 1d114fb..aaca6ee 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable/Product/Collection.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/Resource/Catalog/Product/Type/Configurable/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_Resource_Catalog_Product_Type_Configurable_Product_Collection
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute.php b/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute.php
index ea9c742..1e30491 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_System_Config_Source_Catalog_Product_Configattribute
diff --git a/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute/Select.php b/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute/Select.php
index 0f1ec23..67e9c95 100644
--- a/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute/Select.php
+++ b/app/code/core/Mage/ConfigurableSwatches/Model/System/Config/Source/Catalog/Product/Configattribute/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_ConfigurableSwatches_Model_System_Config_Source_Catalog_Product_Configattribute_Select
diff --git a/app/code/core/Mage/ConfigurableSwatches/etc/adminhtml.xml b/app/code/core/Mage/ConfigurableSwatches/etc/adminhtml.xml
index be0f304..277f7cd 100644
--- a/app/code/core/Mage/ConfigurableSwatches/etc/adminhtml.xml
+++ b/app/code/core/Mage/ConfigurableSwatches/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ConfigurableSwatches/etc/config.xml b/app/code/core/Mage/ConfigurableSwatches/etc/config.xml
index 5234f05..0aa38d2 100644
--- a/app/code/core/Mage/ConfigurableSwatches/etc/config.xml
+++ b/app/code/core/Mage/ConfigurableSwatches/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ConfigurableSwatches/etc/jstranslator.xml b/app/code/core/Mage/ConfigurableSwatches/etc/jstranslator.xml
index 057efe0..8d9ce80 100644
--- a/app/code/core/Mage/ConfigurableSwatches/etc/jstranslator.xml
+++ b/app/code/core/Mage/ConfigurableSwatches/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ConfigurableSwatches/etc/system.xml b/app/code/core/Mage/ConfigurableSwatches/etc/system.xml
index 80887b1..e1ddecc 100644
--- a/app/code/core/Mage/ConfigurableSwatches/etc/system.xml
+++ b/app/code/core/Mage/ConfigurableSwatches/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit.php
index 3518e60..7833b16 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Form.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Form.php
index 9750d54..5b4c8ed 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Form.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Abstract.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Abstract.php
index e830899..d2dd367 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Abstract.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Authors.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Authors.php
index 16184b6..7180bef 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Authors.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Authors.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Contents.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Contents.php
index fa367dd..bad1453 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Contents.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Contents.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Depends.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Depends.php
index 9e8173b..f594e41 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Depends.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Depends.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Grid.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Grid.php
index a624840..cf4f81f 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Grid.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Load.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Load.php
index 883d9d4..2feaf75 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Load.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Load.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Local.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Local.php
index 3fbcaa9..3c7cd39 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Local.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Local.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Package.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Package.php
index 739dc4e..e26b88d 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Package.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Release.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Release.php
index c35585b..4214ae6 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Release.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tab/Release.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tabs.php b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tabs.php
index 53cfda1..6287293 100644
--- a/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tabs.php
+++ b/app/code/core/Mage/Connect/Block/Adminhtml/Extension/Custom/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Helper/Data.php b/app/code/core/Mage/Connect/Helper/Data.php
index a2111f1..b6be996 100644
--- a/app/code/core/Mage/Connect/Helper/Data.php
+++ b/app/code/core/Mage/Connect/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Model/Extension.php b/app/code/core/Mage/Connect/Model/Extension.php
index 988fd3f..254c4a9 100644
--- a/app/code/core/Mage/Connect/Model/Extension.php
+++ b/app/code/core/Mage/Connect/Model/Extension.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Model/Extension/Collection.php b/app/code/core/Mage/Connect/Model/Extension/Collection.php
index 24e4305..15e3efe 100644
--- a/app/code/core/Mage/Connect/Model/Extension/Collection.php
+++ b/app/code/core/Mage/Connect/Model/Extension/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/Model/Session.php b/app/code/core/Mage/Connect/Model/Session.php
index b48456f..b4ac794 100644
--- a/app/code/core/Mage/Connect/Model/Session.php
+++ b/app/code/core/Mage/Connect/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/CustomController.php b/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/CustomController.php
index 9c55408..bed0cfd 100644
--- a/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/CustomController.php
+++ b/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/CustomController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/LocalController.php b/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/LocalController.php
index 6bc5289..e7144aa 100644
--- a/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/LocalController.php
+++ b/app/code/core/Mage/Connect/controllers/Adminhtml/Extension/LocalController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Connect/etc/adminhtml.xml b/app/code/core/Mage/Connect/etc/adminhtml.xml
index 4e27dac..167016d 100644
--- a/app/code/core/Mage/Connect/etc/adminhtml.xml
+++ b/app/code/core/Mage/Connect/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Connect/etc/config.xml b/app/code/core/Mage/Connect/etc/config.xml
index d16214f..d848014 100644
--- a/app/code/core/Mage/Connect/etc/config.xml
+++ b/app/code/core/Mage/Connect/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Contacts/Helper/Data.php b/app/code/core/Mage/Contacts/Helper/Data.php
index f172bc1..14a8481 100644
--- a/app/code/core/Mage/Contacts/Helper/Data.php
+++ b/app/code/core/Mage/Contacts/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/Model/System/Config/Backend/Links.php b/app/code/core/Mage/Contacts/Model/System/Config/Backend/Links.php
index a4485ed..505cce1 100644
--- a/app/code/core/Mage/Contacts/Model/System/Config/Backend/Links.php
+++ b/app/code/core/Mage/Contacts/Model/System/Config/Backend/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/controllers/IndexController.php b/app/code/core/Mage/Contacts/controllers/IndexController.php
index ce972fa..8842f59 100644
--- a/app/code/core/Mage/Contacts/controllers/IndexController.php
+++ b/app/code/core/Mage/Contacts/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/etc/adminhtml.xml b/app/code/core/Mage/Contacts/etc/adminhtml.xml
index 35cbaf6..7230a30 100644
--- a/app/code/core/Mage/Contacts/etc/adminhtml.xml
+++ b/app/code/core/Mage/Contacts/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Contacts/etc/config.xml b/app/code/core/Mage/Contacts/etc/config.xml
index ccd2f69..5f25faf 100644
--- a/app/code/core/Mage/Contacts/etc/config.xml
+++ b/app/code/core/Mage/Contacts/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Contacts/etc/system.xml b/app/code/core/Mage/Contacts/etc/system.xml
index 03aa6df..ee59ecd 100644
--- a/app/code/core/Mage/Contacts/etc/system.xml
+++ b/app/code/core/Mage/Contacts/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Contacts/sql/contacts_setup/install-1.6.0.0.php b/app/code/core/Mage/Contacts/sql/contacts_setup/install-1.6.0.0.php
index 4967183..9fdda47 100644
--- a/app/code/core/Mage/Contacts/sql/contacts_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Contacts/sql/contacts_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.7.1.php b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.7.1.php
index e9fb3d1..4f4e25b 100644
--- a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.7.1.php
+++ b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.8.0.php b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.8.0.php
index c296f5b..931f172 100644
--- a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.8.0.php
+++ b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-install-0.8.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 80f2006..ac2e100 100644
--- a/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Contacts/sql/contacts_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Contacts
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Abstract.php b/app/code/core/Mage/Core/Block/Abstract.php
index f1d7678..6f14908 100644
--- a/app/code/core/Mage/Core/Block/Abstract.php
+++ b/app/code/core/Mage/Core/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -1004,6 +1004,22 @@ abstract class Mage_Core_Block_Abstract extends Varien_Object
     }
 
     /**
+     * Generate security url by route and parameters (add form key if "Add Secret Key to URLs" disabled)
+     *
+     * @param string $route
+     * @param array $params
+     *
+     * @return string
+     */
+    public function getUrlSecure($route = '', $params = array())
+    {
+        if (!Mage::helper('adminhtml')->isEnabledSecurityKeyUrl()) {
+            $params[Mage_Core_Model_Url::FORM_KEY] = $this->getFormKey();
+        }
+        return $this->getUrl($route, $params);
+    }
+
+    /**
      * Generate base64-encoded url by route and parameters
      *
      * @param   string $route
diff --git a/app/code/core/Mage/Core/Block/Flush.php b/app/code/core/Mage/Core/Block/Flush.php
index a7690bb..416a11c 100644
--- a/app/code/core/Mage/Core/Block/Flush.php
+++ b/app/code/core/Mage/Core/Block/Flush.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Html/Calendar.php b/app/code/core/Mage/Core/Block/Html/Calendar.php
index fa0b681..2648b43 100644
--- a/app/code/core/Mage/Core/Block/Html/Calendar.php
+++ b/app/code/core/Mage/Core/Block/Html/Calendar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Html/Date.php b/app/code/core/Mage/Core/Block/Html/Date.php
index 2c30fd7..6ab2ef8 100644
--- a/app/code/core/Mage/Core/Block/Html/Date.php
+++ b/app/code/core/Mage/Core/Block/Html/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Html/Link.php b/app/code/core/Mage/Core/Block/Html/Link.php
index cc0636b..de290f9 100644
--- a/app/code/core/Mage/Core/Block/Html/Link.php
+++ b/app/code/core/Mage/Core/Block/Html/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Html/Select.php b/app/code/core/Mage/Core/Block/Html/Select.php
index 5ecd6d3..c142cef 100644
--- a/app/code/core/Mage/Core/Block/Html/Select.php
+++ b/app/code/core/Mage/Core/Block/Html/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Messages.php b/app/code/core/Mage/Core/Block/Messages.php
index 832a292..aa402af 100644
--- a/app/code/core/Mage/Core/Block/Messages.php
+++ b/app/code/core/Mage/Core/Block/Messages.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Profiler.php b/app/code/core/Mage/Core/Block/Profiler.php
index 3b37ce4..9ff32b9 100644
--- a/app/code/core/Mage/Core/Block/Profiler.php
+++ b/app/code/core/Mage/Core/Block/Profiler.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Store/Switcher.php b/app/code/core/Mage/Core/Block/Store/Switcher.php
index 48e2a3a..57a289d 100644
--- a/app/code/core/Mage/Core/Block/Store/Switcher.php
+++ b/app/code/core/Mage/Core/Block/Store/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Template.php b/app/code/core/Mage/Core/Block/Template.php
index 8d073ba..45d4fee 100644
--- a/app/code/core/Mage/Core/Block/Template.php
+++ b/app/code/core/Mage/Core/Block/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Template/Facade.php b/app/code/core/Mage/Core/Block/Template/Facade.php
index eb1b9a7..9a2f5b2 100644
--- a/app/code/core/Mage/Core/Block/Template/Facade.php
+++ b/app/code/core/Mage/Core/Block/Template/Facade.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Template/Smarty.php b/app/code/core/Mage/Core/Block/Template/Smarty.php
index 735e6c4..0eebe39 100644
--- a/app/code/core/Mage/Core/Block/Template/Smarty.php
+++ b/app/code/core/Mage/Core/Block/Template/Smarty.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Template/Zend.php b/app/code/core/Mage/Core/Block/Template/Zend.php
index c82bad1..fdea576 100644
--- a/app/code/core/Mage/Core/Block/Template/Zend.php
+++ b/app/code/core/Mage/Core/Block/Template/Zend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text.php b/app/code/core/Mage/Core/Block/Text.php
index 0a4470d..1b2ea70 100644
--- a/app/code/core/Mage/Core/Block/Text.php
+++ b/app/code/core/Mage/Core/Block/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/List.php b/app/code/core/Mage/Core/Block/Text/List.php
index 517d346..66c6af3 100644
--- a/app/code/core/Mage/Core/Block/Text/List.php
+++ b/app/code/core/Mage/Core/Block/Text/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/List/Item.php b/app/code/core/Mage/Core/Block/Text/List/Item.php
index 962ea66..c5d786e 100644
--- a/app/code/core/Mage/Core/Block/Text/List/Item.php
+++ b/app/code/core/Mage/Core/Block/Text/List/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/List/Link.php b/app/code/core/Mage/Core/Block/Text/List/Link.php
index 4baafec..03d9563 100644
--- a/app/code/core/Mage/Core/Block/Text/List/Link.php
+++ b/app/code/core/Mage/Core/Block/Text/List/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag.php b/app/code/core/Mage/Core/Block/Text/Tag.php
index 034a368..9f52f39 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag/Css.php b/app/code/core/Mage/Core/Block/Text/Tag/Css.php
index 5a00b15..df3040d 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag/Css.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag/Css.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag/Css/Admin.php b/app/code/core/Mage/Core/Block/Text/Tag/Css/Admin.php
index df7f1c0..3a4201a 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag/Css/Admin.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag/Css/Admin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag/Debug.php b/app/code/core/Mage/Core/Block/Text/Tag/Debug.php
index 942c5d7..6952c46 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag/Debug.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag/Debug.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag/Js.php b/app/code/core/Mage/Core/Block/Text/Tag/Js.php
index 9e72bd6..81103d1 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag/Js.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Block/Text/Tag/Meta.php b/app/code/core/Mage/Core/Block/Text/Tag/Meta.php
index 5fe10d6..802a26e 100644
--- a/app/code/core/Mage/Core/Block/Text/Tag/Meta.php
+++ b/app/code/core/Mage/Core/Block/Text/Tag/Meta.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Front/Action.php b/app/code/core/Mage/Core/Controller/Front/Action.php
index a8b9058..14fbede 100644
--- a/app/code/core/Mage/Core/Controller/Front/Action.php
+++ b/app/code/core/Mage/Core/Controller/Front/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Front/Router.php b/app/code/core/Mage/Core/Controller/Front/Router.php
index dd84a21..37cc958 100644
--- a/app/code/core/Mage/Core/Controller/Front/Router.php
+++ b/app/code/core/Mage/Core/Controller/Front/Router.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Request/Http.php b/app/code/core/Mage/Core/Controller/Request/Http.php
index 4c6236e..45ba237 100644
--- a/app/code/core/Mage/Core/Controller/Request/Http.php
+++ b/app/code/core/Mage/Core/Controller/Request/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Response/Http.php b/app/code/core/Mage/Core/Controller/Response/Http.php
index 818daac..5ebe9ab 100644
--- a/app/code/core/Mage/Core/Controller/Response/Http.php
+++ b/app/code/core/Mage/Core/Controller/Response/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Action.php b/app/code/core/Mage/Core/Controller/Varien/Action.php
index 00db488..191963c 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Action.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Exception.php b/app/code/core/Mage/Core/Controller/Varien/Exception.php
index c40ce4c..a25efb2 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Exception.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Front.php b/app/code/core/Mage/Core/Controller/Varien/Front.php
index bc18957..1954214 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Front.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Front.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Router/Abstract.php b/app/code/core/Mage/Core/Controller/Varien/Router/Abstract.php
index fd69cc7..7facaa2 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Router/Abstract.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Router/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Router/Admin.php b/app/code/core/Mage/Core/Controller/Varien/Router/Admin.php
index e03cd61..3d91996 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Router/Admin.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Router/Admin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Router/Default.php b/app/code/core/Mage/Core/Controller/Varien/Router/Default.php
index 3dd8ec9..a0c4e61 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Router/Default.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Router/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Controller/Varien/Router/Standard.php b/app/code/core/Mage/Core/Controller/Varien/Router/Standard.php
index 7ada834..59d2a55 100644
--- a/app/code/core/Mage/Core/Controller/Varien/Router/Standard.php
+++ b/app/code/core/Mage/Core/Controller/Varien/Router/Standard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Exception.php b/app/code/core/Mage/Core/Exception.php
index 2f4bb5a..c2bc31e 100644
--- a/app/code/core/Mage/Core/Exception.php
+++ b/app/code/core/Mage/Core/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Abstract.php b/app/code/core/Mage/Core/Helper/Abstract.php
index c93e461..ea847e3 100644
--- a/app/code/core/Mage/Core/Helper/Abstract.php
+++ b/app/code/core/Mage/Core/Helper/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -277,7 +277,45 @@ abstract class Mage_Core_Helper_Abstract
      */
     public function escapeUrl($data)
     {
-        return htmlspecialchars($data);
+        return htmlspecialchars(
+            $this->escapeScriptIdentifiers((string) $data),
+            ENT_COMPAT | ENT_HTML5 | ENT_HTML401,
+            'UTF-8'
+        );
+    }
+
+    /**
+     * Remove `\t`,`\n`,`\r`,`\0`,`\x0B:` symbols from the string.
+     *
+     * @param string $data
+     * @return string
+     */
+    public function escapeSpecial($data)
+    {
+        $specialSymbolsFiltrationPattern = '/[\t\n\r\0\x0B]+/';
+
+        return (string) preg_replace($specialSymbolsFiltrationPattern, '', $data);
+    }
+
+    /**
+     * Remove `javascript:`, `vbscript:`, `data:` words from the string.
+     *
+     * @param string $data
+     * @return string
+     */
+    public function escapeScriptIdentifiers($data)
+    {
+        $scripIdentifiersFiltrationPattern = '/((javascript(\\\\x3a|:|%3A))|(data(\\\\x3a|:|%3A))|(vbscript:))|'
+            . '((\\\\x6A\\\\x61\\\\x76\\\\x61\\\\x73\\\\x63\\\\x72\\\\x69\\\\x70\\\\x74(\\\\x3a|:|%3A))|'
+            . '(\\\\x64\\\\x61\\\\x74\\\\x61(\\\\x3a|:|%3A)))/i';
+
+        $preFilteredData = $this->escapeSpecial($data);
+        $filteredData = preg_replace($scripIdentifiersFiltrationPattern, ':', $preFilteredData) ?: '';
+        if (preg_match($scripIdentifiersFiltrationPattern, $filteredData)) {
+            $filteredData = $this->escapeScriptIdentifiers($filteredData);
+        }
+
+        return $filteredData;
     }
 
     /**
diff --git a/app/code/core/Mage/Core/Helper/Array.php b/app/code/core/Mage/Core/Helper/Array.php
index 4eb1ef9..5774042 100644
--- a/app/code/core/Mage/Core/Helper/Array.php
+++ b/app/code/core/Mage/Core/Helper/Array.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Cookie.php b/app/code/core/Mage/Core/Helper/Cookie.php
index 4d5ba5f..d9d916f 100644
--- a/app/code/core/Mage/Core/Helper/Cookie.php
+++ b/app/code/core/Mage/Core/Helper/Cookie.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Data.php b/app/code/core/Mage/Core/Helper/Data.php
index f55957a..e2e41b4 100644
--- a/app/code/core/Mage/Core/Helper/Data.php
+++ b/app/code/core/Mage/Core/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/File/Storage.php b/app/code/core/Mage/Core/Helper/File/Storage.php
index 82111a3..05892c9 100644
--- a/app/code/core/Mage/Core/Helper/File/Storage.php
+++ b/app/code/core/Mage/Core/Helper/File/Storage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/File/Storage/Database.php b/app/code/core/Mage/Core/Helper/File/Storage/Database.php
index cea0687..a879adf 100644
--- a/app/code/core/Mage/Core/Helper/File/Storage/Database.php
+++ b/app/code/core/Mage/Core/Helper/File/Storage/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Hint.php b/app/code/core/Mage/Core/Helper/Hint.php
index e199a60..8559d39 100644
--- a/app/code/core/Mage/Core/Helper/Hint.php
+++ b/app/code/core/Mage/Core/Helper/Hint.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Http.php b/app/code/core/Mage/Core/Helper/Http.php
index 748c63d..0136bd0 100644
--- a/app/code/core/Mage/Core/Helper/Http.php
+++ b/app/code/core/Mage/Core/Helper/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Js.php b/app/code/core/Mage/Core/Helper/Js.php
index 8a27009..9d4a329 100644
--- a/app/code/core/Mage/Core/Helper/Js.php
+++ b/app/code/core/Mage/Core/Helper/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/String.php b/app/code/core/Mage/Core/Helper/String.php
index 93db4cf..94ccc22 100644
--- a/app/code/core/Mage/Core/Helper/String.php
+++ b/app/code/core/Mage/Core/Helper/String.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Translate.php b/app/code/core/Mage/Core/Helper/Translate.php
index f399a0a..b5527e9 100644
--- a/app/code/core/Mage/Core/Helper/Translate.php
+++ b/app/code/core/Mage/Core/Helper/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/UnserializeArray.php b/app/code/core/Mage/Core/Helper/UnserializeArray.php
index c83b37a..5aad92b 100644
--- a/app/code/core/Mage/Core/Helper/UnserializeArray.php
+++ b/app/code/core/Mage/Core/Helper/UnserializeArray.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Url.php b/app/code/core/Mage/Core/Helper/Url.php
index 3e24493..c8eca83 100644
--- a/app/code/core/Mage/Core/Helper/Url.php
+++ b/app/code/core/Mage/Core/Helper/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Helper/Url/Rewrite.php b/app/code/core/Mage/Core/Helper/Url/Rewrite.php
index 64d25f3..79ced64 100644
--- a/app/code/core/Mage/Core/Helper/Url/Rewrite.php
+++ b/app/code/core/Mage/Core/Helper/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Abstract.php b/app/code/core/Mage/Core/Model/Abstract.php
index 0be1a47..757164d 100644
--- a/app/code/core/Mage/Core/Model/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/App.php b/app/code/core/Mage/Core/Model/App.php
index 8677ab6..1e5e6d6 100644
--- a/app/code/core/Mage/Core/Model/App.php
+++ b/app/code/core/Mage/Core/Model/App.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/App/Area.php b/app/code/core/Mage/Core/Model/App/Area.php
index 5f35cf1..87d9300 100644
--- a/app/code/core/Mage/Core/Model/App/Area.php
+++ b/app/code/core/Mage/Core/Model/App/Area.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/App/Emulation.php b/app/code/core/Mage/Core/Model/App/Emulation.php
index 1f60f00..189a627 100644
--- a/app/code/core/Mage/Core/Model/App/Emulation.php
+++ b/app/code/core/Mage/Core/Model/App/Emulation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Cache.php b/app/code/core/Mage/Core/Model/Cache.php
index c2ff2d4..856677e 100644
--- a/app/code/core/Mage/Core/Model/Cache.php
+++ b/app/code/core/Mage/Core/Model/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Calculator.php b/app/code/core/Mage/Core/Model/Calculator.php
index 71f97b1..fb0717f 100644
--- a/app/code/core/Mage/Core/Model/Calculator.php
+++ b/app/code/core/Mage/Core/Model/Calculator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config.php b/app/code/core/Mage/Core/Model/Config.php
index 70ddede..472c1a7 100644
--- a/app/code/core/Mage/Core/Model/Config.php
+++ b/app/code/core/Mage/Core/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config/Base.php b/app/code/core/Mage/Core/Model/Config/Base.php
index 471b568..a9b1ca9 100644
--- a/app/code/core/Mage/Core/Model/Config/Base.php
+++ b/app/code/core/Mage/Core/Model/Config/Base.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config/Data.php b/app/code/core/Mage/Core/Model/Config/Data.php
index 7f72073..a2be7be 100644
--- a/app/code/core/Mage/Core/Model/Config/Data.php
+++ b/app/code/core/Mage/Core/Model/Config/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config/Element.php b/app/code/core/Mage/Core/Model/Config/Element.php
index ea4a60e..77d3a38 100644
--- a/app/code/core/Mage/Core/Model/Config/Element.php
+++ b/app/code/core/Mage/Core/Model/Config/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config/Options.php b/app/code/core/Mage/Core/Model/Config/Options.php
index 36b9bcd..b67f26a 100644
--- a/app/code/core/Mage/Core/Model/Config/Options.php
+++ b/app/code/core/Mage/Core/Model/Config/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Config/System.php b/app/code/core/Mage/Core/Model/Config/System.php
index cd6e9da..98f6639 100644
--- a/app/code/core/Mage/Core/Model/Config/System.php
+++ b/app/code/core/Mage/Core/Model/Config/System.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Convert.php b/app/code/core/Mage/Core/Model/Convert.php
index 06ac99c..b405a3f 100644
--- a/app/code/core/Mage/Core/Model/Convert.php
+++ b/app/code/core/Mage/Core/Model/Convert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Cookie.php b/app/code/core/Mage/Core/Model/Cookie.php
index f0b7a2d..208d9d7 100644
--- a/app/code/core/Mage/Core/Model/Cookie.php
+++ b/app/code/core/Mage/Core/Model/Cookie.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Date.php b/app/code/core/Mage/Core/Model/Date.php
index 42b29d2..c74d2cd 100644
--- a/app/code/core/Mage/Core/Model/Date.php
+++ b/app/code/core/Mage/Core/Model/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design.php b/app/code/core/Mage/Core/Model/Design.php
index 0ff7923..9548804 100644
--- a/app/code/core/Mage/Core/Model/Design.php
+++ b/app/code/core/Mage/Core/Model/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design/Config.php b/app/code/core/Mage/Core/Model/Design/Config.php
index 911afb4..cba779c 100644
--- a/app/code/core/Mage/Core/Model/Design/Config.php
+++ b/app/code/core/Mage/Core/Model/Design/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design/Fallback.php b/app/code/core/Mage/Core/Model/Design/Fallback.php
index caec6cd..e0b8bf4 100644
--- a/app/code/core/Mage/Core/Model/Design/Fallback.php
+++ b/app/code/core/Mage/Core/Model/Design/Fallback.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design/Package.php b/app/code/core/Mage/Core/Model/Design/Package.php
index f4c67ff..d0587e8 100644
--- a/app/code/core/Mage/Core/Model/Design/Package.php
+++ b/app/code/core/Mage/Core/Model/Design/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design/Source/Apply.php b/app/code/core/Mage/Core/Model/Design/Source/Apply.php
index 4004497..ddca7a3 100644
--- a/app/code/core/Mage/Core/Model/Design/Source/Apply.php
+++ b/app/code/core/Mage/Core/Model/Design/Source/Apply.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Design/Source/Design.php b/app/code/core/Mage/Core/Model/Design/Source/Design.php
index 6c835e1..477821f 100644
--- a/app/code/core/Mage/Core/Model/Design/Source/Design.php
+++ b/app/code/core/Mage/Core/Model/Design/Source/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Domainpolicy.php b/app/code/core/Mage/Core/Model/Domainpolicy.php
index 80ecd9f..45fadb0 100644
--- a/app/code/core/Mage/Core/Model/Domainpolicy.php
+++ b/app/code/core/Mage/Core/Model/Domainpolicy.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email.php b/app/code/core/Mage/Core/Model/Email.php
index b72bec4..ab18e8b 100644
--- a/app/code/core/Mage/Core/Model/Email.php
+++ b/app/code/core/Mage/Core/Model/Email.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Info.php b/app/code/core/Mage/Core/Model/Email/Info.php
index 9acdf66..11ce16c 100644
--- a/app/code/core/Mage/Core/Model/Email/Info.php
+++ b/app/code/core/Mage/Core/Model/Email/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Queue.php b/app/code/core/Mage/Core/Model/Email/Queue.php
index 64bd6b2..81ac43d 100644
--- a/app/code/core/Mage/Core/Model/Email/Queue.php
+++ b/app/code/core/Mage/Core/Model/Email/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Template.php b/app/code/core/Mage/Core/Model/Email/Template.php
index 1f654a4..9c28d45 100644
--- a/app/code/core/Mage/Core/Model/Email/Template.php
+++ b/app/code/core/Mage/Core/Model/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Template/Abstract.php b/app/code/core/Mage/Core/Model/Email/Template/Abstract.php
index 498e810..4ee32f3 100644
--- a/app/code/core/Mage/Core/Model/Email/Template/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Email/Template/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Template/Filter.php b/app/code/core/Mage/Core/Model/Email/Template/Filter.php
index d60c428..2d64307 100644
--- a/app/code/core/Mage/Core/Model/Email/Template/Filter.php
+++ b/app/code/core/Mage/Core/Model/Email/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Template/Mailer.php b/app/code/core/Mage/Core/Model/Email/Template/Mailer.php
index a3506bf..2192867 100644
--- a/app/code/core/Mage/Core/Model/Email/Template/Mailer.php
+++ b/app/code/core/Mage/Core/Model/Email/Template/Mailer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Email/Transport.php b/app/code/core/Mage/Core/Model/Email/Transport.php
index b13d97f..be9541d 100644
--- a/app/code/core/Mage/Core/Model/Email/Transport.php
+++ b/app/code/core/Mage/Core/Model/Email/Transport.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Encryption.php b/app/code/core/Mage/Core/Model/Encryption.php
index 021bd85..7bf43e7 100644
--- a/app/code/core/Mage/Core/Model/Encryption.php
+++ b/app/code/core/Mage/Core/Model/Encryption.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Factory.php b/app/code/core/Mage/Core/Model/Factory.php
index 0bf9e96..3fc4553 100644
--- a/app/code/core/Mage/Core/Model/Factory.php
+++ b/app/code/core/Mage/Core/Model/Factory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage.php b/app/code/core/Mage/Core/Model/File/Storage.php
index f6f653d..7a964df 100644
--- a/app/code/core/Mage/Core/Model/File/Storage.php
+++ b/app/code/core/Mage/Core/Model/File/Storage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/Abstract.php b/app/code/core/Mage/Core/Model/File/Storage/Abstract.php
index af415a3..d97ac52 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/Abstract.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/Database.php b/app/code/core/Mage/Core/Model/File/Storage/Database.php
index 1ed65e1..719130e 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/Database.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/Database/Abstract.php b/app/code/core/Mage/Core/Model/File/Storage/Database/Abstract.php
index 001318e..8d97619 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/Database/Abstract.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/Database/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/Directory/Database.php b/app/code/core/Mage/Core/Model/File/Storage/Directory/Database.php
index aebade2..e2f9a37 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/Directory/Database.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/Directory/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/File.php b/app/code/core/Mage/Core/Model/File/Storage/File.php
index e23116c..57eb0e0 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/File.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Storage/Flag.php b/app/code/core/Mage/Core/Model/File/Storage/Flag.php
index e006525..fd4cfea 100644
--- a/app/code/core/Mage/Core/Model/File/Storage/Flag.php
+++ b/app/code/core/Mage/Core/Model/File/Storage/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Uploader.php b/app/code/core/Mage/Core/Model/File/Uploader.php
index 42c3452..a35a4c0 100644
--- a/app/code/core/Mage/Core/Model/File/Uploader.php
+++ b/app/code/core/Mage/Core/Model/File/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php b/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
index 6c8cfd3..ca5a664 100644
--- a/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
+++ b/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Validator/Image.php b/app/code/core/Mage/Core/Model/File/Validator/Image.php
index 0d4e188..4017c61 100644
--- a/app/code/core/Mage/Core/Model/File/Validator/Image.php
+++ b/app/code/core/Mage/Core/Model/File/Validator/Image.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Validator/NotProtectedExtension.php b/app/code/core/Mage/Core/Model/File/Validator/NotProtectedExtension.php
index 755ddba..cf83db2 100644
--- a/app/code/core/Mage/Core/Model/File/Validator/NotProtectedExtension.php
+++ b/app/code/core/Mage/Core/Model/File/Validator/NotProtectedExtension.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/File/Validator/StreamWrapper.php b/app/code/core/Mage/Core/Model/File/Validator/StreamWrapper.php
new file mode 100644
index 0000000..8b3be5e
--- /dev/null
+++ b/app/code/core/Mage/Core/Model/File/Validator/StreamWrapper.php
@@ -0,0 +1,69 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Mage
+ * @package     Mage_Core
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+/**
+ * Validator for check is stream wrapper allowed
+ *
+ * @category   Mage
+ * @package    Mage_Core
+ * @author     Magento Core Team <core@magentocommerce.com>
+ */
+class Mage_Core_Model_File_Validator_StreamWrapper
+{
+    /**
+     * Allowed stream wrappers
+     *
+     * @var array
+     */
+    protected $_allowedStreamWrappers = array();
+
+    /**
+     * Mage_Core_Model_File_Validator_StreamWrapper constructor.
+     *
+     * @param array $allowedStreamWrappers
+     */
+    public function __construct($allowedStreamWrappers = array())
+    {
+        $this->_allowedStreamWrappers = $allowedStreamWrappers;
+    }
+
+    /**
+     * Validation callback for checking is stream wrapper allowed
+     *
+     * @param  string $filePath Path to file
+     * @return boolean
+     */
+    public function validate($filePath)
+    {
+        if (($pos = strpos($filePath, '://')) > 0) {
+            $wrapper = substr($filePath, 0, $pos);
+            if (!in_array($wrapper, $this->_allowedStreamWrappers)) {
+                 return false;
+            }
+        }
+        return true;
+    }
+}
diff --git a/app/code/core/Mage/Core/Model/Flag.php b/app/code/core/Mage/Core/Model/Flag.php
index 7e32aff..2f683dd 100644
--- a/app/code/core/Mage/Core/Model/Flag.php
+++ b/app/code/core/Mage/Core/Model/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Input/Filter.php b/app/code/core/Mage/Core/Model/Input/Filter.php
index 81749dd..17904d1 100644
--- a/app/code/core/Mage/Core/Model/Input/Filter.php
+++ b/app/code/core/Mage/Core/Model/Input/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Input/Filter/MaliciousCode.php b/app/code/core/Mage/Core/Model/Input/Filter/MaliciousCode.php
index ee120ff..7bc7c95 100644
--- a/app/code/core/Mage/Core/Model/Input/Filter/MaliciousCode.php
+++ b/app/code/core/Mage/Core/Model/Input/Filter/MaliciousCode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -50,7 +50,7 @@ class Mage_Core_Model_Input_Filter_MaliciousCode implements Zend_Filter_Interfac
         //js in the style attribute
         '/style=[^<]*((expression\s*?\([^<]*?\))|(behavior\s*:))[^<]*(?=\>)/Uis',
         //js attributes
-        '/(ondblclick|onclick|onkeydown|onkeypress|onkeyup|onmousedown|onmousemove|onmouseout|onmouseover|onmouseup|onload|onunload|onerror)\s*=[^<]*(?=\>)/Uis',
+        '/(ondblclick|onclick|onkeydown|onkeypress|onkeyup|onmousedown|onmousemove|onmouseout|onmouseover|onmouseup|onload|onunload|onerror)\s*=[^>]*(?=\>)/Uis',
         //tags
         '/<\/?(script|meta|link|frame|iframe).*>/Uis',
         //base64 usage
diff --git a/app/code/core/Mage/Core/Model/Language.php b/app/code/core/Mage/Core/Model/Language.php
index af81335..acb3ce2 100644
--- a/app/code/core/Mage/Core/Model/Language.php
+++ b/app/code/core/Mage/Core/Model/Language.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Layout.php b/app/code/core/Mage/Core/Model/Layout.php
index 7f2f154..f032e00 100644
--- a/app/code/core/Mage/Core/Model/Layout.php
+++ b/app/code/core/Mage/Core/Model/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Layout/Data.php b/app/code/core/Mage/Core/Model/Layout/Data.php
index ab254bc..285621c 100644
--- a/app/code/core/Mage/Core/Model/Layout/Data.php
+++ b/app/code/core/Mage/Core/Model/Layout/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Layout/Element.php b/app/code/core/Mage/Core/Model/Layout/Element.php
index c1f4f6f..af8a24a 100644
--- a/app/code/core/Mage/Core/Model/Layout/Element.php
+++ b/app/code/core/Mage/Core/Model/Layout/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Layout/Update.php b/app/code/core/Mage/Core/Model/Layout/Update.php
index eba701e..bd5fc32 100644
--- a/app/code/core/Mage/Core/Model/Layout/Update.php
+++ b/app/code/core/Mage/Core/Model/Layout/Update.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Locale.php b/app/code/core/Mage/Core/Model/Locale.php
index 2d041ba..c6578c0 100644
--- a/app/code/core/Mage/Core/Model/Locale.php
+++ b/app/code/core/Mage/Core/Model/Locale.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Locale/Config.php b/app/code/core/Mage/Core/Model/Locale/Config.php
index f2960e3..209359d 100644
--- a/app/code/core/Mage/Core/Model/Locale/Config.php
+++ b/app/code/core/Mage/Core/Model/Locale/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Core_Model_Locale_Config
diff --git a/app/code/core/Mage/Core/Model/Log/Adapter.php b/app/code/core/Mage/Core/Model/Log/Adapter.php
index 5b20c09..6dedfd1 100644
--- a/app/code/core/Mage/Core/Model/Log/Adapter.php
+++ b/app/code/core/Mage/Core/Model/Log/Adapter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Logger.php b/app/code/core/Mage/Core/Model/Logger.php
index 9238ca7..a986727 100644
--- a/app/code/core/Mage/Core/Model/Logger.php
+++ b/app/code/core/Mage/Core/Model/Logger.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Magento/Api.php b/app/code/core/Mage/Core/Model/Magento/Api.php
index 93c67e7..dbaadae 100644
--- a/app/code/core/Mage/Core/Model/Magento/Api.php
+++ b/app/code/core/Mage/Core/Model/Magento/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Magento/Api/V2.php b/app/code/core/Mage/Core/Model/Magento/Api/V2.php
index d5fcc0e..f1b14d9 100644
--- a/app/code/core/Mage/Core/Model/Magento/Api/V2.php
+++ b/app/code/core/Mage/Core/Model/Magento/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message.php b/app/code/core/Mage/Core/Model/Message.php
index e6eed9f..7954f0e 100644
--- a/app/code/core/Mage/Core/Model/Message.php
+++ b/app/code/core/Mage/Core/Model/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Abstract.php b/app/code/core/Mage/Core/Model/Message/Abstract.php
index 14fb80d..eb38ac0 100644
--- a/app/code/core/Mage/Core/Model/Message/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Message/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Collection.php b/app/code/core/Mage/Core/Model/Message/Collection.php
index 83f3944..d6d3893 100644
--- a/app/code/core/Mage/Core/Model/Message/Collection.php
+++ b/app/code/core/Mage/Core/Model/Message/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Error.php b/app/code/core/Mage/Core/Model/Message/Error.php
index 97ee924..00bd89e 100644
--- a/app/code/core/Mage/Core/Model/Message/Error.php
+++ b/app/code/core/Mage/Core/Model/Message/Error.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Notice.php b/app/code/core/Mage/Core/Model/Message/Notice.php
index 0a9b4ae..de74476 100644
--- a/app/code/core/Mage/Core/Model/Message/Notice.php
+++ b/app/code/core/Mage/Core/Model/Message/Notice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Success.php b/app/code/core/Mage/Core/Model/Message/Success.php
index 0bf8163..9989cd4 100644
--- a/app/code/core/Mage/Core/Model/Message/Success.php
+++ b/app/code/core/Mage/Core/Model/Message/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Message/Warning.php b/app/code/core/Mage/Core/Model/Message/Warning.php
index 23d67e7..2ea04b9 100644
--- a/app/code/core/Mage/Core/Model/Message/Warning.php
+++ b/app/code/core/Mage/Core/Model/Message/Warning.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Abstract.php b/app/code/core/Mage/Core/Model/Mysql4/Abstract.php
index e21d7f3..82c0fe3 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Cache.php b/app/code/core/Mage/Core/Model/Mysql4/Cache.php
index 36cf456..dd92e90 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Cache.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Collection/Abstract.php b/app/code/core/Mage/Core/Model/Mysql4/Collection/Abstract.php
index 96bbb13..57d7bcd 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Collection/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Config.php b/app/code/core/Mage/Core/Model/Mysql4/Config.php
index 7bae301..3818dcb 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Config.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Config/Data.php b/app/code/core/Mage/Core/Model/Mysql4/Config/Data.php
index 52e2457..a7c1cc3 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Config/Data.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Config/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Config/Data/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Config/Data/Collection.php
index 4c626d2..0e08b10 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Config/Data/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Config/Data/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Design.php b/app/code/core/Mage/Core/Model/Mysql4/Design.php
index 0aad96f..69a72fc 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Design.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Design/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Design/Collection.php
index 7843f3e..42dc570 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Design/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Design/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Design/Package/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Design/Package/Collection.php
index a029f87..df02a51 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Design/Package/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Design/Package/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Design/Theme/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Design/Theme/Collection.php
index c314b30..db5540f 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Design/Theme/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Design/Theme/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Email/Template.php b/app/code/core/Mage/Core/Model/Mysql4/Email/Template.php
index 8bd386c..1fbcf3e 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Email/Template.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Email/Template/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Email/Template/Collection.php
index 125b2af..758cb28 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Email/Template/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Email/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Abstract.php b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Abstract.php
index b8d6ff9..fa8ef49 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Database.php b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Database.php
index f66d478..3721491 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Database.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Directory/Database.php b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Directory/Database.php
index 809b431..793dced 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Directory/Database.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/Directory/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/File.php b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/File.php
index 7a5206b..acf49a2 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/File/Storage/File.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/File/Storage/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Flag.php b/app/code/core/Mage/Core/Model/Mysql4/Flag.php
index 302563f..53f0273 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Flag.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Language.php b/app/code/core/Mage/Core/Model/Mysql4/Language.php
index 9c88215..3b3d11c 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Language.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Language.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Language/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Language/Collection.php
index 2e70bd4..1622909 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Language/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Language/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Layout.php b/app/code/core/Mage/Core/Model/Mysql4/Layout.php
index 9446796..21df8f5 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Layout.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Resource.php b/app/code/core/Mage/Core/Model/Mysql4/Resource.php
index d6efc40..f346f03 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Resource.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Session.php b/app/code/core/Mage/Core/Model/Mysql4/Session.php
index 6d73829..1c62e30 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Session.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Store.php b/app/code/core/Mage/Core/Model/Mysql4/Store.php
index 9b7c6e6..1335bb9 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Store.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Store/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Store/Collection.php
index 4fe14ae..f2c6d7f 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Store/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Store/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Store/Group.php b/app/code/core/Mage/Core/Model/Mysql4/Store/Group.php
index d6df596..4bf54e4 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Store/Group.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Store/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Store/Group/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Store/Group/Collection.php
index 936ab7a..0b6c7ab 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Store/Group/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Store/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Translate.php b/app/code/core/Mage/Core/Model/Mysql4/Translate.php
index b2032f0..ee881f5 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Translate.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Translate/String.php b/app/code/core/Mage/Core/Model/Mysql4/Translate/String.php
index f2e26cc..e9e5a70 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Translate/String.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Translate/String.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite.php b/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite.php
index 3136f4f..2958b52 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite/Collection.php
index e1177f5..5467706 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Url/Rewrite/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Variable.php b/app/code/core/Mage/Core/Model/Mysql4/Variable.php
index c87f477..91cb4d8 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Variable.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Variable/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Variable/Collection.php
index 35a38e0..df7a2d2 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Variable/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Variable/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Website.php b/app/code/core/Mage/Core/Model/Mysql4/Website.php
index ecf6818..ed417dd 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Website.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Mysql4/Website/Collection.php b/app/code/core/Mage/Core/Model/Mysql4/Website/Collection.php
index 7b2d7e1..07b1361 100644
--- a/app/code/core/Mage/Core/Model/Mysql4/Website/Collection.php
+++ b/app/code/core/Mage/Core/Model/Mysql4/Website/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Observer.php b/app/code/core/Mage/Core/Model/Observer.php
index 38c5300..0d570be 100644
--- a/app/code/core/Mage/Core/Model/Observer.php
+++ b/app/code/core/Mage/Core/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource.php b/app/code/core/Mage/Core/Model/Resource.php
index 7e48903..f122536 100644
--- a/app/code/core/Mage/Core/Model/Resource.php
+++ b/app/code/core/Mage/Core/Model/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Abstract.php
index cb39545..2c2e75e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Cache.php b/app/code/core/Mage/Core/Model/Resource/Cache.php
index 32bf2e3..cf8203e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Cache.php
+++ b/app/code/core/Mage/Core/Model/Resource/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Config.php b/app/code/core/Mage/Core/Model/Resource/Config.php
index 91e3ff4..696951e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Config.php
+++ b/app/code/core/Mage/Core/Model/Resource/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Config/Data.php b/app/code/core/Mage/Core/Model/Resource/Config/Data.php
index d25b07a..873b900 100644
--- a/app/code/core/Mage/Core/Model/Resource/Config/Data.php
+++ b/app/code/core/Mage/Core/Model/Resource/Config/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Config/Data/Collection.php b/app/code/core/Mage/Core/Model/Resource/Config/Data/Collection.php
index fd282ed..e7139e2 100644
--- a/app/code/core/Mage/Core/Model/Resource/Config/Data/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Config/Data/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Db/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Db/Abstract.php
index eeb0fd6..6f54900 100644
--- a/app/code/core/Mage/Core/Model/Resource/Db/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Db/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Db/Collection/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Db/Collection/Abstract.php
index cd55746..63d14d7 100644
--- a/app/code/core/Mage/Core/Model/Resource/Db/Collection/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Db/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Design.php b/app/code/core/Mage/Core/Model/Resource/Design.php
index 6fc54b8..d52f88a 100644
--- a/app/code/core/Mage/Core/Model/Resource/Design.php
+++ b/app/code/core/Mage/Core/Model/Resource/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Design/Collection.php b/app/code/core/Mage/Core/Model/Resource/Design/Collection.php
index 1e5e6c2..1225919 100644
--- a/app/code/core/Mage/Core/Model/Resource/Design/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Design/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Design/Package/Collection.php b/app/code/core/Mage/Core/Model/Resource/Design/Package/Collection.php
index 81b6326..122dfbf 100644
--- a/app/code/core/Mage/Core/Model/Resource/Design/Package/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Design/Package/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Email/Queue.php b/app/code/core/Mage/Core/Model/Resource/Email/Queue.php
index c682fc1..3a968ca 100644
--- a/app/code/core/Mage/Core/Model/Resource/Email/Queue.php
+++ b/app/code/core/Mage/Core/Model/Resource/Email/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Core_Model_Resource_Email_Queue extends Mage_Core_Model_Resource_Db_Abstract
diff --git a/app/code/core/Mage/Core/Model/Resource/Email/Queue/Collection.php b/app/code/core/Mage/Core/Model/Resource/Email/Queue/Collection.php
index 7c4ea9d..248f311 100644
--- a/app/code/core/Mage/Core/Model/Resource/Email/Queue/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Email/Queue/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Email/Template.php b/app/code/core/Mage/Core/Model/Resource/Email/Template.php
index e97e18e..ce9b179 100644
--- a/app/code/core/Mage/Core/Model/Resource/Email/Template.php
+++ b/app/code/core/Mage/Core/Model/Resource/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Email/Template/Collection.php b/app/code/core/Mage/Core/Model/Resource/Email/Template/Collection.php
index 5093f5b..59eb81e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Email/Template/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Email/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Entity/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Entity/Abstract.php
index b0b2016..2327a6e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Entity/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Entity/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Entity/Table.php b/app/code/core/Mage/Core/Model/Resource/Entity/Table.php
index cbb562e..be81ccc 100644
--- a/app/code/core/Mage/Core/Model/Resource/Entity/Table.php
+++ b/app/code/core/Mage/Core/Model/Resource/Entity/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/File/Storage/Abstract.php b/app/code/core/Mage/Core/Model/Resource/File/Storage/Abstract.php
index 912a1b8..67c6a34 100644
--- a/app/code/core/Mage/Core/Model/Resource/File/Storage/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/File/Storage/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/File/Storage/Database.php b/app/code/core/Mage/Core/Model/Resource/File/Storage/Database.php
index 5fd21c4..a52585c 100644
--- a/app/code/core/Mage/Core/Model/Resource/File/Storage/Database.php
+++ b/app/code/core/Mage/Core/Model/Resource/File/Storage/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/File/Storage/Directory/Database.php b/app/code/core/Mage/Core/Model/Resource/File/Storage/Directory/Database.php
index 8f3e890..34825b6 100644
--- a/app/code/core/Mage/Core/Model/Resource/File/Storage/Directory/Database.php
+++ b/app/code/core/Mage/Core/Model/Resource/File/Storage/Directory/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/File/Storage/File.php b/app/code/core/Mage/Core/Model/Resource/File/Storage/File.php
index c2d44a4..e70740e 100644
--- a/app/code/core/Mage/Core/Model/Resource/File/Storage/File.php
+++ b/app/code/core/Mage/Core/Model/Resource/File/Storage/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Flag.php b/app/code/core/Mage/Core/Model/Resource/Flag.php
index e75eb47..aa01f64 100644
--- a/app/code/core/Mage/Core/Model/Resource/Flag.php
+++ b/app/code/core/Mage/Core/Model/Resource/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Helper/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Helper/Abstract.php
index 7a4db7f..39ec44f 100644
--- a/app/code/core/Mage/Core/Model/Resource/Helper/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Helper/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Core/Model/Resource/Helper/Mysql4.php
index 04d6df5..4630bb2 100644
--- a/app/code/core/Mage/Core/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Core/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Iterator.php b/app/code/core/Mage/Core/Model/Resource/Iterator.php
index a857841..ad96ebb 100644
--- a/app/code/core/Mage/Core/Model/Resource/Iterator.php
+++ b/app/code/core/Mage/Core/Model/Resource/Iterator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Language.php b/app/code/core/Mage/Core/Model/Resource/Language.php
index 061de03..a04e4b0 100644
--- a/app/code/core/Mage/Core/Model/Resource/Language.php
+++ b/app/code/core/Mage/Core/Model/Resource/Language.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Language/Collection.php b/app/code/core/Mage/Core/Model/Resource/Language/Collection.php
index f2462a4..7dca44a 100644
--- a/app/code/core/Mage/Core/Model/Resource/Language/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Language/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Layout.php b/app/code/core/Mage/Core/Model/Resource/Layout.php
index 79ec5ac..4f778fb 100644
--- a/app/code/core/Mage/Core/Model/Resource/Layout.php
+++ b/app/code/core/Mage/Core/Model/Resource/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Resource.php b/app/code/core/Mage/Core/Model/Resource/Resource.php
index b9f80c7..9e2b422 100644
--- a/app/code/core/Mage/Core/Model/Resource/Resource.php
+++ b/app/code/core/Mage/Core/Model/Resource/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Session.php b/app/code/core/Mage/Core/Model/Resource/Session.php
index 520fcef..eb59f55 100644
--- a/app/code/core/Mage/Core/Model/Resource/Session.php
+++ b/app/code/core/Mage/Core/Model/Resource/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Setup.php b/app/code/core/Mage/Core/Model/Resource/Setup.php
index 737f4fb..e3a5e72 100644
--- a/app/code/core/Mage/Core/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Core/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Setup/Query/Modifier.php b/app/code/core/Mage/Core/Model/Resource/Setup/Query/Modifier.php
index 46eb478..df4c571 100644
--- a/app/code/core/Mage/Core/Model/Resource/Setup/Query/Modifier.php
+++ b/app/code/core/Mage/Core/Model/Resource/Setup/Query/Modifier.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Store.php b/app/code/core/Mage/Core/Model/Resource/Store.php
index 2132ab9..f44861c 100644
--- a/app/code/core/Mage/Core/Model/Resource/Store.php
+++ b/app/code/core/Mage/Core/Model/Resource/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Store/Collection.php b/app/code/core/Mage/Core/Model/Resource/Store/Collection.php
index 34f4586..8456f11 100644
--- a/app/code/core/Mage/Core/Model/Resource/Store/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Store/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Store/Group.php b/app/code/core/Mage/Core/Model/Resource/Store/Group.php
index 4df8afe..39bbc36 100644
--- a/app/code/core/Mage/Core/Model/Resource/Store/Group.php
+++ b/app/code/core/Mage/Core/Model/Resource/Store/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Store/Group/Collection.php b/app/code/core/Mage/Core/Model/Resource/Store/Group/Collection.php
index 4d1322d..783515e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Store/Group/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Store/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Transaction.php b/app/code/core/Mage/Core/Model/Resource/Transaction.php
index 08100e8..137d9f4 100644
--- a/app/code/core/Mage/Core/Model/Resource/Transaction.php
+++ b/app/code/core/Mage/Core/Model/Resource/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Translate.php b/app/code/core/Mage/Core/Model/Resource/Translate.php
index 7df1011..33aaf4b 100644
--- a/app/code/core/Mage/Core/Model/Resource/Translate.php
+++ b/app/code/core/Mage/Core/Model/Resource/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Translate/String.php b/app/code/core/Mage/Core/Model/Resource/Translate/String.php
index eb1dd8c..39cb8a1 100644
--- a/app/code/core/Mage/Core/Model/Resource/Translate/String.php
+++ b/app/code/core/Mage/Core/Model/Resource/Translate/String.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Type/Abstract.php b/app/code/core/Mage/Core/Model/Resource/Type/Abstract.php
index bcfe533..fa8696b 100644
--- a/app/code/core/Mage/Core/Model/Resource/Type/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Resource/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Type/Db.php b/app/code/core/Mage/Core/Model/Resource/Type/Db.php
index 2304ced..45c3258 100644
--- a/app/code/core/Mage/Core/Model/Resource/Type/Db.php
+++ b/app/code/core/Mage/Core/Model/Resource/Type/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli.php b/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli.php
index 71802f0..92b7599 100644
--- a/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli.php
+++ b/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli/Setup.php b/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli/Setup.php
index 3549070..a9cffbc 100644
--- a/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli/Setup.php
+++ b/app/code/core/Mage/Core/Model/Resource/Type/Db/Mysqli/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Type/Db/Pdo/Mysql.php b/app/code/core/Mage/Core/Model/Resource/Type/Db/Pdo/Mysql.php
index ca05113..817cdd5 100644
--- a/app/code/core/Mage/Core/Model/Resource/Type/Db/Pdo/Mysql.php
+++ b/app/code/core/Mage/Core/Model/Resource/Type/Db/Pdo/Mysql.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Url/Rewrite.php b/app/code/core/Mage/Core/Model/Resource/Url/Rewrite.php
index 1b24d45..c76af28 100644
--- a/app/code/core/Mage/Core/Model/Resource/Url/Rewrite.php
+++ b/app/code/core/Mage/Core/Model/Resource/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Url/Rewrite/Collection.php b/app/code/core/Mage/Core/Model/Resource/Url/Rewrite/Collection.php
index d6ae9e7..84291fb 100644
--- a/app/code/core/Mage/Core/Model/Resource/Url/Rewrite/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Url/Rewrite/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Variable.php b/app/code/core/Mage/Core/Model/Resource/Variable.php
index 22495b7..f269192 100644
--- a/app/code/core/Mage/Core/Model/Resource/Variable.php
+++ b/app/code/core/Mage/Core/Model/Resource/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Variable/Collection.php b/app/code/core/Mage/Core/Model/Resource/Variable/Collection.php
index b1a41f5..b1fe66a 100644
--- a/app/code/core/Mage/Core/Model/Resource/Variable/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Variable/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Website.php b/app/code/core/Mage/Core/Model/Resource/Website.php
index 26aff5d..47c64a2e 100644
--- a/app/code/core/Mage/Core/Model/Resource/Website.php
+++ b/app/code/core/Mage/Core/Model/Resource/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Resource/Website/Collection.php b/app/code/core/Mage/Core/Model/Resource/Website/Collection.php
index cc8cdb5..8ab2f97 100644
--- a/app/code/core/Mage/Core/Model/Resource/Website/Collection.php
+++ b/app/code/core/Mage/Core/Model/Resource/Website/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Session.php b/app/code/core/Mage/Core/Model/Session.php
index 81e2b4b..8828cbc 100644
--- a/app/code/core/Mage/Core/Model/Session.php
+++ b/app/code/core/Mage/Core/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Session/Abstract.php b/app/code/core/Mage/Core/Model/Session/Abstract.php
index bff216a..77faefc 100644
--- a/app/code/core/Mage/Core/Model/Session/Abstract.php
+++ b/app/code/core/Mage/Core/Model/Session/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Session/Abstract/Varien.php b/app/code/core/Mage/Core/Model/Session/Abstract/Varien.php
index 33e5a48..b33cd12 100644
--- a/app/code/core/Mage/Core/Model/Session/Abstract/Varien.php
+++ b/app/code/core/Mage/Core/Model/Session/Abstract/Varien.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Session/Abstract/Zend.php b/app/code/core/Mage/Core/Model/Session/Abstract/Zend.php
index ec2e9c2..cb655c0 100644
--- a/app/code/core/Mage/Core/Model/Session/Abstract/Zend.php
+++ b/app/code/core/Mage/Core/Model/Session/Abstract/Zend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Session/Exception.php b/app/code/core/Mage/Core/Model/Session/Exception.php
index 41b53b4..dcf23f7 100644
--- a/app/code/core/Mage/Core/Model/Session/Exception.php
+++ b/app/code/core/Mage/Core/Model/Session/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Source/Email/Variables.php b/app/code/core/Mage/Core/Model/Source/Email/Variables.php
index b3349c5..b7a9523 100644
--- a/app/code/core/Mage/Core/Model/Source/Email/Variables.php
+++ b/app/code/core/Mage/Core/Model/Source/Email/Variables.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store.php b/app/code/core/Mage/Core/Model/Store.php
index 687bd64..6be1324 100644
--- a/app/code/core/Mage/Core/Model/Store.php
+++ b/app/code/core/Mage/Core/Model/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store/Api.php b/app/code/core/Mage/Core/Model/Store/Api.php
index 0201f43..15f4141 100644
--- a/app/code/core/Mage/Core/Model/Store/Api.php
+++ b/app/code/core/Mage/Core/Model/Store/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store/Api/V2.php b/app/code/core/Mage/Core/Model/Store/Api/V2.php
index 504c2da..8ae5402 100644
--- a/app/code/core/Mage/Core/Model/Store/Api/V2.php
+++ b/app/code/core/Mage/Core/Model/Store/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store/Exception.php b/app/code/core/Mage/Core/Model/Store/Exception.php
index c2a43e2..08359b0 100644
--- a/app/code/core/Mage/Core/Model/Store/Exception.php
+++ b/app/code/core/Mage/Core/Model/Store/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store/Group.php b/app/code/core/Mage/Core/Model/Store/Group.php
index 5f28728..7c25c67 100644
--- a/app/code/core/Mage/Core/Model/Store/Group.php
+++ b/app/code/core/Mage/Core/Model/Store/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Store/Observer.php b/app/code/core/Mage/Core/Model/Store/Observer.php
index 3577a0c..edfe1e9 100644
--- a/app/code/core/Mage/Core/Model/Store/Observer.php
+++ b/app/code/core/Mage/Core/Model/Store/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Template.php b/app/code/core/Mage/Core/Model/Template.php
index d70922e..8757988 100644
--- a/app/code/core/Mage/Core/Model/Template.php
+++ b/app/code/core/Mage/Core/Model/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Translate.php b/app/code/core/Mage/Core/Model/Translate.php
index d69b7af..2e3fd6e 100644
--- a/app/code/core/Mage/Core/Model/Translate.php
+++ b/app/code/core/Mage/Core/Model/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Translate/Expr.php b/app/code/core/Mage/Core/Model/Translate/Expr.php
index 6f8bf35..bbd9f97 100644
--- a/app/code/core/Mage/Core/Model/Translate/Expr.php
+++ b/app/code/core/Mage/Core/Model/Translate/Expr.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Core/Model/Translate/Inline.php b/app/code/core/Mage/Core/Model/Translate/Inline.php
index f18fc25..336c14a 100644
--- a/app/code/core/Mage/Core/Model/Translate/Inline.php
+++ b/app/code/core/Mage/Core/Model/Translate/Inline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Translate/String.php b/app/code/core/Mage/Core/Model/Translate/String.php
index a03b424..a5f2e92 100644
--- a/app/code/core/Mage/Core/Model/Translate/String.php
+++ b/app/code/core/Mage/Core/Model/Translate/String.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Url.php b/app/code/core/Mage/Core/Model/Url.php
index 59b9980..0fae7c1 100644
--- a/app/code/core/Mage/Core/Model/Url.php
+++ b/app/code/core/Mage/Core/Model/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Url/Rewrite.php b/app/code/core/Mage/Core/Model/Url/Rewrite.php
index 5a69ad0..f13407d 100644
--- a/app/code/core/Mage/Core/Model/Url/Rewrite.php
+++ b/app/code/core/Mage/Core/Model/Url/Rewrite.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Url/Rewrite/Interface.php b/app/code/core/Mage/Core/Model/Url/Rewrite/Interface.php
index 4f10d1e..9c4d4c2 100644
--- a/app/code/core/Mage/Core/Model/Url/Rewrite/Interface.php
+++ b/app/code/core/Mage/Core/Model/Url/Rewrite/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Url/Rewrite/Request.php b/app/code/core/Mage/Core/Model/Url/Rewrite/Request.php
index eb5e2d8..ea69dd7 100644
--- a/app/code/core/Mage/Core/Model/Url/Rewrite/Request.php
+++ b/app/code/core/Mage/Core/Model/Url/Rewrite/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Url/Validator.php b/app/code/core/Mage/Core/Model/Url/Validator.php
index 561ebd2..8be726e 100644
--- a/app/code/core/Mage/Core/Model/Url/Validator.php
+++ b/app/code/core/Mage/Core/Model/Url/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Variable.php b/app/code/core/Mage/Core/Model/Variable.php
index f277d54..cca2044 100644
--- a/app/code/core/Mage/Core/Model/Variable.php
+++ b/app/code/core/Mage/Core/Model/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Variable/Config.php b/app/code/core/Mage/Core/Model/Variable/Config.php
index 1b93631..290074f 100644
--- a/app/code/core/Mage/Core/Model/Variable/Config.php
+++ b/app/code/core/Mage/Core/Model/Variable/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Variable/Observer.php b/app/code/core/Mage/Core/Model/Variable/Observer.php
index 400204a..3f7cca3 100644
--- a/app/code/core/Mage/Core/Model/Variable/Observer.php
+++ b/app/code/core/Mage/Core/Model/Variable/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/Model/Website.php b/app/code/core/Mage/Core/Model/Website.php
index 22fa23c..e49a3ae 100644
--- a/app/code/core/Mage/Core/Model/Website.php
+++ b/app/code/core/Mage/Core/Model/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/controllers/AjaxController.php b/app/code/core/Mage/Core/controllers/AjaxController.php
index 40f2c81..6aa576f 100644
--- a/app/code/core/Mage/Core/controllers/AjaxController.php
+++ b/app/code/core/Mage/Core/controllers/AjaxController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/controllers/IndexController.php b/app/code/core/Mage/Core/controllers/IndexController.php
index f1d256a..2986d5e 100644
--- a/app/code/core/Mage/Core/controllers/IndexController.php
+++ b/app/code/core/Mage/Core/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/etc/api.xml b/app/code/core/Mage/Core/etc/api.xml
index 8adf374..e3bdf6f 100644
--- a/app/code/core/Mage/Core/etc/api.xml
+++ b/app/code/core/Mage/Core/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Core/etc/config.xml b/app/code/core/Mage/Core/etc/config.xml
index 2e5da43..d0b5293 100644
--- a/app/code/core/Mage/Core/etc/config.xml
+++ b/app/code/core/Mage/Core/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Core/etc/jstranslator.xml b/app/code/core/Mage/Core/etc/jstranslator.xml
index dd04c22..97ee655 100644
--- a/app/code/core/Mage/Core/etc/jstranslator.xml
+++ b/app/code/core/Mage/Core/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Core/etc/system.xml b/app/code/core/Mage/Core/etc/system.xml
index a622e40..13d799e 100644
--- a/app/code/core/Mage/Core/etc/system.xml
+++ b/app/code/core/Mage/Core/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -823,6 +823,21 @@
                         </weekend>
                     </fields>
                 </locale>
+                <file>
+                    <label>File Settings</label>
+                    <frontend_type>text</frontend_type>
+                    <show_in_default>0</show_in_default>
+                    <show_in_website>0</show_in_website>
+                    <show_in_store>0</show_in_store>
+                    <fields>
+                        <protected_extensions>
+                            <backend_model>adminhtml/system_config_backend_protected</backend_model>
+                            <show_in_default>0</show_in_default>
+                            <show_in_website>0</show_in_website>
+                            <show_in_store>0</show_in_store>
+                        </protected_extensions>
+                    </fields>
+                </file>
                 <store_information translate="label">
                     <label>Store Information</label>
                     <frontend_type>text</frontend_type>
diff --git a/app/code/core/Mage/Core/functions.php b/app/code/core/Mage/Core/functions.php
index 1bdb70d..3def24e 100644
--- a/app/code/core/Mage/Core/functions.php
+++ b/app/code/core/Mage/Core/functions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/install-1.6.0.0.php b/app/code/core/Mage/Core/sql/core_setup/install-1.6.0.0.php
index 16b3361..4741aa8 100644
--- a/app/code/core/Mage/Core/sql/core_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Core/sql/core_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-data-upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-data-upgrade-1.6.0.2-1.6.0.3.php
index a75a69e..4167942 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-data-upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-data-upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.7.0.php
index 668dc40..7f067d0 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.8.0.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.8.0.php
index dcb214c..1b3c5be 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.8.0.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-install-0.8.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.6.26-0.7.0.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.6.26-0.7.0.php
index 3b9c1d7..1c5f88b 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.6.26-0.7.0.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.6.26-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.1-0.7.2.php
index f63cadb..6cfc8a9 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 22a8ed5..470e38a 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 3939fa5..30e75d2 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.4-0.7.5.php
index bf40997..19539b1 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 1cb7554..7e87f1b 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 309680c..69d219e 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 058a669..5c53be2 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.8-0.7.9.php
index c2de0b6..55de465 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.0-0.8.1.php
index f031649..f760f59 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.1-0.8.2.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.1-0.8.2.php
index 7d7eb15..d8a63f9 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.1-0.8.2.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.1-0.8.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.10-0.8.11.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.10-0.8.11.php
index 5493b50..6984a45 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.10-0.8.11.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.10-0.8.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.11-0.8.12.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.11-0.8.12.php
index 92a8f0e..07a96d9 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.11-0.8.12.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.11-0.8.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.12-0.8.13.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.12-0.8.13.php
index 343fbbf..6735d34 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.12-0.8.13.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.12-0.8.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.13-0.8.14.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.13-0.8.14.php
index 81114fc..cf756d5 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.13-0.8.14.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.13-0.8.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.14-0.8.15.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.14-0.8.15.php
index cb24b60..cd18fbb 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.14-0.8.15.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.14-0.8.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.15-0.8.16.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.15-0.8.16.php
index 796ebd9..0e631e2 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.15-0.8.16.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.15-0.8.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.16-0.8.17.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.16-0.8.17.php
index b14a452..57a27bc 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.16-0.8.17.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.16-0.8.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.17-0.8.18.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.17-0.8.18.php
index 28e4321..bb4f64d 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.17-0.8.18.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.17-0.8.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.18-0.8.19.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.18-0.8.19.php
index ddb47c4..dfe4ad9 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.18-0.8.19.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.18-0.8.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.19-0.8.20.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.19-0.8.20.php
index f3321b5..e95ce76 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.19-0.8.20.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.19-0.8.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.2-0.8.3.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.2-0.8.3.php
index ce175b9..a704a91 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.2-0.8.3.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.2-0.8.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.20-0.8.21.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.20-0.8.21.php
index e08ccfd..99dc142 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.20-0.8.21.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.20-0.8.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.21-0.8.22.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.21-0.8.22.php
index 3bc9edc..819700c 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.21-0.8.22.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.21-0.8.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.22-0.8.23.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.22-0.8.23.php
index a818041..82822f7 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.22-0.8.23.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.22-0.8.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.23-0.8.24.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.23-0.8.24.php
index 88823b0..4ecac23 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.23-0.8.24.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.23-0.8.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.24-0.8.25.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.24-0.8.25.php
index 3fa7da0..51d81b9 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.24-0.8.25.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.24-0.8.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.25-0.8.26.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.25-0.8.26.php
index fa35e3f..df30cb5 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.25-0.8.26.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.25-0.8.26.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.26-0.8.27.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.26-0.8.27.php
index f120561..676802f 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.26-0.8.27.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.26-0.8.27.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.27-0.8.28.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.27-0.8.28.php
index 945c0b4..1cea5d0 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.27-0.8.28.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.27-0.8.28.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.3-0.8.4.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.3-0.8.4.php
index a793627..88b12e1 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.3-0.8.4.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.3-0.8.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.4-0.8.5.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.4-0.8.5.php
index e9dae2f..97ed881 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.4-0.8.5.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.4-0.8.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.5-0.8.6.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.5-0.8.6.php
index 0ec72d5..7e12877 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.5-0.8.6.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.5-0.8.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.6-0.8.7.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.6-0.8.7.php
index 7909722..bdcdbc8 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.6-0.8.7.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.6-0.8.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.7-0.8.8.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.7-0.8.8.php
index b45a7f1..cde381a 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.7-0.8.8.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.7-0.8.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.8-0.8.9.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.8-0.8.9.php
index cc83171..aa01568 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.8-0.8.9.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.8-0.8.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.9-0.8.10.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.9-0.8.10.php
index 8cc0210..683074b 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.9-0.8.10.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-0.8.9-0.8.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 041c8df..162dfb1 100644
--- a/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Core/sql/core_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.1-1.6.0.2.php
index d1e40fe..ecbdb20 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.2-1.6.0.3.php
index 8e52e07..288c275 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.3-1.6.0.4.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.3-1.6.0.4.php
index 4c852f8..e95d0ac 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.3-1.6.0.4.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.3-1.6.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.5-1.6.0.6.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.5-1.6.0.6.php
index a678e2e..221a6ac 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.5-1.6.0.6.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.5-1.6.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.6-1.6.0.7.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.6-1.6.0.7.php
index a5af4c8..f1a0946 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.6-1.6.0.7.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.6-1.6.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.7-1.6.0.8.php b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.7-1.6.0.8.php
index f9da012..e5ac8a8 100644
--- a/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.7-1.6.0.8.php
+++ b/app/code/core/Mage/Core/sql/core_setup/upgrade-1.6.0.7-1.6.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Exception.php b/app/code/core/Mage/Cron/Exception.php
index eaa797d..fc1cd42 100644
--- a/app/code/core/Mage/Cron/Exception.php
+++ b/app/code/core/Mage/Cron/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Helper/Data.php b/app/code/core/Mage/Cron/Helper/Data.php
index 73e76c8..1e9b43f 100644
--- a/app/code/core/Mage/Cron/Helper/Data.php
+++ b/app/code/core/Mage/Cron/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Mysql4/Schedule.php b/app/code/core/Mage/Cron/Model/Mysql4/Schedule.php
index e1fddc1..2098151 100644
--- a/app/code/core/Mage/Cron/Model/Mysql4/Schedule.php
+++ b/app/code/core/Mage/Cron/Model/Mysql4/Schedule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Mysql4/Schedule/Collection.php b/app/code/core/Mage/Cron/Model/Mysql4/Schedule/Collection.php
index 86fd9df..18d36eb 100644
--- a/app/code/core/Mage/Cron/Model/Mysql4/Schedule/Collection.php
+++ b/app/code/core/Mage/Cron/Model/Mysql4/Schedule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Observer.php b/app/code/core/Mage/Cron/Model/Observer.php
index 0ef6249..13e61a6 100644
--- a/app/code/core/Mage/Cron/Model/Observer.php
+++ b/app/code/core/Mage/Cron/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Resource/Schedule.php b/app/code/core/Mage/Cron/Model/Resource/Schedule.php
index 924f0a8..3b65355 100644
--- a/app/code/core/Mage/Cron/Model/Resource/Schedule.php
+++ b/app/code/core/Mage/Cron/Model/Resource/Schedule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Resource/Schedule/Collection.php b/app/code/core/Mage/Cron/Model/Resource/Schedule/Collection.php
index 834b536..e37dd7a 100644
--- a/app/code/core/Mage/Cron/Model/Resource/Schedule/Collection.php
+++ b/app/code/core/Mage/Cron/Model/Resource/Schedule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/Model/Schedule.php b/app/code/core/Mage/Cron/Model/Schedule.php
index 2ab8e46..eed958d 100644
--- a/app/code/core/Mage/Cron/Model/Schedule.php
+++ b/app/code/core/Mage/Cron/Model/Schedule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/etc/config.xml b/app/code/core/Mage/Cron/etc/config.xml
index 2957ca6..e07f5c9 100644
--- a/app/code/core/Mage/Cron/etc/config.xml
+++ b/app/code/core/Mage/Cron/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Cron/etc/system.xml b/app/code/core/Mage/Cron/etc/system.xml
index 847c2b3..972faa0 100644
--- a/app/code/core/Mage/Cron/etc/system.xml
+++ b/app/code/core/Mage/Cron/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Cron/sql/cron_setup/install-1.6.0.0.php b/app/code/core/Mage/Cron/sql/cron_setup/install-1.6.0.0.php
index 2bd608b..6535787 100644
--- a/app/code/core/Mage/Cron/sql/cron_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Cron/sql/cron_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-install-0.7.0.php
index c13976b..5baae33 100644
--- a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 50ca6e0..75a8aef 100644
--- a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 60d3136..27b9577 100644
--- a/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Cron/sql/cron_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cron
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/Block/Adminhtml/System/Currencysymbol.php b/app/code/core/Mage/CurrencySymbol/Block/Adminhtml/System/Currencysymbol.php
index 2a4e9b8..89db92c 100644
--- a/app/code/core/Mage/CurrencySymbol/Block/Adminhtml/System/Currencysymbol.php
+++ b/app/code/core/Mage/CurrencySymbol/Block/Adminhtml/System/Currencysymbol.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/Helper/Data.php b/app/code/core/Mage/CurrencySymbol/Helper/Data.php
index c9a3d6b..ac1a905 100644
--- a/app/code/core/Mage/CurrencySymbol/Helper/Data.php
+++ b/app/code/core/Mage/CurrencySymbol/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/Model/Observer.php b/app/code/core/Mage/CurrencySymbol/Model/Observer.php
index fda3787..fd41d33 100644
--- a/app/code/core/Mage/CurrencySymbol/Model/Observer.php
+++ b/app/code/core/Mage/CurrencySymbol/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php b/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
index dd054a7..d92bae1 100644
--- a/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
+++ b/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/controllers/Adminhtml/System/CurrencysymbolController.php b/app/code/core/Mage/CurrencySymbol/controllers/Adminhtml/System/CurrencysymbolController.php
index f2928e7..271195d 100644
--- a/app/code/core/Mage/CurrencySymbol/controllers/Adminhtml/System/CurrencysymbolController.php
+++ b/app/code/core/Mage/CurrencySymbol/controllers/Adminhtml/System/CurrencysymbolController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/CurrencySymbol/etc/adminhtml.xml b/app/code/core/Mage/CurrencySymbol/etc/adminhtml.xml
index c636d80..c0d57e3 100644
--- a/app/code/core/Mage/CurrencySymbol/etc/adminhtml.xml
+++ b/app/code/core/Mage/CurrencySymbol/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/CurrencySymbol/etc/config.xml b/app/code/core/Mage/CurrencySymbol/etc/config.xml
index e18ee88..1c0df55 100644
--- a/app/code/core/Mage/CurrencySymbol/etc/config.xml
+++ b/app/code/core/Mage/CurrencySymbol/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/Block/Account.php b/app/code/core/Mage/Customer/Block/Account.php
index d282186..af7f5fd 100644
--- a/app/code/core/Mage/Customer/Block/Account.php
+++ b/app/code/core/Mage/Customer/Block/Account.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Changeforgotten.php b/app/code/core/Mage/Customer/Block/Account/Changeforgotten.php
index ad00b7c..efbb24e 100644
--- a/app/code/core/Mage/Customer/Block/Account/Changeforgotten.php
+++ b/app/code/core/Mage/Customer/Block/Account/Changeforgotten.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard.php b/app/code/core/Mage/Customer/Block/Account/Dashboard.php
index 205c087..ad17fce 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Address.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Address.php
index dc1391a..7f82548 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Address.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Block.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Block.php
index 84a0c2a..6f2d79d 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Block.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Hello.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Hello.php
index c96d7dc..d7b720e 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Hello.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Hello.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Info.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Info.php
index 288d6e5..7099363 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Info.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Newsletter.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Newsletter.php
index 23f0776..774c3dd 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Newsletter.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Newsletter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Dashboard/Sidebar.php b/app/code/core/Mage/Customer/Block/Account/Dashboard/Sidebar.php
index a754038..ad1c55d 100644
--- a/app/code/core/Mage/Customer/Block/Account/Dashboard/Sidebar.php
+++ b/app/code/core/Mage/Customer/Block/Account/Dashboard/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Forgotpassword.php b/app/code/core/Mage/Customer/Block/Account/Forgotpassword.php
index 43238b5..492a35a 100644
--- a/app/code/core/Mage/Customer/Block/Account/Forgotpassword.php
+++ b/app/code/core/Mage/Customer/Block/Account/Forgotpassword.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Navigation.php b/app/code/core/Mage/Customer/Block/Account/Navigation.php
index 4505462..d977ada 100644
--- a/app/code/core/Mage/Customer/Block/Account/Navigation.php
+++ b/app/code/core/Mage/Customer/Block/Account/Navigation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Account/Resetpassword.php b/app/code/core/Mage/Customer/Block/Account/Resetpassword.php
index d04eddc..f922b5c 100644
--- a/app/code/core/Mage/Customer/Block/Account/Resetpassword.php
+++ b/app/code/core/Mage/Customer/Block/Account/Resetpassword.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Address/Book.php b/app/code/core/Mage/Customer/Block/Address/Book.php
index d9cf492..f3071d0 100644
--- a/app/code/core/Mage/Customer/Block/Address/Book.php
+++ b/app/code/core/Mage/Customer/Block/Address/Book.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Address/Edit.php b/app/code/core/Mage/Customer/Block/Address/Edit.php
index 586534f..328537b 100644
--- a/app/code/core/Mage/Customer/Block/Address/Edit.php
+++ b/app/code/core/Mage/Customer/Block/Address/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Address/Renderer/Default.php b/app/code/core/Mage/Customer/Block/Address/Renderer/Default.php
index 27fbf5a..fd7f731 100644
--- a/app/code/core/Mage/Customer/Block/Address/Renderer/Default.php
+++ b/app/code/core/Mage/Customer/Block/Address/Renderer/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Address/Renderer/Interface.php b/app/code/core/Mage/Customer/Block/Address/Renderer/Interface.php
index 07f8484..85f9c3b 100644
--- a/app/code/core/Mage/Customer/Block/Address/Renderer/Interface.php
+++ b/app/code/core/Mage/Customer/Block/Address/Renderer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Form/Edit.php b/app/code/core/Mage/Customer/Block/Form/Edit.php
index 94b48dd..62521cd 100644
--- a/app/code/core/Mage/Customer/Block/Form/Edit.php
+++ b/app/code/core/Mage/Customer/Block/Form/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Form/Login.php b/app/code/core/Mage/Customer/Block/Form/Login.php
index 6e4a68d..56780e0 100644
--- a/app/code/core/Mage/Customer/Block/Form/Login.php
+++ b/app/code/core/Mage/Customer/Block/Form/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Form/Register.php b/app/code/core/Mage/Customer/Block/Form/Register.php
index cc5b4cb..c1b53d7 100644
--- a/app/code/core/Mage/Customer/Block/Form/Register.php
+++ b/app/code/core/Mage/Customer/Block/Form/Register.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Newsletter.php b/app/code/core/Mage/Customer/Block/Newsletter.php
index 3feacf9..639c53f 100644
--- a/app/code/core/Mage/Customer/Block/Newsletter.php
+++ b/app/code/core/Mage/Customer/Block/Newsletter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Widget/Abstract.php b/app/code/core/Mage/Customer/Block/Widget/Abstract.php
index 2d6bd33..33bf2a9 100644
--- a/app/code/core/Mage/Customer/Block/Widget/Abstract.php
+++ b/app/code/core/Mage/Customer/Block/Widget/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Widget/Dob.php b/app/code/core/Mage/Customer/Block/Widget/Dob.php
index dea7207..f57a19f 100644
--- a/app/code/core/Mage/Customer/Block/Widget/Dob.php
+++ b/app/code/core/Mage/Customer/Block/Widget/Dob.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Widget/Gender.php b/app/code/core/Mage/Customer/Block/Widget/Gender.php
index 144488f..d757a78 100644
--- a/app/code/core/Mage/Customer/Block/Widget/Gender.php
+++ b/app/code/core/Mage/Customer/Block/Widget/Gender.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Widget/Name.php b/app/code/core/Mage/Customer/Block/Widget/Name.php
index 0fe974f..c2df514 100644
--- a/app/code/core/Mage/Customer/Block/Widget/Name.php
+++ b/app/code/core/Mage/Customer/Block/Widget/Name.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Block/Widget/Taxvat.php b/app/code/core/Mage/Customer/Block/Widget/Taxvat.php
index fb861d6..7f55716 100644
--- a/app/code/core/Mage/Customer/Block/Widget/Taxvat.php
+++ b/app/code/core/Mage/Customer/Block/Widget/Taxvat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Exception.php b/app/code/core/Mage/Customer/Exception.php
index d779e2d..a328be4 100644
--- a/app/code/core/Mage/Customer/Exception.php
+++ b/app/code/core/Mage/Customer/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Helper/Address.php b/app/code/core/Mage/Customer/Helper/Address.php
index 3d097c4..8d1ace5 100644
--- a/app/code/core/Mage/Customer/Helper/Address.php
+++ b/app/code/core/Mage/Customer/Helper/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Helper/Data.php b/app/code/core/Mage/Customer/Helper/Data.php
index 7f07a8c..fc3627c 100644
--- a/app/code/core/Mage/Customer/Helper/Data.php
+++ b/app/code/core/Mage/Customer/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Address.php b/app/code/core/Mage/Customer/Model/Address.php
index f589c55..e1f711e 100644
--- a/app/code/core/Mage/Customer/Model/Address.php
+++ b/app/code/core/Mage/Customer/Model/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Address/Abstract.php b/app/code/core/Mage/Customer/Model/Address/Abstract.php
index b430a00..83b284d 100644
--- a/app/code/core/Mage/Customer/Model/Address/Abstract.php
+++ b/app/code/core/Mage/Customer/Model/Address/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Address/Api.php b/app/code/core/Mage/Customer/Model/Address/Api.php
index b6124e3..2d56b2e 100644
--- a/app/code/core/Mage/Customer/Model/Address/Api.php
+++ b/app/code/core/Mage/Customer/Model/Address/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Address/Api/V2.php b/app/code/core/Mage/Customer/Model/Address/Api/V2.php
index 44c9633..ffe393b 100644
--- a/app/code/core/Mage/Customer/Model/Address/Api/V2.php
+++ b/app/code/core/Mage/Customer/Model/Address/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Address/Config.php b/app/code/core/Mage/Customer/Model/Address/Config.php
index 0699019..240dc1c 100644
--- a/app/code/core/Mage/Customer/Model/Address/Config.php
+++ b/app/code/core/Mage/Customer/Model/Address/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api/Resource.php b/app/code/core/Mage/Customer/Model/Api/Resource.php
index 2372d0a..59b8f6f 100644
--- a/app/code/core/Mage/Customer/Model/Api/Resource.php
+++ b/app/code/core/Mage/Customer/Model/Api/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer.php b/app/code/core/Mage/Customer/Model/Api2/Customer.php
index d2c6fdf..11f6920 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Address.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Address.php
index 0c4a088..d16c4be 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Address.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest.php
index a9abb6e..c5f8162 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Admin/V1.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Admin/V1.php
index d95230b..64d2da0 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Customer/V1.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Customer/V1.php
index a5d8db1..adfa114 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Validator.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Validator.php
index c4471b2..aed24ca 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Validator.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Address/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest.php
index 825d238..a22d899 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Admin/V1.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Admin/V1.php
index 857c63d..9980ff0 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Customer/V1.php b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Customer/V1.php
index 7612ce5..5a3169f 100644
--- a/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Customer/Model/Api2/Customer/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute.php b/app/code/core/Mage/Customer/Model/Attribute.php
index 2b2991a..755ee78 100644
--- a/app/code/core/Mage/Customer/Model/Attribute.php
+++ b/app/code/core/Mage/Customer/Model/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Backend/Data/Boolean.php b/app/code/core/Mage/Customer/Model/Attribute/Backend/Data/Boolean.php
index 8778b15..9498b49 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Backend/Data/Boolean.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Backend/Data/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data.php b/app/code/core/Mage/Customer/Model/Attribute/Data.php
index 8cbe15c..fa394fc 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Abstract.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Abstract.php
index 5540925..47eff34 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Abstract.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Boolean.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Boolean.php
index 3e18302..b054e90 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Boolean.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Date.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Date.php
index 044b775..4268ca8 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Date.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/File.php b/app/code/core/Mage/Customer/Model/Attribute/Data/File.php
index d27c842..992538b 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/File.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Hidden.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Hidden.php
index 6826cdd..66c8e6e 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Hidden.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Hidden.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Image.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Image.php
index 144eb59..7288e75 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Image.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Multiline.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Multiline.php
index 0be9b25..e962e2d 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Multiline.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Multiline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Multiselect.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Multiselect.php
index 32a50dd..5a73452 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Multiselect.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Postcode.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Postcode.php
index 8c7fd04..7ad26ff 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Postcode.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Postcode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Select.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Select.php
index 356fb79..55906e3 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Select.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Text.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Text.php
index 3ab57ae..6006bdc 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Text.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Attribute/Data/Textarea.php b/app/code/core/Mage/Customer/Model/Attribute/Data/Textarea.php
index 519fbe1..69a3402 100644
--- a/app/code/core/Mage/Customer/Model/Attribute/Data/Textarea.php
+++ b/app/code/core/Mage/Customer/Model/Attribute/Data/Textarea.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Config/Share.php b/app/code/core/Mage/Customer/Model/Config/Share.php
index 1c0d7d8..06b480e 100644
--- a/app/code/core/Mage/Customer/Model/Config/Share.php
+++ b/app/code/core/Mage/Customer/Model/Config/Share.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Convert/Adapter/Customer.php b/app/code/core/Mage/Customer/Model/Convert/Adapter/Customer.php
index 4275716..d4aee10 100644
--- a/app/code/core/Mage/Customer/Model/Convert/Adapter/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Convert/Adapter/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Convert/Parser/Customer.php b/app/code/core/Mage/Customer/Model/Convert/Parser/Customer.php
index 0c7b44c..dc11f42 100644
--- a/app/code/core/Mage/Customer/Model/Convert/Parser/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Convert/Parser/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer.php b/app/code/core/Mage/Customer/Model/Customer.php
index 92e4d8e..b9da9d0 100644
--- a/app/code/core/Mage/Customer/Model/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Api.php b/app/code/core/Mage/Customer/Model/Customer/Api.php
index dc7a7c6..ccebdbc 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Api.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Api/V2.php b/app/code/core/Mage/Customer/Model/Customer/Api/V2.php
index 54c39fc..8ab71ac 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Api/V2.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Billing.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Billing.php
index b06bd1f..49bea45 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Billing.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Password.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Password.php
index 25e0d8f..3b0d961 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Password.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Password.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Shipping.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Shipping.php
index 97a6ad3..4e29ced 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Shipping.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Store.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Store.php
index c6eced8..2bc2d47 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Store.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Website.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Website.php
index bc93216..84d0e3a 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Website.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Backend/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Group.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Group.php
index 722a69d..72fa5dc 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Group.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Store.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Store.php
index e13b6a8..5f0581a 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Store.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Website.php b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Website.php
index eba5d25..30d4a79 100644
--- a/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Website.php
+++ b/app/code/core/Mage/Customer/Model/Customer/Attribute/Source/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address.php b/app/code/core/Mage/Customer/Model/Entity/Address.php
index 1f63b5d..fb4843e 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Region.php b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Region.php
index 3c8e985..4d55f01 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Region.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Street.php b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Street.php
index 22bc75c..3defd5e 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Street.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Backend/Street.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Collection.php
index 65fc91c..eff940b 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Country.php b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Country.php
index ea6e831..99d78b4 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Country.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Region.php b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Region.php
index bb8a111..9c17fcf 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Region.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Attribute/Source/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Address/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Address/Collection.php
index 4b0632e..e722ec2 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Address/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Attribute.php b/app/code/core/Mage/Customer/Model/Entity/Attribute.php
index c54b156..980f3a7 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Attribute.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Attribute/Collection.php
index b074078..134ab5c 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Customer.php b/app/code/core/Mage/Customer/Model/Entity/Customer.php
index ce3ce64..420b066 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Customer/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Customer/Collection.php
index a52b72c..044b16e 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Customer/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Form/Attribute.php b/app/code/core/Mage/Customer/Model/Entity/Form/Attribute.php
index c4c531e..45281c2 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Form/Attribute.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Form/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Form/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Form/Attribute/Collection.php
index 0e16fec..a2b2bdf 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Form/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Form/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Group.php b/app/code/core/Mage/Customer/Model/Entity/Group.php
index 3a0b1b7..a02ab99 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Group.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Group/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Group/Collection.php
index 8086907..99e0eb2 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Group/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Setup.php b/app/code/core/Mage/Customer/Model/Entity/Setup.php
index 3a8afff..6c67989 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Setup.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Entity/Wishlist/Collection.php b/app/code/core/Mage/Customer/Model/Entity/Wishlist/Collection.php
index 8a2d8b3..f0c813b 100644
--- a/app/code/core/Mage/Customer/Model/Entity/Wishlist/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Entity/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Flowpassword.php b/app/code/core/Mage/Customer/Model/Flowpassword.php
index 5cfea5e..bd7dfaa 100644
--- a/app/code/core/Mage/Customer/Model/Flowpassword.php
+++ b/app/code/core/Mage/Customer/Model/Flowpassword.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Form.php b/app/code/core/Mage/Customer/Model/Form.php
index f3f3936..89871a8 100644
--- a/app/code/core/Mage/Customer/Model/Form.php
+++ b/app/code/core/Mage/Customer/Model/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Group.php b/app/code/core/Mage/Customer/Model/Group.php
index 0f9271f..8110fc6 100644
--- a/app/code/core/Mage/Customer/Model/Group.php
+++ b/app/code/core/Mage/Customer/Model/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Group/Api.php b/app/code/core/Mage/Customer/Model/Group/Api.php
index da86a41..2e90dab 100644
--- a/app/code/core/Mage/Customer/Model/Group/Api.php
+++ b/app/code/core/Mage/Customer/Model/Group/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Group/Api/V2.php b/app/code/core/Mage/Customer/Model/Group/Api/V2.php
index d62d955..6f0dd39 100644
--- a/app/code/core/Mage/Customer/Model/Group/Api/V2.php
+++ b/app/code/core/Mage/Customer/Model/Group/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Observer.php b/app/code/core/Mage/Customer/Model/Observer.php
index fb2899d..ce5c434 100644
--- a/app/code/core/Mage/Customer/Model/Observer.php
+++ b/app/code/core/Mage/Customer/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address.php b/app/code/core/Mage/Customer/Model/Resource/Address.php
index f92a857..f28f597 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Region.php b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Region.php
index 1b22723..48573dc 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Region.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Street.php b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Street.php
index badfecd..5fe1f20 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Street.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Backend/Street.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Collection.php
index 3044109..a2d52c5 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Country.php b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Country.php
index 8632c8b..98c3a1e 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Country.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Region.php b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Region.php
index 15ad619..0ea6676 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Region.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Attribute/Source/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Address/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Address/Collection.php
index b668a46..cd1b5d0 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Address/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Attribute.php b/app/code/core/Mage/Customer/Model/Resource/Attribute.php
index 30063ee..cfe23ab 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Attribute.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Attribute/Collection.php
index f0dc1a4..a936150 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Customer.php b/app/code/core/Mage/Customer/Model/Resource/Customer.php
index f223470..5baa6d5 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Customer.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Customer/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Customer/Collection.php
index 5471cae..b5d3fd0 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Customer/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Flowpassword.php b/app/code/core/Mage/Customer/Model/Resource/Flowpassword.php
index 2120207..1e281d1 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Flowpassword.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Flowpassword.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Flowpassword/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Flowpassword/Collection.php
index 5ac2b5a..61008d3 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Flowpassword/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Flowpassword/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Form/Attribute.php b/app/code/core/Mage/Customer/Model/Resource/Form/Attribute.php
index ab73d7f..c778e3e 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Form/Attribute.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Form/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Form/Attribute/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Form/Attribute/Collection.php
index 495f8ea..494823d 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Form/Attribute/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Form/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Group.php b/app/code/core/Mage/Customer/Model/Resource/Group.php
index a9747d2..4f296bb 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Group.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Group/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Group/Collection.php
index 46cdec5..a681986 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Group/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Setup.php b/app/code/core/Mage/Customer/Model/Resource/Setup.php
index 6f5a5c2..4afa390 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Resource/Wishlist/Collection.php b/app/code/core/Mage/Customer/Model/Resource/Wishlist/Collection.php
index f496d7d..a76d1ce 100644
--- a/app/code/core/Mage/Customer/Model/Resource/Wishlist/Collection.php
+++ b/app/code/core/Mage/Customer/Model/Resource/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/Model/Session.php b/app/code/core/Mage/Customer/Model/Session.php
index 38f395a..35689c9 100644
--- a/app/code/core/Mage/Customer/Model/Session.php
+++ b/app/code/core/Mage/Customer/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/controllers/AccountController.php b/app/code/core/Mage/Customer/controllers/AccountController.php
index fca3fef..fc0639e 100644
--- a/app/code/core/Mage/Customer/controllers/AccountController.php
+++ b/app/code/core/Mage/Customer/controllers/AccountController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/controllers/AddressController.php b/app/code/core/Mage/Customer/controllers/AddressController.php
index a847e34..54ae734 100644
--- a/app/code/core/Mage/Customer/controllers/AddressController.php
+++ b/app/code/core/Mage/Customer/controllers/AddressController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/controllers/ReviewController.php b/app/code/core/Mage/Customer/controllers/ReviewController.php
index 6558815..c713a6c 100644
--- a/app/code/core/Mage/Customer/controllers/ReviewController.php
+++ b/app/code/core/Mage/Customer/controllers/ReviewController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.2-1.6.2.0.3.php b/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.2-1.6.2.0.3.php
index f97bd0c..390c7b6 100644
--- a/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.2-1.6.2.0.3.php
+++ b/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.2-1.6.2.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.4-1.6.2.0.5.php b/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.4-1.6.2.0.5.php
index 9fe6edf..09424e2 100644
--- a/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.4-1.6.2.0.5.php
+++ b/app/code/core/Mage/Customer/data/customer_setup/data-upgrade-1.6.2.0.4-1.6.2.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/etc/adminhtml.xml b/app/code/core/Mage/Customer/etc/adminhtml.xml
index 00de922..6b692c9 100644
--- a/app/code/core/Mage/Customer/etc/adminhtml.xml
+++ b/app/code/core/Mage/Customer/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/etc/api.xml b/app/code/core/Mage/Customer/etc/api.xml
index 8ea3e99..3a37685 100644
--- a/app/code/core/Mage/Customer/etc/api.xml
+++ b/app/code/core/Mage/Customer/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/etc/api2.xml b/app/code/core/Mage/Customer/etc/api2.xml
index cf47603..bfe6769 100644
--- a/app/code/core/Mage/Customer/etc/api2.xml
+++ b/app/code/core/Mage/Customer/etc/api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/etc/config.xml b/app/code/core/Mage/Customer/etc/config.xml
index 0379057..7583623 100644
--- a/app/code/core/Mage/Customer/etc/config.xml
+++ b/app/code/core/Mage/Customer/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/etc/system.xml b/app/code/core/Mage/Customer/etc/system.xml
index a83731b..0d0dcaf 100644
--- a/app/code/core/Mage/Customer/etc/system.xml
+++ b/app/code/core/Mage/Customer/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/install-1.6.0.0.php b/app/code/core/Mage/Customer/sql/customer_setup/install-1.6.0.0.php
index 1e488c0..6fa4477 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php
index b2690be..0de95d7 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php
index 6a7d601..7f8bd4c 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php
index 4ba93f9..568aadb 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php
index 6d790d4..f75e40d 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.7.0.php
index 629955d..93b0a9a 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.8.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.8.0.php
index 2495fb7..ebc1407 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.8.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-0.8.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-1.4.0.0.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-1.4.0.0.0.php
index bc1bd2a..2eedcb1 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-1.4.0.0.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-install-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.6.1-0.7.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.6.1-0.7.0.php
index 8f60e62..504d54c 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.6.1-0.7.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.6.1-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 70534ba..dd00393 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.2-0.7.3.php
index a2bfcc8..9c75d4c 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.0-0.8.1.php
index e458c92..94dad06 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.10-0.8.11.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.10-0.8.11.php
index ccb9a5f..d341c8f 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.10-0.8.11.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.10-0.8.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.11-0.8.12.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.11-0.8.12.php
index b92ef0d..fd8c3da 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.11-0.8.12.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.11-0.8.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.12-1.4.0.0.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.12-1.4.0.0.0.php
index fcb2e9b..cb7e063 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.12-1.4.0.0.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.12-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.4-0.8.5.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.4-0.8.5.php
index 1f422d8..df8d7d4 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.4-0.8.5.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.4-0.8.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.5-0.8.6.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.5-0.8.6.php
index cadc003..eb86d2a 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.5-0.8.6.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.5-0.8.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.6-0.8.7.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.6-0.8.7.php
index 84d5601..7610f78 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.6-0.8.7.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.6-0.8.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.7-0.8.8.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.7-0.8.8.php
index 1b1c24e..8c69b87 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.7-0.8.8.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.7-0.8.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.8-0.8.9.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.8-0.8.9.php
index 21eddcc..2ab767e 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.8-0.8.9.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.8-0.8.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.9-0.8.10.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.9-0.8.10.php
index 76c4779..c48f2c5 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.9-0.8.10.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-0.8.9-0.8.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
index 7c17f2f..defd397 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
index 5e341a7..556fa4c 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
index 4fad743..b35da00 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
index 78537d0..816d5de 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
index 59d1932..9423b5f 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
index aa5e67a..1aa6be9 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
index acf994f..f97bd66 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
index d8c7843..64b6965 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /* @var $installer Mage_Customer_Model_Entity_Setup */
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
index 57af9a1..5dd4b90 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
index c95d3a7..f8872e7 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
index 2d1543a..9d7a9f7 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 9d0814e..42c7c34 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
index 92a41ba..ac38590 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.1.0-1.6.2.0.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.1.0-1.6.2.0.php
index dc6714f..c68fb62 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.1.0-1.6.2.0.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.1.0-1.6.2.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0-1.6.2.0.1.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0-1.6.2.0.1.php
index 7597837..e569145 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0-1.6.2.0.1.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0-1.6.2.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.1-1.6.2.0.2.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.1-1.6.2.0.2.php
index ecc82c9..25c5294 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.1-1.6.2.0.2.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.1-1.6.2.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.3-1.6.2.0.4.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.3-1.6.2.0.4.php
index 911894e..68b014c 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.3-1.6.2.0.4.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.3-1.6.2.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.4-1.6.2.0.5.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.4-1.6.2.0.5.php
index 318ed83..1c8de73 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.4-1.6.2.0.5.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.4-1.6.2.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.5-1.6.2.0.6.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.5-1.6.2.0.6.php
index 5611761..7b70fb1 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.5-1.6.2.0.6.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.5-1.6.2.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.6-1.6.2.0.7.php b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.6-1.6.2.0.7.php
index 867227e..9674a82 100644
--- a/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.6-1.6.2.0.7.php
+++ b/app/code/core/Mage/Customer/sql/customer_setup/upgrade-1.6.2.0.6-1.6.2.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Customer
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Helper/Data.php b/app/code/core/Mage/Dataflow/Helper/Data.php
index 3a65e92..35941cc 100644
--- a/app/code/core/Mage/Dataflow/Helper/Data.php
+++ b/app/code/core/Mage/Dataflow/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Batch.php b/app/code/core/Mage/Dataflow/Model/Batch.php
index b85ae2b..b26dbad 100644
--- a/app/code/core/Mage/Dataflow/Model/Batch.php
+++ b/app/code/core/Mage/Dataflow/Model/Batch.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Batch/Abstract.php b/app/code/core/Mage/Dataflow/Model/Batch/Abstract.php
index edbd082..25c5545 100644
--- a/app/code/core/Mage/Dataflow/Model/Batch/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Batch/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Batch/Export.php b/app/code/core/Mage/Dataflow/Model/Batch/Export.php
index 9abe9b3..7752d7e 100644
--- a/app/code/core/Mage/Dataflow/Model/Batch/Export.php
+++ b/app/code/core/Mage/Dataflow/Model/Batch/Export.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Batch/Import.php b/app/code/core/Mage/Dataflow/Model/Batch/Import.php
index ef26400..7cd4b79 100644
--- a/app/code/core/Mage/Dataflow/Model/Batch/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Batch/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Batch/Io.php b/app/code/core/Mage/Dataflow/Model/Batch/Io.php
index ef7e3c8..e6d69d8 100644
--- a/app/code/core/Mage/Dataflow/Model/Batch/Io.php
+++ b/app/code/core/Mage/Dataflow/Model/Batch/Io.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert.php b/app/code/core/Mage/Dataflow/Model/Convert.php
index 5dc0e90..d1d8b7a 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Action.php b/app/code/core/Mage/Dataflow/Model/Convert/Action.php
index 1da1ee0..92433bb 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Action.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Action/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Action/Abstract.php
index a6db827..ea930e1 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Action/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Action/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Action/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Action/Interface.php
index e6309b3..baae939 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Action/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Action/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Abstract.php
index e49c4ed..fe3537c 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Db/Table.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Db/Table.php
index 7548d9f..d6d1204 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Db/Table.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Db/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http.php
index 3dec07f..8e21e1e 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http/Curl.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http/Curl.php
index 520adc3..62cc8ca 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http/Curl.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Http/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Interface.php
index 198173d..9d4cbfb 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Io.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Io.php
index 7b82881..e39513e 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Io.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Io.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Soap.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Soap.php
index c8f2ebc..d079bbd 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Soap.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Soap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Std.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Std.php
index 5788e32..63bcdf3 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Std.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Std.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Cache.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Cache.php
index 820e58b..4a4bd79 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Cache.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Db.php b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Db.php
index 1efb8c0..0345f05 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Db.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Adapter/Zend/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Container/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Container/Abstract.php
index eef2300..888e68b 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Container/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Container/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Container/Collection.php b/app/code/core/Mage/Dataflow/Model/Convert/Container/Collection.php
index 682d331..a3a0527 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Container/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Container/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Container/Generic.php b/app/code/core/Mage/Dataflow/Model/Convert/Container/Generic.php
index c5f8fc7..6b0d0e5 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Container/Generic.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Container/Generic.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Container/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Container/Interface.php
index 54efc95..abb7aad 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Container/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Container/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Exception.php b/app/code/core/Mage/Dataflow/Model/Convert/Exception.php
index 4bc7fae..a6e47a0 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Exception.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Iterator.php b/app/code/core/Mage/Dataflow/Model/Convert/Iterator.php
index 32c31a0..9435ee0 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Iterator.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Iterator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Dataflow_Model_Session_Adapter_Iterator extends Mage_Dataflow_Model_Convert_Adapter_Abstract
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/File/Csv.php b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/File/Csv.php
index f1c2525..98fe886 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/File/Csv.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/File/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Dataflow_Model_Convert_Iterator_File_Csv extends Mage_Dataflow_Model_Convert_Parser_Abstract
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Http.php b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Http.php
index 572aa0b..d1f317e 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Http.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Interface.php
index 58cbe44..494ac35 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Iterator/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Abstract.php
index b77a44c..9804676 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Column.php b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Column.php
index 9e6861e..519b90c 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Column.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Interface.php
index a2ad0a4..6440b64 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Mapper/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Abstract.php
index 0224447..ed1c371 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Csv.php b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Csv.php
index a3d7d63..01b80fa 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Csv.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Interface.php
index 9061446..cb452af 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Serialize.php b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Serialize.php
index e466575..44827bb 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Serialize.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Serialize.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Xml/Excel.php b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Xml/Excel.php
index 84d5945..18de8bc 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Parser/Xml/Excel.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Parser/Xml/Excel.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Profile.php b/app/code/core/Mage/Dataflow/Model/Convert/Profile.php
index 67db1bc..b55de53 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Profile.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Abstract.php
index d429570..45c4e02 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Collection.php b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Collection.php
index 1fda47b..b68046a 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Interface.php
index cacff1f..948ac2a 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Profile/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Profile/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Abstract.php b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Abstract.php
index 69037b9..37ed39a 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Column.php b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Column.php
index d64abac..82f429a 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Column.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Dryrun.php b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Dryrun.php
index 4af4a29..6f0c8b9 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Dryrun.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Dryrun.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Interface.php b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Interface.php
index b8dbf97..8d794cb 100644
--- a/app/code/core/Mage/Dataflow/Model/Convert/Validator/Interface.php
+++ b/app/code/core/Mage/Dataflow/Model/Convert/Validator/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Import.php b/app/code/core/Mage/Dataflow/Model/Import.php
index 22f7ecf..fb46c12 100644
--- a/app/code/core/Mage/Dataflow/Model/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch.php
index 5a9f0ab..3fbd26d 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Abstract.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Abstract.php
index 4a248bb..dbd8ae0 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Collection.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Collection.php
index 7816cbe..4fe60d0 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Export.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Export.php
index 68cf05b..3d28806 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Export.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Export.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Import.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Import.php
index 70573d6..5be7ee2 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Batch/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Catalogold.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Catalogold.php
index aa57f74..060050b 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Catalogold.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Catalogold.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Import.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Import.php
index f859b04..2d9b979 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Import/Collection.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Import/Collection.php
index 6ace0b5..e851489 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Import/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Import/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile.php
index 6a15bb6..d0d53eb 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/Collection.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/Collection.php
index 80371bd..badb470 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History.php
index fc59fd2..c0a1639 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History/Collection.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History/Collection.php
index 3567555..faf4cdc 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Profile/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Mysql4/Session.php b/app/code/core/Mage/Dataflow/Model/Mysql4/Session.php
index 2894f9b..cce9247 100644
--- a/app/code/core/Mage/Dataflow/Model/Mysql4/Session.php
+++ b/app/code/core/Mage/Dataflow/Model/Mysql4/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Profile.php b/app/code/core/Mage/Dataflow/Model/Profile.php
index 55b65db..ce4c7f5 100644
--- a/app/code/core/Mage/Dataflow/Model/Profile.php
+++ b/app/code/core/Mage/Dataflow/Model/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Profile/History.php b/app/code/core/Mage/Dataflow/Model/Profile/History.php
index 9a4a63f..38752e4 100644
--- a/app/code/core/Mage/Dataflow/Model/Profile/History.php
+++ b/app/code/core/Mage/Dataflow/Model/Profile/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Batch.php b/app/code/core/Mage/Dataflow/Model/Resource/Batch.php
index 779ba5b..1076586 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Batch.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Batch.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Abstract.php b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Abstract.php
index bcfb6f8..0f62057 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Abstract.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Collection.php b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Collection.php
index d323c8c..e794c9a 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Export.php b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Export.php
index 55e61ba..fe8c70d 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Export.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Export.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Import.php b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Import.php
index f598872..7c48d15 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Batch/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Batch/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Import.php b/app/code/core/Mage/Dataflow/Model/Resource/Import.php
index de3d127..58dcbb8 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Import.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Import/Collection.php b/app/code/core/Mage/Dataflow/Model/Resource/Import/Collection.php
index 2828711..6589526 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Import/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Import/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Profile.php b/app/code/core/Mage/Dataflow/Model/Resource/Profile.php
index ed1ad23..3078c6d 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Profile.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Profile/Collection.php b/app/code/core/Mage/Dataflow/Model/Resource/Profile/Collection.php
index 3af86ea..201e232 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Profile/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Profile/History.php b/app/code/core/Mage/Dataflow/Model/Resource/Profile/History.php
index 404d1b3..77f1f3a 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Profile/History.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Profile/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Profile/History/Collection.php b/app/code/core/Mage/Dataflow/Model/Resource/Profile/History/Collection.php
index f08673d..871c840 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Profile/History/Collection.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Profile/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Resource/Session.php b/app/code/core/Mage/Dataflow/Model/Resource/Session.php
index 92a62c9..5555abe 100644
--- a/app/code/core/Mage/Dataflow/Model/Resource/Session.php
+++ b/app/code/core/Mage/Dataflow/Model/Resource/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Session.php b/app/code/core/Mage/Dataflow/Model/Session.php
index 4fd0b1d..4356be0 100644
--- a/app/code/core/Mage/Dataflow/Model/Session.php
+++ b/app/code/core/Mage/Dataflow/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Session/Adapter/Http.php b/app/code/core/Mage/Dataflow/Model/Session/Adapter/Http.php
index abacee6..ceca795 100644
--- a/app/code/core/Mage/Dataflow/Model/Session/Adapter/Http.php
+++ b/app/code/core/Mage/Dataflow/Model/Session/Adapter/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/Model/Session/Parser/Csv.php b/app/code/core/Mage/Dataflow/Model/Session/Parser/Csv.php
index 391c972..0dbb90c 100644
--- a/app/code/core/Mage/Dataflow/Model/Session/Parser/Csv.php
+++ b/app/code/core/Mage/Dataflow/Model/Session/Parser/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/data/dataflow_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Dataflow/data/dataflow_setup/data-install-1.6.0.0.php
index 5fd5888..242c6c8 100644
--- a/app/code/core/Mage/Dataflow/data/dataflow_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Dataflow/data/dataflow_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/etc/config.xml b/app/code/core/Mage/Dataflow/etc/config.xml
index f7faa97..32ea819 100644
--- a/app/code/core/Mage/Dataflow/etc/config.xml
+++ b/app/code/core/Mage/Dataflow/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/install-1.6.0.0.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/install-1.6.0.0.php
index c95f1a3..e86fc2d 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-install-0.7.0.php
index 68887e4..62b4bba 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.0-0.7.1.php
index cf7f5e6..b0f1eb2 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $this->startSetup()->run("
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 7b80df0..a382790 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $this->startSetup()->run("
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 88a4a1e..4783550 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 05b9d7c..5312972 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 9255ba2..de1cd86 100644
--- a/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Dataflow/sql/dataflow_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Dataflow
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Currency/Base.php b/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Currency/Base.php
index efba602..f1e64f4 100644
--- a/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Currency/Base.php
+++ b/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Currency/Base.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Region/Updater.php b/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Region/Updater.php
index f5a63f1..5e50283 100644
--- a/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Region/Updater.php
+++ b/app/code/core/Mage/Directory/Block/Adminhtml/Frontend/Region/Updater.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Block/Currency.php b/app/code/core/Mage/Directory/Block/Currency.php
index d0ff427..d74e4c4 100644
--- a/app/code/core/Mage/Directory/Block/Currency.php
+++ b/app/code/core/Mage/Directory/Block/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Block/Data.php b/app/code/core/Mage/Directory/Block/Data.php
index e15ca1a..ab22c2b 100644
--- a/app/code/core/Mage/Directory/Block/Data.php
+++ b/app/code/core/Mage/Directory/Block/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Exception.php b/app/code/core/Mage/Directory/Exception.php
index 9a7eca9..b9d7def 100644
--- a/app/code/core/Mage/Directory/Exception.php
+++ b/app/code/core/Mage/Directory/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Helper/Data.php b/app/code/core/Mage/Directory/Helper/Data.php
index 072c27f..aa59e6a 100644
--- a/app/code/core/Mage/Directory/Helper/Data.php
+++ b/app/code/core/Mage/Directory/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Helper/Url.php b/app/code/core/Mage/Directory/Helper/Url.php
index 8f6257c..0ca95d3 100644
--- a/app/code/core/Mage/Directory/Helper/Url.php
+++ b/app/code/core/Mage/Directory/Helper/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Country.php b/app/code/core/Mage/Directory/Model/Country.php
index 65b08f2..e0dd4d5 100644
--- a/app/code/core/Mage/Directory/Model/Country.php
+++ b/app/code/core/Mage/Directory/Model/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Country/Api.php b/app/code/core/Mage/Directory/Model/Country/Api.php
index 2810bba..3e1b19d 100644
--- a/app/code/core/Mage/Directory/Model/Country/Api.php
+++ b/app/code/core/Mage/Directory/Model/Country/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Country/Api/V2.php b/app/code/core/Mage/Directory/Model/Country/Api/V2.php
index eaf7490..0bc2d9d 100644
--- a/app/code/core/Mage/Directory/Model/Country/Api/V2.php
+++ b/app/code/core/Mage/Directory/Model/Country/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Country/Format.php b/app/code/core/Mage/Directory/Model/Country/Format.php
index 70146ac..b6408c5 100644
--- a/app/code/core/Mage/Directory/Model/Country/Format.php
+++ b/app/code/core/Mage/Directory/Model/Country/Format.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Currency.php b/app/code/core/Mage/Directory/Model/Currency.php
index 66724e8..79e495f 100644
--- a/app/code/core/Mage/Directory/Model/Currency.php
+++ b/app/code/core/Mage/Directory/Model/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Currency/Filter.php b/app/code/core/Mage/Directory/Model/Currency/Filter.php
index c49f8d6..2fa91d1 100644
--- a/app/code/core/Mage/Directory/Model/Currency/Filter.php
+++ b/app/code/core/Mage/Directory/Model/Currency/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Currency/Import/Abstract.php b/app/code/core/Mage/Directory/Model/Currency/Import/Abstract.php
index 497bd21..9f44731 100644
--- a/app/code/core/Mage/Directory/Model/Currency/Import/Abstract.php
+++ b/app/code/core/Mage/Directory/Model/Currency/Import/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Currency/Import/Webservicex.php b/app/code/core/Mage/Directory/Model/Currency/Import/Webservicex.php
index fe0a7cc..a220c5e 100644
--- a/app/code/core/Mage/Directory/Model/Currency/Import/Webservicex.php
+++ b/app/code/core/Mage/Directory/Model/Currency/Import/Webservicex.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Country.php b/app/code/core/Mage/Directory/Model/Mysql4/Country.php
index ac7d9b6..f068aeb 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Country.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Country/Collection.php b/app/code/core/Mage/Directory/Model/Mysql4/Country/Collection.php
index 9d0d835..8426620 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Country/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Country/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Country/Format.php b/app/code/core/Mage/Directory/Model/Mysql4/Country/Format.php
index 91f5e46..14d69c6 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Country/Format.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Country/Format.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Country/Format/Collection.php b/app/code/core/Mage/Directory/Model/Mysql4/Country/Format/Collection.php
index 1464fa2..1c02407 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Country/Format/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Country/Format/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Currency.php b/app/code/core/Mage/Directory/Model/Mysql4/Currency.php
index 802dbc5..09a400d 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Currency.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Currency/Collection.php b/app/code/core/Mage/Directory/Model/Mysql4/Currency/Collection.php
index 8155966..cda253d 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Currency/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Currency/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Region.php b/app/code/core/Mage/Directory/Model/Mysql4/Region.php
index c5dd69b..947ce60 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Region.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Mysql4/Region/Collection.php b/app/code/core/Mage/Directory/Model/Mysql4/Region/Collection.php
index 76ea34a..0eb17b6 100644
--- a/app/code/core/Mage/Directory/Model/Mysql4/Region/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Mysql4/Region/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Observer.php b/app/code/core/Mage/Directory/Model/Observer.php
index 41a5332..106a14d 100644
--- a/app/code/core/Mage/Directory/Model/Observer.php
+++ b/app/code/core/Mage/Directory/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Region.php b/app/code/core/Mage/Directory/Model/Region.php
index 6f018ad..bd2fbdb 100644
--- a/app/code/core/Mage/Directory/Model/Region.php
+++ b/app/code/core/Mage/Directory/Model/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Region/Api.php b/app/code/core/Mage/Directory/Model/Region/Api.php
index 3e57842..f396acf 100644
--- a/app/code/core/Mage/Directory/Model/Region/Api.php
+++ b/app/code/core/Mage/Directory/Model/Region/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Region/Api/V2.php b/app/code/core/Mage/Directory/Model/Region/Api/V2.php
index 8fa11e3..d6566ab 100644
--- a/app/code/core/Mage/Directory/Model/Region/Api/V2.php
+++ b/app/code/core/Mage/Directory/Model/Region/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Country.php b/app/code/core/Mage/Directory/Model/Resource/Country.php
index 9518cdf..478acea 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Country.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Country/Collection.php b/app/code/core/Mage/Directory/Model/Resource/Country/Collection.php
index a744551..da4e46e 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Country/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Country/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Country/Format.php b/app/code/core/Mage/Directory/Model/Resource/Country/Format.php
index ea47371..1f1709f 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Country/Format.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Country/Format.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Country/Format/Collection.php b/app/code/core/Mage/Directory/Model/Resource/Country/Format/Collection.php
index 48eb82a..fc10009 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Country/Format/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Country/Format/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Currency.php b/app/code/core/Mage/Directory/Model/Resource/Currency.php
index 5fbed23..21c7c99 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Currency.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Currency.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Currency/Collection.php b/app/code/core/Mage/Directory/Model/Resource/Currency/Collection.php
index 2fcf6da..086f4a2 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Currency/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Currency/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Region.php b/app/code/core/Mage/Directory/Model/Resource/Region.php
index 6572a0a..c8a8fda 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Region.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/Model/Resource/Region/Collection.php b/app/code/core/Mage/Directory/Model/Resource/Region/Collection.php
index be3a2d8..abab0f6 100644
--- a/app/code/core/Mage/Directory/Model/Resource/Region/Collection.php
+++ b/app/code/core/Mage/Directory/Model/Resource/Region/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/controllers/CurrencyController.php b/app/code/core/Mage/Directory/controllers/CurrencyController.php
index 244d77b..8a26ed0 100644
--- a/app/code/core/Mage/Directory/controllers/CurrencyController.php
+++ b/app/code/core/Mage/Directory/controllers/CurrencyController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/data/directory_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Directory/data/directory_setup/data-install-1.6.0.0.php
index 55df2fae..0a3c51d 100644
--- a/app/code/core/Mage/Directory/data/directory_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Directory/data/directory_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.0-1.6.0.1.php
index f36e441..aa57508 100644
--- a/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.2-1.6.0.3.php
index 191972b..2284a2d 100644
--- a/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Directory/data/directory_setup/data-upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/etc/api.xml b/app/code/core/Mage/Directory/etc/api.xml
index 5875d48..b1f3fb7 100644
--- a/app/code/core/Mage/Directory/etc/api.xml
+++ b/app/code/core/Mage/Directory/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Directory/etc/config.xml b/app/code/core/Mage/Directory/etc/config.xml
index 074b525..4cfe784 100644
--- a/app/code/core/Mage/Directory/etc/config.xml
+++ b/app/code/core/Mage/Directory/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Directory/etc/system.xml b/app/code/core/Mage/Directory/etc/system.xml
index 5b9dcf29..e4f5efa 100644
--- a/app/code/core/Mage/Directory/etc/system.xml
+++ b/app/code/core/Mage/Directory/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/install-1.6.0.0.php b/app/code/core/Mage/Directory/sql/directory_setup/install-1.6.0.0.php
index 2ead819..ad6c32b 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.7.0.php
index ef70432..45d12bc 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.8.0.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.8.0.php
index cc25079..d8fcc93 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.8.0.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-install-0.8.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 910ec1b..4093036 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.1-0.7.2.php
index dc26018..7376309 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.0-0.8.1.php
index 69707c9..8eb3402 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.1-0.8.2.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.1-0.8.2.php
index e2ab4c9..c5e59fb 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.1-0.8.2.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.1-0.8.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.10-0.8.11.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.10-0.8.11.php
index e83d951..b1a7319 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.10-0.8.11.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.10-0.8.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.2-0.8.3.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.2-0.8.3.php
index 8a4c11c..2d72b00 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.2-0.8.3.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.2-0.8.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.3-0.8.4.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.3-0.8.4.php
index 40ab7fc..75cf813 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.3-0.8.4.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.3-0.8.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.4-0.8.5.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.4-0.8.5.php
index 9a438a1..504bfc1 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.4-0.8.5.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.4-0.8.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.5-0.8.6.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.5-0.8.6.php
index e331770..c130b79 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.5-0.8.6.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.5-0.8.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.6-0.8.7.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.6-0.8.7.php
index b8212df..2d46445 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.6-0.8.7.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.6-0.8.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.7-0.8.8.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.7-0.8.8.php
index de64521..c1a9184 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.7-0.8.8.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.7-0.8.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.8-0.8.9.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.8-0.8.9.php
index 50e3309..0e072e1 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.8-0.8.9.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.8-0.8.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.9-0.8.10.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.9-0.8.10.php
index 1c4a4d0..fa5ed95 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.9-0.8.10.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-0.8.9-0.8.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index f455521..b13bbf1 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
index 118bf65..0b41c66 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Directory/sql/directory_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Directory/sql/directory_setup/upgrade-1.6.0.1-1.6.0.2.php
index 2ac968d..831c6e6 100644
--- a/app/code/core/Mage/Directory/sql/directory_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Directory/sql/directory_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Downloadable.php b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Downloadable.php
index 0fc2889..88851cf 100644
--- a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Composite/Fieldset/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
index a2e489d..3cde81a 100644
--- a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
index 661908f..2fdafa0 100644
--- a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
+++ b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
index 357e177..27e89c6 100644
--- a/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
+++ b/app/code/core/Mage/Downloadable/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Adminhtml/Sales/Items/Column/Downloadable/Name.php b/app/code/core/Mage/Downloadable/Block/Adminhtml/Sales/Items/Column/Downloadable/Name.php
index e9541bb..8075474 100644
--- a/app/code/core/Mage/Downloadable/Block/Adminhtml/Sales/Items/Column/Downloadable/Name.php
+++ b/app/code/core/Mage/Downloadable/Block/Adminhtml/Sales/Items/Column/Downloadable/Name.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Catalog/Product/Links.php b/app/code/core/Mage/Downloadable/Block/Catalog/Product/Links.php
index c6f9125..d4d63fc 100644
--- a/app/code/core/Mage/Downloadable/Block/Catalog/Product/Links.php
+++ b/app/code/core/Mage/Downloadable/Block/Catalog/Product/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Catalog/Product/Samples.php b/app/code/core/Mage/Downloadable/Block/Catalog/Product/Samples.php
index 70c3e1c..d005687 100644
--- a/app/code/core/Mage/Downloadable/Block/Catalog/Product/Samples.php
+++ b/app/code/core/Mage/Downloadable/Block/Catalog/Product/Samples.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Catalog/Product/View/Type.php b/app/code/core/Mage/Downloadable/Block/Catalog/Product/View/Type.php
index a8f4ab9..9099129 100644
--- a/app/code/core/Mage/Downloadable/Block/Catalog/Product/View/Type.php
+++ b/app/code/core/Mage/Downloadable/Block/Catalog/Product/View/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Checkout/Cart/Item/Renderer.php b/app/code/core/Mage/Downloadable/Block/Checkout/Cart/Item/Renderer.php
index 33f5eb2..dd983e8 100644
--- a/app/code/core/Mage/Downloadable/Block/Checkout/Cart/Item/Renderer.php
+++ b/app/code/core/Mage/Downloadable/Block/Checkout/Cart/Item/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Checkout/Success.php b/app/code/core/Mage/Downloadable/Block/Checkout/Success.php
index 2784e01..4ffa421 100644
--- a/app/code/core/Mage/Downloadable/Block/Checkout/Success.php
+++ b/app/code/core/Mage/Downloadable/Block/Checkout/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Customer/Products/List.php b/app/code/core/Mage/Downloadable/Block/Customer/Products/List.php
index e4b76ba..d1b978f 100644
--- a/app/code/core/Mage/Downloadable/Block/Customer/Products/List.php
+++ b/app/code/core/Mage/Downloadable/Block/Customer/Products/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Downloadable.php b/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Downloadable.php
index 269927f..67ee17a 100644
--- a/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Order/Downloadable.php b/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Order/Downloadable.php
index e227b6a..9ed5644 100644
--- a/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Order/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Block/Sales/Order/Email/Items/Order/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Block/Sales/Order/Item/Renderer/Downloadable.php b/app/code/core/Mage/Downloadable/Block/Sales/Order/Item/Renderer/Downloadable.php
index 09639a4..6157000 100644
--- a/app/code/core/Mage/Downloadable/Block/Sales/Order/Item/Renderer/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Block/Sales/Order/Item/Renderer/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Helper/Catalog/Product/Configuration.php b/app/code/core/Mage/Downloadable/Helper/Catalog/Product/Configuration.php
index a1530b8..0dc1e7c 100644
--- a/app/code/core/Mage/Downloadable/Helper/Catalog/Product/Configuration.php
+++ b/app/code/core/Mage/Downloadable/Helper/Catalog/Product/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Helper/Data.php b/app/code/core/Mage/Downloadable/Helper/Data.php
index 3617541..f5b0408 100644
--- a/app/code/core/Mage/Downloadable/Helper/Data.php
+++ b/app/code/core/Mage/Downloadable/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Helper/Download.php b/app/code/core/Mage/Downloadable/Helper/Download.php
index 5ee62a3..9b41c96 100644
--- a/app/code/core/Mage/Downloadable/Helper/Download.php
+++ b/app/code/core/Mage/Downloadable/Helper/Download.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Helper/File.php b/app/code/core/Mage/Downloadable/Helper/File.php
index c2ce22f..7723c5a 100644
--- a/app/code/core/Mage/Downloadable/Helper/File.php
+++ b/app/code/core/Mage/Downloadable/Helper/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/CatalogIndex/Data/Downloadable.php b/app/code/core/Mage/Downloadable/Model/CatalogIndex/Data/Downloadable.php
index a2e4b89..0976e7a 100644
--- a/app/code/core/Mage/Downloadable/Model/CatalogIndex/Data/Downloadable.php
+++ b/app/code/core/Mage/Downloadable/Model/CatalogIndex/Data/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link.php b/app/code/core/Mage/Downloadable/Model/Link.php
index c07a7a3..390cccd 100644
--- a/app/code/core/Mage/Downloadable/Model/Link.php
+++ b/app/code/core/Mage/Downloadable/Model/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Api.php b/app/code/core/Mage/Downloadable/Model/Link/Api.php
index 56bea0a..51056a0 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Api.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Api/Uploader.php b/app/code/core/Mage/Downloadable/Model/Link/Api/Uploader.php
index afb8eb7..ae0634e 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Api/Uploader.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Api/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Api/V2.php b/app/code/core/Mage/Downloadable/Model/Link/Api/V2.php
index 6806caa..0cc7432 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Api/V2.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Api/Validator.php b/app/code/core/Mage/Downloadable/Model/Link/Api/Validator.php
index ab814e5..ef44878 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Api/Validator.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Api/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Purchased.php b/app/code/core/Mage/Downloadable/Model/Link/Purchased.php
index ccea82c..730f277 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Purchased.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Purchased.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Link/Purchased/Item.php b/app/code/core/Mage/Downloadable/Model/Link/Purchased/Item.php
index e6006e3..bfabfe3 100644
--- a/app/code/core/Mage/Downloadable/Model/Link/Purchased/Item.php
+++ b/app/code/core/Mage/Downloadable/Model/Link/Purchased/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Indexer/Price.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Indexer/Price.php
index 8270566..d807073 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Indexer/Price.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link.php
index 8dd5f0f..cc86bea 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Collection.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Collection.php
index 6e211e8..5f44b95 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased.php
index 47eaa4e..6848a69 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Collection.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Collection.php
index bd93328..37d7300 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item.php
index 8aa9fd2..408d7d8 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item/Collection.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item/Collection.php
index 9a09aad..21e7e04 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Link/Purchased/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Sample.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Sample.php
index 0132163..d0f72f4 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Sample.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Sample.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Mysql4/Sample/Collection.php b/app/code/core/Mage/Downloadable/Model/Mysql4/Sample/Collection.php
index 9567c91..4b04ecf 100644
--- a/app/code/core/Mage/Downloadable/Model/Mysql4/Sample/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Mysql4/Sample/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Observer.php b/app/code/core/Mage/Downloadable/Model/Observer.php
index 92c2b61..cb277e5 100644
--- a/app/code/core/Mage/Downloadable/Model/Observer.php
+++ b/app/code/core/Mage/Downloadable/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Product/Price.php b/app/code/core/Mage/Downloadable/Model/Product/Price.php
index f3efe64..ef821f9 100644
--- a/app/code/core/Mage/Downloadable/Model/Product/Price.php
+++ b/app/code/core/Mage/Downloadable/Model/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Product/Type.php b/app/code/core/Mage/Downloadable/Model/Product/Type.php
index 79b0db8..51be256 100644
--- a/app/code/core/Mage/Downloadable/Model/Product/Type.php
+++ b/app/code/core/Mage/Downloadable/Model/Product/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Indexer/Price.php b/app/code/core/Mage/Downloadable/Model/Resource/Indexer/Price.php
index 5be792d..7f387b1 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Indexer/Price.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Indexer/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link.php b/app/code/core/Mage/Downloadable/Model/Resource/Link.php
index 6bc63d9..dc0962f 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link/Collection.php b/app/code/core/Mage/Downloadable/Model/Resource/Link/Collection.php
index d5bd941..8fcc44c 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased.php b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased.php
index e342d41..7c202dd 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Collection.php b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Collection.php
index 35e6123..a0cc04d 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item.php b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item.php
index 1f6859e..f224c54 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item/Collection.php b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item/Collection.php
index 32e28fd..ddb4cf8 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Link/Purchased/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Sample.php b/app/code/core/Mage/Downloadable/Model/Resource/Sample.php
index 0536fdb..269dcf3 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Sample.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Sample.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Resource/Sample/Collection.php b/app/code/core/Mage/Downloadable/Model/Resource/Sample/Collection.php
index 1add028..df82763 100644
--- a/app/code/core/Mage/Downloadable/Model/Resource/Sample/Collection.php
+++ b/app/code/core/Mage/Downloadable/Model/Resource/Sample/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Abstract.php b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Abstract.php
index 7969540..8c1a254 100644
--- a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Abstract.php
+++ b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Creditmemo.php b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Creditmemo.php
index 95b8905..8a7bede 100644
--- a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Creditmemo.php
+++ b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Invoice.php b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Invoice.php
index fb2407e..70e7fe7 100644
--- a/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Invoice.php
+++ b/app/code/core/Mage/Downloadable/Model/Sales/Order/Pdf/Items/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/Sample.php b/app/code/core/Mage/Downloadable/Model/Sample.php
index f4a05a7..684618c 100644
--- a/app/code/core/Mage/Downloadable/Model/Sample.php
+++ b/app/code/core/Mage/Downloadable/Model/Sample.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/System/Config/Source/Contentdisposition.php b/app/code/core/Mage/Downloadable/Model/System/Config/Source/Contentdisposition.php
index 68006d3..a862b0d 100644
--- a/app/code/core/Mage/Downloadable/Model/System/Config/Source/Contentdisposition.php
+++ b/app/code/core/Mage/Downloadable/Model/System/Config/Source/Contentdisposition.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/Model/System/Config/Source/Orderitemstatus.php b/app/code/core/Mage/Downloadable/Model/System/Config/Source/Orderitemstatus.php
index fd35f65..3ec4ded 100644
--- a/app/code/core/Mage/Downloadable/Model/System/Config/Source/Orderitemstatus.php
+++ b/app/code/core/Mage/Downloadable/Model/System/Config/Source/Orderitemstatus.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/FileController.php b/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/FileController.php
index 9003c7d..c317d0e 100644
--- a/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/FileController.php
+++ b/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/FileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/Product/EditController.php b/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/Product/EditController.php
index 596c8ec..88c204b 100644
--- a/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/Product/EditController.php
+++ b/app/code/core/Mage/Downloadable/controllers/Adminhtml/Downloadable/Product/EditController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/CustomerController.php b/app/code/core/Mage/Downloadable/controllers/CustomerController.php
index 9bb60d2..7dcbe6c 100644
--- a/app/code/core/Mage/Downloadable/controllers/CustomerController.php
+++ b/app/code/core/Mage/Downloadable/controllers/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/DownloadController.php b/app/code/core/Mage/Downloadable/controllers/DownloadController.php
index de70788..180e013 100644
--- a/app/code/core/Mage/Downloadable/controllers/DownloadController.php
+++ b/app/code/core/Mage/Downloadable/controllers/DownloadController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/FileController.php b/app/code/core/Mage/Downloadable/controllers/FileController.php
index 2c211f3..a03cc8b 100644
--- a/app/code/core/Mage/Downloadable/controllers/FileController.php
+++ b/app/code/core/Mage/Downloadable/controllers/FileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/controllers/Product/EditController.php b/app/code/core/Mage/Downloadable/controllers/Product/EditController.php
index 4388712..486545e 100644
--- a/app/code/core/Mage/Downloadable/controllers/Product/EditController.php
+++ b/app/code/core/Mage/Downloadable/controllers/Product/EditController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/data/downloadable_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Downloadable/data/downloadable_setup/data-install-1.6.0.0.php
index 130de3d..c0feeb2 100644
--- a/app/code/core/Mage/Downloadable/data/downloadable_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Downloadable/data/downloadable_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /** @var $installer Mage_Downloadable_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Downloadable/etc/adminhtml.xml b/app/code/core/Mage/Downloadable/etc/adminhtml.xml
index b96e6e8..ace51a3 100644
--- a/app/code/core/Mage/Downloadable/etc/adminhtml.xml
+++ b/app/code/core/Mage/Downloadable/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Downloadable/etc/api.xml b/app/code/core/Mage/Downloadable/etc/api.xml
index 15fbbe7..d49adcc 100644
--- a/app/code/core/Mage/Downloadable/etc/api.xml
+++ b/app/code/core/Mage/Downloadable/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Downloadable/etc/config.xml b/app/code/core/Mage/Downloadable/etc/config.xml
index ee06dc9..cec6903 100644
--- a/app/code/core/Mage/Downloadable/etc/config.xml
+++ b/app/code/core/Mage/Downloadable/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Downloadable/etc/system.xml b/app/code/core/Mage/Downloadable/etc/system.xml
index 11e086f..64ba150 100644
--- a/app/code/core/Mage/Downloadable/etc/system.xml
+++ b/app/code/core/Mage/Downloadable/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/install-1.6.0.0.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/install-1.6.0.0.php
index c515a34..3d41c86 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-0.1.0.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-0.1.0.php
index 4dad559..af91f04 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-0.1.0.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-0.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-1.4.0.0.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-1.4.0.0.php
index 89f535f..d7097d1 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-1.4.0.0.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-install-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.0-0.1.1.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.0-0.1.1.php
index 1732b8b..d2e1438 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.0-0.1.1.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.0-0.1.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.1-0.1.2.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.1-0.1.2.php
index b4059f9..631a0d6 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.1-0.1.2.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.1-0.1.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.10-0.1.11.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.10-0.1.11.php
index 9a57b4f..9e3491b 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.10-0.1.11.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.10-0.1.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.11-0.1.12.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.11-0.1.12.php
index 9e326c9..5b9b819 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.11-0.1.12.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.11-0.1.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.12-0.1.13.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.12-0.1.13.php
index 876f522..76b1a50 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.12-0.1.13.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.12-0.1.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.13-0.1.14.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.13-0.1.14.php
index 5e281f9..c6ad62c 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.13-0.1.14.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.13-0.1.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.14-0.1.15.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.14-0.1.15.php
index af57a0e..66a5837 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.14-0.1.15.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.14-0.1.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.15-0.1.16.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.15-0.1.16.php
index 6e9b23e..2dfd741 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.15-0.1.16.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.15-0.1.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.2-0.1.3.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.2-0.1.3.php
index b183ea3..5499642 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.2-0.1.3.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.2-0.1.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.3-0.1.4.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.3-0.1.4.php
index 7665aea..1ec5220 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.3-0.1.4.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.3-0.1.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.4-0.1.5.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.4-0.1.5.php
index 8a85d96..0cb1a88 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.4-0.1.5.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.4-0.1.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.5-0.1.6.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.5-0.1.6.php
index 372c223..fe5c93a 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.5-0.1.6.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.5-0.1.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.6-0.1.7.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.6-0.1.7.php
index fcca318..cfbb176 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.6-0.1.7.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.6-0.1.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.7-0.1.8.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.7-0.1.8.php
index 0779333..035b23a 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.7-0.1.8.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.7-0.1.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.8-0.1.9.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.8-0.1.9.php
index f2c52ce..5dd7d78 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.8-0.1.9.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.8-0.1.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.9-0.1.10.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.9-0.1.10.php
index 6694ed3..59f6794 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.9-0.1.10.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-0.1.9-0.1.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.3.9-1.4.0.0.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.3.9-1.4.0.0.php
index a799a1c..2727c1f 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.3.9-1.4.0.0.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.3.9-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
index 896f8f8..b78bd8d 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
index ae81cf7..cffd5e8 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
index f97fe5a..ca4437a 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index c3d1fea..292bf35 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php
index 5dbb582..adbf55b 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0-1.6.0.0.1.php
index 363af02..f6e412c 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
index 900519e..0e61968 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.1-1.6.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
index 995826e..830c998 100644
--- a/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
+++ b/app/code/core/Mage/Downloadable/sql/downloadable_setup/upgrade-1.6.0.0.2-1.6.0.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /* @var $installer Mage_Core_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Js.php b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Js.php
index 3add45a..9ae66e9 100644
--- a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Js.php
+++ b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Js.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Main/Abstract.php b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Main/Abstract.php
index ea94b29..94f145d 100644
--- a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Main/Abstract.php
+++ b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Main/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Options/Abstract.php b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Options/Abstract.php
index 598b9de..131a71c 100644
--- a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Options/Abstract.php
+++ b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Edit/Options/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Grid/Abstract.php b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Grid/Abstract.php
index b1146be..3af52e6 100644
--- a/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Grid/Abstract.php
+++ b/app/code/core/Mage/Eav/Block/Adminhtml/Attribute/Grid/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Exception.php b/app/code/core/Mage/Eav/Exception.php
index a92340a..2d92f3b 100644
--- a/app/code/core/Mage/Eav/Exception.php
+++ b/app/code/core/Mage/Eav/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Helper/Data.php b/app/code/core/Mage/Eav/Helper/Data.php
index 2ba8c45..b458e55 100644
--- a/app/code/core/Mage/Eav/Helper/Data.php
+++ b/app/code/core/Mage/Eav/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype.php b/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype.php
index af1ee87..84f7a2e 100644
--- a/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype.php
+++ b/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Eav_Model_Adminhtml_System_Config_Source_Inputtype
diff --git a/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype/Validator.php b/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype/Validator.php
index b2f0d07..d91b891 100644
--- a/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype/Validator.php
+++ b/app/code/core/Mage/Eav/Model/Adminhtml/System/Config/Source/Inputtype/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute.php b/app/code/core/Mage/Eav/Model/Attribute.php
index db9c4f8..85e703d 100644
--- a/app/code/core/Mage/Eav/Model/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data.php b/app/code/core/Mage/Eav/Model/Attribute/Data.php
index 9c1fe0b..155dfd6 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Abstract.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Abstract.php
index af0eb87..f70a141 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Boolean.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Boolean.php
index 482bd68..6bea6b6 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Boolean.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Date.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Date.php
index 2a855c6..0703b12 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Date.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Datetime.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Datetime.php
index af7aa03..207f865 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Datetime.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/File.php b/app/code/core/Mage/Eav/Model/Attribute/Data/File.php
index 506de69..ee6b215 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/File.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -184,6 +184,7 @@ class Mage_Eav_Model_Attribute_Data_File extends Mage_Eav_Model_Attribute_Data_A
         }
 
         if (count($errors) == 0) {
+            $attribute->setAttributeValidationAsPassed();
             return true;
         }
 
@@ -204,6 +205,10 @@ class Mage_Eav_Model_Attribute_Data_File extends Mage_Eav_Model_Attribute_Data_A
         }
 
         $attribute = $this->getAttribute();
+        if (!$attribute->isAttributeValidationPassed()) {
+            return $this;
+        }
+
         $original  = $this->getEntity()->getData($attribute->getAttributeCode());
         $toDelete  = false;
         if ($original) {
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Hidden.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Hidden.php
index 31ebf0f..b4f536e 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Hidden.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Hidden.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Image.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Image.php
index c67a1ae..9e1b64d 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Image.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Multiline.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Multiline.php
index 70e0d50..0d53bab 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Multiline.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Multiline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Multiselect.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Multiselect.php
index 5e2b4eb..6421a4f 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Multiselect.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Select.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Select.php
index f6445c6..6c2014f 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Select.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Text.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Text.php
index 49d95df..07d6df6 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Text.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Attribute/Data/Textarea.php b/app/code/core/Mage/Eav/Model/Attribute/Data/Textarea.php
index 85eb19e..9d1a8a6 100644
--- a/app/code/core/Mage/Eav/Model/Attribute/Data/Textarea.php
+++ b/app/code/core/Mage/Eav/Model/Attribute/Data/Textarea.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Config.php b/app/code/core/Mage/Eav/Model/Config.php
index f442800..e2229d5 100644
--- a/app/code/core/Mage/Eav/Model/Config.php
+++ b/app/code/core/Mage/Eav/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Convert/Adapter/Entity.php b/app/code/core/Mage/Eav/Model/Convert/Adapter/Entity.php
index c032fc7..812239b 100644
--- a/app/code/core/Mage/Eav/Model/Convert/Adapter/Entity.php
+++ b/app/code/core/Mage/Eav/Model/Convert/Adapter/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Convert/Adapter/Grid.php b/app/code/core/Mage/Eav/Model/Convert/Adapter/Grid.php
index f0a8aa6..e8f81e3 100644
--- a/app/code/core/Mage/Eav/Model/Convert/Adapter/Grid.php
+++ b/app/code/core/Mage/Eav/Model/Convert/Adapter/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Convert/Parser/Abstract.php b/app/code/core/Mage/Eav/Model/Convert/Parser/Abstract.php
index ce2dbd5..b3b761d 100644
--- a/app/code/core/Mage/Eav/Model/Convert/Parser/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Convert/Parser/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity.php b/app/code/core/Mage/Eav/Model/Entity.php
index 5f27a28..b471582 100644
--- a/app/code/core/Mage/Eav/Model/Entity.php
+++ b/app/code/core/Mage/Eav/Model/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Abstract.php
index d047316..1f3b6a7 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute.php b/app/code/core/Mage/Eav/Model/Entity/Attribute.php
index b291fd1..0a8b62a 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Abstract.php
index 0aac056..3186b62 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -87,6 +87,13 @@ abstract class Mage_Eav_Model_Entity_Attribute_Abstract extends Mage_Core_Model_
     protected $_dataTable                   = null;
 
     /**
+     * Attribute validation flag
+     *
+     * @var boolean
+     */
+    protected $_attributeValidationPassed   = false;
+
+    /**
      * Initialize resource model
      */
     protected function _construct()
@@ -122,6 +129,16 @@ abstract class Mage_Eav_Model_Entity_Attribute_Abstract extends Mage_Core_Model_
     }
 
     /**
+     * Mark current attribute as passed validation
+     *
+     * @return void
+     */
+    public function setAttributeValidationAsPassed()
+    {
+        $this->_attributeValidationPassed = true;
+    }
+
+    /**
      * Retrieve attribute configuration (deprecated)
      *
      * @return Mage_Eav_Model_Entity_Attribute_Abstract
@@ -427,6 +444,16 @@ abstract class Mage_Eav_Model_Entity_Attribute_Abstract extends Mage_Core_Model_
     }
 
     /**
+     * Check if attribute is valid
+     *
+     * @return boolean
+     */
+    public function isAttributeValidationPassed()
+    {
+        return $this->_attributeValidationPassed;
+    }
+
+    /**
      * Check if attribute in specified set
      *
      * @param int|array $setId
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Abstract.php
index 7dc965e..9f163da 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Array.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Array.php
index 33ea266..5c36f56 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Array.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Array.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Datetime.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Datetime.php
index 235be0b..ef5345a 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Datetime.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Default.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Default.php
index ac4d57c..5cb1c5b 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Default.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Increment.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Increment.php
index d6ea599..0b601b2 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Increment.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Increment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Interface.php
index 1dab023..ff3185a 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Serialized.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Serialized.php
index 3f15dea..5998d2f 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Serialized.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Serialized.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Store.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Store.php
index 05f0de5..c26f7f0 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Store.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Created.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Created.php
index 70a0a95..ab8d38d 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Created.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Created.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Updated.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Updated.php
index c4c27b2..f9ae606 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Updated.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Backend/Time/Updated.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Exception.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Exception.php
index b117ce5..9848da9 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Exception.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Abstract.php
index 5a6fcda..dbce2e0 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Datetime.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Datetime.php
index 5d79c9a..338fa55 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Datetime.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Default.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Default.php
index edc62a5..baead0f 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Default.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Interface.php
index 9cbb479..8eca6f7 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Frontend/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Group.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Group.php
index 4df31ac..e5babae 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Group.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Interface.php
index 43e98d3..72188ee 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Option.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Option.php
index 5a74455..c09a380 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Option.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Set.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Set.php
index 9b1523f..ce1aedc 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Set.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Set.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Abstract.php
index 45d8c59..3ebd2be 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Boolean.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Boolean.php
index 4252b2c..3b981e5 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Boolean.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Config.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Config.php
index 50f4454..302fb7d 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Config.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Interface.php
index 4c369c6..ad770e0 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Store.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Store.php
index e9d1b95..9ca42b5 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Store.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Table.php b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Table.php
index 6b1aa15..2820d47 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Table.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Attribute/Source/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Collection.php b/app/code/core/Mage/Eav/Model/Entity/Collection.php
index 63da332..ad2f5d3 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Collection/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Collection/Abstract.php
index 815b3be..fb04e39 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Collection/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Increment/Abstract.php b/app/code/core/Mage/Eav/Model/Entity/Increment/Abstract.php
index fd18e9d..7536473 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Increment/Abstract.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Increment/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Increment/Alphanum.php b/app/code/core/Mage/Eav/Model/Entity/Increment/Alphanum.php
index 52a3061..ad5750c 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Increment/Alphanum.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Increment/Alphanum.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Increment/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Increment/Interface.php
index 82caa41..97753d2 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Increment/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Increment/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Increment/Numeric.php b/app/code/core/Mage/Eav/Model/Entity/Increment/Numeric.php
index 6343ea8..59be82d 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Increment/Numeric.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Increment/Numeric.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Interface.php b/app/code/core/Mage/Eav/Model/Entity/Interface.php
index 6ced8ac..b8ec1c3 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Interface.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Setup.php b/app/code/core/Mage/Eav/Model/Entity/Setup.php
index 660eb7b..b78c920 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Setup.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Store.php b/app/code/core/Mage/Eav/Model/Entity/Store.php
index 1cb39e0..37f2b2f 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Store.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Entity/Type.php b/app/code/core/Mage/Eav/Model/Entity/Type.php
index cdc2a74..e85df43 100644
--- a/app/code/core/Mage/Eav/Model/Entity/Type.php
+++ b/app/code/core/Mage/Eav/Model/Entity/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Form.php b/app/code/core/Mage/Eav/Model/Form.php
index 6ccbe95..c901ef1 100644
--- a/app/code/core/Mage/Eav/Model/Form.php
+++ b/app/code/core/Mage/Eav/Model/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Form/Element.php b/app/code/core/Mage/Eav/Model/Form/Element.php
index b8b3f75..fc67707 100644
--- a/app/code/core/Mage/Eav/Model/Form/Element.php
+++ b/app/code/core/Mage/Eav/Model/Form/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Form/Fieldset.php b/app/code/core/Mage/Eav/Model/Form/Fieldset.php
index ae3be9e..129fa45 100644
--- a/app/code/core/Mage/Eav/Model/Form/Fieldset.php
+++ b/app/code/core/Mage/Eav/Model/Form/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Form/Type.php b/app/code/core/Mage/Eav/Model/Form/Type.php
index fd1ebf3..aefe338 100644
--- a/app/code/core/Mage/Eav/Model/Form/Type.php
+++ b/app/code/core/Mage/Eav/Model/Form/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Config.php b/app/code/core/Mage/Eav/Model/Mysql4/Config.php
index 19cc640..83352d2 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Config.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute.php
index 9b96af9..17999a7 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Collection.php
index 6282811..a9d5dab 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group.php
index 06440d8..6192895 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group/Collection.php
index fa834cb..d9b2a09 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option.php
index a354497..89ee612 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option/Collection.php
index c06a6e2..aff1fdd 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set.php
index 580c998..de07e7e 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set/Collection.php
index 0450193..6371ba3 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Attribute/Set/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Store.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Store.php
index 3157595..c077bb6 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Store.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type.php
index b633b6d..deea060 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type/Collection.php
index 955e878..b4bb5a7 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Entity/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Element.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Element.php
index 383149d..ce685ed 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Element.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Element/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Element/Collection.php
index f892f76..9185ef1 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Element/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Element/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset.php
index 064f555..ca8e1ad 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset/Collection.php
index 8c7d7f1..f37a1ec 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Fieldset/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Type.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Type.php
index 2c53db4..a5111d6 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Type.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Mysql4/Form/Type/Collection.php b/app/code/core/Mage/Eav/Model/Mysql4/Form/Type/Collection.php
index c4db50e..0117017 100644
--- a/app/code/core/Mage/Eav/Model/Mysql4/Form/Type/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Mysql4/Form/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Attribute.php b/app/code/core/Mage/Eav/Model/Resource/Attribute.php
index abb643f..1873164 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Attribute/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Attribute/Collection.php
index c3a970d..2dce2fe 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Attribute/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Config.php b/app/code/core/Mage/Eav/Model/Resource/Config.php
index 6979ec3..e8bfaa4 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Config.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute.php
index 2cfb137..ecfd0c0 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Collection.php
index 6f42159..8a282c9 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group.php
index f0e2fe4..7ef3f8f 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group/Collection.php
index 3a2c274..ac6ea54 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Group/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option.php
index fe39807..8d23832 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option/Collection.php
index 2d6bc4d..8b97edb 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set.php
index 7a0aed7..00c5b48 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set/Collection.php
index 92aa06b..4443d7e 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Attribute/Set/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Store.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Store.php
index ce86c06..bb982df 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Store.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Type.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Type.php
index 94ca08c..27ae4b5 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Type.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Entity/Type/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Entity/Type/Collection.php
index 083b1c7..4941352 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Entity/Type/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Entity/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Attribute.php b/app/code/core/Mage/Eav/Model/Resource/Form/Attribute.php
index 83e7d7f..f0393ce 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Attribute.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Attribute/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Form/Attribute/Collection.php
index 679191c..49a2fd2 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Attribute/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Element.php b/app/code/core/Mage/Eav/Model/Resource/Form/Element.php
index 09461b0..589c1bd 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Element.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Element/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Form/Element/Collection.php
index 131d480..a0624f1 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Element/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Element/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset.php b/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset.php
index ef6b2a7..7a1d9ab 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset/Collection.php
index e248848..aa03cac 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Fieldset/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Type.php b/app/code/core/Mage/Eav/Model/Resource/Form/Type.php
index 3451c4d..a39db09 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Type.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Form/Type/Collection.php b/app/code/core/Mage/Eav/Model/Resource/Form/Type/Collection.php
index 39a0b9c..705d8c7 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Form/Type/Collection.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Form/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Eav/Model/Resource/Helper/Mysql4.php
index a2b295e..f455fa6 100644
--- a/app/code/core/Mage/Eav/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Eav/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/etc/config.xml b/app/code/core/Mage/Eav/etc/config.xml
index 431937a..74ce655 100644
--- a/app/code/core/Mage/Eav/etc/config.xml
+++ b/app/code/core/Mage/Eav/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/install-1.6.0.0.php b/app/code/core/Mage/Eav/sql/eav_setup/install-1.6.0.0.php
index 3d48f45..f5fb423 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-install-0.7.0.php
index 4827797..9d67dfb 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 62f7e94..45485e6 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 79eec3e..d34c4e2 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.10-0.7.11.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.10-0.7.11.php
index e55557d..c94c729 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.10-0.7.11.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.10-0.7.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.11-0.7.12.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.11-0.7.12.php
index bf022cc..cb8d1b1 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.11-0.7.12.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.11-0.7.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.12-0.7.13.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.12-0.7.13.php
index 30fc284..e065ae8 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.12-0.7.13.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.12-0.7.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.13-0.7.14.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.13-0.7.14.php
index a280bb1..cce114e 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.13-0.7.14.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.13-0.7.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.14-0.7.15.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.14-0.7.15.php
index 822d57d..db900d8 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.14-0.7.15.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.14-0.7.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.15-0.7.16.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.15-0.7.16.php
index 6592e08..15cdbbb 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.15-0.7.16.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.15-0.7.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.2-0.7.3.php
index b789689..43657e8 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.3-0.7.4.php
index c7da416..3356e91 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 9cad2c8..ace4a5d 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.5-0.7.6.php
index ad32b0d..2400857 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.6-0.7.7.php
index d7df5dd..2454487 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.7-0.7.8.php
index d905eca..a81c5c7 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.8-0.7.9.php
index da212eb..e163ac2 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 7a2a43e..54b95ef 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 14da457..64cabcc 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Eav/sql/eav_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Eav/sql/eav_setup/upgrade-1.6.0.0-1.6.0.1.php
index dc1a748..c481155 100644
--- a/app/code/core/Mage/Eav/sql/eav_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Eav/sql/eav_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Eav
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Product/Helper/Form/Config.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Product/Helper/Form/Config.php
index 47a2bbc..a24c4ca 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Product/Helper/Form/Config.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Product/Helper/Form/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Form.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Form.php
index 5505157..f1e69b3 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Form.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Giftoptions.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Giftoptions.php
index 26054b7..633a9d8 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Giftoptions.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Giftoptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Items.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Items.php
index f20eb6f..f7d9248 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Items.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Form.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Form.php
index 5cf81cd..24be9ea 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Form.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Giftoptions.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Giftoptions.php
index 8082fbf..f4bd03a 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Giftoptions.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Giftoptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Items.php b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Items.php
index 8b578fe..0cce8da 100644
--- a/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Items.php
+++ b/app/code/core/Mage/GiftMessage/Block/Adminhtml/Sales/Order/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Message/Form.php b/app/code/core/Mage/GiftMessage/Block/Message/Form.php
index 5cb870f..8bf08ce 100644
--- a/app/code/core/Mage/GiftMessage/Block/Message/Form.php
+++ b/app/code/core/Mage/GiftMessage/Block/Message/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Message/Helper.php b/app/code/core/Mage/GiftMessage/Block/Message/Helper.php
index 87e7f47..4fa7035 100644
--- a/app/code/core/Mage/GiftMessage/Block/Message/Helper.php
+++ b/app/code/core/Mage/GiftMessage/Block/Message/Helper.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Block/Message/Inline.php b/app/code/core/Mage/GiftMessage/Block/Message/Inline.php
index 6082e44..a576e3d 100644
--- a/app/code/core/Mage/GiftMessage/Block/Message/Inline.php
+++ b/app/code/core/Mage/GiftMessage/Block/Message/Inline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Helper/Data.php b/app/code/core/Mage/GiftMessage/Helper/Data.php
index d4a7146..e99b914 100644
--- a/app/code/core/Mage/GiftMessage/Helper/Data.php
+++ b/app/code/core/Mage/GiftMessage/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Helper/Message.php b/app/code/core/Mage/GiftMessage/Helper/Message.php
index 2b87a7e..43bb3a6 100644
--- a/app/code/core/Mage/GiftMessage/Helper/Message.php
+++ b/app/code/core/Mage/GiftMessage/Helper/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Helper/Url.php b/app/code/core/Mage/GiftMessage/Helper/Url.php
index ae5349a..7e4c267 100644
--- a/app/code/core/Mage/GiftMessage/Helper/Url.php
+++ b/app/code/core/Mage/GiftMessage/Helper/Url.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Api.php b/app/code/core/Mage/GiftMessage/Model/Api.php
index 636d2a4..f338410 100644
--- a/app/code/core/Mage/GiftMessage/Model/Api.php
+++ b/app/code/core/Mage/GiftMessage/Model/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Api/V2.php b/app/code/core/Mage/GiftMessage/Model/Api/V2.php
index 058880b..1f80c40 100644
--- a/app/code/core/Mage/GiftMessage/Model/Api/V2.php
+++ b/app/code/core/Mage/GiftMessage/Model/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Backend/Boolean/Config.php b/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Backend/Boolean/Config.php
index 845e254..468cfdc 100644
--- a/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Backend/Boolean/Config.php
+++ b/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Backend/Boolean/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Source/Boolean/Config.php b/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Source/Boolean/Config.php
index 77400f5..924ae79 100644
--- a/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Source/Boolean/Config.php
+++ b/app/code/core/Mage/GiftMessage/Model/Entity/Attribute/Source/Boolean/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Message.php b/app/code/core/Mage/GiftMessage/Model/Message.php
index 71919d3..99ee4ac 100644
--- a/app/code/core/Mage/GiftMessage/Model/Message.php
+++ b/app/code/core/Mage/GiftMessage/Model/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Mysql4/Message.php b/app/code/core/Mage/GiftMessage/Model/Mysql4/Message.php
index 22fdc37..4988ab4 100644
--- a/app/code/core/Mage/GiftMessage/Model/Mysql4/Message.php
+++ b/app/code/core/Mage/GiftMessage/Model/Mysql4/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Mysql4/Message/Collection.php b/app/code/core/Mage/GiftMessage/Model/Mysql4/Message/Collection.php
index 8a8e6f7..3da3ec3 100644
--- a/app/code/core/Mage/GiftMessage/Model/Mysql4/Message/Collection.php
+++ b/app/code/core/Mage/GiftMessage/Model/Mysql4/Message/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Mysql4/Setup.php b/app/code/core/Mage/GiftMessage/Model/Mysql4/Setup.php
index e23d137..38a4564 100644
--- a/app/code/core/Mage/GiftMessage/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/GiftMessage/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Observer.php b/app/code/core/Mage/GiftMessage/Model/Observer.php
index 77158bf..64a947d 100644
--- a/app/code/core/Mage/GiftMessage/Model/Observer.php
+++ b/app/code/core/Mage/GiftMessage/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Resource/Message.php b/app/code/core/Mage/GiftMessage/Model/Resource/Message.php
index a971cb8..d2da059 100644
--- a/app/code/core/Mage/GiftMessage/Model/Resource/Message.php
+++ b/app/code/core/Mage/GiftMessage/Model/Resource/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Resource/Message/Collection.php b/app/code/core/Mage/GiftMessage/Model/Resource/Message/Collection.php
index 7e5c860..1df0d3a 100644
--- a/app/code/core/Mage/GiftMessage/Model/Resource/Message/Collection.php
+++ b/app/code/core/Mage/GiftMessage/Model/Resource/Message/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/Model/Resource/Setup.php b/app/code/core/Mage/GiftMessage/Model/Resource/Setup.php
index d3748c2..5a6f67e 100644
--- a/app/code/core/Mage/GiftMessage/Model/Resource/Setup.php
+++ b/app/code/core/Mage/GiftMessage/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/controllers/IndexController.php b/app/code/core/Mage/GiftMessage/controllers/IndexController.php
index d01be23..929d452 100644
--- a/app/code/core/Mage/GiftMessage/controllers/IndexController.php
+++ b/app/code/core/Mage/GiftMessage/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/etc/api.xml b/app/code/core/Mage/GiftMessage/etc/api.xml
index 4d308b7..24dc653 100644
--- a/app/code/core/Mage/GiftMessage/etc/api.xml
+++ b/app/code/core/Mage/GiftMessage/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GiftMessage/etc/config.xml b/app/code/core/Mage/GiftMessage/etc/config.xml
index 8d3f923..ac4bc27 100644
--- a/app/code/core/Mage/GiftMessage/etc/config.xml
+++ b/app/code/core/Mage/GiftMessage/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GiftMessage/etc/system.xml b/app/code/core/Mage/GiftMessage/etc/system.xml
index 4187fe1..9ca3f14 100644
--- a/app/code/core/Mage/GiftMessage/etc/system.xml
+++ b/app/code/core/Mage/GiftMessage/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/install-1.6.0.0.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/install-1.6.0.0.php
index e4a3846..230b8d5 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-install-0.7.0.php
index 1203bd9..78ca348 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.1.3-0.7.0.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.1.3-0.7.0.php
index 673d687..2f111ef 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.1.3-0.7.0.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.1.3-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $this->startSetup()
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 1555d9a..dc27c34 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.1-0.7.2.php
index ab7298b..a3a0c83 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.2-0.7.3.php
index d8cbcbf..e45291d 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.3-0.7.4.php
index c2e9fd5..79d5e6c 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.4-0.7.5.php
index f07bafb..419cbd4 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.5-0.7.6.php
index c6dc5ec..5379cd8 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index de3b019..843a48a 100644
--- a/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/GiftMessage/sql/giftmessage_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GiftMessage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleAnalytics/Block/Ga.php b/app/code/core/Mage/GoogleAnalytics/Block/Ga.php
index 1dff35a..0e445cc 100644
--- a/app/code/core/Mage/GoogleAnalytics/Block/Ga.php
+++ b/app/code/core/Mage/GoogleAnalytics/Block/Ga.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleAnalytics/Helper/Data.php b/app/code/core/Mage/GoogleAnalytics/Helper/Data.php
index 1a0ea95..acd275d 100644
--- a/app/code/core/Mage/GoogleAnalytics/Helper/Data.php
+++ b/app/code/core/Mage/GoogleAnalytics/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleAnalytics/Model/Observer.php b/app/code/core/Mage/GoogleAnalytics/Model/Observer.php
index 9c29d93..2321075 100644
--- a/app/code/core/Mage/GoogleAnalytics/Model/Observer.php
+++ b/app/code/core/Mage/GoogleAnalytics/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleAnalytics/Model/System/Config/Source/Type.php b/app/code/core/Mage/GoogleAnalytics/Model/System/Config/Source/Type.php
index ba73533..dbf5a18 100644
--- a/app/code/core/Mage/GoogleAnalytics/Model/System/Config/Source/Type.php
+++ b/app/code/core/Mage/GoogleAnalytics/Model/System/Config/Source/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleAnalytics/etc/adminhtml.xml b/app/code/core/Mage/GoogleAnalytics/etc/adminhtml.xml
index dcda935..cc98d0a 100644
--- a/app/code/core/Mage/GoogleAnalytics/etc/adminhtml.xml
+++ b/app/code/core/Mage/GoogleAnalytics/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleAnalytics/etc/config.xml b/app/code/core/Mage/GoogleAnalytics/etc/config.xml
index 4bf51c4..5bbd9e7 100644
--- a/app/code/core/Mage/GoogleAnalytics/etc/config.xml
+++ b/app/code/core/Mage/GoogleAnalytics/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleAnalytics/etc/system.xml b/app/code/core/Mage/GoogleAnalytics/etc/system.xml
index f347f45..ed5a69e 100644
--- a/app/code/core/Mage/GoogleAnalytics/etc/system.xml
+++ b/app/code/core/Mage/GoogleAnalytics/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleAnalytics/sql/googleanalytics_setup/install-1.6.0.0.php b/app/code/core/Mage/GoogleAnalytics/sql/googleanalytics_setup/install-1.6.0.0.php
index daaf438..f6a02d4 100644
--- a/app/code/core/Mage/GoogleAnalytics/sql/googleanalytics_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/GoogleAnalytics/sql/googleanalytics_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleAnalytics
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Captcha.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Captcha.php
index 6e68b59..43100de 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Captcha.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Captcha.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items.php
index b96ba64..03978d6 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Item.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Item.php
index 0bc8433..b9d21c9 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Item.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Product.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Product.php
index b2e9d5c..7382d96 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Product.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Renderer/Id.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Renderer/Id.php
index 0bd4b09..5692c47 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Renderer/Id.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Items/Renderer/Id.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Store/Switcher.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Store/Switcher.php
index dc01fe0..ecbe31c 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Store/Switcher.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Store/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types.php
index 1d06b6c..afe624a 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit.php
index 5d670a7..4f658a7 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Attributes.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Attributes.php
index f31a1c6..1e1cc9b 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Attributes.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Form.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Form.php
index 3ec0c5d..c96248d 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Form.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Grid.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Grid.php
index aa8f6de..799e5aa 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Grid.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Renderer/Country.php b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Renderer/Country.php
index cf4cf3d..8bb3aad 100644
--- a/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Renderer/Country.php
+++ b/app/code/core/Mage/GoogleBase/Block/Adminhtml/Types/Renderer/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Helper/Data.php b/app/code/core/Mage/GoogleBase/Helper/Data.php
index 806da56..b4a9ad1 100644
--- a/app/code/core/Mage/GoogleBase/Helper/Data.php
+++ b/app/code/core/Mage/GoogleBase/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Attribute.php b/app/code/core/Mage/GoogleBase/Model/Attribute.php
index b2a3842..ef827c3 100644
--- a/app/code/core/Mage/GoogleBase/Model/Attribute.php
+++ b/app/code/core/Mage/GoogleBase/Model/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Config.php b/app/code/core/Mage/GoogleBase/Model/Config.php
index 08c15e1..30988df 100644
--- a/app/code/core/Mage/GoogleBase/Model/Config.php
+++ b/app/code/core/Mage/GoogleBase/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Item.php b/app/code/core/Mage/GoogleBase/Model/Item.php
index 81ef065..b43dfaf 100644
--- a/app/code/core/Mage/GoogleBase/Model/Item.php
+++ b/app/code/core/Mage/GoogleBase/Model/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute.php
index 52075a0..561362a 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute/Collection.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute/Collection.php
index 86561f4..d2d58c6 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Item.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Item.php
index 1d8fa20..85d8990 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Item.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Item/Collection.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Item/Collection.php
index f04a238..8900f34 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Item/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Type.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Type.php
index 53e04c6..de58034 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Type.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Mysql4/Type/Collection.php b/app/code/core/Mage/GoogleBase/Model/Mysql4/Type/Collection.php
index 21a73e3..f172470 100644
--- a/app/code/core/Mage/GoogleBase/Model/Mysql4/Type/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Mysql4/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Observer.php b/app/code/core/Mage/GoogleBase/Model/Observer.php
index 8a16cb3..66a82fb 100644
--- a/app/code/core/Mage/GoogleBase/Model/Observer.php
+++ b/app/code/core/Mage/GoogleBase/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Attribute.php b/app/code/core/Mage/GoogleBase/Model/Resource/Attribute.php
index c2b8d8c..0e3f9a7 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Attribute.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Attribute/Collection.php b/app/code/core/Mage/GoogleBase/Model/Resource/Attribute/Collection.php
index d5e53af..0f5dedf 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Attribute/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Attribute/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Item.php b/app/code/core/Mage/GoogleBase/Model/Resource/Item.php
index 3b65d32..f7238e3 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Item.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Item/Collection.php b/app/code/core/Mage/GoogleBase/Model/Resource/Item/Collection.php
index ed5d90b..6fcf6f8 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Item/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Type.php b/app/code/core/Mage/GoogleBase/Model/Resource/Type.php
index aecb9a7..b422a1a 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Type.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Resource/Type/Collection.php b/app/code/core/Mage/GoogleBase/Model/Resource/Type/Collection.php
index 45c6240..8c04217 100644
--- a/app/code/core/Mage/GoogleBase/Model/Resource/Type/Collection.php
+++ b/app/code/core/Mage/GoogleBase/Model/Resource/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Service.php b/app/code/core/Mage/GoogleBase/Model/Service.php
index 3e48b5f..df93296 100644
--- a/app/code/core/Mage/GoogleBase/Model/Service.php
+++ b/app/code/core/Mage/GoogleBase/Model/Service.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Service/Feed.php b/app/code/core/Mage/GoogleBase/Model/Service/Feed.php
index f178e7e..2c3ae6e 100644
--- a/app/code/core/Mage/GoogleBase/Model/Service/Feed.php
+++ b/app/code/core/Mage/GoogleBase/Model/Service/Feed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Service/Item.php b/app/code/core/Mage/GoogleBase/Model/Service/Item.php
index 96f41ac..0ab58e6 100644
--- a/app/code/core/Mage/GoogleBase/Model/Service/Item.php
+++ b/app/code/core/Mage/GoogleBase/Model/Service/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Source/Accounttype.php b/app/code/core/Mage/GoogleBase/Model/Source/Accounttype.php
index ad68ab3..64aa100 100644
--- a/app/code/core/Mage/GoogleBase/Model/Source/Accounttype.php
+++ b/app/code/core/Mage/GoogleBase/Model/Source/Accounttype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Source/Authtype.php b/app/code/core/Mage/GoogleBase/Model/Source/Authtype.php
index 445ea06..c56bb0d 100644
--- a/app/code/core/Mage/GoogleBase/Model/Source/Authtype.php
+++ b/app/code/core/Mage/GoogleBase/Model/Source/Authtype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Source/Country.php b/app/code/core/Mage/GoogleBase/Model/Source/Country.php
index 14ba71e..a3f451d 100644
--- a/app/code/core/Mage/GoogleBase/Model/Source/Country.php
+++ b/app/code/core/Mage/GoogleBase/Model/Source/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Source/Statuses.php b/app/code/core/Mage/GoogleBase/Model/Source/Statuses.php
index 0f39b3b..361b607 100644
--- a/app/code/core/Mage/GoogleBase/Model/Source/Statuses.php
+++ b/app/code/core/Mage/GoogleBase/Model/Source/Statuses.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/Model/Type.php b/app/code/core/Mage/GoogleBase/Model/Type.php
index 203f794..0e4f2f4 100644
--- a/app/code/core/Mage/GoogleBase/Model/Type.php
+++ b/app/code/core/Mage/GoogleBase/Model/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/ItemsController.php b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/ItemsController.php
index 80a634a..c729346 100644
--- a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/ItemsController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/ItemsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/SelectionController.php b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/SelectionController.php
index 10614b5..4cb7b53 100644
--- a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/SelectionController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/SelectionController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/TypesController.php b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/TypesController.php
index 36ff3b8..ffd43f1 100644
--- a/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/TypesController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/Adminhtml/Googlebase/TypesController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/ItemsController.php b/app/code/core/Mage/GoogleBase/controllers/ItemsController.php
index 42ed927..2f59816 100644
--- a/app/code/core/Mage/GoogleBase/controllers/ItemsController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/ItemsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/SelectionController.php b/app/code/core/Mage/GoogleBase/controllers/SelectionController.php
index 3af0267..e3f0a88 100644
--- a/app/code/core/Mage/GoogleBase/controllers/SelectionController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/SelectionController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/controllers/TypesController.php b/app/code/core/Mage/GoogleBase/controllers/TypesController.php
index ac275d7..a21bfb8 100644
--- a/app/code/core/Mage/GoogleBase/controllers/TypesController.php
+++ b/app/code/core/Mage/GoogleBase/controllers/TypesController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/etc/adminhtml.xml b/app/code/core/Mage/GoogleBase/etc/adminhtml.xml
index c2e1b8b..a48582d 100644
--- a/app/code/core/Mage/GoogleBase/etc/adminhtml.xml
+++ b/app/code/core/Mage/GoogleBase/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleBase/etc/config.xml b/app/code/core/Mage/GoogleBase/etc/config.xml
index 9868681..773d336 100644
--- a/app/code/core/Mage/GoogleBase/etc/config.xml
+++ b/app/code/core/Mage/GoogleBase/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleBase/etc/system.xml b/app/code/core/Mage/GoogleBase/etc/system.xml
index 5c78d60..0de2af8 100644
--- a/app/code/core/Mage/GoogleBase/etc/system.xml
+++ b/app/code/core/Mage/GoogleBase/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/install-1.6.0.0.php b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/install-1.6.0.0.php
index f0c5c79..608f254 100644
--- a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-install-0.1.0.php b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-install-0.1.0.php
index 8a37480..14905db 100644
--- a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-install-0.1.0.php
+++ b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-install-0.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.0-0.1.1.php b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.0-0.1.1.php
index 95a2ad6..8606c73 100644
--- a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.0-0.1.1.php
+++ b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.0-0.1.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.1-0.1.2.php b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.1-0.1.2.php
index 97f2f75..3202335 100644
--- a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.1-0.1.2.php
+++ b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-0.1.1-0.1.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 1a21181..97ee291 100644
--- a/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/GoogleBase/sql/googlebase_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleBase
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleCheckout/Model/Payment.php b/app/code/core/Mage/GoogleCheckout/Model/Payment.php
index 78147da..f9e68aa 100644
--- a/app/code/core/Mage/GoogleCheckout/Model/Payment.php
+++ b/app/code/core/Mage/GoogleCheckout/Model/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleCheckout
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/GoogleCheckout/etc/config.xml b/app/code/core/Mage/GoogleCheckout/etc/config.xml
index 69bbd52..6deda1d 100644
--- a/app/code/core/Mage/GoogleCheckout/etc/config.xml
+++ b/app/code/core/Mage/GoogleCheckout/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_GoogleCheckout
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit.php
index c63b2d6..d4695e8 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit/Form.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit/Form.php
index ec9ff12..4802228 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit/Form.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Filter.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Filter.php
index 74465aa..628b9d0 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Filter.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Export/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit.php
index cf865f0..2c3fa61 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit/Form.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit/Form.php
index ac6149b..4794348 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit/Form.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Frame/Result.php b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Frame/Result.php
index baf24c9..85cb04d 100644
--- a/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Frame/Result.php
+++ b/app/code/core/Mage/ImportExport/Block/Adminhtml/Import/Frame/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Helper/Data.php b/app/code/core/Mage/ImportExport/Helper/Data.php
index 6dea706..2f51e3b 100644
--- a/app/code/core/Mage/ImportExport/Helper/Data.php
+++ b/app/code/core/Mage/ImportExport/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Abstract.php b/app/code/core/Mage/ImportExport/Model/Abstract.php
index 98ccb62..43933fc 100644
--- a/app/code/core/Mage/ImportExport/Model/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Config.php b/app/code/core/Mage/ImportExport/Model/Config.php
index e4469dc..f7b4de7 100644
--- a/app/code/core/Mage/ImportExport/Model/Config.php
+++ b/app/code/core/Mage/ImportExport/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export.php b/app/code/core/Mage/ImportExport/Model/Export.php
index 5a30d44..854b452 100644
--- a/app/code/core/Mage/ImportExport/Model/Export.php
+++ b/app/code/core/Mage/ImportExport/Model/Export.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Adapter/Abstract.php b/app/code/core/Mage/ImportExport/Model/Export/Adapter/Abstract.php
index 278ac89..1b32cd3 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Adapter/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Adapter/Csv.php b/app/code/core/Mage/ImportExport/Model/Export/Adapter/Csv.php
index 72ccd5d..1280d43 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Adapter/Csv.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Adapter/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Abstract.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Abstract.php
index ba55a6e..3027b34 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Customer.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Customer.php
index 36f7d77..d88b5c1 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Customer.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product.php
index ac40f15..469a90e 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Abstract.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Abstract.php
index db18eff..677086c 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Configurable.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Configurable.php
index 1fe0d70..3bd93b0 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Configurable.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Grouped.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Grouped.php
index 6098e24..a400cc4 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Grouped.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Simple.php b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Simple.php
index 11767e7..dc9016f 100644
--- a/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Simple.php
+++ b/app/code/core/Mage/ImportExport/Model/Export/Entity/Product/Type/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import.php b/app/code/core/Mage/ImportExport/Model/Import.php
index d9e1c91..65d2db0 100644
--- a/app/code/core/Mage/ImportExport/Model/Import.php
+++ b/app/code/core/Mage/ImportExport/Model/Import.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Adapter.php b/app/code/core/Mage/ImportExport/Model/Import/Adapter.php
index 3a9d074..433dbe9 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Adapter.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Adapter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Adapter/Abstract.php b/app/code/core/Mage/ImportExport/Model/Import/Adapter/Abstract.php
index 8bfc294..38c969f 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Adapter/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Adapter/Csv.php b/app/code/core/Mage/ImportExport/Model/Import/Adapter/Csv.php
index df7e314..d6a535d 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Adapter/Csv.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Adapter/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Abstract.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Abstract.php
index a01e381..7d4eaad 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer.php
index 2ebff1b..0225e74 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer/Address.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer/Address.php
index 3c17249..dd6d3b6 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer/Address.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Customer/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product.php
index a09b76c..897ae70 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Abstract.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Abstract.php
index 46f10b7..d54ccf1b 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Abstract.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Configurable.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Configurable.php
index b534ad7..ac8ec9c 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Configurable.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Grouped.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Grouped.php
index 77a9871..af54876 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Grouped.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Simple.php b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Simple.php
index 64eabfc..82c46dc 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Simple.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Entity/Product/Type/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product.php b/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product.php
index c85e8d8..bfb0637 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product/Resource.php b/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product/Resource.php
index 7558c0c..bd0d2a3 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product/Resource.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Proxy/Product/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Import/Uploader.php b/app/code/core/Mage/ImportExport/Model/Import/Uploader.php
index 064d319..d161171 100644
--- a/app/code/core/Mage/ImportExport/Model/Import/Uploader.php
+++ b/app/code/core/Mage/ImportExport/Model/Import/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Mysql4/Import/Data.php b/app/code/core/Mage/ImportExport/Model/Mysql4/Import/Data.php
index 40a600c..00c56d8 100644
--- a/app/code/core/Mage/ImportExport/Model/Mysql4/Import/Data.php
+++ b/app/code/core/Mage/ImportExport/Model/Mysql4/Import/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Mysql4/Setup.php b/app/code/core/Mage/ImportExport/Model/Mysql4/Setup.php
index d841d6b..272bafd 100644
--- a/app/code/core/Mage/ImportExport/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/ImportExport/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Product/Attribute/Backend/Urlkey.php b/app/code/core/Mage/ImportExport/Model/Product/Attribute/Backend/Urlkey.php
index 8104421..4e1bc5d 100644
--- a/app/code/core/Mage/ImportExport/Model/Product/Attribute/Backend/Urlkey.php
+++ b/app/code/core/Mage/ImportExport/Model/Product/Attribute/Backend/Urlkey.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/ImportExport/Model/Resource/Helper/Mysql4.php
index 19b8874..312f56f 100644
--- a/app/code/core/Mage/ImportExport/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/ImportExport/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Resource/Import/Data.php b/app/code/core/Mage/ImportExport/Model/Resource/Import/Data.php
index a4fc7a7..4c13d73 100644
--- a/app/code/core/Mage/ImportExport/Model/Resource/Import/Data.php
+++ b/app/code/core/Mage/ImportExport/Model/Resource/Import/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Resource/Setup.php b/app/code/core/Mage/ImportExport/Model/Resource/Setup.php
index 98324c2..54a9084 100644
--- a/app/code/core/Mage/ImportExport/Model/Resource/Setup.php
+++ b/app/code/core/Mage/ImportExport/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Source/Export/Entity.php b/app/code/core/Mage/ImportExport/Model/Source/Export/Entity.php
index aaa62b2..a7f074e 100644
--- a/app/code/core/Mage/ImportExport/Model/Source/Export/Entity.php
+++ b/app/code/core/Mage/ImportExport/Model/Source/Export/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Source/Export/Format.php b/app/code/core/Mage/ImportExport/Model/Source/Export/Format.php
index 1b9cb71..cdcaf0c 100644
--- a/app/code/core/Mage/ImportExport/Model/Source/Export/Format.php
+++ b/app/code/core/Mage/ImportExport/Model/Source/Export/Format.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Source/Import/Behavior.php b/app/code/core/Mage/ImportExport/Model/Source/Import/Behavior.php
index fab707a..a722e36 100644
--- a/app/code/core/Mage/ImportExport/Model/Source/Import/Behavior.php
+++ b/app/code/core/Mage/ImportExport/Model/Source/Import/Behavior.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/Model/Source/Import/Entity.php b/app/code/core/Mage/ImportExport/Model/Source/Import/Entity.php
index 2f80f91..cef4939 100644
--- a/app/code/core/Mage/ImportExport/Model/Source/Import/Entity.php
+++ b/app/code/core/Mage/ImportExport/Model/Source/Import/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/controllers/Adminhtml/ExportController.php b/app/code/core/Mage/ImportExport/controllers/Adminhtml/ExportController.php
index 5298ec9..78f43d9 100644
--- a/app/code/core/Mage/ImportExport/controllers/Adminhtml/ExportController.php
+++ b/app/code/core/Mage/ImportExport/controllers/Adminhtml/ExportController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/controllers/Adminhtml/ImportController.php b/app/code/core/Mage/ImportExport/controllers/Adminhtml/ImportController.php
index 0811a37..eb7409a 100644
--- a/app/code/core/Mage/ImportExport/controllers/Adminhtml/ImportController.php
+++ b/app/code/core/Mage/ImportExport/controllers/Adminhtml/ImportController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/etc/adminhtml.xml b/app/code/core/Mage/ImportExport/etc/adminhtml.xml
index ff8d233..6801619 100644
--- a/app/code/core/Mage/ImportExport/etc/adminhtml.xml
+++ b/app/code/core/Mage/ImportExport/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ImportExport/etc/config.xml b/app/code/core/Mage/ImportExport/etc/config.xml
index d10be92..882ea43 100644
--- a/app/code/core/Mage/ImportExport/etc/config.xml
+++ b/app/code/core/Mage/ImportExport/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ImportExport/etc/system.xml b/app/code/core/Mage/ImportExport/etc/system.xml
index c032ea4..9a9294a 100644
--- a/app/code/core/Mage/ImportExport/etc/system.xml
+++ b/app/code/core/Mage/ImportExport/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ImportExport/sql/importexport_setup/install-1.6.0.0.php b/app/code/core/Mage/ImportExport/sql/importexport_setup/install-1.6.0.0.php
index 2066653..9bb7656 100644
--- a/app/code/core/Mage/ImportExport/sql/importexport_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/ImportExport/sql/importexport_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-install-0.1.0.php b/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-install-0.1.0.php
index 51f3c9e..e459a4f 100644
--- a/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-install-0.1.0.php
+++ b/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-install-0.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
index 2f015e4..644f5bc 100644
--- a/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/ImportExport/sql/importexport_setup/mysql4-upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Notifications.php b/app/code/core/Mage/Index/Block/Adminhtml/Notifications.php
index d77aa72..d03ac90 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Notifications.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Notifications.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process.php b/app/code/core/Mage/Index/Block/Adminhtml/Process.php
index 36a3633..895e412 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit.php
index b6c66d7..6a3e788 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Form.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Form.php
index b1076e6..2975efe 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Form.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tab/Main.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tab/Main.php
index 63d7f14..948e9f2 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tabs.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tabs.php
index 6347fc9..60bac4c 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tabs.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid.php
index b3cd14a..78f7596 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid/Massaction.php b/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid/Massaction.php
index cb02324..ff59f99 100644
--- a/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid/Massaction.php
+++ b/app/code/core/Mage/Index/Block/Adminhtml/Process/Grid/Massaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Exception.php b/app/code/core/Mage/Index/Exception.php
index 4224c8e..81aee58 100644
--- a/app/code/core/Mage/Index/Exception.php
+++ b/app/code/core/Mage/Index/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Helper/Data.php b/app/code/core/Mage/Index/Helper/Data.php
index 592cc32..e692358 100644
--- a/app/code/core/Mage/Index/Helper/Data.php
+++ b/app/code/core/Mage/Index/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Event.php b/app/code/core/Mage/Index/Model/Event.php
index c0d1b55..7a47d2c 100644
--- a/app/code/core/Mage/Index/Model/Event.php
+++ b/app/code/core/Mage/Index/Model/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Indexer.php b/app/code/core/Mage/Index/Model/Indexer.php
index 761ab05..72f5288 100644
--- a/app/code/core/Mage/Index/Model/Indexer.php
+++ b/app/code/core/Mage/Index/Model/Indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Indexer/Abstract.php b/app/code/core/Mage/Index/Model/Indexer/Abstract.php
index 8a3f6d7..e6e960b 100644
--- a/app/code/core/Mage/Index/Model/Indexer/Abstract.php
+++ b/app/code/core/Mage/Index/Model/Indexer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Lock.php b/app/code/core/Mage/Index/Model/Lock.php
index dcc3d16..5c7dec6 100644
--- a/app/code/core/Mage/Index/Model/Lock.php
+++ b/app/code/core/Mage/Index/Model/Lock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Lock/Storage/Db.php b/app/code/core/Mage/Index/Model/Lock/Storage/Db.php
index 6084665..94a088a 100644
--- a/app/code/core/Mage/Index/Model/Lock/Storage/Db.php
+++ b/app/code/core/Mage/Index/Model/Lock/Storage/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Lock/Storage/Interface.php b/app/code/core/Mage/Index/Model/Lock/Storage/Interface.php
index c762790..55b83ae 100644
--- a/app/code/core/Mage/Index/Model/Lock/Storage/Interface.php
+++ b/app/code/core/Mage/Index/Model/Lock/Storage/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Abstract.php b/app/code/core/Mage/Index/Model/Mysql4/Abstract.php
index eae311e..e102038 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Abstract.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Event.php b/app/code/core/Mage/Index/Model/Mysql4/Event.php
index a056063..ea03801 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Event.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Event/Collection.php b/app/code/core/Mage/Index/Model/Mysql4/Event/Collection.php
index 2162808..63a9802 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Event/Collection.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Event/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Process.php b/app/code/core/Mage/Index/Model/Mysql4/Process.php
index ab90950..16a1933 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Process.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Process/Collection.php b/app/code/core/Mage/Index/Model/Mysql4/Process/Collection.php
index 22fc4e1..7036fb8 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Process/Collection.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Process/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Mysql4/Setup.php b/app/code/core/Mage/Index/Model/Mysql4/Setup.php
index e2f204e..c15a77c 100644
--- a/app/code/core/Mage/Index/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Index/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Observer.php b/app/code/core/Mage/Index/Model/Observer.php
index 6d8b014..402e6d0 100644
--- a/app/code/core/Mage/Index/Model/Observer.php
+++ b/app/code/core/Mage/Index/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Process.php b/app/code/core/Mage/Index/Model/Process.php
index d344dcf..f8fe443 100644
--- a/app/code/core/Mage/Index/Model/Process.php
+++ b/app/code/core/Mage/Index/Model/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Abstract.php b/app/code/core/Mage/Index/Model/Resource/Abstract.php
index 4986ec1..93c7e4e 100644
--- a/app/code/core/Mage/Index/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Index/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Event.php b/app/code/core/Mage/Index/Model/Resource/Event.php
index 88d8972..2b7a2c4 100644
--- a/app/code/core/Mage/Index/Model/Resource/Event.php
+++ b/app/code/core/Mage/Index/Model/Resource/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Event/Collection.php b/app/code/core/Mage/Index/Model/Resource/Event/Collection.php
index 2d06a2f..37d9a75 100644
--- a/app/code/core/Mage/Index/Model/Resource/Event/Collection.php
+++ b/app/code/core/Mage/Index/Model/Resource/Event/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Helper/Lock/Interface.php b/app/code/core/Mage/Index/Model/Resource/Helper/Lock/Interface.php
index 0866039..2a6b62d 100644
--- a/app/code/core/Mage/Index/Model/Resource/Helper/Lock/Interface.php
+++ b/app/code/core/Mage/Index/Model/Resource/Helper/Lock/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Index/Model/Resource/Helper/Mysql4.php
index cb1e2b9..33a1120 100644
--- a/app/code/core/Mage/Index/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Index/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Lock/Resource.php b/app/code/core/Mage/Index/Model/Resource/Lock/Resource.php
index c3abe39..3add101 100644
--- a/app/code/core/Mage/Index/Model/Resource/Lock/Resource.php
+++ b/app/code/core/Mage/Index/Model/Resource/Lock/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Process.php b/app/code/core/Mage/Index/Model/Resource/Process.php
index 4000e8d..23f9a17 100644
--- a/app/code/core/Mage/Index/Model/Resource/Process.php
+++ b/app/code/core/Mage/Index/Model/Resource/Process.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Process/Collection.php b/app/code/core/Mage/Index/Model/Resource/Process/Collection.php
index a194cf2..6cc1daf 100644
--- a/app/code/core/Mage/Index/Model/Resource/Process/Collection.php
+++ b/app/code/core/Mage/Index/Model/Resource/Process/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/Model/Resource/Setup.php b/app/code/core/Mage/Index/Model/Resource/Setup.php
index 939ec5c..085176a 100644
--- a/app/code/core/Mage/Index/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Index/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/controllers/Adminhtml/ProcessController.php b/app/code/core/Mage/Index/controllers/Adminhtml/ProcessController.php
index d5942bd..6592684 100644
--- a/app/code/core/Mage/Index/controllers/Adminhtml/ProcessController.php
+++ b/app/code/core/Mage/Index/controllers/Adminhtml/ProcessController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Index_Adminhtml_ProcessController extends Mage_Adminhtml_Controller_Action
diff --git a/app/code/core/Mage/Index/etc/adminhtml.xml b/app/code/core/Mage/Index/etc/adminhtml.xml
index eaaf106..e0d9c20 100644
--- a/app/code/core/Mage/Index/etc/adminhtml.xml
+++ b/app/code/core/Mage/Index/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Index/etc/config.xml b/app/code/core/Mage/Index/etc/config.xml
index 1e3882c..7a8b1ed 100644
--- a/app/code/core/Mage/Index/etc/config.xml
+++ b/app/code/core/Mage/Index/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Index/sql/index_setup/install-1.6.0.0.php b/app/code/core/Mage/Index/sql/index_setup/install-1.6.0.0.php
index 23c6bca..51966b6 100644
--- a/app/code/core/Mage/Index/sql/index_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Index/sql/index_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/sql/index_setup/mysql4-install-1.4.0.0.php b/app/code/core/Mage/Index/sql/index_setup/mysql4-install-1.4.0.0.php
index 6cbf6bc..cd6417f 100644
--- a/app/code/core/Mage/Index/sql/index_setup/mysql4-install-1.4.0.0.php
+++ b/app/code/core/Mage/Index/sql/index_setup/mysql4-install-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
index 5a9dcd8..829bb4e 100644
--- a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
+++ b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
index a6854b8..76372e3 100644
--- a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
+++ b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index f29f0e3..810f775 100644
--- a/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Index/sql/index_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Index
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Abstract.php b/app/code/core/Mage/Install/Block/Abstract.php
index a23a81b..5db9d86 100644
--- a/app/code/core/Mage/Install/Block/Abstract.php
+++ b/app/code/core/Mage/Install/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Install/Block/Admin.php b/app/code/core/Mage/Install/Block/Admin.php
index 3b1c8d6..b03ccd6 100644
--- a/app/code/core/Mage/Install/Block/Admin.php
+++ b/app/code/core/Mage/Install/Block/Admin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Install/Block/Begin.php b/app/code/core/Mage/Install/Block/Begin.php
index de3617c..2fdc7cc 100644
--- a/app/code/core/Mage/Install/Block/Begin.php
+++ b/app/code/core/Mage/Install/Block/Begin.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Config.php b/app/code/core/Mage/Install/Block/Config.php
index 00eca72..e34ba8a 100644
--- a/app/code/core/Mage/Install/Block/Config.php
+++ b/app/code/core/Mage/Install/Block/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Db/Main.php b/app/code/core/Mage/Install/Block/Db/Main.php
index 0a4d5af..2013d52 100644
--- a/app/code/core/Mage/Install/Block/Db/Main.php
+++ b/app/code/core/Mage/Install/Block/Db/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Db/Type.php b/app/code/core/Mage/Install/Block/Db/Type.php
index 119cc40..dae6d4b 100644
--- a/app/code/core/Mage/Install/Block/Db/Type.php
+++ b/app/code/core/Mage/Install/Block/Db/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Db/Type/Mysql4.php b/app/code/core/Mage/Install/Block/Db/Type/Mysql4.php
index a083a4a..3f017cd 100644
--- a/app/code/core/Mage/Install/Block/Db/Type/Mysql4.php
+++ b/app/code/core/Mage/Install/Block/Db/Type/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Download.php b/app/code/core/Mage/Install/Block/Download.php
index 7468b61..3f30699 100644
--- a/app/code/core/Mage/Install/Block/Download.php
+++ b/app/code/core/Mage/Install/Block/Download.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/End.php b/app/code/core/Mage/Install/Block/End.php
index 2a49f40..b0745da 100644
--- a/app/code/core/Mage/Install/Block/End.php
+++ b/app/code/core/Mage/Install/Block/End.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/Locale.php b/app/code/core/Mage/Install/Block/Locale.php
index fccc709..550f06a 100644
--- a/app/code/core/Mage/Install/Block/Locale.php
+++ b/app/code/core/Mage/Install/Block/Locale.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Block/State.php b/app/code/core/Mage/Install/Block/State.php
index 429b3d9..561e862 100644
--- a/app/code/core/Mage/Install/Block/State.php
+++ b/app/code/core/Mage/Install/Block/State.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Controller/Action.php b/app/code/core/Mage/Install/Controller/Action.php
index e7391b3..c14e5c1 100644
--- a/app/code/core/Mage/Install/Controller/Action.php
+++ b/app/code/core/Mage/Install/Controller/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Controller/Router/Install.php b/app/code/core/Mage/Install/Controller/Router/Install.php
index 0bdbba8..1d867df 100644
--- a/app/code/core/Mage/Install/Controller/Router/Install.php
+++ b/app/code/core/Mage/Install/Controller/Router/Install.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Helper/Data.php b/app/code/core/Mage/Install/Helper/Data.php
index d21c11a..327d269 100644
--- a/app/code/core/Mage/Install/Helper/Data.php
+++ b/app/code/core/Mage/Install/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Config.php b/app/code/core/Mage/Install/Model/Config.php
index 88d34c7..c17fed7 100644
--- a/app/code/core/Mage/Install/Model/Config.php
+++ b/app/code/core/Mage/Install/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer.php b/app/code/core/Mage/Install/Model/Installer.php
index 6a17182..de96701 100644
--- a/app/code/core/Mage/Install/Model/Installer.php
+++ b/app/code/core/Mage/Install/Model/Installer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Abstract.php b/app/code/core/Mage/Install/Model/Installer/Abstract.php
index e5cf693..84a44bc 100644
--- a/app/code/core/Mage/Install/Model/Installer/Abstract.php
+++ b/app/code/core/Mage/Install/Model/Installer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Config.php b/app/code/core/Mage/Install/Model/Installer/Config.php
index 25dbded..e493553 100644
--- a/app/code/core/Mage/Install/Model/Installer/Config.php
+++ b/app/code/core/Mage/Install/Model/Installer/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Console.php b/app/code/core/Mage/Install/Model/Installer/Console.php
index 303bd07..43916c2 100644
--- a/app/code/core/Mage/Install/Model/Installer/Console.php
+++ b/app/code/core/Mage/Install/Model/Installer/Console.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Data.php b/app/code/core/Mage/Install/Model/Installer/Data.php
index 2623d85..1e41763 100644
--- a/app/code/core/Mage/Install/Model/Installer/Data.php
+++ b/app/code/core/Mage/Install/Model/Installer/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Db.php b/app/code/core/Mage/Install/Model/Installer/Db.php
index 18d24a1..ab9f2c2 100644
--- a/app/code/core/Mage/Install/Model/Installer/Db.php
+++ b/app/code/core/Mage/Install/Model/Installer/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Db/Abstract.php b/app/code/core/Mage/Install/Model/Installer/Db/Abstract.php
index b2672cc..9ef99b7 100644
--- a/app/code/core/Mage/Install/Model/Installer/Db/Abstract.php
+++ b/app/code/core/Mage/Install/Model/Installer/Db/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Db/Mysql4.php b/app/code/core/Mage/Install/Model/Installer/Db/Mysql4.php
index a38b5f1..78356a3 100644
--- a/app/code/core/Mage/Install/Model/Installer/Db/Mysql4.php
+++ b/app/code/core/Mage/Install/Model/Installer/Db/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Env.php b/app/code/core/Mage/Install/Model/Installer/Env.php
index 9fb8855..62b3054 100644
--- a/app/code/core/Mage/Install/Model/Installer/Env.php
+++ b/app/code/core/Mage/Install/Model/Installer/Env.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Filesystem.php b/app/code/core/Mage/Install/Model/Installer/Filesystem.php
index e7e9269..bd3c773 100644
--- a/app/code/core/Mage/Install/Model/Installer/Filesystem.php
+++ b/app/code/core/Mage/Install/Model/Installer/Filesystem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Installer/Pear.php b/app/code/core/Mage/Install/Model/Installer/Pear.php
index 8b0a8b9..53072c6 100644
--- a/app/code/core/Mage/Install/Model/Installer/Pear.php
+++ b/app/code/core/Mage/Install/Model/Installer/Pear.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Observer.php b/app/code/core/Mage/Install/Model/Observer.php
index 72cc493..f4054f9 100644
--- a/app/code/core/Mage/Install/Model/Observer.php
+++ b/app/code/core/Mage/Install/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Session.php b/app/code/core/Mage/Install/Model/Session.php
index 19b075e..49ddef7 100644
--- a/app/code/core/Mage/Install/Model/Session.php
+++ b/app/code/core/Mage/Install/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/Model/Wizard.php b/app/code/core/Mage/Install/Model/Wizard.php
index 6b1c388..cf9beaa 100644
--- a/app/code/core/Mage/Install/Model/Wizard.php
+++ b/app/code/core/Mage/Install/Model/Wizard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/controllers/IndexController.php b/app/code/core/Mage/Install/controllers/IndexController.php
index 0f4e823..c830ef2 100644
--- a/app/code/core/Mage/Install/controllers/IndexController.php
+++ b/app/code/core/Mage/Install/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/controllers/WizardController.php b/app/code/core/Mage/Install/controllers/WizardController.php
index 0ec9c79..695084b 100644
--- a/app/code/core/Mage/Install/controllers/WizardController.php
+++ b/app/code/core/Mage/Install/controllers/WizardController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Install/etc/config.xml b/app/code/core/Mage/Install/etc/config.xml
index e16b8fe..4eb2065 100644
--- a/app/code/core/Mage/Install/etc/config.xml
+++ b/app/code/core/Mage/Install/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Install/etc/install.xml b/app/code/core/Mage/Install/etc/install.xml
index e347021..862fd66 100644
--- a/app/code/core/Mage/Install/etc/install.xml
+++ b/app/code/core/Mage/Install/etc/install.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Install
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Log/Helper/Data.php b/app/code/core/Mage/Log/Helper/Data.php
index 059712b..560a046 100644
--- a/app/code/core/Mage/Log/Helper/Data.php
+++ b/app/code/core/Mage/Log/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Adminhtml/System/Config/Source/Loglevel.php b/app/code/core/Mage/Log/Model/Adminhtml/System/Config/Source/Loglevel.php
index 548d1f9..428d610 100644
--- a/app/code/core/Mage/Log/Model/Adminhtml/System/Config/Source/Loglevel.php
+++ b/app/code/core/Mage/Log/Model/Adminhtml/System/Config/Source/Loglevel.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Aggregation.php b/app/code/core/Mage/Log/Model/Aggregation.php
index f4e894c..5ed4b95 100644
--- a/app/code/core/Mage/Log/Model/Aggregation.php
+++ b/app/code/core/Mage/Log/Model/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Cron.php b/app/code/core/Mage/Log/Model/Cron.php
index a9a214c..06d505e 100644
--- a/app/code/core/Mage/Log/Model/Cron.php
+++ b/app/code/core/Mage/Log/Model/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Customer.php b/app/code/core/Mage/Log/Model/Customer.php
index f5d6d66..82c3c83 100644
--- a/app/code/core/Mage/Log/Model/Customer.php
+++ b/app/code/core/Mage/Log/Model/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Log.php b/app/code/core/Mage/Log/Model/Log.php
index 9bb5c6f..1effef6 100644
--- a/app/code/core/Mage/Log/Model/Log.php
+++ b/app/code/core/Mage/Log/Model/Log.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Aggregation.php b/app/code/core/Mage/Log/Model/Mysql4/Aggregation.php
index f997070..ef6565f 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Aggregation.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Customer.php b/app/code/core/Mage/Log/Model/Mysql4/Customer.php
index 445b7aa..8c56a9a 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Customer.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Log.php b/app/code/core/Mage/Log/Model/Mysql4/Log.php
index 26a7b7d..c4de9e2 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Log.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Log.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Visitor.php b/app/code/core/Mage/Log/Model/Mysql4/Visitor.php
index 6db70c8..d028edb 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Visitor.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Visitor.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Collection.php b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Collection.php
index e45fcf7..0aaacdf 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Collection.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online.php b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online.php
index b046ad9..ad3d341 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online/Collection.php b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online/Collection.php
index 1a7e626..9752768 100644
--- a/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online/Collection.php
+++ b/app/code/core/Mage/Log/Model/Mysql4/Visitor/Online/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Aggregation.php b/app/code/core/Mage/Log/Model/Resource/Aggregation.php
index 108b0d7..6812c34 100644
--- a/app/code/core/Mage/Log/Model/Resource/Aggregation.php
+++ b/app/code/core/Mage/Log/Model/Resource/Aggregation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Customer.php b/app/code/core/Mage/Log/Model/Resource/Customer.php
index f3a6438..9c8bf26 100644
--- a/app/code/core/Mage/Log/Model/Resource/Customer.php
+++ b/app/code/core/Mage/Log/Model/Resource/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Log.php b/app/code/core/Mage/Log/Model/Resource/Log.php
index 3ed3486..a66bf0c 100644
--- a/app/code/core/Mage/Log/Model/Resource/Log.php
+++ b/app/code/core/Mage/Log/Model/Resource/Log.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Visitor.php b/app/code/core/Mage/Log/Model/Resource/Visitor.php
index 8b07134..cc4b6d1 100644
--- a/app/code/core/Mage/Log/Model/Resource/Visitor.php
+++ b/app/code/core/Mage/Log/Model/Resource/Visitor.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Visitor/Collection.php b/app/code/core/Mage/Log/Model/Resource/Visitor/Collection.php
index 172a4b4..58772e5 100644
--- a/app/code/core/Mage/Log/Model/Resource/Visitor/Collection.php
+++ b/app/code/core/Mage/Log/Model/Resource/Visitor/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Visitor/Online.php b/app/code/core/Mage/Log/Model/Resource/Visitor/Online.php
index 89e1a0a..2a4138b 100644
--- a/app/code/core/Mage/Log/Model/Resource/Visitor/Online.php
+++ b/app/code/core/Mage/Log/Model/Resource/Visitor/Online.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Resource/Visitor/Online/Collection.php b/app/code/core/Mage/Log/Model/Resource/Visitor/Online/Collection.php
index 058a3a8..918b22f 100644
--- a/app/code/core/Mage/Log/Model/Resource/Visitor/Online/Collection.php
+++ b/app/code/core/Mage/Log/Model/Resource/Visitor/Online/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Visitor.php b/app/code/core/Mage/Log/Model/Visitor.php
index 57a93d3..2784475 100644
--- a/app/code/core/Mage/Log/Model/Visitor.php
+++ b/app/code/core/Mage/Log/Model/Visitor.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/Model/Visitor/Online.php b/app/code/core/Mage/Log/Model/Visitor/Online.php
index fe071e4..5fb7b09 100644
--- a/app/code/core/Mage/Log/Model/Visitor/Online.php
+++ b/app/code/core/Mage/Log/Model/Visitor/Online.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/data/log_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Log/data/log_setup/data-install-1.6.0.0.php
index 6172a30..0c6055a 100644
--- a/app/code/core/Mage/Log/data/log_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Log/data/log_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/etc/config.xml b/app/code/core/Mage/Log/etc/config.xml
index 07795fc..21a7890 100644
--- a/app/code/core/Mage/Log/etc/config.xml
+++ b/app/code/core/Mage/Log/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Log/etc/system.xml b/app/code/core/Mage/Log/etc/system.xml
index 363997c..ebaf421 100644
--- a/app/code/core/Mage/Log/etc/system.xml
+++ b/app/code/core/Mage/Log/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Log/sql/log_setup/install-1.6.0.0.php b/app/code/core/Mage/Log/sql/log_setup/install-1.6.0.0.php
index ed2acb7..ad4956a 100644
--- a/app/code/core/Mage/Log/sql/log_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Log/sql/log_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-install-0.7.0.php
index 2db8c2e..999638e 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.0-0.7.1.php
index e050d24..b490c57 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 1d9692b..b4140f2 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 76d120c..56035bf 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.4-0.7.5.php
index f4a69af..732f090 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 90a9e41..1193a17 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 3352366..67dfbc6 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index f3aa52b..b1621d0 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
index f2cfccb..a4bf456 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.0.0-1.6.1.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.1.0-1.6.1.1.php b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.1.0-1.6.1.1.php
index eaebc2f..3eb3e84 100644
--- a/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.1.0-1.6.1.1.php
+++ b/app/code/core/Mage/Log/sql/log_setup/mysql4-upgrade-1.6.1.0-1.6.1.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Log
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Media/Helper/Data.php b/app/code/core/Mage/Media/Helper/Data.php
index b6eed7b..68bbeec 100644
--- a/app/code/core/Mage/Media/Helper/Data.php
+++ b/app/code/core/Mage/Media/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Media
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Media/Model/File/Image.php b/app/code/core/Mage/Media/Model/File/Image.php
index 6e304c0..442c08b 100644
--- a/app/code/core/Mage/Media/Model/File/Image.php
+++ b/app/code/core/Mage/Media/Model/File/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Media
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Media/Model/Image.php b/app/code/core/Mage/Media/Model/Image.php
index 2866644..7f0dac2 100644
--- a/app/code/core/Mage/Media/Model/Image.php
+++ b/app/code/core/Mage/Media/Model/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Media
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Media/Model/Image/Config/Interface.php b/app/code/core/Mage/Media/Model/Image/Config/Interface.php
index a5b480b..a6246da 100644
--- a/app/code/core/Mage/Media/Model/Image/Config/Interface.php
+++ b/app/code/core/Mage/Media/Model/Image/Config/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Media
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Media/etc/config.xml b/app/code/core/Mage/Media/etc/config.xml
index 4869703..41585fa 100644
--- a/app/code/core/Mage/Media/etc/config.xml
+++ b/app/code/core/Mage/Media/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Media
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Newsletter/Block/Subscribe.php b/app/code/core/Mage/Newsletter/Block/Subscribe.php
index 5610dac..7fd5b45 100644
--- a/app/code/core/Mage/Newsletter/Block/Subscribe.php
+++ b/app/code/core/Mage/Newsletter/Block/Subscribe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Helper/Data.php b/app/code/core/Mage/Newsletter/Helper/Data.php
index 7daf26d..7327aba 100644
--- a/app/code/core/Mage/Newsletter/Helper/Data.php
+++ b/app/code/core/Mage/Newsletter/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Message.php b/app/code/core/Mage/Newsletter/Model/Message.php
index 608f7a7..8ed53a7 100644
--- a/app/code/core/Mage/Newsletter/Model/Message.php
+++ b/app/code/core/Mage/Newsletter/Model/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Problem.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Problem.php
index fca824c..c97ba33 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Problem.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Problem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Problem/Collection.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Problem/Collection.php
index 4c0e358..bcdc343 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Problem/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Problem/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Queue.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Queue.php
index 6bee6d7..2590816 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Queue.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Queue/Collection.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Queue/Collection.php
index 5b555ec..b0969fb 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Queue/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Queue/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber.php
index 28f7101..cbd6604 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber/Collection.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber/Collection.php
index 9761d97..32ac1df 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Subscriber/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Template.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Template.php
index 40ead2e..86f7ec0 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Template.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Mysql4/Template/Collection.php b/app/code/core/Mage/Newsletter/Model/Mysql4/Template/Collection.php
index 812235b..be4fa2a 100644
--- a/app/code/core/Mage/Newsletter/Model/Mysql4/Template/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Mysql4/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Observer.php b/app/code/core/Mage/Newsletter/Model/Observer.php
index 0bfe516..af3fee5 100644
--- a/app/code/core/Mage/Newsletter/Model/Observer.php
+++ b/app/code/core/Mage/Newsletter/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Problem.php b/app/code/core/Mage/Newsletter/Model/Problem.php
index 501ecf0..555d6f1 100644
--- a/app/code/core/Mage/Newsletter/Model/Problem.php
+++ b/app/code/core/Mage/Newsletter/Model/Problem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Queue.php b/app/code/core/Mage/Newsletter/Model/Queue.php
index e86abee..d857cc9 100644
--- a/app/code/core/Mage/Newsletter/Model/Queue.php
+++ b/app/code/core/Mage/Newsletter/Model/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Problem.php b/app/code/core/Mage/Newsletter/Model/Resource/Problem.php
index 297886e..0e96d09 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Problem.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Problem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Problem/Collection.php b/app/code/core/Mage/Newsletter/Model/Resource/Problem/Collection.php
index 57939b9..f91c9b5 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Problem/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Problem/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Queue.php b/app/code/core/Mage/Newsletter/Model/Resource/Queue.php
index a268f48..d200749 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Queue.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Queue/Collection.php b/app/code/core/Mage/Newsletter/Model/Resource/Queue/Collection.php
index f9f88f3..3ad2003 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Queue/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Queue/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Subscriber.php b/app/code/core/Mage/Newsletter/Model/Resource/Subscriber.php
index 9cf5776..08bdc4e 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Subscriber.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Subscriber.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Subscriber/Collection.php b/app/code/core/Mage/Newsletter/Model/Resource/Subscriber/Collection.php
index bf60836..3efff04 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Subscriber/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Subscriber/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Template.php b/app/code/core/Mage/Newsletter/Model/Resource/Template.php
index 75a06be..a7ee3ab 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Template.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Resource/Template/Collection.php b/app/code/core/Mage/Newsletter/Model/Resource/Template/Collection.php
index 6e6dd99..a19cfc7 100644
--- a/app/code/core/Mage/Newsletter/Model/Resource/Template/Collection.php
+++ b/app/code/core/Mage/Newsletter/Model/Resource/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Session.php b/app/code/core/Mage/Newsletter/Model/Session.php
index d9406d6..54293b4 100644
--- a/app/code/core/Mage/Newsletter/Model/Session.php
+++ b/app/code/core/Mage/Newsletter/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Subscriber.php b/app/code/core/Mage/Newsletter/Model/Subscriber.php
index 91de958..5b68871 100644
--- a/app/code/core/Mage/Newsletter/Model/Subscriber.php
+++ b/app/code/core/Mage/Newsletter/Model/Subscriber.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Template.php b/app/code/core/Mage/Newsletter/Model/Template.php
index 50bacbf..86f396b 100644
--- a/app/code/core/Mage/Newsletter/Model/Template.php
+++ b/app/code/core/Mage/Newsletter/Model/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/Model/Template/Filter.php b/app/code/core/Mage/Newsletter/Model/Template/Filter.php
index b561c4d..8aac557 100644
--- a/app/code/core/Mage/Newsletter/Model/Template/Filter.php
+++ b/app/code/core/Mage/Newsletter/Model/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/controllers/ManageController.php b/app/code/core/Mage/Newsletter/controllers/ManageController.php
index ff04eea..cff66a0 100644
--- a/app/code/core/Mage/Newsletter/controllers/ManageController.php
+++ b/app/code/core/Mage/Newsletter/controllers/ManageController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/controllers/SubscriberController.php b/app/code/core/Mage/Newsletter/controllers/SubscriberController.php
index 1fd20cc..0ea68a9 100644
--- a/app/code/core/Mage/Newsletter/controllers/SubscriberController.php
+++ b/app/code/core/Mage/Newsletter/controllers/SubscriberController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.0-1.6.0.1.php
index 86e84f0..b0e93a4 100644
--- a/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.1-1.6.0.2.php
index d761bed..d31de4b 100644
--- a/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Newsletter/data/newsletter_setup/data-upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/etc/adminhtml.xml b/app/code/core/Mage/Newsletter/etc/adminhtml.xml
index 49e689b..348e1e3 100644
--- a/app/code/core/Mage/Newsletter/etc/adminhtml.xml
+++ b/app/code/core/Mage/Newsletter/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Newsletter/etc/config.xml b/app/code/core/Mage/Newsletter/etc/config.xml
index 1e889c0..a70ff01 100644
--- a/app/code/core/Mage/Newsletter/etc/config.xml
+++ b/app/code/core/Mage/Newsletter/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Newsletter/etc/system.xml b/app/code/core/Mage/Newsletter/etc/system.xml
index ca8b314..de4c119 100644
--- a/app/code/core/Mage/Newsletter/etc/system.xml
+++ b/app/code/core/Mage/Newsletter/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/install-1.6.0.0.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/install-1.6.0.0.php
index 9234b5b..752cf28 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.7.0.php
index c727a5b..b834286 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.8.0.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.8.0.php
index e2d42c4..bd1bab1 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.8.0.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-install-0.8.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.7.0-0.7.1.php
index f0f73b0..6e007bf 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.0-0.8.1.php
index 90a20cf..79f7e9d 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.1-0.8.2.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.1-0.8.2.php
index 08abb94..bc10672 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.1-0.8.2.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.1-0.8.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.2-0.8.3.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.2-0.8.3.php
index 11818c5..52a9118 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.2-0.8.3.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-0.8.2-0.8.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 52c20fe..e1a9119 100644
--- a/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Newsletter/sql/newsletter_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Newsletter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token.php
index 4cfd22b..83c29a0 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token/Grid.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token/Grid.php
index fdcc481..6b53743 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token/Grid.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Admin/Token/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize.php
index 11b7a55..a83f755 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize/Button.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize/Button.php
index 2fbbc9b..c01bf23 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize/Button.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Authorize/Button.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens.php
index 516d8e2..722ea71 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens/Grid.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens/Grid.php
index c3fe9aa..400a475 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens/Grid.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/AuthorizedTokens/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer.php
index 1c60215..213de30 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit.php
index 05b7bce..fac0e33 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit/Form.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit/Form.php
index 6b4ccbb..85f320f 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit/Form.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Grid.php b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Grid.php
index 3a05dac..02bf7fd 100644
--- a/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Grid.php
+++ b/app/code/core/Mage/Oauth/Block/Adminhtml/Oauth/Consumer/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Authorize.php b/app/code/core/Mage/Oauth/Block/Authorize.php
index a77066d..48cadab 100644
--- a/app/code/core/Mage/Oauth/Block/Authorize.php
+++ b/app/code/core/Mage/Oauth/Block/Authorize.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Authorize/Abstract.php b/app/code/core/Mage/Oauth/Block/Authorize/Abstract.php
index 7b908d8..071034f 100644
--- a/app/code/core/Mage/Oauth/Block/Authorize/Abstract.php
+++ b/app/code/core/Mage/Oauth/Block/Authorize/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Authorize/Button.php b/app/code/core/Mage/Oauth/Block/Authorize/Button.php
index 87512ca..fd3fd62 100644
--- a/app/code/core/Mage/Oauth/Block/Authorize/Button.php
+++ b/app/code/core/Mage/Oauth/Block/Authorize/Button.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Authorize/ButtonBaseAbstract.php b/app/code/core/Mage/Oauth/Block/Authorize/ButtonBaseAbstract.php
index f7203b5..e4262a3 100644
--- a/app/code/core/Mage/Oauth/Block/Authorize/ButtonBaseAbstract.php
+++ b/app/code/core/Mage/Oauth/Block/Authorize/ButtonBaseAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/AuthorizeBaseAbstract.php b/app/code/core/Mage/Oauth/Block/AuthorizeBaseAbstract.php
index d8f61c3..4cea076 100644
--- a/app/code/core/Mage/Oauth/Block/AuthorizeBaseAbstract.php
+++ b/app/code/core/Mage/Oauth/Block/AuthorizeBaseAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Block/Customer/Token/List.php b/app/code/core/Mage/Oauth/Block/Customer/Token/List.php
index c159f24..9cf3118 100644
--- a/app/code/core/Mage/Oauth/Block/Customer/Token/List.php
+++ b/app/code/core/Mage/Oauth/Block/Customer/Token/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Exception.php b/app/code/core/Mage/Oauth/Exception.php
index 83e0943..2167b72 100644
--- a/app/code/core/Mage/Oauth/Exception.php
+++ b/app/code/core/Mage/Oauth/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Helper/Data.php b/app/code/core/Mage/Oauth/Helper/Data.php
index d084e09..9dd77b9 100644
--- a/app/code/core/Mage/Oauth/Helper/Data.php
+++ b/app/code/core/Mage/Oauth/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Consumer.php b/app/code/core/Mage/Oauth/Model/Consumer.php
index 0b5a8aa..e955f8c 100644
--- a/app/code/core/Mage/Oauth/Model/Consumer.php
+++ b/app/code/core/Mage/Oauth/Model/Consumer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Consumer/Validator/KeyLength.php b/app/code/core/Mage/Oauth/Model/Consumer/Validator/KeyLength.php
index 79cda81..10c8a93 100644
--- a/app/code/core/Mage/Oauth/Model/Consumer/Validator/KeyLength.php
+++ b/app/code/core/Mage/Oauth/Model/Consumer/Validator/KeyLength.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Nonce.php b/app/code/core/Mage/Oauth/Model/Nonce.php
index 82b3fee..a36c4dc 100644
--- a/app/code/core/Mage/Oauth/Model/Nonce.php
+++ b/app/code/core/Mage/Oauth/Model/Nonce.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Observer.php b/app/code/core/Mage/Oauth/Model/Observer.php
index 14e2263..5fac598 100644
--- a/app/code/core/Mage/Oauth/Model/Observer.php
+++ b/app/code/core/Mage/Oauth/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Consumer.php b/app/code/core/Mage/Oauth/Model/Resource/Consumer.php
index c4872b3..c5d8491 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Consumer.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Consumer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Consumer/Collection.php b/app/code/core/Mage/Oauth/Model/Resource/Consumer/Collection.php
index e9dbca1..986b528 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Consumer/Collection.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Consumer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Nonce.php b/app/code/core/Mage/Oauth/Model/Resource/Nonce.php
index 3639f66..568d41d 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Nonce.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Nonce.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Nonce/Collection.php b/app/code/core/Mage/Oauth/Model/Resource/Nonce/Collection.php
index aa13b9e..fe870e7 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Nonce/Collection.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Nonce/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Setup.php b/app/code/core/Mage/Oauth/Model/Resource/Setup.php
index 647ad1f..ca5a00f 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Token.php b/app/code/core/Mage/Oauth/Model/Resource/Token.php
index 723d93b..6b72701 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Token.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Token.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Resource/Token/Collection.php b/app/code/core/Mage/Oauth/Model/Resource/Token/Collection.php
index 5c83c69..245cdec 100644
--- a/app/code/core/Mage/Oauth/Model/Resource/Token/Collection.php
+++ b/app/code/core/Mage/Oauth/Model/Resource/Token/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Server.php b/app/code/core/Mage/Oauth/Model/Server.php
index 4755da7..37e1086 100644
--- a/app/code/core/Mage/Oauth/Model/Server.php
+++ b/app/code/core/Mage/Oauth/Model/Server.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/Model/Token.php b/app/code/core/Mage/Oauth/Model/Token.php
index 7837419..41431c1 100644
--- a/app/code/core/Mage/Oauth/Model/Token.php
+++ b/app/code/core/Mage/Oauth/Model/Token.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/Admin/TokenController.php b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/Admin/TokenController.php
index 2ba11ef..8b452af 100644
--- a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/Admin/TokenController.php
+++ b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/Admin/TokenController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizeController.php b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizeController.php
index def4932..51a5cb1 100644
--- a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizeController.php
+++ b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizedTokensController.php b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizedTokensController.php
index 314c739..2e0be37 100644
--- a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizedTokensController.php
+++ b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/AuthorizedTokensController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/ConsumerController.php b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/ConsumerController.php
index af00474..b31b3ec 100644
--- a/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/ConsumerController.php
+++ b/app/code/core/Mage/Oauth/controllers/Adminhtml/Oauth/ConsumerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -57,6 +57,7 @@ class Mage_Oauth_Adminhtml_Oauth_ConsumerController extends Mage_Adminhtml_Contr
      */
     public function preDispatch()
     {
+        $this->_setForcedFormKeyActions(array('delete'));
         $this->_title($this->__('System'))
             ->_title($this->__('OAuth'))
             ->_title($this->__('Consumers'));
diff --git a/app/code/core/Mage/Oauth/controllers/AuthorizeController.php b/app/code/core/Mage/Oauth/controllers/AuthorizeController.php
index fd475c1..91c8bd8 100644
--- a/app/code/core/Mage/Oauth/controllers/AuthorizeController.php
+++ b/app/code/core/Mage/Oauth/controllers/AuthorizeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/Customer/TokenController.php b/app/code/core/Mage/Oauth/controllers/Customer/TokenController.php
index 7e05e3b..b6f97ef 100644
--- a/app/code/core/Mage/Oauth/controllers/Customer/TokenController.php
+++ b/app/code/core/Mage/Oauth/controllers/Customer/TokenController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/InitiateController.php b/app/code/core/Mage/Oauth/controllers/InitiateController.php
index 8f34af2..6cf62aa 100644
--- a/app/code/core/Mage/Oauth/controllers/InitiateController.php
+++ b/app/code/core/Mage/Oauth/controllers/InitiateController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/controllers/TokenController.php b/app/code/core/Mage/Oauth/controllers/TokenController.php
index 78b6c10..1d6669c 100644
--- a/app/code/core/Mage/Oauth/controllers/TokenController.php
+++ b/app/code/core/Mage/Oauth/controllers/TokenController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Oauth/etc/adminhtml.xml b/app/code/core/Mage/Oauth/etc/adminhtml.xml
index 9dc9c00..af07cf3 100644
--- a/app/code/core/Mage/Oauth/etc/adminhtml.xml
+++ b/app/code/core/Mage/Oauth/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Oauth/etc/config.xml b/app/code/core/Mage/Oauth/etc/config.xml
index e8a3fc5..433d250 100644
--- a/app/code/core/Mage/Oauth/etc/config.xml
+++ b/app/code/core/Mage/Oauth/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Oauth/etc/system.xml b/app/code/core/Mage/Oauth/etc/system.xml
index 695046a..2f9c600 100644
--- a/app/code/core/Mage/Oauth/etc/system.xml
+++ b/app/code/core/Mage/Oauth/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Oauth/sql/oauth_setup/install-1.0.0.0.php b/app/code/core/Mage/Oauth/sql/oauth_setup/install-1.0.0.0.php
index 427a8e8..f0ed8f5 100644
--- a/app/code/core/Mage/Oauth/sql/oauth_setup/install-1.0.0.0.php
+++ b/app/code/core/Mage/Oauth/sql/oauth_setup/install-1.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/app/code/core/Mage/Page/Block/Html.php b/app/code/core/Mage/Page/Block/Html.php
index 4975e65..2fa00ad 100644
--- a/app/code/core/Mage/Page/Block/Html.php
+++ b/app/code/core/Mage/Page/Block/Html.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Breadcrumbs.php b/app/code/core/Mage/Page/Block/Html/Breadcrumbs.php
index fa81104..cf9a841 100644
--- a/app/code/core/Mage/Page/Block/Html/Breadcrumbs.php
+++ b/app/code/core/Mage/Page/Block/Html/Breadcrumbs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/CookieNotice.php b/app/code/core/Mage/Page/Block/Html/CookieNotice.php
index 6434768..1cf5a6e 100644
--- a/app/code/core/Mage/Page/Block/Html/CookieNotice.php
+++ b/app/code/core/Mage/Page/Block/Html/CookieNotice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Footer.php b/app/code/core/Mage/Page/Block/Html/Footer.php
index 7c1bddd..1f7bbdb 100644
--- a/app/code/core/Mage/Page/Block/Html/Footer.php
+++ b/app/code/core/Mage/Page/Block/Html/Footer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Head.php b/app/code/core/Mage/Page/Block/Html/Head.php
index ee4595f..196c30e 100644
--- a/app/code/core/Mage/Page/Block/Html/Head.php
+++ b/app/code/core/Mage/Page/Block/Html/Head.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Header.php b/app/code/core/Mage/Page/Block/Html/Header.php
index 2f8dc8d..d76f816 100644
--- a/app/code/core/Mage/Page/Block/Html/Header.php
+++ b/app/code/core/Mage/Page/Block/Html/Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Notices.php b/app/code/core/Mage/Page/Block/Html/Notices.php
index a497c17..50a1bc5 100644
--- a/app/code/core/Mage/Page/Block/Html/Notices.php
+++ b/app/code/core/Mage/Page/Block/Html/Notices.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Pager.php b/app/code/core/Mage/Page/Block/Html/Pager.php
index 733e217..c8bf58f 100644
--- a/app/code/core/Mage/Page/Block/Html/Pager.php
+++ b/app/code/core/Mage/Page/Block/Html/Pager.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Toplinks.php b/app/code/core/Mage/Page/Block/Html/Toplinks.php
index 36cd9bb..3b44717 100644
--- a/app/code/core/Mage/Page/Block/Html/Toplinks.php
+++ b/app/code/core/Mage/Page/Block/Html/Toplinks.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Topmenu.php b/app/code/core/Mage/Page/Block/Html/Topmenu.php
index 4abf0ca..9cf9a9b 100644
--- a/app/code/core/Mage/Page/Block/Html/Topmenu.php
+++ b/app/code/core/Mage/Page/Block/Html/Topmenu.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Topmenu/Renderer.php b/app/code/core/Mage/Page/Block/Html/Topmenu/Renderer.php
index b5c6e51..aaddf9f 100644
--- a/app/code/core/Mage/Page/Block/Html/Topmenu/Renderer.php
+++ b/app/code/core/Mage/Page/Block/Html/Topmenu/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Welcome.php b/app/code/core/Mage/Page/Block/Html/Welcome.php
index 6f90684..a7c0166 100644
--- a/app/code/core/Mage/Page/Block/Html/Welcome.php
+++ b/app/code/core/Mage/Page/Block/Html/Welcome.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Html/Wrapper.php b/app/code/core/Mage/Page/Block/Html/Wrapper.php
index 0148d36..c25b09d 100644
--- a/app/code/core/Mage/Page/Block/Html/Wrapper.php
+++ b/app/code/core/Mage/Page/Block/Html/Wrapper.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Js/Cookie.php b/app/code/core/Mage/Page/Block/Js/Cookie.php
index a9323ec..70d3d0c 100644
--- a/app/code/core/Mage/Page/Block/Js/Cookie.php
+++ b/app/code/core/Mage/Page/Block/Js/Cookie.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Js/Translate.php b/app/code/core/Mage/Page/Block/Js/Translate.php
index 4cb2792..44be252 100644
--- a/app/code/core/Mage/Page/Block/Js/Translate.php
+++ b/app/code/core/Mage/Page/Block/Js/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Redirect.php b/app/code/core/Mage/Page/Block/Redirect.php
index 18d9b08..f0c3c96 100644
--- a/app/code/core/Mage/Page/Block/Redirect.php
+++ b/app/code/core/Mage/Page/Block/Redirect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Switch.php b/app/code/core/Mage/Page/Block/Switch.php
index 99630c1..dbd6ff4 100644
--- a/app/code/core/Mage/Page/Block/Switch.php
+++ b/app/code/core/Mage/Page/Block/Switch.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Template/Container.php b/app/code/core/Mage/Page/Block/Template/Container.php
index 2988960..40d57b6 100644
--- a/app/code/core/Mage/Page/Block/Template/Container.php
+++ b/app/code/core/Mage/Page/Block/Template/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Template/Links.php b/app/code/core/Mage/Page/Block/Template/Links.php
index 88056e1..57072d60 100644
--- a/app/code/core/Mage/Page/Block/Template/Links.php
+++ b/app/code/core/Mage/Page/Block/Template/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Block/Template/Links/Block.php b/app/code/core/Mage/Page/Block/Template/Links/Block.php
index 4ae326f..cabe794 100644
--- a/app/code/core/Mage/Page/Block/Template/Links/Block.php
+++ b/app/code/core/Mage/Page/Block/Template/Links/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Helper/Data.php b/app/code/core/Mage/Page/Helper/Data.php
index 107de2e..83a0b8c 100644
--- a/app/code/core/Mage/Page/Helper/Data.php
+++ b/app/code/core/Mage/Page/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Helper/Html.php b/app/code/core/Mage/Page/Helper/Html.php
index 9de7d6c..9a185b8 100644
--- a/app/code/core/Mage/Page/Helper/Html.php
+++ b/app/code/core/Mage/Page/Helper/Html.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  
diff --git a/app/code/core/Mage/Page/Helper/Layout.php b/app/code/core/Mage/Page/Helper/Layout.php
index 78d17a7..bab8238 100644
--- a/app/code/core/Mage/Page/Helper/Layout.php
+++ b/app/code/core/Mage/Page/Helper/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Model/Config.php b/app/code/core/Mage/Page/Model/Config.php
index 4302cc3..591f388 100644
--- a/app/code/core/Mage/Page/Model/Config.php
+++ b/app/code/core/Mage/Page/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/Model/Source/Layout.php b/app/code/core/Mage/Page/Model/Source/Layout.php
index 6baf629..1386125 100644
--- a/app/code/core/Mage/Page/Model/Source/Layout.php
+++ b/app/code/core/Mage/Page/Model/Source/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Page/etc/config.xml b/app/code/core/Mage/Page/etc/config.xml
index 3f38084..420ded2 100644
--- a/app/code/core/Mage/Page/etc/config.xml
+++ b/app/code/core/Mage/Page/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -130,7 +130,7 @@
                 <welcome>Default welcome msg!</welcome>
             </header>
             <footer translate="copyright" module="page">
-                <copyright>&amp;copy; 2018 Magento Demo Store. All Rights Reserved.</copyright>
+                <copyright>&amp;copy; 2019 Magento Demo Store. All Rights Reserved.</copyright>
             </footer>
         </design>
         <system>
diff --git a/app/code/core/Mage/Page/etc/system.xml b/app/code/core/Mage/Page/etc/system.xml
index 92198bf..4e55be7 100644
--- a/app/code/core/Mage/Page/etc/system.xml
+++ b/app/code/core/Mage/Page/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Page
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/PageCache/Block/Adminhtml/Cache/Additional.php b/app/code/core/Mage/PageCache/Block/Adminhtml/Cache/Additional.php
index 1d5118a..137709c 100644
--- a/app/code/core/Mage/PageCache/Block/Adminhtml/Cache/Additional.php
+++ b/app/code/core/Mage/PageCache/Block/Adminhtml/Cache/Additional.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/Helper/Data.php b/app/code/core/Mage/PageCache/Helper/Data.php
index d4c7498..e38886b 100644
--- a/app/code/core/Mage/PageCache/Helper/Data.php
+++ b/app/code/core/Mage/PageCache/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/Model/Control/Interface.php b/app/code/core/Mage/PageCache/Model/Control/Interface.php
index 4a07bf0..6ecf427 100644
--- a/app/code/core/Mage/PageCache/Model/Control/Interface.php
+++ b/app/code/core/Mage/PageCache/Model/Control/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/Model/Control/Zend.php b/app/code/core/Mage/PageCache/Model/Control/Zend.php
index 3479ce4..f88dceb 100644
--- a/app/code/core/Mage/PageCache/Model/Control/Zend.php
+++ b/app/code/core/Mage/PageCache/Model/Control/Zend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/Model/Observer.php b/app/code/core/Mage/PageCache/Model/Observer.php
index 1bad30b..d846eac 100644
--- a/app/code/core/Mage/PageCache/Model/Observer.php
+++ b/app/code/core/Mage/PageCache/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/Model/System/Config/Source/Controls.php b/app/code/core/Mage/PageCache/Model/System/Config/Source/Controls.php
index 4c62d4a..2c6244b 100644
--- a/app/code/core/Mage/PageCache/Model/System/Config/Source/Controls.php
+++ b/app/code/core/Mage/PageCache/Model/System/Config/Source/Controls.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/controllers/Adminhtml/PageCacheController.php b/app/code/core/Mage/PageCache/controllers/Adminhtml/PageCacheController.php
index ef4b7fa..17ccfeb 100644
--- a/app/code/core/Mage/PageCache/controllers/Adminhtml/PageCacheController.php
+++ b/app/code/core/Mage/PageCache/controllers/Adminhtml/PageCacheController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PageCache/etc/adminhtml.xml b/app/code/core/Mage/PageCache/etc/adminhtml.xml
index 2dc0852..0812c50 100644
--- a/app/code/core/Mage/PageCache/etc/adminhtml.xml
+++ b/app/code/core/Mage/PageCache/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/PageCache/etc/config.xml b/app/code/core/Mage/PageCache/etc/config.xml
index ea3402b..79e652c 100644
--- a/app/code/core/Mage/PageCache/etc/config.xml
+++ b/app/code/core/Mage/PageCache/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/PageCache/etc/system.xml b/app/code/core/Mage/PageCache/etc/system.xml
index 5ed8dfe..d562139 100644
--- a/app/code/core/Mage/PageCache/etc/system.xml
+++ b/app/code/core/Mage/PageCache/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paygate/Block/Authorizenet/Form/Cc.php b/app/code/core/Mage/Paygate/Block/Authorizenet/Form/Cc.php
index 3bb7c90..5ee4e24 100644
--- a/app/code/core/Mage/Paygate/Block/Authorizenet/Form/Cc.php
+++ b/app/code/core/Mage/Paygate/Block/Authorizenet/Form/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Block/Authorizenet/Info/Cc.php b/app/code/core/Mage/Paygate/Block/Authorizenet/Info/Cc.php
index 462541f..a0aacff 100644
--- a/app/code/core/Mage/Paygate/Block/Authorizenet/Info/Cc.php
+++ b/app/code/core/Mage/Paygate/Block/Authorizenet/Info/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Helper/Data.php b/app/code/core/Mage/Paygate/Helper/Data.php
index 2c2ae4f..398cf71 100644
--- a/app/code/core/Mage/Paygate/Helper/Data.php
+++ b/app/code/core/Mage/Paygate/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet.php b/app/code/core/Mage/Paygate/Model/Authorizenet.php
index 13ea6e6..f3c1a89 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Cards.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Cards.php
index 32e4462..ab02025 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Cards.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Cards.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Debug.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Debug.php
index ed67393..6b65855 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Debug.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Debug.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Request.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Request.php
index 07ab265..18a9521 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Request.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Result.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Result.php
index 93ca247..6f3128c 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Result.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Source/Cctype.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Source/Cctype.php
index c59ee30..864f577 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Source/Cctype.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Source/Cctype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Authorizenet/Source/PaymentAction.php b/app/code/core/Mage/Paygate/Model/Authorizenet/Source/PaymentAction.php
index 466bf21..aa77b10 100644
--- a/app/code/core/Mage/Paygate/Model/Authorizenet/Source/PaymentAction.php
+++ b/app/code/core/Mage/Paygate/Model/Authorizenet/Source/PaymentAction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug.php b/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug.php
index 76c0717..b045c6b 100644
--- a/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug.php
+++ b/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug/Collection.php b/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug/Collection.php
index 1153143..80268d4 100644
--- a/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug/Collection.php
+++ b/app/code/core/Mage/Paygate/Model/Mysql4/Authorizenet/Debug/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug.php b/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug.php
index d82dcb7..a1fe9d2 100644
--- a/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug.php
+++ b/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug/Collection.php b/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug/Collection.php
index 8ff3d0a..bc55fbb 100644
--- a/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug/Collection.php
+++ b/app/code/core/Mage/Paygate/Model/Resource/Authorizenet/Debug/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/controllers/Adminhtml/Paygate/Authorizenet/PaymentController.php b/app/code/core/Mage/Paygate/controllers/Adminhtml/Paygate/Authorizenet/PaymentController.php
index cb3bb4e..dd34243 100644
--- a/app/code/core/Mage/Paygate/controllers/Adminhtml/Paygate/Authorizenet/PaymentController.php
+++ b/app/code/core/Mage/Paygate/controllers/Adminhtml/Paygate/Authorizenet/PaymentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/controllers/Authorizenet/PaymentController.php b/app/code/core/Mage/Paygate/controllers/Authorizenet/PaymentController.php
index 7ab3229..1172e30 100644
--- a/app/code/core/Mage/Paygate/controllers/Authorizenet/PaymentController.php
+++ b/app/code/core/Mage/Paygate/controllers/Authorizenet/PaymentController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/etc/config.xml b/app/code/core/Mage/Paygate/etc/config.xml
index f02a7fe..8beee05 100644
--- a/app/code/core/Mage/Paygate/etc/config.xml
+++ b/app/code/core/Mage/Paygate/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paygate/etc/system.xml b/app/code/core/Mage/Paygate/etc/system.xml
index 5e08ac0..f434526 100644
--- a/app/code/core/Mage/Paygate/etc/system.xml
+++ b/app/code/core/Mage/Paygate/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paygate/sql/paygate_setup/install-1.6.0.0.php b/app/code/core/Mage/Paygate/sql/paygate_setup/install-1.6.0.0.php
index 85b66be..920ebcc 100644
--- a/app/code/core/Mage/Paygate/sql/paygate_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Paygate/sql/paygate_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-data-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-data-upgrade-0.7.0-0.7.1.php
index 652f7cb..fd55e17 100644
--- a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-data-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-data-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-install-0.7.0.php
index ee9ce9d..8090f42 100644
--- a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 52d51cb..e786112 100644
--- a/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Paygate/sql/paygate_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paygate
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Catalog/Product/View/Profile.php b/app/code/core/Mage/Payment/Block/Catalog/Product/View/Profile.php
index d2cab4b..7b5fa49 100644
--- a/app/code/core/Mage/Payment/Block/Catalog/Product/View/Profile.php
+++ b/app/code/core/Mage/Payment/Block/Catalog/Product/View/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form.php b/app/code/core/Mage/Payment/Block/Form.php
index 2dbb578..9f64306 100644
--- a/app/code/core/Mage/Payment/Block/Form.php
+++ b/app/code/core/Mage/Payment/Block/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Banktransfer.php b/app/code/core/Mage/Payment/Block/Form/Banktransfer.php
index d0e7bfc..597e731 100644
--- a/app/code/core/Mage/Payment/Block/Form/Banktransfer.php
+++ b/app/code/core/Mage/Payment/Block/Form/Banktransfer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Cashondelivery.php b/app/code/core/Mage/Payment/Block/Form/Cashondelivery.php
index afa9400..aa9d3bd 100644
--- a/app/code/core/Mage/Payment/Block/Form/Cashondelivery.php
+++ b/app/code/core/Mage/Payment/Block/Form/Cashondelivery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Cc.php b/app/code/core/Mage/Payment/Block/Form/Cc.php
index b1a415b..45260df 100644
--- a/app/code/core/Mage/Payment/Block/Form/Cc.php
+++ b/app/code/core/Mage/Payment/Block/Form/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Ccsave.php b/app/code/core/Mage/Payment/Block/Form/Ccsave.php
index 6a3b9c4..8c45131 100644
--- a/app/code/core/Mage/Payment/Block/Form/Ccsave.php
+++ b/app/code/core/Mage/Payment/Block/Form/Ccsave.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Checkmo.php b/app/code/core/Mage/Payment/Block/Form/Checkmo.php
index c181837..9795db8 100644
--- a/app/code/core/Mage/Payment/Block/Form/Checkmo.php
+++ b/app/code/core/Mage/Payment/Block/Form/Checkmo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Container.php b/app/code/core/Mage/Payment/Block/Form/Container.php
index d02c775..e4e7a9a 100644
--- a/app/code/core/Mage/Payment/Block/Form/Container.php
+++ b/app/code/core/Mage/Payment/Block/Form/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Form/Purchaseorder.php b/app/code/core/Mage/Payment/Block/Form/Purchaseorder.php
index ae009b4..61eb309 100644
--- a/app/code/core/Mage/Payment/Block/Form/Purchaseorder.php
+++ b/app/code/core/Mage/Payment/Block/Form/Purchaseorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info.php b/app/code/core/Mage/Payment/Block/Info.php
index 7ac5407..963a13f 100644
--- a/app/code/core/Mage/Payment/Block/Info.php
+++ b/app/code/core/Mage/Payment/Block/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Banktransfer.php b/app/code/core/Mage/Payment/Block/Info/Banktransfer.php
index 7aa8dd6..7a35a42 100644
--- a/app/code/core/Mage/Payment/Block/Info/Banktransfer.php
+++ b/app/code/core/Mage/Payment/Block/Info/Banktransfer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Cc.php b/app/code/core/Mage/Payment/Block/Info/Cc.php
index d787555..a599b4f 100644
--- a/app/code/core/Mage/Payment/Block/Info/Cc.php
+++ b/app/code/core/Mage/Payment/Block/Info/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Ccsave.php b/app/code/core/Mage/Payment/Block/Info/Ccsave.php
index 81e3983..2c712bb 100644
--- a/app/code/core/Mage/Payment/Block/Info/Ccsave.php
+++ b/app/code/core/Mage/Payment/Block/Info/Ccsave.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Checkmo.php b/app/code/core/Mage/Payment/Block/Info/Checkmo.php
index f19df0c..28a713a 100644
--- a/app/code/core/Mage/Payment/Block/Info/Checkmo.php
+++ b/app/code/core/Mage/Payment/Block/Info/Checkmo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Container.php b/app/code/core/Mage/Payment/Block/Info/Container.php
index 8dc6077..6bb2904 100644
--- a/app/code/core/Mage/Payment/Block/Info/Container.php
+++ b/app/code/core/Mage/Payment/Block/Info/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Block/Info/Purchaseorder.php b/app/code/core/Mage/Payment/Block/Info/Purchaseorder.php
index 81b7791..a014019 100644
--- a/app/code/core/Mage/Payment/Block/Info/Purchaseorder.php
+++ b/app/code/core/Mage/Payment/Block/Info/Purchaseorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Exception.php b/app/code/core/Mage/Payment/Exception.php
index d058574..48d2e1e 100644
--- a/app/code/core/Mage/Payment/Exception.php
+++ b/app/code/core/Mage/Payment/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Helper/Data.php b/app/code/core/Mage/Payment/Helper/Data.php
index c2c2ddb..c5aa08f 100644
--- a/app/code/core/Mage/Payment/Helper/Data.php
+++ b/app/code/core/Mage/Payment/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Billing/Agreement/MethodInterface.php b/app/code/core/Mage/Payment/Model/Billing/Agreement/MethodInterface.php
index 9ccaf5e..eaea6e8 100644
--- a/app/code/core/Mage/Payment/Model/Billing/Agreement/MethodInterface.php
+++ b/app/code/core/Mage/Payment/Model/Billing/Agreement/MethodInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Billing/AgreementAbstract.php b/app/code/core/Mage/Payment/Model/Billing/AgreementAbstract.php
index fad535e..4318867 100644
--- a/app/code/core/Mage/Payment/Model/Billing/AgreementAbstract.php
+++ b/app/code/core/Mage/Payment/Model/Billing/AgreementAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Config.php b/app/code/core/Mage/Payment/Model/Config.php
index 29fe233..c4b9ed3 100644
--- a/app/code/core/Mage/Payment/Model/Config.php
+++ b/app/code/core/Mage/Payment/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Info.php b/app/code/core/Mage/Payment/Model/Info.php
index 8148c20..f037277 100644
--- a/app/code/core/Mage/Payment/Model/Info.php
+++ b/app/code/core/Mage/Payment/Model/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Info/Exception.php b/app/code/core/Mage/Payment/Model/Info/Exception.php
index f23ee2f..fa180d3 100644
--- a/app/code/core/Mage/Payment/Model/Info/Exception.php
+++ b/app/code/core/Mage/Payment/Model/Info/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Abstract.php b/app/code/core/Mage/Payment/Model/Method/Abstract.php
index 0feab33..e742405 100644
--- a/app/code/core/Mage/Payment/Model/Method/Abstract.php
+++ b/app/code/core/Mage/Payment/Model/Method/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Banktransfer.php b/app/code/core/Mage/Payment/Model/Method/Banktransfer.php
index f5fdf27..9f00ef2 100644
--- a/app/code/core/Mage/Payment/Model/Method/Banktransfer.php
+++ b/app/code/core/Mage/Payment/Model/Method/Banktransfer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Cashondelivery.php b/app/code/core/Mage/Payment/Model/Method/Cashondelivery.php
index 63cae44..90ec67c 100644
--- a/app/code/core/Mage/Payment/Model/Method/Cashondelivery.php
+++ b/app/code/core/Mage/Payment/Model/Method/Cashondelivery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Cc.php b/app/code/core/Mage/Payment/Model/Method/Cc.php
index 5bf90c8..84dc70c 100644
--- a/app/code/core/Mage/Payment/Model/Method/Cc.php
+++ b/app/code/core/Mage/Payment/Model/Method/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Ccsave.php b/app/code/core/Mage/Payment/Model/Method/Ccsave.php
index 3839696..db2cd70 100644
--- a/app/code/core/Mage/Payment/Model/Method/Ccsave.php
+++ b/app/code/core/Mage/Payment/Model/Method/Ccsave.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Checkmo.php b/app/code/core/Mage/Payment/Model/Method/Checkmo.php
index 87ab4b0..92c4235 100644
--- a/app/code/core/Mage/Payment/Model/Method/Checkmo.php
+++ b/app/code/core/Mage/Payment/Model/Method/Checkmo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Free.php b/app/code/core/Mage/Payment/Model/Method/Free.php
index 83a4f1d..153afec 100644
--- a/app/code/core/Mage/Payment/Model/Method/Free.php
+++ b/app/code/core/Mage/Payment/Model/Method/Free.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Method/Purchaseorder.php b/app/code/core/Mage/Payment/Model/Method/Purchaseorder.php
index 5e4c217..c32d899 100644
--- a/app/code/core/Mage/Payment/Model/Method/Purchaseorder.php
+++ b/app/code/core/Mage/Payment/Model/Method/Purchaseorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Observer.php b/app/code/core/Mage/Payment/Model/Observer.php
index 6439094..9924987 100644
--- a/app/code/core/Mage/Payment/Model/Observer.php
+++ b/app/code/core/Mage/Payment/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Paygate/Request.php b/app/code/core/Mage/Payment/Model/Paygate/Request.php
index 700b49d..8f4c5c5 100644
--- a/app/code/core/Mage/Payment/Model/Paygate/Request.php
+++ b/app/code/core/Mage/Payment/Model/Paygate/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Paygate/Result.php b/app/code/core/Mage/Payment/Model/Paygate/Result.php
index bc3e116..31d2164 100644
--- a/app/code/core/Mage/Payment/Model/Paygate/Result.php
+++ b/app/code/core/Mage/Payment/Model/Paygate/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Recurring/Profile.php b/app/code/core/Mage/Payment/Model/Recurring/Profile.php
index 5734860..1903424 100644
--- a/app/code/core/Mage/Payment/Model/Recurring/Profile.php
+++ b/app/code/core/Mage/Payment/Model/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Recurring/Profile/MethodInterface.php b/app/code/core/Mage/Payment/Model/Recurring/Profile/MethodInterface.php
index e881279..3ddc200 100644
--- a/app/code/core/Mage/Payment/Model/Recurring/Profile/MethodInterface.php
+++ b/app/code/core/Mage/Payment/Model/Recurring/Profile/MethodInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Source/Cctype.php b/app/code/core/Mage/Payment/Model/Source/Cctype.php
index 792183f..52495e0 100644
--- a/app/code/core/Mage/Payment/Model/Source/Cctype.php
+++ b/app/code/core/Mage/Payment/Model/Source/Cctype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/Model/Source/Invoice.php b/app/code/core/Mage/Payment/Model/Source/Invoice.php
index 0409c58..7985c5e 100644
--- a/app/code/core/Mage/Payment/Model/Source/Invoice.php
+++ b/app/code/core/Mage/Payment/Model/Source/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Payment/etc/adminhtml.xml b/app/code/core/Mage/Payment/etc/adminhtml.xml
index ab81230..90384e7 100644
--- a/app/code/core/Mage/Payment/etc/adminhtml.xml
+++ b/app/code/core/Mage/Payment/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Payment/etc/config.xml b/app/code/core/Mage/Payment/etc/config.xml
index 18eca28..f960ddc 100644
--- a/app/code/core/Mage/Payment/etc/config.xml
+++ b/app/code/core/Mage/Payment/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Payment/etc/system.xml b/app/code/core/Mage/Payment/etc/system.xml
index 101bae7..f4651b3 100644
--- a/app/code/core/Mage/Payment/etc/system.xml
+++ b/app/code/core/Mage/Payment/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Payment/sql/payment_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Payment/sql/payment_setup/upgrade-1.6.0.0-1.6.0.1.php
index 37eaac6..ecf327b 100644
--- a/app/code/core/Mage/Payment/sql/payment_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Payment/sql/payment_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Payment
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details.php b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details.php
index 33f39a2..7ff18aa 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details/Form.php b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details/Form.php
index 858f02b..5ecccab 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Details/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report.php b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report.php
index 90fca13..c50a41b 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report/Grid.php b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report/Grid.php
index 1866214..90a291f 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report/Grid.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/Settlement/Report/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/ApiWizard.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/ApiWizard.php
index 2f1ca6e..deabd33 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/ApiWizard.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/ApiWizard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/BmlApiWizard.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/BmlApiWizard.php
index fa12d46..bceafac 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/BmlApiWizard.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/BmlApiWizard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Country.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Country.php
index 3982b8b..103f0bd 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Country.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Hidden.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Hidden.php
index 487ae76..7bf50d3 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Hidden.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/Hidden.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/SolutionType.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/SolutionType.php
index effe326..8d02dcf 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/SolutionType.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Field/SolutionType.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Deprecated.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Deprecated.php
index 7151bd3..c8089e6 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Deprecated.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Deprecated.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Expanded.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Expanded.php
index ff92199..2eedfa0 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Expanded.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Expanded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Global.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Global.php
index 50e1d87..3ac517b 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Global.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Global.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Group.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Group.php
index cd509d7..e5a5c76 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Group.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Group.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Hint.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Hint.php
index f62faf8..70abdad 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Hint.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Hint.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Location.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Location.php
index 96617d9..04afc8f 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Location.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Location.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/PathDependent.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/PathDependent.php
index b3fbb32..b25dbe5 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/PathDependent.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/PathDependent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Payment.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Payment.php
index 3b6f9fd..363b523 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Payment.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Store.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Store.php
index 1b7c761..f26f48a 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Store.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Fieldset/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Advanced.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Advanced.php
index 80728bd..2ba5099 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Advanced.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Advanced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Info.php b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Info.php
index 3afa261..1bf87ef 100644
--- a/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Info.php
+++ b/app/code/core/Mage/Paypal/Block/Adminhtml/System/Config/Payflowlink/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Bml/Banners.php b/app/code/core/Mage/Paypal/Block/Bml/Banners.php
index 35cb2d7..f5934d8 100644
--- a/app/code/core/Mage/Paypal/Block/Bml/Banners.php
+++ b/app/code/core/Mage/Paypal/Block/Bml/Banners.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Bml/Form.php b/app/code/core/Mage/Paypal/Block/Bml/Form.php
index 5692356..8ed570c 100644
--- a/app/code/core/Mage/Paypal/Block/Bml/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Bml/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Form.php b/app/code/core/Mage/Paypal/Block/Express/Form.php
index 1d422b2..d64dfbb 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Review.php b/app/code/core/Mage/Paypal/Block/Express/Review.php
index 1eabe2f..3fbee5c 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Review.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Review/Billing.php b/app/code/core/Mage/Paypal/Block/Express/Review/Billing.php
index 0c510a3..0456ba5 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Review/Billing.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Review/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Review/Details.php b/app/code/core/Mage/Paypal/Block/Express/Review/Details.php
index 9afbaf1..16acb2f 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Review/Details.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Review/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Review/Shipping.php b/app/code/core/Mage/Paypal/Block/Express/Review/Shipping.php
index 731d535..28dd8e6 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Review/Shipping.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Review/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Express/Shortcut.php b/app/code/core/Mage/Paypal/Block/Express/Shortcut.php
index b81a3f6..af567ce 100644
--- a/app/code/core/Mage/Paypal/Block/Express/Shortcut.php
+++ b/app/code/core/Mage/Paypal/Block/Express/Shortcut.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Form.php b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Form.php
index 6ddf75f..a6dee97 100644
--- a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Iframe.php b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Iframe.php
index 4c6847b..1d0ae1f 100644
--- a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Iframe.php
+++ b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Iframe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Info.php b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Info.php
index 9e5181a..caefdd4 100644
--- a/app/code/core/Mage/Paypal/Block/Hosted/Pro/Info.php
+++ b/app/code/core/Mage/Paypal/Block/Hosted/Pro/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Iframe.php b/app/code/core/Mage/Paypal/Block/Iframe.php
index 62b32af..b67a47f 100644
--- a/app/code/core/Mage/Paypal/Block/Iframe.php
+++ b/app/code/core/Mage/Paypal/Block/Iframe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Logo.php b/app/code/core/Mage/Paypal/Block/Logo.php
index 7764c03..5927dbf 100644
--- a/app/code/core/Mage/Paypal/Block/Logo.php
+++ b/app/code/core/Mage/Paypal/Block/Logo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Form.php b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Form.php
index 5464b85..8a8f1ed 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Iframe.php b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Iframe.php
index b7eec5b..688131e 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Iframe.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Iframe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Info.php b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Info.php
index 5226654..f3490bb 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Info.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Review.php b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Review.php
index 2b18b24..b22ed18 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Review.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Advanced/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Link/Form.php b/app/code/core/Mage/Paypal/Block/Payflow/Link/Form.php
index f13c8bb..c24ee2c 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Link/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Link/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Link/Iframe.php b/app/code/core/Mage/Paypal/Block/Payflow/Link/Iframe.php
index e19ecbb..213d8e0 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Link/Iframe.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Link/Iframe.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Link/Info.php b/app/code/core/Mage/Paypal/Block/Payflow/Link/Info.php
index 630e12f..f1f2576 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Link/Info.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Link/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payflow/Link/Review.php b/app/code/core/Mage/Paypal/Block/Payflow/Link/Review.php
index 6efd4cd..c5ea208 100644
--- a/app/code/core/Mage/Paypal/Block/Payflow/Link/Review.php
+++ b/app/code/core/Mage/Paypal/Block/Payflow/Link/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Payment/Info.php b/app/code/core/Mage/Paypal/Block/Payment/Info.php
index eb29c8d..225e4fd 100644
--- a/app/code/core/Mage/Paypal/Block/Payment/Info.php
+++ b/app/code/core/Mage/Paypal/Block/Payment/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Standard/Form.php b/app/code/core/Mage/Paypal/Block/Standard/Form.php
index 2c6cc7f..123343f 100644
--- a/app/code/core/Mage/Paypal/Block/Standard/Form.php
+++ b/app/code/core/Mage/Paypal/Block/Standard/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Block/Standard/Redirect.php b/app/code/core/Mage/Paypal/Block/Standard/Redirect.php
index 3c9a1bd..f936364 100644
--- a/app/code/core/Mage/Paypal/Block/Standard/Redirect.php
+++ b/app/code/core/Mage/Paypal/Block/Standard/Redirect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Paypal_Block_Standard_Redirect extends Mage_Core_Block_Abstract
diff --git a/app/code/core/Mage/Paypal/Controller/Express/Abstract.php b/app/code/core/Mage/Paypal/Controller/Express/Abstract.php
index 920271e..8632eaf 100644
--- a/app/code/core/Mage/Paypal/Controller/Express/Abstract.php
+++ b/app/code/core/Mage/Paypal/Controller/Express/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Exception.php b/app/code/core/Mage/Paypal/Exception.php
index 2715b3c..2d859ac 100644
--- a/app/code/core/Mage/Paypal/Exception.php
+++ b/app/code/core/Mage/Paypal/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Helper/Checkout.php b/app/code/core/Mage/Paypal/Helper/Checkout.php
index d2a9d45..19eee4f 100644
--- a/app/code/core/Mage/Paypal/Helper/Checkout.php
+++ b/app/code/core/Mage/Paypal/Helper/Checkout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Helper/Data.php b/app/code/core/Mage/Paypal/Helper/Data.php
index 420a61b..74be47a 100644
--- a/app/code/core/Mage/Paypal/Helper/Data.php
+++ b/app/code/core/Mage/Paypal/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Helper/Hss.php b/app/code/core/Mage/Paypal/Helper/Hss.php
index 27feada..6f66c8e 100644
--- a/app/code/core/Mage/Paypal/Helper/Hss.php
+++ b/app/code/core/Mage/Paypal/Helper/Hss.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Api/Abstract.php b/app/code/core/Mage/Paypal/Model/Api/Abstract.php
index 4f9ed47..da5dafc 100644
--- a/app/code/core/Mage/Paypal/Model/Api/Abstract.php
+++ b/app/code/core/Mage/Paypal/Model/Api/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Api/Nvp.php b/app/code/core/Mage/Paypal/Model/Api/Nvp.php
index 75488ca..eda4fe4 100644
--- a/app/code/core/Mage/Paypal/Model/Api/Nvp.php
+++ b/app/code/core/Mage/Paypal/Model/Api/Nvp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Api/ProcessableException.php b/app/code/core/Mage/Paypal/Model/Api/ProcessableException.php
index e0b3147..4fdea9c 100644
--- a/app/code/core/Mage/Paypal/Model/Api/ProcessableException.php
+++ b/app/code/core/Mage/Paypal/Model/Api/ProcessableException.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Api/Standard.php b/app/code/core/Mage/Paypal/Model/Api/Standard.php
index eefe161..a0f257e 100644
--- a/app/code/core/Mage/Paypal/Model/Api/Standard.php
+++ b/app/code/core/Mage/Paypal/Model/Api/Standard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Bml.php b/app/code/core/Mage/Paypal/Model/Bml.php
index d7b390d..d640b5b 100644
--- a/app/code/core/Mage/Paypal/Model/Bml.php
+++ b/app/code/core/Mage/Paypal/Model/Bml.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Cart.php b/app/code/core/Mage/Paypal/Model/Cart.php
index e28fa59..d6b6eed 100644
--- a/app/code/core/Mage/Paypal/Model/Cart.php
+++ b/app/code/core/Mage/Paypal/Model/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Cert.php b/app/code/core/Mage/Paypal/Model/Cert.php
index e3607c3..cbba2e0 100644
--- a/app/code/core/Mage/Paypal/Model/Cert.php
+++ b/app/code/core/Mage/Paypal/Model/Cert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Config.php b/app/code/core/Mage/Paypal/Model/Config.php
index e098d07..7ae8ae7 100644
--- a/app/code/core/Mage/Paypal/Model/Config.php
+++ b/app/code/core/Mage/Paypal/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Direct.php b/app/code/core/Mage/Paypal/Model/Direct.php
index 7a1d5b5..f502422 100644
--- a/app/code/core/Mage/Paypal/Model/Direct.php
+++ b/app/code/core/Mage/Paypal/Model/Direct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Express.php b/app/code/core/Mage/Paypal/Model/Express.php
index c957f31..7f6ec59 100644
--- a/app/code/core/Mage/Paypal/Model/Express.php
+++ b/app/code/core/Mage/Paypal/Model/Express.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Express/Checkout.php b/app/code/core/Mage/Paypal/Model/Express/Checkout.php
index aadff02..fed50f7 100644
--- a/app/code/core/Mage/Paypal/Model/Express/Checkout.php
+++ b/app/code/core/Mage/Paypal/Model/Express/Checkout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Hostedpro.php b/app/code/core/Mage/Paypal/Model/Hostedpro.php
index 3760ba7..8735c79 100644
--- a/app/code/core/Mage/Paypal/Model/Hostedpro.php
+++ b/app/code/core/Mage/Paypal/Model/Hostedpro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Hostedpro/Request.php b/app/code/core/Mage/Paypal/Model/Hostedpro/Request.php
index 518614e..bd0c1d6 100644
--- a/app/code/core/Mage/Paypal/Model/Hostedpro/Request.php
+++ b/app/code/core/Mage/Paypal/Model/Hostedpro/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Info.php b/app/code/core/Mage/Paypal/Model/Info.php
index 1d02878..e69a619 100644
--- a/app/code/core/Mage/Paypal/Model/Info.php
+++ b/app/code/core/Mage/Paypal/Model/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Ipn.php b/app/code/core/Mage/Paypal/Model/Ipn.php
index 6c77ca2..291adf7 100644
--- a/app/code/core/Mage/Paypal/Model/Ipn.php
+++ b/app/code/core/Mage/Paypal/Model/Ipn.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Method/Agreement.php b/app/code/core/Mage/Paypal/Model/Method/Agreement.php
index b70367e..89bc0dd 100644
--- a/app/code/core/Mage/Paypal/Model/Method/Agreement.php
+++ b/app/code/core/Mage/Paypal/Model/Method/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Mysql4/Cert.php b/app/code/core/Mage/Paypal/Model/Mysql4/Cert.php
index 17cae92..4e709f9 100644
--- a/app/code/core/Mage/Paypal/Model/Mysql4/Cert.php
+++ b/app/code/core/Mage/Paypal/Model/Mysql4/Cert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement.php b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement.php
index 851896f..9409b7f 100644
--- a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement.php
+++ b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row.php b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row.php
index bc73c40..8647061 100644
--- a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row.php
+++ b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row/Collection.php b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row/Collection.php
index f1bbd60..b44fef2 100644
--- a/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row/Collection.php
+++ b/app/code/core/Mage/Paypal/Model/Mysql4/Report/Settlement/Row/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Mysql4/Setup.php b/app/code/core/Mage/Paypal/Model/Mysql4/Setup.php
index 8a3cf18..8be99a6 100644
--- a/app/code/core/Mage/Paypal/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Paypal/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Observer.php b/app/code/core/Mage/Paypal/Model/Observer.php
index 499e5a6..1495d56 100644
--- a/app/code/core/Mage/Paypal/Model/Observer.php
+++ b/app/code/core/Mage/Paypal/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Payflow/Request.php b/app/code/core/Mage/Paypal/Model/Payflow/Request.php
index 41113c1..ddeadb3 100644
--- a/app/code/core/Mage/Paypal/Model/Payflow/Request.php
+++ b/app/code/core/Mage/Paypal/Model/Payflow/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Payflowadvanced.php b/app/code/core/Mage/Paypal/Model/Payflowadvanced.php
index a0e947c..e5bfc5f 100644
--- a/app/code/core/Mage/Paypal/Model/Payflowadvanced.php
+++ b/app/code/core/Mage/Paypal/Model/Payflowadvanced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Payflowlink.php b/app/code/core/Mage/Paypal/Model/Payflowlink.php
index 1cfb57b..6d94ebb 100644
--- a/app/code/core/Mage/Paypal/Model/Payflowlink.php
+++ b/app/code/core/Mage/Paypal/Model/Payflowlink.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Payflowpro.php b/app/code/core/Mage/Paypal/Model/Payflowpro.php
index ff962b3..cd259ca 100644
--- a/app/code/core/Mage/Paypal/Model/Payflowpro.php
+++ b/app/code/core/Mage/Paypal/Model/Payflowpro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Payment/Transaction.php b/app/code/core/Mage/Paypal/Model/Payment/Transaction.php
index c16957c..a072d95 100644
--- a/app/code/core/Mage/Paypal/Model/Payment/Transaction.php
+++ b/app/code/core/Mage/Paypal/Model/Payment/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Pro.php b/app/code/core/Mage/Paypal/Model/Pro.php
index be43b5c..6f421e0 100644
--- a/app/code/core/Mage/Paypal/Model/Pro.php
+++ b/app/code/core/Mage/Paypal/Model/Pro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Report/Settlement.php b/app/code/core/Mage/Paypal/Model/Report/Settlement.php
index e4053eb..55b50be 100644
--- a/app/code/core/Mage/Paypal/Model/Report/Settlement.php
+++ b/app/code/core/Mage/Paypal/Model/Report/Settlement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Report/Settlement/Row.php b/app/code/core/Mage/Paypal/Model/Report/Settlement/Row.php
index b1f3138..449ba2e 100644
--- a/app/code/core/Mage/Paypal/Model/Report/Settlement/Row.php
+++ b/app/code/core/Mage/Paypal/Model/Report/Settlement/Row.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Cert.php b/app/code/core/Mage/Paypal/Model/Resource/Cert.php
index 7603bf7..bca09c4 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Cert.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Cert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction.php b/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction.php
index ddede5e..86433d8 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction/Collection.php b/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction/Collection.php
index 6cdcc18..7feb561 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction/Collection.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Payment/Transaction/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement.php b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement.php
index 898490f..faf335f 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row.php b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row.php
index 0ca4736..b6e070d 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row/Collection.php b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row/Collection.php
index 53b4f16..0605fd4 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row/Collection.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Report/Settlement/Row/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Resource/Setup.php b/app/code/core/Mage/Paypal/Model/Resource/Setup.php
index d00dd8f..009f3a7 100644
--- a/app/code/core/Mage/Paypal/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Paypal/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Session.php b/app/code/core/Mage/Paypal/Model/Session.php
index 927144a..526c7a1 100644
--- a/app/code/core/Mage/Paypal/Model/Session.php
+++ b/app/code/core/Mage/Paypal/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/Standard.php b/app/code/core/Mage/Paypal/Model/Standard.php
index 8698874..826df2d 100644
--- a/app/code/core/Mage/Paypal/Model/Standard.php
+++ b/app/code/core/Mage/Paypal/Model/Standard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cert.php b/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cert.php
index 089f454..1f73370 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cert.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cert.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cron.php b/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cron.php
index 2526ae2..62e5231 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cron.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Backend/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Backend/MerchantCountry.php b/app/code/core/Mage/Paypal/Model/System/Config/Backend/MerchantCountry.php
index 4c07122..1826bb9 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Backend/MerchantCountry.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Backend/MerchantCountry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/AuthorizationAmounts.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/AuthorizationAmounts.php
index 2452652..031d5e1 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/AuthorizationAmounts.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/AuthorizationAmounts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlPosition.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlPosition.php
index dd48472..946ef95 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlPosition.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlPosition.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlSize.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlSize.php
index 4ff4349..b19774c 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlSize.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/BmlSize.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/BuyerCountry.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/BuyerCountry.php
index afea4f6..2f9d344 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/BuyerCountry.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/BuyerCountry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/FetchingSchedule.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/FetchingSchedule.php
index f840191..83c39f7 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/FetchingSchedule.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/FetchingSchedule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/Logo.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/Logo.php
index 1af3902..cf88fd9 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/Logo.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/Logo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/MerchantCountry.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/MerchantCountry.php
index efdd807..6b295fe 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/MerchantCountry.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/MerchantCountry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions.php
index 0e35d65..0ab4d75 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions/Express.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions/Express.php
index f6509ed..a1d4ad0 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions/Express.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/PaymentActions/Express.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/RequireBillingAddress.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/RequireBillingAddress.php
index da2f710..d93fff3 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/RequireBillingAddress.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/RequireBillingAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/UrlMethod.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/UrlMethod.php
index 7ee4c63..53261d8 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/UrlMethod.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/UrlMethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/Model/System/Config/Source/YesnoShortcut.php b/app/code/core/Mage/Paypal/Model/System/Config/Source/YesnoShortcut.php
index bab23af..1feddf1 100644
--- a/app/code/core/Mage/Paypal/Model/System/Config/Source/YesnoShortcut.php
+++ b/app/code/core/Mage/Paypal/Model/System/Config/Source/YesnoShortcut.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/UnavailableException.php b/app/code/core/Mage/Paypal/UnavailableException.php
index a4ca58a..3696c86 100644
--- a/app/code/core/Mage/Paypal/UnavailableException.php
+++ b/app/code/core/Mage/Paypal/UnavailableException.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/Adminhtml/Paypal/ReportsController.php b/app/code/core/Mage/Paypal/controllers/Adminhtml/Paypal/ReportsController.php
index 600a82b..62b772d 100644
--- a/app/code/core/Mage/Paypal/controllers/Adminhtml/Paypal/ReportsController.php
+++ b/app/code/core/Mage/Paypal/controllers/Adminhtml/Paypal/ReportsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/BmlController.php b/app/code/core/Mage/Paypal/controllers/BmlController.php
index 7aa11f0..98f60f2 100644
--- a/app/code/core/Mage/Paypal/controllers/BmlController.php
+++ b/app/code/core/Mage/Paypal/controllers/BmlController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/ExpressController.php b/app/code/core/Mage/Paypal/controllers/ExpressController.php
index f013573..0f30d7b 100644
--- a/app/code/core/Mage/Paypal/controllers/ExpressController.php
+++ b/app/code/core/Mage/Paypal/controllers/ExpressController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/HostedproController.php b/app/code/core/Mage/Paypal/controllers/HostedproController.php
index 0ab6bf8..bbf9f28 100644
--- a/app/code/core/Mage/Paypal/controllers/HostedproController.php
+++ b/app/code/core/Mage/Paypal/controllers/HostedproController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/IpnController.php b/app/code/core/Mage/Paypal/controllers/IpnController.php
index 4a95b7d..7be7a0a 100644
--- a/app/code/core/Mage/Paypal/controllers/IpnController.php
+++ b/app/code/core/Mage/Paypal/controllers/IpnController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/PayflowController.php b/app/code/core/Mage/Paypal/controllers/PayflowController.php
index 7d82233..6137dcb 100644
--- a/app/code/core/Mage/Paypal/controllers/PayflowController.php
+++ b/app/code/core/Mage/Paypal/controllers/PayflowController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/PayflowadvancedController.php b/app/code/core/Mage/Paypal/controllers/PayflowadvancedController.php
index caadfcb..ecf0716 100644
--- a/app/code/core/Mage/Paypal/controllers/PayflowadvancedController.php
+++ b/app/code/core/Mage/Paypal/controllers/PayflowadvancedController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/controllers/StandardController.php b/app/code/core/Mage/Paypal/controllers/StandardController.php
index e87467a..0c61775 100644
--- a/app/code/core/Mage/Paypal/controllers/StandardController.php
+++ b/app/code/core/Mage/Paypal/controllers/StandardController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/data/paypal_setup/data-install-1.6.0.5.php b/app/code/core/Mage/Paypal/data/paypal_setup/data-install-1.6.0.5.php
index 5def52d..4ee9437 100644
--- a/app/code/core/Mage/Paypal/data/paypal_setup/data-install-1.6.0.5.php
+++ b/app/code/core/Mage/Paypal/data/paypal_setup/data-install-1.6.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.2-1.6.0.3.php
index 701db95..ce9036a 100644
--- a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.4-1.6.0.5.php b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.4-1.6.0.5.php
index 47c7004..2b3764c 100644
--- a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.4-1.6.0.5.php
+++ b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.4-1.6.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.5-1.6.0.6.php b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.5-1.6.0.6.php
index d9110c7..4db064c 100644
--- a/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.5-1.6.0.6.php
+++ b/app/code/core/Mage/Paypal/data/paypal_setup/data-upgrade-1.6.0.5-1.6.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/etc/adminhtml.xml b/app/code/core/Mage/Paypal/etc/adminhtml.xml
index 92cd97d..f911687 100644
--- a/app/code/core/Mage/Paypal/etc/adminhtml.xml
+++ b/app/code/core/Mage/Paypal/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paypal/etc/config.xml b/app/code/core/Mage/Paypal/etc/config.xml
index b1a1499..50b2f26 100644
--- a/app/code/core/Mage/Paypal/etc/config.xml
+++ b/app/code/core/Mage/Paypal/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paypal/etc/system.xml b/app/code/core/Mage/Paypal/etc/system.xml
index 1fd9547..c4505a8 100644
--- a/app/code/core/Mage/Paypal/etc/system.xml
+++ b/app/code/core/Mage/Paypal/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/install-1.6.0.0.php b/app/code/core/Mage/Paypal/sql/paypal_setup/install-1.6.0.0.php
index 5fa72f7..e8b565a 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-0.7.0.php
index e5f91a8..fd188cc 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-1.4.0.0.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-1.4.0.0.php
index 44ba846..5380ec6 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-1.4.0.0.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-install-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.1-0.7.2.php
index ca07b79..1d504cb 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 1ccb001..c2af171 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
index 72b0845..ba49251 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
index 0932443..ff84dbc 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 5a4c5ab..f2e56b4 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.0-1.6.0.1.php
index 709856a..24d2d2c 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.1-1.6.0.2.php
index b5019d8..50f6af5 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.3-1.6.0.4.php b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.3-1.6.0.4.php
index 0764aac..531e2c7 100644
--- a/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.3-1.6.0.4.php
+++ b/app/code/core/Mage/Paypal/sql/paypal_setup/upgrade-1.6.0.3-1.6.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Paypal
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Block/Bml/Form.php b/app/code/core/Mage/PaypalUk/Block/Bml/Form.php
index 7ac3ec3..0c90ab9 100644
--- a/app/code/core/Mage/PaypalUk/Block/Bml/Form.php
+++ b/app/code/core/Mage/PaypalUk/Block/Bml/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Block/Express/Form.php b/app/code/core/Mage/PaypalUk/Block/Express/Form.php
index 322380f..53aa202 100644
--- a/app/code/core/Mage/PaypalUk/Block/Express/Form.php
+++ b/app/code/core/Mage/PaypalUk/Block/Express/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Block/Express/Shortcut.php b/app/code/core/Mage/PaypalUk/Block/Express/Shortcut.php
index 3142934..b962aaf 100644
--- a/app/code/core/Mage/PaypalUk/Block/Express/Shortcut.php
+++ b/app/code/core/Mage/PaypalUk/Block/Express/Shortcut.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Helper/Data.php b/app/code/core/Mage/PaypalUk/Helper/Data.php
index 3f59ffa..8081292 100644
--- a/app/code/core/Mage/PaypalUk/Helper/Data.php
+++ b/app/code/core/Mage/PaypalUk/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Api/Express/Nvp.php b/app/code/core/Mage/PaypalUk/Model/Api/Express/Nvp.php
index 1f2d02a..963a267 100644
--- a/app/code/core/Mage/PaypalUk/Model/Api/Express/Nvp.php
+++ b/app/code/core/Mage/PaypalUk/Model/Api/Express/Nvp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Api/Nvp.php b/app/code/core/Mage/PaypalUk/Model/Api/Nvp.php
index 9614ff8..ea59322 100644
--- a/app/code/core/Mage/PaypalUk/Model/Api/Nvp.php
+++ b/app/code/core/Mage/PaypalUk/Model/Api/Nvp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Bml.php b/app/code/core/Mage/PaypalUk/Model/Bml.php
index 93b51f5..a3a2069 100644
--- a/app/code/core/Mage/PaypalUk/Model/Bml.php
+++ b/app/code/core/Mage/PaypalUk/Model/Bml.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Direct.php b/app/code/core/Mage/PaypalUk/Model/Direct.php
index 5202927..d36455f 100644
--- a/app/code/core/Mage/PaypalUk/Model/Direct.php
+++ b/app/code/core/Mage/PaypalUk/Model/Direct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Express.php b/app/code/core/Mage/PaypalUk/Model/Express.php
index 96e9aaa..b354b71 100644
--- a/app/code/core/Mage/PaypalUk/Model/Express.php
+++ b/app/code/core/Mage/PaypalUk/Model/Express.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Express/Checkout.php b/app/code/core/Mage/PaypalUk/Model/Express/Checkout.php
index aa7de18..f03acbe 100644
--- a/app/code/core/Mage/PaypalUk/Model/Express/Checkout.php
+++ b/app/code/core/Mage/PaypalUk/Model/Express/Checkout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Express/Pro.php b/app/code/core/Mage/PaypalUk/Model/Express/Pro.php
index 249f362..f45313d 100644
--- a/app/code/core/Mage/PaypalUk/Model/Express/Pro.php
+++ b/app/code/core/Mage/PaypalUk/Model/Express/Pro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Pro.php b/app/code/core/Mage/PaypalUk/Model/Pro.php
index ba86db9..913afc6 100644
--- a/app/code/core/Mage/PaypalUk/Model/Pro.php
+++ b/app/code/core/Mage/PaypalUk/Model/Pro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/Model/Session.php b/app/code/core/Mage/PaypalUk/Model/Session.php
index 5ddff91..c4bc066 100644
--- a/app/code/core/Mage/PaypalUk/Model/Session.php
+++ b/app/code/core/Mage/PaypalUk/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/controllers/BmlController.php b/app/code/core/Mage/PaypalUk/controllers/BmlController.php
index 0372b14..3dc0124 100644
--- a/app/code/core/Mage/PaypalUk/controllers/BmlController.php
+++ b/app/code/core/Mage/PaypalUk/controllers/BmlController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/controllers/ExpressController.php b/app/code/core/Mage/PaypalUk/controllers/ExpressController.php
index 90ab08c..fddc302 100644
--- a/app/code/core/Mage/PaypalUk/controllers/ExpressController.php
+++ b/app/code/core/Mage/PaypalUk/controllers/ExpressController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/etc/config.xml b/app/code/core/Mage/PaypalUk/etc/config.xml
index 3ac5416..5efda6a 100644
--- a/app/code/core/Mage/PaypalUk/etc/config.xml
+++ b/app/code/core/Mage/PaypalUk/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/install-1.6.0.0.php b/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/install-1.6.0.0.php
index bee3e17..80d9ab5 100644
--- a/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/mysql4-install-0.7.0.php
index 899d673..e6747fd 100644
--- a/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/PaypalUk/sql/paypaluk_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_PaypalUk
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Block/Form/Remember.php b/app/code/core/Mage/Persistent/Block/Form/Remember.php
index a88a8f9..175ba75 100644
--- a/app/code/core/Mage/Persistent/Block/Form/Remember.php
+++ b/app/code/core/Mage/Persistent/Block/Form/Remember.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Block/Header/Additional.php b/app/code/core/Mage/Persistent/Block/Header/Additional.php
index ba3208f..211c6be 100644
--- a/app/code/core/Mage/Persistent/Block/Header/Additional.php
+++ b/app/code/core/Mage/Persistent/Block/Header/Additional.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Helper/Data.php b/app/code/core/Mage/Persistent/Helper/Data.php
index 56773a7..cb14857 100644
--- a/app/code/core/Mage/Persistent/Helper/Data.php
+++ b/app/code/core/Mage/Persistent/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Helper/Session.php b/app/code/core/Mage/Persistent/Helper/Session.php
index 505ea61..468f38f 100644
--- a/app/code/core/Mage/Persistent/Helper/Session.php
+++ b/app/code/core/Mage/Persistent/Helper/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Model/Observer.php b/app/code/core/Mage/Persistent/Model/Observer.php
index 0933a17..114e394 100644
--- a/app/code/core/Mage/Persistent/Model/Observer.php
+++ b/app/code/core/Mage/Persistent/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Model/Observer/Session.php b/app/code/core/Mage/Persistent/Model/Observer/Session.php
index ab5dbba..2b032cb 100644
--- a/app/code/core/Mage/Persistent/Model/Observer/Session.php
+++ b/app/code/core/Mage/Persistent/Model/Observer/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Model/Persistent/Config.php b/app/code/core/Mage/Persistent/Model/Persistent/Config.php
index b613613..dac3661 100644
--- a/app/code/core/Mage/Persistent/Model/Persistent/Config.php
+++ b/app/code/core/Mage/Persistent/Model/Persistent/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Model/Resource/Session.php b/app/code/core/Mage/Persistent/Model/Resource/Session.php
index eabccc7..e7c67e1 100644
--- a/app/code/core/Mage/Persistent/Model/Resource/Session.php
+++ b/app/code/core/Mage/Persistent/Model/Resource/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/Model/Session.php b/app/code/core/Mage/Persistent/Model/Session.php
index 3ca51bf..73f9f12 100644
--- a/app/code/core/Mage/Persistent/Model/Session.php
+++ b/app/code/core/Mage/Persistent/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/controllers/IndexController.php b/app/code/core/Mage/Persistent/controllers/IndexController.php
index dd1aac5..f4b1db9 100644
--- a/app/code/core/Mage/Persistent/controllers/IndexController.php
+++ b/app/code/core/Mage/Persistent/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Persistent/etc/adminhtml.xml b/app/code/core/Mage/Persistent/etc/adminhtml.xml
index 6728261..992310c 100644
--- a/app/code/core/Mage/Persistent/etc/adminhtml.xml
+++ b/app/code/core/Mage/Persistent/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Persistent/etc/config.xml b/app/code/core/Mage/Persistent/etc/config.xml
index d08ba7c..7eacba3 100644
--- a/app/code/core/Mage/Persistent/etc/config.xml
+++ b/app/code/core/Mage/Persistent/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Persistent/etc/persistent.xml b/app/code/core/Mage/Persistent/etc/persistent.xml
index caba1f5..74ebaf3 100644
--- a/app/code/core/Mage/Persistent/etc/persistent.xml
+++ b/app/code/core/Mage/Persistent/etc/persistent.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Persistent/etc/system.xml b/app/code/core/Mage/Persistent/etc/system.xml
index 59ff8dd..5f87dda 100644
--- a/app/code/core/Mage/Persistent/etc/system.xml
+++ b/app/code/core/Mage/Persistent/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Persistent/sql/persistent_setup/install-1.0.0.0.php b/app/code/core/Mage/Persistent/sql/persistent_setup/install-1.0.0.0.php
index ff24b0e..8e5660d 100644
--- a/app/code/core/Mage/Persistent/sql/persistent_setup/install-1.0.0.0.php
+++ b/app/code/core/Mage/Persistent/sql/persistent_setup/install-1.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Block/ActivePoll.php b/app/code/core/Mage/Poll/Block/ActivePoll.php
index 5473c3d..19ff05b 100644
--- a/app/code/core/Mage/Poll/Block/ActivePoll.php
+++ b/app/code/core/Mage/Poll/Block/ActivePoll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Block/Poll.php b/app/code/core/Mage/Poll/Block/Poll.php
index bbec7c8..bd9768f 100644
--- a/app/code/core/Mage/Poll/Block/Poll.php
+++ b/app/code/core/Mage/Poll/Block/Poll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Helper/Data.php b/app/code/core/Mage/Poll/Helper/Data.php
index a724a60..803957b 100644
--- a/app/code/core/Mage/Poll/Helper/Data.php
+++ b/app/code/core/Mage/Poll/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Mysql4/Poll.php b/app/code/core/Mage/Poll/Model/Mysql4/Poll.php
index 121c136..f569862 100644
--- a/app/code/core/Mage/Poll/Model/Mysql4/Poll.php
+++ b/app/code/core/Mage/Poll/Model/Mysql4/Poll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer.php b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer.php
index cce5fa9..3e36b3c 100644
--- a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer.php
+++ b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer/Collection.php b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer/Collection.php
index c1ad647..4f5cbf3 100644
--- a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer/Collection.php
+++ b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Answer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Collection.php b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Collection.php
index d2818a0..70b7eb6 100644
--- a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Collection.php
+++ b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Vote.php b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Vote.php
index ee6b01a..8505379 100644
--- a/app/code/core/Mage/Poll/Model/Mysql4/Poll/Vote.php
+++ b/app/code/core/Mage/Poll/Model/Mysql4/Poll/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Poll.php b/app/code/core/Mage/Poll/Model/Poll.php
index 8e79bf6..edaf0de 100644
--- a/app/code/core/Mage/Poll/Model/Poll.php
+++ b/app/code/core/Mage/Poll/Model/Poll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Poll/Answer.php b/app/code/core/Mage/Poll/Model/Poll/Answer.php
index f53fef8..25e15f9 100644
--- a/app/code/core/Mage/Poll/Model/Poll/Answer.php
+++ b/app/code/core/Mage/Poll/Model/Poll/Answer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Poll/Vote.php b/app/code/core/Mage/Poll/Model/Poll/Vote.php
index f026a16..f09a198 100644
--- a/app/code/core/Mage/Poll/Model/Poll/Vote.php
+++ b/app/code/core/Mage/Poll/Model/Poll/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Resource/Poll.php b/app/code/core/Mage/Poll/Model/Resource/Poll.php
index 3730e3d..9d8b516 100644
--- a/app/code/core/Mage/Poll/Model/Resource/Poll.php
+++ b/app/code/core/Mage/Poll/Model/Resource/Poll.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Resource/Poll/Answer.php b/app/code/core/Mage/Poll/Model/Resource/Poll/Answer.php
index 76d0653..0f4ef98 100644
--- a/app/code/core/Mage/Poll/Model/Resource/Poll/Answer.php
+++ b/app/code/core/Mage/Poll/Model/Resource/Poll/Answer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Resource/Poll/Answer/Collection.php b/app/code/core/Mage/Poll/Model/Resource/Poll/Answer/Collection.php
index d321045..e48ab74 100644
--- a/app/code/core/Mage/Poll/Model/Resource/Poll/Answer/Collection.php
+++ b/app/code/core/Mage/Poll/Model/Resource/Poll/Answer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Resource/Poll/Collection.php b/app/code/core/Mage/Poll/Model/Resource/Poll/Collection.php
index 62b7a9c..7ec3107 100644
--- a/app/code/core/Mage/Poll/Model/Resource/Poll/Collection.php
+++ b/app/code/core/Mage/Poll/Model/Resource/Poll/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/Model/Resource/Poll/Vote.php b/app/code/core/Mage/Poll/Model/Resource/Poll/Vote.php
index e7062e6..4fed9ba 100644
--- a/app/code/core/Mage/Poll/Model/Resource/Poll/Vote.php
+++ b/app/code/core/Mage/Poll/Model/Resource/Poll/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/controllers/VoteController.php b/app/code/core/Mage/Poll/controllers/VoteController.php
index 1629a90..026f2e1 100644
--- a/app/code/core/Mage/Poll/controllers/VoteController.php
+++ b/app/code/core/Mage/Poll/controllers/VoteController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/data/poll_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Poll/data/poll_setup/data-install-1.6.0.0.php
index f213c3c..8563834 100644
--- a/app/code/core/Mage/Poll/data/poll_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Poll/data/poll_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/etc/adminhtml.xml b/app/code/core/Mage/Poll/etc/adminhtml.xml
index ad9e743..6abbbd0 100644
--- a/app/code/core/Mage/Poll/etc/adminhtml.xml
+++ b/app/code/core/Mage/Poll/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Poll/etc/config.xml b/app/code/core/Mage/Poll/etc/config.xml
index e4b15e2..8c66467 100644
--- a/app/code/core/Mage/Poll/etc/config.xml
+++ b/app/code/core/Mage/Poll/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Poll/etc/system.xml b/app/code/core/Mage/Poll/etc/system.xml
index d4890f6..4f7d297 100644
--- a/app/code/core/Mage/Poll/etc/system.xml
+++ b/app/code/core/Mage/Poll/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/install-1.6.0.0.php b/app/code/core/Mage/Poll/sql/poll_setup/install-1.6.0.0.php
index fe4884a..5a6b9bb 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-install-0.7.0.php
index b361f3e..72f0237 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.6.0-0.6.1.php b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.6.0-0.6.1.php
index ba272a2..5d93fff 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.6.0-0.6.1.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.6.0-0.6.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 494a856..ed7e82f 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index b4d4438..fb063e7 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
index 706e57d..424dcc5 100644
--- a/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Poll/sql/poll_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Poll
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Email/Abstract.php b/app/code/core/Mage/ProductAlert/Block/Email/Abstract.php
index 60d4ff8..7357d0d 100644
--- a/app/code/core/Mage/ProductAlert/Block/Email/Abstract.php
+++ b/app/code/core/Mage/ProductAlert/Block/Email/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Email/Price.php b/app/code/core/Mage/ProductAlert/Block/Email/Price.php
index 266998b..53aad8b 100644
--- a/app/code/core/Mage/ProductAlert/Block/Email/Price.php
+++ b/app/code/core/Mage/ProductAlert/Block/Email/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Email/Stock.php b/app/code/core/Mage/ProductAlert/Block/Email/Stock.php
index bd40ebd..5da5e75 100644
--- a/app/code/core/Mage/ProductAlert/Block/Email/Stock.php
+++ b/app/code/core/Mage/ProductAlert/Block/Email/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Price.php b/app/code/core/Mage/ProductAlert/Block/Price.php
index 0263b36..51584c1 100644
--- a/app/code/core/Mage/ProductAlert/Block/Price.php
+++ b/app/code/core/Mage/ProductAlert/Block/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Product/View.php b/app/code/core/Mage/ProductAlert/Block/Product/View.php
index 7bb135d..9ba403e 100644
--- a/app/code/core/Mage/ProductAlert/Block/Product/View.php
+++ b/app/code/core/Mage/ProductAlert/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Block/Stock.php b/app/code/core/Mage/ProductAlert/Block/Stock.php
index a9d9005..da1fb26 100644
--- a/app/code/core/Mage/ProductAlert/Block/Stock.php
+++ b/app/code/core/Mage/ProductAlert/Block/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Helper/Data.php b/app/code/core/Mage/ProductAlert/Helper/Data.php
index ffa35c8..2237ecc 100644
--- a/app/code/core/Mage/ProductAlert/Helper/Data.php
+++ b/app/code/core/Mage/ProductAlert/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Email.php b/app/code/core/Mage/ProductAlert/Model/Email.php
index 8a39a0e..12e0e82 100644
--- a/app/code/core/Mage/ProductAlert/Model/Email.php
+++ b/app/code/core/Mage/ProductAlert/Model/Email.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price.php
index f444f0c..ab460e9 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Collection.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Collection.php
index e28e3bd..fa3dfe6 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Customer/Collection.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Customer/Collection.php
index 21062b1..e07ee75 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Customer/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Price/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock.php
index ca37584..1f19b8a 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Collection.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Collection.php
index 1644a49..bf6d617 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Customer/Collection.php b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Customer/Collection.php
index 42a9417..f34a145 100644
--- a/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Customer/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Mysql4/Stock/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Observer.php b/app/code/core/Mage/ProductAlert/Model/Observer.php
index 4ed41b0..fcf9d13 100644
--- a/app/code/core/Mage/ProductAlert/Model/Observer.php
+++ b/app/code/core/Mage/ProductAlert/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Price.php b/app/code/core/Mage/ProductAlert/Model/Price.php
index f348c21..f73cb99 100644
--- a/app/code/core/Mage/ProductAlert/Model/Price.php
+++ b/app/code/core/Mage/ProductAlert/Model/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Abstract.php b/app/code/core/Mage/ProductAlert/Model/Resource/Abstract.php
index cf8d914..7dc0f86 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Price.php b/app/code/core/Mage/ProductAlert/Model/Resource/Price.php
index 90a09e9..5154744 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Price.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Price/Collection.php b/app/code/core/Mage/ProductAlert/Model/Resource/Price/Collection.php
index 71f9adf..682fd4c 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Price/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Price/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Price/Customer/Collection.php b/app/code/core/Mage/ProductAlert/Model/Resource/Price/Customer/Collection.php
index 4822ef7..2bccbb5 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Price/Customer/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Price/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Stock.php b/app/code/core/Mage/ProductAlert/Model/Resource/Stock.php
index 77fd1cd..f82ff10 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Stock.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Collection.php b/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Collection.php
index 5c7b6c0..6d2bf24 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Customer/Collection.php b/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Customer/Collection.php
index 0e0aeb5..afec758 100644
--- a/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Customer/Collection.php
+++ b/app/code/core/Mage/ProductAlert/Model/Resource/Stock/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/Model/Stock.php b/app/code/core/Mage/ProductAlert/Model/Stock.php
index f83f2bf..87dc1b2 100644
--- a/app/code/core/Mage/ProductAlert/Model/Stock.php
+++ b/app/code/core/Mage/ProductAlert/Model/Stock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/controllers/AddController.php b/app/code/core/Mage/ProductAlert/controllers/AddController.php
index ab6ca59..4dcf922 100644
--- a/app/code/core/Mage/ProductAlert/controllers/AddController.php
+++ b/app/code/core/Mage/ProductAlert/controllers/AddController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/controllers/UnsubscribeController.php b/app/code/core/Mage/ProductAlert/controllers/UnsubscribeController.php
index 7e8bc10..ca300ad 100644
--- a/app/code/core/Mage/ProductAlert/controllers/UnsubscribeController.php
+++ b/app/code/core/Mage/ProductAlert/controllers/UnsubscribeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/etc/config.xml b/app/code/core/Mage/ProductAlert/etc/config.xml
index b5835d5..0704632 100644
--- a/app/code/core/Mage/ProductAlert/etc/config.xml
+++ b/app/code/core/Mage/ProductAlert/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ProductAlert/etc/system.xml b/app/code/core/Mage/ProductAlert/etc/system.xml
index 04506b7..8b5d9d7 100644
--- a/app/code/core/Mage/ProductAlert/etc/system.xml
+++ b/app/code/core/Mage/ProductAlert/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/ProductAlert/sql/productalert_setup/install-1.6.0.0.php b/app/code/core/Mage/ProductAlert/sql/productalert_setup/install-1.6.0.0.php
index 018dccb..9cc90b4 100644
--- a/app/code/core/Mage/ProductAlert/sql/productalert_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/ProductAlert/sql/productalert_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-install-0.7.0.php
index 1e10af8..b05e3a8 100644
--- a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 3630a07..5599712 100644
--- a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 267f562..7066ffd 100644
--- a/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/ProductAlert/sql/productalert_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_ProductAlert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Block/Entity/Detailed.php b/app/code/core/Mage/Rating/Block/Entity/Detailed.php
index b1b6e32..6a6e955 100644
--- a/app/code/core/Mage/Rating/Block/Entity/Detailed.php
+++ b/app/code/core/Mage/Rating/Block/Entity/Detailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Helper/Data.php b/app/code/core/Mage/Rating/Helper/Data.php
index c6d472f..7e1de14 100644
--- a/app/code/core/Mage/Rating/Helper/Data.php
+++ b/app/code/core/Mage/Rating/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating.php
index 056a6d1..dc730d4 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Collection.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Collection.php
index 47788c8..eec624a 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Entity.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Entity.php
index 2fed278..157d38f 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Entity.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option.php
index e6bbe50..1b2f251 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Collection.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Collection.php
index bbddb2e..b986bc3 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote.php
index 0c9e3b2..9ce0cd4 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote/Collection.php b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote/Collection.php
index 2da5098..f1bcc40 100644
--- a/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Mysql4/Rating/Option/Vote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Observer.php b/app/code/core/Mage/Rating/Model/Observer.php
index 70f3984..f8b2fd5 100644
--- a/app/code/core/Mage/Rating/Model/Observer.php
+++ b/app/code/core/Mage/Rating/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Rating.php b/app/code/core/Mage/Rating/Model/Rating.php
index ce02858..686fdec 100644
--- a/app/code/core/Mage/Rating/Model/Rating.php
+++ b/app/code/core/Mage/Rating/Model/Rating.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Rating/Entity.php b/app/code/core/Mage/Rating/Model/Rating/Entity.php
index 9cfa384..c317e3e 100644
--- a/app/code/core/Mage/Rating/Model/Rating/Entity.php
+++ b/app/code/core/Mage/Rating/Model/Rating/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Rating/Option.php b/app/code/core/Mage/Rating/Model/Rating/Option.php
index 1823e50..c1e82fc 100644
--- a/app/code/core/Mage/Rating/Model/Rating/Option.php
+++ b/app/code/core/Mage/Rating/Model/Rating/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Rating/Option/Vote.php b/app/code/core/Mage/Rating/Model/Rating/Option/Vote.php
index 3867f7e..de95f5a 100644
--- a/app/code/core/Mage/Rating/Model/Rating/Option/Vote.php
+++ b/app/code/core/Mage/Rating/Model/Rating/Option/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating.php b/app/code/core/Mage/Rating/Model/Resource/Rating.php
index 84f22b3..8f8a07b 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Collection.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Collection.php
index 6bb74bf..cca0505 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Entity.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Entity.php
index f919ec8..5ab8e5b 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Entity.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Entity.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Option.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Option.php
index 5b15def..f01d5e3 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Option.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Collection.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Collection.php
index f14b547..c1b3a73 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote.php
index d3fd6d5..a005d58 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote/Collection.php b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote/Collection.php
index c8c32f9..e30b047 100644
--- a/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote/Collection.php
+++ b/app/code/core/Mage/Rating/Model/Resource/Rating/Option/Vote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/data/rating_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Rating/data/rating_setup/data-install-1.6.0.0.php
index e22f017..f7e128b 100644
--- a/app/code/core/Mage/Rating/data/rating_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Rating/data/rating_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/etc/adminhtml.xml b/app/code/core/Mage/Rating/etc/adminhtml.xml
index d106386..c7de935 100644
--- a/app/code/core/Mage/Rating/etc/adminhtml.xml
+++ b/app/code/core/Mage/Rating/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Rating/etc/config.xml b/app/code/core/Mage/Rating/etc/config.xml
index 2d3ba82..1186bf5 100644
--- a/app/code/core/Mage/Rating/etc/config.xml
+++ b/app/code/core/Mage/Rating/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/install-1.6.0.0.php b/app/code/core/Mage/Rating/sql/rating_setup/install-1.6.0.0.php
index 7cb4bb1..0508c02 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-install-0.7.0.php
index 2de5b0d..d8e65d0 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.0-0.7.1.php
index b4e94f8..1cc9cf3 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 7296aa4..0b95743 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index d80f4a7..76e0c43 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
index c8ca7ad..9882206 100644
--- a/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Rating/sql/rating_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rating
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Block/Product/Abstract.php b/app/code/core/Mage/Reports/Block/Product/Abstract.php
index 7402bbc..11e33d1 100644
--- a/app/code/core/Mage/Reports/Block/Product/Abstract.php
+++ b/app/code/core/Mage/Reports/Block/Product/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Block/Product/Compared.php b/app/code/core/Mage/Reports/Block/Product/Compared.php
index ee225d5..5da949e 100644
--- a/app/code/core/Mage/Reports/Block/Product/Compared.php
+++ b/app/code/core/Mage/Reports/Block/Product/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Block/Product/Viewed.php b/app/code/core/Mage/Reports/Block/Product/Viewed.php
index d2ca743..01bb2ba 100644
--- a/app/code/core/Mage/Reports/Block/Product/Viewed.php
+++ b/app/code/core/Mage/Reports/Block/Product/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Block/Product/Widget/Compared.php b/app/code/core/Mage/Reports/Block/Product/Widget/Compared.php
index dd2c433..dcc2110 100644
--- a/app/code/core/Mage/Reports/Block/Product/Widget/Compared.php
+++ b/app/code/core/Mage/Reports/Block/Product/Widget/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Block/Product/Widget/Viewed.php b/app/code/core/Mage/Reports/Block/Product/Widget/Viewed.php
index cf91532..5fd44d4 100644
--- a/app/code/core/Mage/Reports/Block/Product/Widget/Viewed.php
+++ b/app/code/core/Mage/Reports/Block/Product/Widget/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Exception.php b/app/code/core/Mage/Reports/Exception.php
index d906bcd..995df41 100644
--- a/app/code/core/Mage/Reports/Exception.php
+++ b/app/code/core/Mage/Reports/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Helper/Data.php b/app/code/core/Mage/Reports/Helper/Data.php
index 8c9dc5a..6f36241 100644
--- a/app/code/core/Mage/Reports/Helper/Data.php
+++ b/app/code/core/Mage/Reports/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Config.php b/app/code/core/Mage/Reports/Model/Config.php
index e668a0f..550c9e8 100644
--- a/app/code/core/Mage/Reports/Model/Config.php
+++ b/app/code/core/Mage/Reports/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Event.php b/app/code/core/Mage/Reports/Model/Event.php
index e55bd8f..aea7e1e 100644
--- a/app/code/core/Mage/Reports/Model/Event.php
+++ b/app/code/core/Mage/Reports/Model/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Event/Observer.php b/app/code/core/Mage/Reports/Model/Event/Observer.php
index e42b25e..01835ae 100644
--- a/app/code/core/Mage/Reports/Model/Event/Observer.php
+++ b/app/code/core/Mage/Reports/Model/Event/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Event/Type.php b/app/code/core/Mage/Reports/Model/Event/Type.php
index ff84e44..b11349a 100644
--- a/app/code/core/Mage/Reports/Model/Event/Type.php
+++ b/app/code/core/Mage/Reports/Model/Event/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Flag.php b/app/code/core/Mage/Reports/Model/Flag.php
index f415170..c3691cc 100644
--- a/app/code/core/Mage/Reports/Model/Flag.php
+++ b/app/code/core/Mage/Reports/Model/Flag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Grouped/Collection.php b/app/code/core/Mage/Reports/Model/Grouped/Collection.php
index 8aef0fa..4618222 100644
--- a/app/code/core/Mage/Reports/Model/Grouped/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Grouped/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Reports_Model_Grouped_Collection
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Accounts/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Accounts/Collection.php
index 2d09e8c..cb1a18c 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Accounts/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Accounts/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Coupons/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Coupons/Collection.php
index 0e1ba67..f15b82d 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Coupons/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Coupons/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Collection.php
index 0e2fdc2..7d3264e 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Orders/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Orders/Collection.php
index 23b1bc3..0fe2de7 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Orders/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Orders/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Totals/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Totals/Collection.php
index 2e2c7d1..8aa0dfb 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Customer/Totals/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Customer/Totals/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Entity/Summary/Collection/Abstract.php b/app/code/core/Mage/Reports/Model/Mysql4/Entity/Summary/Collection/Abstract.php
index a573b36..6eb546a 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Entity/Summary/Collection/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Entity/Summary/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Event.php b/app/code/core/Mage/Reports/Model/Mysql4/Event.php
index 044317a..df3f459 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Event.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Event/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Event/Collection.php
index 97fa2a5..6e2a39c 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Event/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Event/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Event/Type.php b/app/code/core/Mage/Reports/Model/Mysql4/Event/Type.php
index d686fda..ebf1bf8 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Event/Type.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Event/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Event/Type/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Event/Type/Collection.php
index c99048d..ad6d22c 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Event/Type/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Event/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Invoiced/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Invoiced/Collection.php
index c468447..62a752e 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Invoiced/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Invoiced/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Order/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Order/Collection.php
index 8128a11..c33efc6 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Order/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Collection.php
index a604750..deb5735 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Downloads/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Downloads/Collection.php
index 62a1af1..3288ebf 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Downloads/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Downloads/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Abstract.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Abstract.php
index 036a7f8..e91b034 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Collection/Abstract.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Collection/Abstract.php
index 6079e91..f7e6f15 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Collection/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared.php
index a4539d3..25133ba 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared/Collection.php
index ee4931a..5d55153 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Compared/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed.php
index 1848f45..bd2e4ec 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed/Collection.php
index 18e9559..451642c 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Index/Viewed/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Lowstock/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Lowstock/Collection.php
index a1cbec7..dccaf19 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Lowstock/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Lowstock/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Ordered/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Ordered/Collection.php
index 9dfc77a..82cd6b1 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Ordered/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Ordered/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Sold/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Sold/Collection.php
index 90a460e..6798354 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Sold/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Sold/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Product/Viewed/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Product/Viewed/Collection.php
index 056f255..5de22a8 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Product/Viewed/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Product/Viewed/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Quote/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Quote/Collection.php
index 340c5c3..ba45521 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Quote/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Quote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Refunded/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Refunded/Collection.php
index 7940c65..86a73ef 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Refunded/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Refunded/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Report/Abstract.php b/app/code/core/Mage/Reports/Model/Mysql4/Report/Abstract.php
index 1f322a6..c28cd57 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Report/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Report/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Report/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Report/Collection.php
index 6bc35ae..4ca7b85 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Report/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Review/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Review/Collection.php
index d4ef490..e97fdc6 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Review/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Review/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Review/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Review/Customer/Collection.php
index 681e410..05253e9 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Review/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Review/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Review/Product/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Review/Product/Collection.php
index 5afc71c..610185c 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Review/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Review/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Shipping/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Shipping/Collection.php
index 9d2f989..b139628 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Shipping/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Shipping/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Shopcart/Product/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Shopcart/Product/Collection.php
index 454b9a6..7877d98 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Shopcart/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Shopcart/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Collection.php
index 43ae37f..82a3b41 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Customer/Collection.php
index 0e33d91..e6d27f3 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Product/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Product/Collection.php
index c2f765e..4092330 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Tag/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Tag/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Tax/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Tax/Collection.php
index 1f73f03..596b7de 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Tax/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Collection.php
index e395e7d..be54bc7 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Product/Collection.php b/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Product/Collection.php
index 0082559..1d2d7d6 100644
--- a/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Mysql4/Wishlist/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Product/Index/Abstract.php b/app/code/core/Mage/Reports/Model/Product/Index/Abstract.php
index c7f89cb..f8fb933 100644
--- a/app/code/core/Mage/Reports/Model/Product/Index/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Product/Index/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Product/Index/Compared.php b/app/code/core/Mage/Reports/Model/Product/Index/Compared.php
index 21c9506..82f4abe 100644
--- a/app/code/core/Mage/Reports/Model/Product/Index/Compared.php
+++ b/app/code/core/Mage/Reports/Model/Product/Index/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Product/Index/Viewed.php b/app/code/core/Mage/Reports/Model/Product/Index/Viewed.php
index e447029..2a9f0f7 100644
--- a/app/code/core/Mage/Reports/Model/Product/Index/Viewed.php
+++ b/app/code/core/Mage/Reports/Model/Product/Index/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Report.php b/app/code/core/Mage/Reports/Model/Report.php
index 5222a31..ed81455 100644
--- a/app/code/core/Mage/Reports/Model/Report.php
+++ b/app/code/core/Mage/Reports/Model/Report.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Accounts/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Accounts/Collection.php
index e3c8ced..0f79614 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Accounts/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Accounts/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Coupons/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Coupons/Collection.php
index 4775e35..01b098d 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Coupons/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Coupons/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Customer/Collection.php
index 0f635d0..532b372 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Customer/Orders/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Customer/Orders/Collection.php
index 373ae92..c1971d6 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Customer/Orders/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Customer/Orders/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Customer/Totals/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Customer/Totals/Collection.php
index 0b816bf..ba4c38d 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Customer/Totals/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Customer/Totals/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Entity/Summary/Collection/Abstract.php b/app/code/core/Mage/Reports/Model/Resource/Entity/Summary/Collection/Abstract.php
index 9efca09..581fc06 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Entity/Summary/Collection/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Entity/Summary/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Event.php b/app/code/core/Mage/Reports/Model/Resource/Event.php
index a3a4d13..fe0b1f5 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Event.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Event/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Event/Collection.php
index 20b272f..aa59483 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Event/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Event/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Event/Type.php b/app/code/core/Mage/Reports/Model/Resource/Event/Type.php
index 256d883..6687f8b 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Event/Type.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Event/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Event/Type/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Event/Type/Collection.php
index f60842f..6317210 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Event/Type/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Event/Type/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Helper/Interface.php b/app/code/core/Mage/Reports/Model/Resource/Helper/Interface.php
index 833bf5d..5fdae45 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Helper/Interface.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Helper/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Reports/Model/Resource/Helper/Mysql4.php
index 8a23581..d58fda7 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Invoiced/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Invoiced/Collection.php
index 64d1509..488634a 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Invoiced/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Invoiced/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Order/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Order/Collection.php
index 222d8d1..0abdd08 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Order/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Collection.php
index 1ff50d7..50d325c 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Downloads/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Downloads/Collection.php
index ab645c3..6f026a2 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Downloads/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Downloads/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Abstract.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Abstract.php
index f139be0..fd3e0bb 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Collection/Abstract.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Collection/Abstract.php
index 7ff01ec..2316214 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Collection/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared.php
index c7fbd21..d798c93 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared/Collection.php
index 5ecb0f5..a47e4aa 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Compared/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed.php
index 4636e0d..95f696a 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed/Collection.php
index ee37d1a..b59da02 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Index/Viewed/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Lowstock/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Lowstock/Collection.php
index 43b0a40..3890594 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Lowstock/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Lowstock/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Ordered/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Ordered/Collection.php
index a019dd3..4955d14 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Ordered/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Ordered/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Sold/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Sold/Collection.php
index acf2de4..70a481a 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Sold/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Sold/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Product/Viewed/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Product/Viewed/Collection.php
index dda5128..8da9794 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Product/Viewed/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Product/Viewed/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Quote/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Quote/Collection.php
index ba5c367..619d615 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Quote/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Quote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Refunded/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Refunded/Collection.php
index 7c1c225..35c43be 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Refunded/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Refunded/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Report/Abstract.php b/app/code/core/Mage/Reports/Model/Resource/Report/Abstract.php
index fb224d8..3d01291 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Report/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Report/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Report/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Report/Collection.php
index 8a3c789..bc77bb8 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Report/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Report/Collection/Abstract.php b/app/code/core/Mage/Reports/Model/Resource/Report/Collection/Abstract.php
index c27bf0e..5cc594c 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Report/Collection/Abstract.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Report/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed.php b/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed.php
index a8f4957..889777f 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed/Collection.php
index 06e88da..7d0be55 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Report/Product/Viewed/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Review/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Review/Collection.php
index 3f94532..2640563 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Review/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Review/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Review/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Review/Customer/Collection.php
index 46ea3d9..e1c7ee0 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Review/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Review/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Review/Product/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Review/Product/Collection.php
index dc9ffc0..3ba522b 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Review/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Review/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Shipping/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Shipping/Collection.php
index 4114c83..f62fd16 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Shipping/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Shipping/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Shopcart/Product/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Shopcart/Product/Collection.php
index 4876c08..fd5c09c 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Shopcart/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Shopcart/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Tag/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Tag/Collection.php
index d334ba0..b22b426 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Tag/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Tag/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Tag/Customer/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Tag/Customer/Collection.php
index 1f7d629..32d50d4 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Tag/Customer/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Tag/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Tag/Product/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Tag/Product/Collection.php
index 6919230..06927f1 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Tag/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Tag/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Tax/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Tax/Collection.php
index 18e4733..b53f251 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Tax/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Wishlist/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Wishlist/Collection.php
index 99debdf..00aaf59 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Wishlist/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Resource/Wishlist/Product/Collection.php b/app/code/core/Mage/Reports/Model/Resource/Wishlist/Product/Collection.php
index 24765a5..57eeed8 100644
--- a/app/code/core/Mage/Reports/Model/Resource/Wishlist/Product/Collection.php
+++ b/app/code/core/Mage/Reports/Model/Resource/Wishlist/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Session.php b/app/code/core/Mage/Reports/Model/Session.php
index f41e174..e452429 100644
--- a/app/code/core/Mage/Reports/Model/Session.php
+++ b/app/code/core/Mage/Reports/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Test.php b/app/code/core/Mage/Reports/Model/Test.php
index 5be28a5..7cf6c5f 100644
--- a/app/code/core/Mage/Reports/Model/Test.php
+++ b/app/code/core/Mage/Reports/Model/Test.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/Model/Totals.php b/app/code/core/Mage/Reports/Model/Totals.php
index 73752dd..5fea30e 100644
--- a/app/code/core/Mage/Reports/Model/Totals.php
+++ b/app/code/core/Mage/Reports/Model/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/data/reports_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Reports/data/reports_setup/data-install-1.6.0.0.php
index ba6b6b9..d18b13c 100644
--- a/app/code/core/Mage/Reports/data/reports_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Reports/data/reports_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/etc/adminhtml.xml b/app/code/core/Mage/Reports/etc/adminhtml.xml
index 3fd1908..1fff58a 100644
--- a/app/code/core/Mage/Reports/etc/adminhtml.xml
+++ b/app/code/core/Mage/Reports/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Reports/etc/config.xml b/app/code/core/Mage/Reports/etc/config.xml
index 45eb78c..341d310 100644
--- a/app/code/core/Mage/Reports/etc/config.xml
+++ b/app/code/core/Mage/Reports/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Reports/etc/system.xml b/app/code/core/Mage/Reports/etc/system.xml
index 620a7aaf..16934c4 100644
--- a/app/code/core/Mage/Reports/etc/system.xml
+++ b/app/code/core/Mage/Reports/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Reports/etc/widget.xml b/app/code/core/Mage/Reports/etc/widget.xml
index b4f6725..1535272 100644
--- a/app/code/core/Mage/Reports/etc/widget.xml
+++ b/app/code/core/Mage/Reports/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/install-1.6.0.0.php b/app/code/core/Mage/Reports/sql/reports_setup/install-1.6.0.0.php
index b01c48d..b27f908 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-0.7.1.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-0.7.1.php
index f0f0914..25fe6bc 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-0.7.1.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.5.0.0.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.5.0.0.php
index f42d532..b69ffd8 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.5.0.0.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.5.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.6.0.0.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.6.0.0.php
index bf0a82c..a1e92fb 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.6.0.0.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.0-0.7.1.php
index d92a750..0620c53 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 02fbcd0..c1203a7 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 2e35e8b..730a7f9 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 75d146e..339a4b3 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.4-0.7.5.php
index e4c3d80..9df40c3 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.5-0.7.7.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.5-0.7.7.php
index 52437fa..faa66cc 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.5-0.7.7.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.5-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 74fb08e..7477816 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 2fb87ec..90089b7 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 696e053..7ccade3 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index a2c37d4..404f0c6 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Reports/sql/reports_setup/upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/Reports/sql/reports_setup/upgrade-1.6.0.0-1.6.0.0.1.php
index fb6b6c6..5ae1101 100644
--- a/app/code/core/Mage/Reports/sql/reports_setup/upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/Reports/sql/reports_setup/upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Reports
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Customer/List.php b/app/code/core/Mage/Review/Block/Customer/List.php
index b2770dd..4372883 100644
--- a/app/code/core/Mage/Review/Block/Customer/List.php
+++ b/app/code/core/Mage/Review/Block/Customer/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Customer/Recent.php b/app/code/core/Mage/Review/Block/Customer/Recent.php
index 78060e6..29c1152 100644
--- a/app/code/core/Mage/Review/Block/Customer/Recent.php
+++ b/app/code/core/Mage/Review/Block/Customer/Recent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Customer/View.php b/app/code/core/Mage/Review/Block/Customer/View.php
index 58d0413..0400ccb 100644
--- a/app/code/core/Mage/Review/Block/Customer/View.php
+++ b/app/code/core/Mage/Review/Block/Customer/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Form.php b/app/code/core/Mage/Review/Block/Form.php
index f33689b..ff41c8b 100644
--- a/app/code/core/Mage/Review/Block/Form.php
+++ b/app/code/core/Mage/Review/Block/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Helper.php b/app/code/core/Mage/Review/Block/Helper.php
index 428aca3..71190c4 100644
--- a/app/code/core/Mage/Review/Block/Helper.php
+++ b/app/code/core/Mage/Review/Block/Helper.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Product/View.php b/app/code/core/Mage/Review/Block/Product/View.php
index 04cad64..617ad4f 100644
--- a/app/code/core/Mage/Review/Block/Product/View.php
+++ b/app/code/core/Mage/Review/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/Product/View/List.php b/app/code/core/Mage/Review/Block/Product/View/List.php
index 4fe5791..72adf8f 100644
--- a/app/code/core/Mage/Review/Block/Product/View/List.php
+++ b/app/code/core/Mage/Review/Block/Product/View/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Block/View.php b/app/code/core/Mage/Review/Block/View.php
index 5ea8074..3cf2291 100644
--- a/app/code/core/Mage/Review/Block/View.php
+++ b/app/code/core/Mage/Review/Block/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Helper/Data.php b/app/code/core/Mage/Review/Helper/Data.php
index dd29ab8..c52197d 100644
--- a/app/code/core/Mage/Review/Helper/Data.php
+++ b/app/code/core/Mage/Review/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review.php b/app/code/core/Mage/Review/Model/Mysql4/Review.php
index 5512332..7bda051 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review/Collection.php b/app/code/core/Mage/Review/Model/Mysql4/Review/Collection.php
index b0bd8b8..845d0a5 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review/Collection.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review/Product/Collection.php b/app/code/core/Mage/Review/Model/Mysql4/Review/Product/Collection.php
index 893c82b..cddb257 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review/Product/Collection.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review/Status/Collection.php b/app/code/core/Mage/Review/Model/Mysql4/Review/Status/Collection.php
index d8bccd3..5b8cb5c 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review/Status/Collection.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review/Status/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review/Summary.php b/app/code/core/Mage/Review/Model/Mysql4/Review/Summary.php
index 4a04f0c..d4965ff 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review/Summary.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Mysql4/Review/Summary/Collection.php b/app/code/core/Mage/Review/Model/Mysql4/Review/Summary/Collection.php
index a5c9380..dec9df8 100644
--- a/app/code/core/Mage/Review/Model/Mysql4/Review/Summary/Collection.php
+++ b/app/code/core/Mage/Review/Model/Mysql4/Review/Summary/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Observer.php b/app/code/core/Mage/Review/Model/Observer.php
index 302a2fd..d20aede 100644
--- a/app/code/core/Mage/Review/Model/Observer.php
+++ b/app/code/core/Mage/Review/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review.php b/app/code/core/Mage/Review/Model/Resource/Review.php
index d8ff8c9..9d8ba7e 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Collection.php b/app/code/core/Mage/Review/Model/Resource/Review/Collection.php
index 0be6a18..95d7f2f 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Collection.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Product/Collection.php b/app/code/core/Mage/Review/Model/Resource/Review/Product/Collection.php
index c23f70b..b8dcd9a 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Product/Collection.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Status.php b/app/code/core/Mage/Review/Model/Resource/Review/Status.php
index 5e89fa0..b25947e 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Status.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Status/Collection.php b/app/code/core/Mage/Review/Model/Resource/Review/Status/Collection.php
index 5e1f782..2601386 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Status/Collection.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Status/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Summary.php b/app/code/core/Mage/Review/Model/Resource/Review/Summary.php
index 6263067..4c39ee0 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Summary.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Resource/Review/Summary/Collection.php b/app/code/core/Mage/Review/Model/Resource/Review/Summary/Collection.php
index 028618d..00daafd 100644
--- a/app/code/core/Mage/Review/Model/Resource/Review/Summary/Collection.php
+++ b/app/code/core/Mage/Review/Model/Resource/Review/Summary/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Review.php b/app/code/core/Mage/Review/Model/Review.php
index 1b6deef..ec1f17d 100644
--- a/app/code/core/Mage/Review/Model/Review.php
+++ b/app/code/core/Mage/Review/Model/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Review/Status.php b/app/code/core/Mage/Review/Model/Review/Status.php
index b7def06..1e6cd65 100644
--- a/app/code/core/Mage/Review/Model/Review/Status.php
+++ b/app/code/core/Mage/Review/Model/Review/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Review/Summary.php b/app/code/core/Mage/Review/Model/Review/Summary.php
index f216c42..136f125 100644
--- a/app/code/core/Mage/Review/Model/Review/Summary.php
+++ b/app/code/core/Mage/Review/Model/Review/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/Model/Session.php b/app/code/core/Mage/Review/Model/Session.php
index 8318a53..a3952e8 100644
--- a/app/code/core/Mage/Review/Model/Session.php
+++ b/app/code/core/Mage/Review/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/controllers/CustomerController.php b/app/code/core/Mage/Review/controllers/CustomerController.php
index f93c613..d3a4f6a 100644
--- a/app/code/core/Mage/Review/controllers/CustomerController.php
+++ b/app/code/core/Mage/Review/controllers/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/controllers/ProductController.php b/app/code/core/Mage/Review/controllers/ProductController.php
index 7add804..d14be3e 100644
--- a/app/code/core/Mage/Review/controllers/ProductController.php
+++ b/app/code/core/Mage/Review/controllers/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/data/review_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Review/data/review_setup/data-install-1.6.0.0.php
index d93d636..95e5aae 100644
--- a/app/code/core/Mage/Review/data/review_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Review/data/review_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/etc/adminhtml.xml b/app/code/core/Mage/Review/etc/adminhtml.xml
index b5bb889..b067470 100644
--- a/app/code/core/Mage/Review/etc/adminhtml.xml
+++ b/app/code/core/Mage/Review/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Review/etc/config.xml b/app/code/core/Mage/Review/etc/config.xml
index 475a41c..b4b16a9 100644
--- a/app/code/core/Mage/Review/etc/config.xml
+++ b/app/code/core/Mage/Review/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Review/etc/system.xml b/app/code/core/Mage/Review/etc/system.xml
index cfe94e5..b61d3cf 100644
--- a/app/code/core/Mage/Review/etc/system.xml
+++ b/app/code/core/Mage/Review/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Review/sql/review_setup/install-1.6.0.0.php b/app/code/core/Mage/Review/sql/review_setup/install-1.6.0.0.php
index 39be0dd..180506d 100644
--- a/app/code/core/Mage/Review/sql/review_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Review/sql/review_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-install-0.7.0.php
index 9fea8ca..cbc9194 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 1907ca1..ee50603 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 5062931..9f10f10 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 94067c6..3e21afa 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.3-0.7.4.php
index a0d962d..63941bb 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 11eeb7a..25a384d 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.5-0.7.6.php
index cd54c5e..3fb6288 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index f8b9800..8e101c8 100644
--- a/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Review/sql/review_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Review
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Abstract.php b/app/code/core/Mage/Rss/Block/Abstract.php
index e673157..42edf77 100644
--- a/app/code/core/Mage/Rss/Block/Abstract.php
+++ b/app/code/core/Mage/Rss/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Rss_Block_Abstract extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Abstract.php b/app/code/core/Mage/Rss/Block/Catalog/Abstract.php
index 9d170da..1b22d74 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Abstract.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Rss_Block_Catalog_Abstract extends Mage_Rss_Block_Abstract
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Category.php b/app/code/core/Mage/Rss/Block/Catalog/Category.php
index 64cbb59..843551b 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Category.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/New.php b/app/code/core/Mage/Rss/Block/Catalog/New.php
index bffd408..98c6445 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/New.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/NotifyStock.php b/app/code/core/Mage/Rss/Block/Catalog/NotifyStock.php
index 3e27bd4..8ead5eb 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/NotifyStock.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/NotifyStock.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Review.php b/app/code/core/Mage/Rss/Block/Catalog/Review.php
index 5f45cd1..39ae0cf 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Review.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Salesrule.php b/app/code/core/Mage/Rss/Block/Catalog/Salesrule.php
index 20bd293..7f46588 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Salesrule.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Salesrule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Special.php b/app/code/core/Mage/Rss/Block/Catalog/Special.php
index 620176f..ffc0fa0 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Special.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Special.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Catalog/Tag.php b/app/code/core/Mage/Rss/Block/Catalog/Tag.php
index 99116de..5791768 100644
--- a/app/code/core/Mage/Rss/Block/Catalog/Tag.php
+++ b/app/code/core/Mage/Rss/Block/Catalog/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/List.php b/app/code/core/Mage/Rss/Block/List.php
index 1c064a1..7d6a226 100644
--- a/app/code/core/Mage/Rss/Block/List.php
+++ b/app/code/core/Mage/Rss/Block/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Order/Details.php b/app/code/core/Mage/Rss/Block/Order/Details.php
index 4473887..792d4e1 100644
--- a/app/code/core/Mage/Rss/Block/Order/Details.php
+++ b/app/code/core/Mage/Rss/Block/Order/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Rss_Block_Order_Details extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/Rss/Block/Order/New.php b/app/code/core/Mage/Rss/Block/Order/New.php
index 4c58e22..0393cbf 100644
--- a/app/code/core/Mage/Rss/Block/Order/New.php
+++ b/app/code/core/Mage/Rss/Block/Order/New.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Order/Status.php b/app/code/core/Mage/Rss/Block/Order/Status.php
index 089da09..2423309 100644
--- a/app/code/core/Mage/Rss/Block/Order/Status.php
+++ b/app/code/core/Mage/Rss/Block/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Block/Wishlist.php b/app/code/core/Mage/Rss/Block/Wishlist.php
index 91cc9cd..a1fc56f 100644
--- a/app/code/core/Mage/Rss/Block/Wishlist.php
+++ b/app/code/core/Mage/Rss/Block/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Controller/Abstract.php b/app/code/core/Mage/Rss/Controller/Abstract.php
index c51d0ab..601a531 100644
--- a/app/code/core/Mage/Rss/Controller/Abstract.php
+++ b/app/code/core/Mage/Rss/Controller/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Helper/Catalog.php b/app/code/core/Mage/Rss/Helper/Catalog.php
index d33117f..0d0ba08 100644
--- a/app/code/core/Mage/Rss/Helper/Catalog.php
+++ b/app/code/core/Mage/Rss/Helper/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Helper/Data.php b/app/code/core/Mage/Rss/Helper/Data.php
index 2b7eb40..276649d 100644
--- a/app/code/core/Mage/Rss/Helper/Data.php
+++ b/app/code/core/Mage/Rss/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Helper/Order.php b/app/code/core/Mage/Rss/Helper/Order.php
index f5f29fe..e1283ee 100644
--- a/app/code/core/Mage/Rss/Helper/Order.php
+++ b/app/code/core/Mage/Rss/Helper/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/Mysql4/Order.php b/app/code/core/Mage/Rss/Model/Mysql4/Order.php
index 4717226..189616d 100644
--- a/app/code/core/Mage/Rss/Model/Mysql4/Order.php
+++ b/app/code/core/Mage/Rss/Model/Mysql4/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/Observer.php b/app/code/core/Mage/Rss/Model/Observer.php
index f6669f7..f96a779 100644
--- a/app/code/core/Mage/Rss/Model/Observer.php
+++ b/app/code/core/Mage/Rss/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/Resource/Order.php b/app/code/core/Mage/Rss/Model/Resource/Order.php
index 35997a9..24e1d3d 100644
--- a/app/code/core/Mage/Rss/Model/Resource/Order.php
+++ b/app/code/core/Mage/Rss/Model/Resource/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/Rss.php b/app/code/core/Mage/Rss/Model/Rss.php
index b9a3526..39435b7 100644
--- a/app/code/core/Mage/Rss/Model/Rss.php
+++ b/app/code/core/Mage/Rss/Model/Rss.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/Session.php b/app/code/core/Mage/Rss/Model/Session.php
index d5b6729..e563d8d 100644
--- a/app/code/core/Mage/Rss/Model/Session.php
+++ b/app/code/core/Mage/Rss/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/Model/System/Config/Backend/Links.php b/app/code/core/Mage/Rss/Model/System/Config/Backend/Links.php
index 9754c5c..3ac0d7a 100644
--- a/app/code/core/Mage/Rss/Model/System/Config/Backend/Links.php
+++ b/app/code/core/Mage/Rss/Model/System/Config/Backend/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/controllers/CatalogController.php b/app/code/core/Mage/Rss/controllers/CatalogController.php
index 0a50a71..5b10071 100644
--- a/app/code/core/Mage/Rss/controllers/CatalogController.php
+++ b/app/code/core/Mage/Rss/controllers/CatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/controllers/IndexController.php b/app/code/core/Mage/Rss/controllers/IndexController.php
index 94ad128..1628f74 100644
--- a/app/code/core/Mage/Rss/controllers/IndexController.php
+++ b/app/code/core/Mage/Rss/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/controllers/OrderController.php b/app/code/core/Mage/Rss/controllers/OrderController.php
index 40ef65d..77228d0 100644
--- a/app/code/core/Mage/Rss/controllers/OrderController.php
+++ b/app/code/core/Mage/Rss/controllers/OrderController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/data/rss_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Rss/data/rss_setup/data-install-1.6.0.0.php
index fac3c55..ffa5430 100644
--- a/app/code/core/Mage/Rss/data/rss_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Rss/data/rss_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rss/etc/adminhtml.xml b/app/code/core/Mage/Rss/etc/adminhtml.xml
index 33f3ead..0d10a70 100644
--- a/app/code/core/Mage/Rss/etc/adminhtml.xml
+++ b/app/code/core/Mage/Rss/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Rss/etc/config.xml b/app/code/core/Mage/Rss/etc/config.xml
index c776a9e..29cec91 100644
--- a/app/code/core/Mage/Rss/etc/config.xml
+++ b/app/code/core/Mage/Rss/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Rss/etc/system.xml b/app/code/core/Mage/Rss/etc/system.xml
index 196bec2..40cf678 100644
--- a/app/code/core/Mage/Rss/etc/system.xml
+++ b/app/code/core/Mage/Rss/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rss
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -156,8 +156,9 @@
                     <show_in_website>1</show_in_website>
                     <show_in_store>1</show_in_store>
                     <fields>
-                         <status_notified translate="label">
+                         <status_notified translate="label comment">
                             <label>Customer Order Status Notification</label>
+                            <comment>Enabling can increase security risk by exposing some order details.</comment>
                             <frontend_type>select</frontend_type>
                             <source_model>adminhtml/system_config_source_enabledisable</source_model>
                             <sort_order>10</sort_order>
diff --git a/app/code/core/Mage/Rule/Block/Actions.php b/app/code/core/Mage/Rule/Block/Actions.php
index 4ad08c2..b5ddeff 100644
--- a/app/code/core/Mage/Rule/Block/Actions.php
+++ b/app/code/core/Mage/Rule/Block/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Block/Conditions.php b/app/code/core/Mage/Rule/Block/Conditions.php
index e594330..3e737aa 100644
--- a/app/code/core/Mage/Rule/Block/Conditions.php
+++ b/app/code/core/Mage/Rule/Block/Conditions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Block/Editable.php b/app/code/core/Mage/Rule/Block/Editable.php
index fcf2425..904a947 100644
--- a/app/code/core/Mage/Rule/Block/Editable.php
+++ b/app/code/core/Mage/Rule/Block/Editable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Block/Newchild.php b/app/code/core/Mage/Rule/Block/Newchild.php
index c02b16b..230a8e9 100644
--- a/app/code/core/Mage/Rule/Block/Newchild.php
+++ b/app/code/core/Mage/Rule/Block/Newchild.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Block/Rule.php b/app/code/core/Mage/Rule/Block/Rule.php
index 90da764..596ceb0 100644
--- a/app/code/core/Mage/Rule/Block/Rule.php
+++ b/app/code/core/Mage/Rule/Block/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Helper/Data.php b/app/code/core/Mage/Rule/Helper/Data.php
index b9ab359..4fa03ee 100644
--- a/app/code/core/Mage/Rule/Helper/Data.php
+++ b/app/code/core/Mage/Rule/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Abstract.php b/app/code/core/Mage/Rule/Model/Abstract.php
index 4668acc..0b321d9 100644
--- a/app/code/core/Mage/Rule/Model/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Action/Abstract.php b/app/code/core/Mage/Rule/Model/Action/Abstract.php
index 1e6579b..fac5048 100644
--- a/app/code/core/Mage/Rule/Model/Action/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Action/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Action/Collection.php b/app/code/core/Mage/Rule/Model/Action/Collection.php
index d2a8922..31efa27 100644
--- a/app/code/core/Mage/Rule/Model/Action/Collection.php
+++ b/app/code/core/Mage/Rule/Model/Action/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Action/Interface.php b/app/code/core/Mage/Rule/Model/Action/Interface.php
index 9d7a3e9..e63e374 100644
--- a/app/code/core/Mage/Rule/Model/Action/Interface.php
+++ b/app/code/core/Mage/Rule/Model/Action/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Condition/Abstract.php b/app/code/core/Mage/Rule/Model/Condition/Abstract.php
index 62067a6..36b4c55 100644
--- a/app/code/core/Mage/Rule/Model/Condition/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Condition/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Condition/Combine.php b/app/code/core/Mage/Rule/Model/Condition/Combine.php
index 02b00f9..4bdfd25 100644
--- a/app/code/core/Mage/Rule/Model/Condition/Combine.php
+++ b/app/code/core/Mage/Rule/Model/Condition/Combine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Condition/Interface.php b/app/code/core/Mage/Rule/Model/Condition/Interface.php
index b6abd3f..5c8daa9 100644
--- a/app/code/core/Mage/Rule/Model/Condition/Interface.php
+++ b/app/code/core/Mage/Rule/Model/Condition/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Condition/Product/Abstract.php b/app/code/core/Mage/Rule/Model/Condition/Product/Abstract.php
index fff5cc2..11f620c 100644
--- a/app/code/core/Mage/Rule/Model/Condition/Product/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Condition/Product/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Environment.php b/app/code/core/Mage/Rule/Model/Environment.php
index 63f1503..2f18d74 100644
--- a/app/code/core/Mage/Rule/Model/Environment.php
+++ b/app/code/core/Mage/Rule/Model/Environment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Mysql4/Rule.php b/app/code/core/Mage/Rule/Model/Mysql4/Rule.php
index e65288d..9b0caab 100644
--- a/app/code/core/Mage/Rule/Model/Mysql4/Rule.php
+++ b/app/code/core/Mage/Rule/Model/Mysql4/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Mysql4/Rule/Collection.php b/app/code/core/Mage/Rule/Model/Mysql4/Rule/Collection.php
index b29f806..a789840 100644
--- a/app/code/core/Mage/Rule/Model/Mysql4/Rule/Collection.php
+++ b/app/code/core/Mage/Rule/Model/Mysql4/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Renderer/Actions.php b/app/code/core/Mage/Rule/Model/Renderer/Actions.php
index 751a1e0..dfaf37d 100644
--- a/app/code/core/Mage/Rule/Model/Renderer/Actions.php
+++ b/app/code/core/Mage/Rule/Model/Renderer/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Renderer/Conditions.php b/app/code/core/Mage/Rule/Model/Renderer/Conditions.php
index 06cf827..3e57072 100644
--- a/app/code/core/Mage/Rule/Model/Renderer/Conditions.php
+++ b/app/code/core/Mage/Rule/Model/Renderer/Conditions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Resource/Abstract.php b/app/code/core/Mage/Rule/Model/Resource/Abstract.php
index 1cbc95b..ee8484c 100644
--- a/app/code/core/Mage/Rule/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Resource/Rule.php b/app/code/core/Mage/Rule/Model/Resource/Rule.php
index 82f9375..5a7e5e5 100644
--- a/app/code/core/Mage/Rule/Model/Resource/Rule.php
+++ b/app/code/core/Mage/Rule/Model/Resource/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Resource/Rule/Collection.php b/app/code/core/Mage/Rule/Model/Resource/Rule/Collection.php
index 6e1e081..5d3f453 100644
--- a/app/code/core/Mage/Rule/Model/Resource/Rule/Collection.php
+++ b/app/code/core/Mage/Rule/Model/Resource/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Resource/Rule/Collection/Abstract.php b/app/code/core/Mage/Rule/Model/Resource/Rule/Collection/Abstract.php
index da05bc2..d69b92e 100644
--- a/app/code/core/Mage/Rule/Model/Resource/Rule/Collection/Abstract.php
+++ b/app/code/core/Mage/Rule/Model/Resource/Rule/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Resource/Rule/Condition/SqlBuilder.php b/app/code/core/Mage/Rule/Model/Resource/Rule/Condition/SqlBuilder.php
index cbf77e2..b6b0aa3 100644
--- a/app/code/core/Mage/Rule/Model/Resource/Rule/Condition/SqlBuilder.php
+++ b/app/code/core/Mage/Rule/Model/Resource/Rule/Condition/SqlBuilder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/Model/Rule.php b/app/code/core/Mage/Rule/Model/Rule.php
index 1a54c17..bbb72f9 100644
--- a/app/code/core/Mage/Rule/Model/Rule.php
+++ b/app/code/core/Mage/Rule/Model/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Rule/etc/config.xml b/app/code/core/Mage/Rule/etc/config.xml
index cde6e00..b8d1483 100644
--- a/app/code/core/Mage/Rule/etc/config.xml
+++ b/app/code/core/Mage/Rule/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Rule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement.php
index bed82bf..bcfff13 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/Grid.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/Grid.php
index eb5bdee..8afc2b4 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/Grid.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View.php
index 1d0a884..a543abf 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Form.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Form.php
index ad89fc2..42badbf 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Form.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Info.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Info.php
index 3c09e7d..34f08ef 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Info.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Orders.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Orders.php
index e491f2b..8293456 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Orders.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tab/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tabs.php b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tabs.php
index 5ce966f..2afa2ad 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tabs.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Billing/Agreement/View/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Agreement.php b/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Agreement.php
index cc3e1bc..40acf4a 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Agreement.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Recurring/Profile.php b/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Recurring/Profile.php
index 2796295..862768c 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Recurring/Profile.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Customer/Edit/Tab/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile.php
index 343b895..d952b11 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Edit/Form.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Edit/Form.php
index 0f31a57..2b3531d 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Edit/Form.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Grid.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Grid.php
index bb2252d..e023b69 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Grid.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View.php
index fb23a53..414210c 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Getawayinfo.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Getawayinfo.php
index 411db6b..4f498b4 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Getawayinfo.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Getawayinfo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Info.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Info.php
index 51bcddf..16a0214 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Info.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Items.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Items.php
index cf8024d..321871a 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Items.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Info.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Info.php
index f86aa83..19042e3 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Info.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Orders.php b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Orders.php
index f9e2721..4e27ff7 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Orders.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Recurring/Profile/View/Tab/Orders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form.php b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form.php
index 1586cfe..dbdf42e 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Coupon.php b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Coupon.php
index 9b96f56..b7ef5fd 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Coupon.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Order.php b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Order.php
index 59380f0..e25b09d 100644
--- a/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Order.php
+++ b/app/code/core/Mage/Sales/Block/Adminhtml/Report/Filter/Form/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Billing/Agreement/View.php b/app/code/core/Mage/Sales/Block/Billing/Agreement/View.php
index 966ecc1..5a8b134 100644
--- a/app/code/core/Mage/Sales/Block/Billing/Agreement/View.php
+++ b/app/code/core/Mage/Sales/Block/Billing/Agreement/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Billing/Agreements.php b/app/code/core/Mage/Sales/Block/Billing/Agreements.php
index 64625e4..0cf86fb 100644
--- a/app/code/core/Mage/Sales/Block/Billing/Agreements.php
+++ b/app/code/core/Mage/Sales/Block/Billing/Agreements.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Guest/Links.php b/app/code/core/Mage/Sales/Block/Guest/Links.php
index 27a9196..2a19518 100644
--- a/app/code/core/Mage/Sales/Block/Guest/Links.php
+++ b/app/code/core/Mage/Sales/Block/Guest/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Items/Abstract.php b/app/code/core/Mage/Sales/Block/Items/Abstract.php
index ad89ac3..6d1adda 100644
--- a/app/code/core/Mage/Sales/Block/Items/Abstract.php
+++ b/app/code/core/Mage/Sales/Block/Items/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Comments.php b/app/code/core/Mage/Sales/Block/Order/Comments.php
index 0d8f147..42691b9 100644
--- a/app/code/core/Mage/Sales/Block/Order/Comments.php
+++ b/app/code/core/Mage/Sales/Block/Order/Comments.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Sales_Block_Order_Comments extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/Sales/Block/Order/Creditmemo.php b/app/code/core/Mage/Sales/Block/Order/Creditmemo.php
index 9e0493d..a05d11e 100644
--- a/app/code/core/Mage/Sales/Block/Order/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Block/Order/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Creditmemo/Items.php b/app/code/core/Mage/Sales/Block/Order/Creditmemo/Items.php
index 97ff52c..d5a7f87 100644
--- a/app/code/core/Mage/Sales/Block/Order/Creditmemo/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Creditmemo/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Creditmemo/Totals.php b/app/code/core/Mage/Sales/Block/Order/Creditmemo/Totals.php
index af093e8..5f79e49 100644
--- a/app/code/core/Mage/Sales/Block/Order/Creditmemo/Totals.php
+++ b/app/code/core/Mage/Sales/Block/Order/Creditmemo/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Sales_Block_Order_Creditmemo_Totals extends Mage_Sales_Block_Order_Totals
diff --git a/app/code/core/Mage/Sales/Block/Order/Details.php b/app/code/core/Mage/Sales/Block/Order/Details.php
index df5b9c8..207d85d 100644
--- a/app/code/core/Mage/Sales/Block/Order/Details.php
+++ b/app/code/core/Mage/Sales/Block/Order/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Creditmemo/Items.php b/app/code/core/Mage/Sales/Block/Order/Email/Creditmemo/Items.php
index 1434285..6b660e8 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Creditmemo/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Creditmemo/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Invoice/Items.php b/app/code/core/Mage/Sales/Block/Order/Email/Invoice/Items.php
index faa3f82..bc81bb5 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Invoice/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Invoice/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Items.php b/app/code/core/Mage/Sales/Block/Order/Email/Items.php
index 755b374..65356db 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Items/Default.php b/app/code/core/Mage/Sales/Block/Order/Email/Items/Default.php
index 018fbd4..2c70b84 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Items/Default.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Items/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Default.php b/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Default.php
index d9e2a5e..5df8427 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Default.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Grouped.php b/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Grouped.php
index 6feee4e..466c604 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Grouped.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Items/Order/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Email/Shipment/Items.php b/app/code/core/Mage/Sales/Block/Order/Email/Shipment/Items.php
index c863472..a92ca1d 100644
--- a/app/code/core/Mage/Sales/Block/Order/Email/Shipment/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Email/Shipment/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/History.php b/app/code/core/Mage/Sales/Block/Order/History.php
index 0636b23..0489d0e 100644
--- a/app/code/core/Mage/Sales/Block/Order/History.php
+++ b/app/code/core/Mage/Sales/Block/Order/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Info.php b/app/code/core/Mage/Sales/Block/Order/Info.php
index 5c6160e..c814dea 100644
--- a/app/code/core/Mage/Sales/Block/Order/Info.php
+++ b/app/code/core/Mage/Sales/Block/Order/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Info/Buttons.php b/app/code/core/Mage/Sales/Block/Order/Info/Buttons.php
index c3886a1..3cf3d88 100644
--- a/app/code/core/Mage/Sales/Block/Order/Info/Buttons.php
+++ b/app/code/core/Mage/Sales/Block/Order/Info/Buttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Invoice.php b/app/code/core/Mage/Sales/Block/Order/Invoice.php
index 802cd22..5ff52f5 100644
--- a/app/code/core/Mage/Sales/Block/Order/Invoice.php
+++ b/app/code/core/Mage/Sales/Block/Order/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Invoice/Items.php b/app/code/core/Mage/Sales/Block/Order/Invoice/Items.php
index d1da6df..1c6116b 100644
--- a/app/code/core/Mage/Sales/Block/Order/Invoice/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Invoice/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Invoice/Totals.php b/app/code/core/Mage/Sales/Block/Order/Invoice/Totals.php
index 1cbd580..6f0a647 100644
--- a/app/code/core/Mage/Sales/Block/Order/Invoice/Totals.php
+++ b/app/code/core/Mage/Sales/Block/Order/Invoice/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Sales_Block_Order_Invoice_Totals extends Mage_Sales_Block_Order_Totals
diff --git a/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Default.php b/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Default.php
index 4467342..6a58a16 100644
--- a/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Default.php
+++ b/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Grouped.php b/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Grouped.php
index 3217c76..065d5be 100644
--- a/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Grouped.php
+++ b/app/code/core/Mage/Sales/Block/Order/Item/Renderer/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Items.php b/app/code/core/Mage/Sales/Block/Order/Items.php
index 2e6f77b..c2b178b 100644
--- a/app/code/core/Mage/Sales/Block/Order/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Print.php b/app/code/core/Mage/Sales/Block/Order/Print.php
index 6b81900..588d07e 100644
--- a/app/code/core/Mage/Sales/Block/Order/Print.php
+++ b/app/code/core/Mage/Sales/Block/Order/Print.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Print/Creditmemo.php b/app/code/core/Mage/Sales/Block/Order/Print/Creditmemo.php
index 56fae07..b84edb5 100644
--- a/app/code/core/Mage/Sales/Block/Order/Print/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Block/Order/Print/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Print/Invoice.php b/app/code/core/Mage/Sales/Block/Order/Print/Invoice.php
index 67beb47..a0e7db7 100644
--- a/app/code/core/Mage/Sales/Block/Order/Print/Invoice.php
+++ b/app/code/core/Mage/Sales/Block/Order/Print/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Print/Shipment.php b/app/code/core/Mage/Sales/Block/Order/Print/Shipment.php
index 9820fd2..0304c97 100644
--- a/app/code/core/Mage/Sales/Block/Order/Print/Shipment.php
+++ b/app/code/core/Mage/Sales/Block/Order/Print/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Recent.php b/app/code/core/Mage/Sales/Block/Order/Recent.php
index c1e72af..bf7e48d 100644
--- a/app/code/core/Mage/Sales/Block/Order/Recent.php
+++ b/app/code/core/Mage/Sales/Block/Order/Recent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Shipment.php b/app/code/core/Mage/Sales/Block/Order/Shipment.php
index 69aa859..0598493 100644
--- a/app/code/core/Mage/Sales/Block/Order/Shipment.php
+++ b/app/code/core/Mage/Sales/Block/Order/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Shipment/Items.php b/app/code/core/Mage/Sales/Block/Order/Shipment/Items.php
index e217c6d..2c8f324 100644
--- a/app/code/core/Mage/Sales/Block/Order/Shipment/Items.php
+++ b/app/code/core/Mage/Sales/Block/Order/Shipment/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Tax.php b/app/code/core/Mage/Sales/Block/Order/Tax.php
index 3b8a5f9..bac476f 100644
--- a/app/code/core/Mage/Sales/Block/Order/Tax.php
+++ b/app/code/core/Mage/Sales/Block/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Order/Totals.php b/app/code/core/Mage/Sales/Block/Order/Totals.php
index f4b238a..c2fd6d1 100644
--- a/app/code/core/Mage/Sales/Block/Order/Totals.php
+++ b/app/code/core/Mage/Sales/Block/Order/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Sales_Block_Order_Totals extends Mage_Core_Block_Template
diff --git a/app/code/core/Mage/Sales/Block/Order/View.php b/app/code/core/Mage/Sales/Block/Order/View.php
index 6330c14..9cb6693 100644
--- a/app/code/core/Mage/Sales/Block/Order/View.php
+++ b/app/code/core/Mage/Sales/Block/Order/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Payment/Form/Billing/Agreement.php b/app/code/core/Mage/Sales/Block/Payment/Form/Billing/Agreement.php
index 756ce2f..4a00fb0 100644
--- a/app/code/core/Mage/Sales/Block/Payment/Form/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Block/Payment/Form/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Payment/Info/Billing/Agreement.php b/app/code/core/Mage/Sales/Block/Payment/Info/Billing/Agreement.php
index c2d0240..809b7d8 100644
--- a/app/code/core/Mage/Sales/Block/Payment/Info/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Block/Payment/Info/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Recurring/Profile/View.php b/app/code/core/Mage/Sales/Block/Recurring/Profile/View.php
index 0b87c0a..0696516 100644
--- a/app/code/core/Mage/Sales/Block/Recurring/Profile/View.php
+++ b/app/code/core/Mage/Sales/Block/Recurring/Profile/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Recurring/Profiles.php b/app/code/core/Mage/Sales/Block/Recurring/Profiles.php
index a2e0f10..349614d 100644
--- a/app/code/core/Mage/Sales/Block/Recurring/Profiles.php
+++ b/app/code/core/Mage/Sales/Block/Recurring/Profiles.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Reorder/Sidebar.php b/app/code/core/Mage/Sales/Block/Reorder/Sidebar.php
index 6a5c0b2..e71d02c 100644
--- a/app/code/core/Mage/Sales/Block/Reorder/Sidebar.php
+++ b/app/code/core/Mage/Sales/Block/Reorder/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Block/Widget/Guest/Form.php b/app/code/core/Mage/Sales/Block/Widget/Guest/Form.php
index db650bf..e7b68d8 100644
--- a/app/code/core/Mage/Sales/Block/Widget/Guest/Form.php
+++ b/app/code/core/Mage/Sales/Block/Widget/Guest/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Controller/Abstract.php b/app/code/core/Mage/Sales/Controller/Abstract.php
index 51af9d2..9337711 100644
--- a/app/code/core/Mage/Sales/Controller/Abstract.php
+++ b/app/code/core/Mage/Sales/Controller/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Exception.php b/app/code/core/Mage/Sales/Exception.php
index cfc5dc2..272abce 100644
--- a/app/code/core/Mage/Sales/Exception.php
+++ b/app/code/core/Mage/Sales/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Helper/Data.php b/app/code/core/Mage/Sales/Helper/Data.php
index 4538e3e..56242c4 100644
--- a/app/code/core/Mage/Sales/Helper/Data.php
+++ b/app/code/core/Mage/Sales/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Helper/Guest.php b/app/code/core/Mage/Sales/Helper/Guest.php
index b564f27..7b22fcf 100644
--- a/app/code/core/Mage/Sales/Helper/Guest.php
+++ b/app/code/core/Mage/Sales/Helper/Guest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Helper/Reorder.php b/app/code/core/Mage/Sales/Helper/Reorder.php
index e4457b0..6359d2c 100644
--- a/app/code/core/Mage/Sales/Helper/Reorder.php
+++ b/app/code/core/Mage/Sales/Helper/Reorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Abstract.php b/app/code/core/Mage/Sales/Model/Abstract.php
index 5309ae9..759533e 100644
--- a/app/code/core/Mage/Sales/Model/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api/Resource.php b/app/code/core/Mage/Sales/Model/Api/Resource.php
index f399683..0686799 100644
--- a/app/code/core/Mage/Sales/Model/Api/Resource.php
+++ b/app/code/core/Mage/Sales/Model/Api/Resource.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order.php b/app/code/core/Mage/Sales/Model/Api2/Order.php
index 5722541..68b8c68 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Address.php b/app/code/core/Mage/Sales/Model/Api2/Order/Address.php
index bffd4a3..af16f5e 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Address.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest.php b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest.php
index c17c38c..27967ad 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Admin/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Admin/V1.php
index 9a242d7..66f6958 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Customer/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Customer/V1.php
index 1d9dce1..be85632 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Address/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Comment.php b/app/code/core/Mage/Sales/Model/Api2/Order/Comment.php
index bb72138..85f78b2 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest.php b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest.php
index a9df326..c0db2c6 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Admin/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Admin/V1.php
index 9140a08..b61895e 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Customer/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Customer/V1.php
index 37a97ce..ceb3af3 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Comment/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Item.php b/app/code/core/Mage/Sales/Model/Api2/Order/Item.php
index c7436f1..013a8da 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Item.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest.php b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest.php
index 4fb7eb0..360b71b 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Admin/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Admin/V1.php
index 11bbefd..8373764 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Customer/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Customer/V1.php
index 2aff81f..d0fa58e 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Item/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Rest.php b/app/code/core/Mage/Sales/Model/Api2/Order/Rest.php
index 1496bb7..ab42f43 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Rest.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Admin/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Admin/V1.php
index 1edf31b..34d1b9c 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Admin/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Admin/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Customer/V1.php b/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Customer/V1.php
index 3eb526b..9ebbea4 100644
--- a/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Customer/V1.php
+++ b/app/code/core/Mage/Sales/Model/Api2/Order/Rest/Customer/V1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Billing/Agreement.php b/app/code/core/Mage/Sales/Model/Billing/Agreement.php
index df4b8de..72e0a6e 100644
--- a/app/code/core/Mage/Sales/Model/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Model/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Config.php b/app/code/core/Mage/Sales/Model/Config.php
index ac89041..76dfaa5 100644
--- a/app/code/core/Mage/Sales/Model/Config.php
+++ b/app/code/core/Mage/Sales/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Config/Ordered.php b/app/code/core/Mage/Sales/Model/Config/Ordered.php
index e3a7d36..551ffff 100644
--- a/app/code/core/Mage/Sales/Model/Config/Ordered.php
+++ b/app/code/core/Mage/Sales/Model/Config/Ordered.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Convert/Order.php b/app/code/core/Mage/Sales/Model/Convert/Order.php
index d0f07dd..55aedea 100644
--- a/app/code/core/Mage/Sales/Model/Convert/Order.php
+++ b/app/code/core/Mage/Sales/Model/Convert/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Convert/Quote.php b/app/code/core/Mage/Sales/Model/Convert/Quote.php
index 5839e5d..59aaf5b 100644
--- a/app/code/core/Mage/Sales/Model/Convert/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Convert/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Email/Template.php b/app/code/core/Mage/Sales/Model/Email/Template.php
index 2fd0a29..0b14775 100644
--- a/app/code/core/Mage/Sales/Model/Email/Template.php
+++ b/app/code/core/Mage/Sales/Model/Email/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order.php b/app/code/core/Mage/Sales/Model/Entity/Order.php
index f458d89..090e5c9 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Address.php b/app/code/core/Mage/Sales/Model/Entity/Order/Address.php
index 4c2492a..86ba328 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Address.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Address/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Address/Collection.php
index 697d191..48ff54d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Billing.php b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Billing.php
index a71ba47..759e5a4 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Billing.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Child.php
index 922a0e4..c70a277 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Parent.php
index 7454f39..b6fa090 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Shipping.php b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Shipping.php
index 9ba6b4f..b360385 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Attribute/Backend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Collection.php
index 31404f0..93338d8 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo.php
index 25ee63b..edb4061 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Child.php
index c3c8bdb..29e6ef7 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Parent.php
index e928d7b..ab8874d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Collection.php
index ec9f1e1..2c8f002 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment.php
index 010f8ad..f920a98 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment/Collection.php
index f6d0dd8..fd3df17 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item.php
index b5803ac..626d28a 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item/Collection.php
index 6294e17..cbe38ae 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Creditmemo/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice.php
index 7d25b3b..6ec82dc 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Child.php
index 4698ac9..1f4187d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Item.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Item.php
index 9d05922..f73d9a7 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Order.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Order.php
index 91aa5b7..22d611d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Order.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Parent.php
index e2c207e..bed0b40 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Collection.php
index fe10fe3..480064d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment.php
index 71fc933..cf1413a 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment/Collection.php
index 355fd46..efb373c 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item.php
index b5ff6ce..59005d3 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item/Collection.php
index 99a18f0..8f33bc8 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Invoice/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Item.php b/app/code/core/Mage/Sales/Model/Entity/Order/Item.php
index 03dcd13..d46aee6 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Item/Collection.php
index 8ce4bd7..4897033 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Payment.php b/app/code/core/Mage/Sales/Model/Entity/Order/Payment.php
index 2fae7f0..65590cb 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Payment/Collection.php
index 049bfd2..ddde54e 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment.php
index 3b0dd00..cbbe021 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Child.php
index 36bea25..3745f32 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Parent.php
index c9914fb..35ab29d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Collection.php
index b10807e..61e9634 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment.php
index 3fb7121..3a2a7db 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment/Collection.php
index e14424a..3bb2daa 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item.php
index 91babf7..046a353 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item/Collection.php
index 5fec514..2c750c7 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track.php
index cdea6c7..d82b174 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track/Collection.php
index 5af0ed8..ead38c5 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Shipment/Track/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Status/History.php b/app/code/core/Mage/Sales/Model/Entity/Order/Status/History.php
index da14216..e20fe61 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Status/History.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Status/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Order/Status/History/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Order/Status/History/Collection.php
index b95dc40..e7ba8974 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Order/Status/History/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Order/Status/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote.php b/app/code/core/Mage/Sales/Model/Entity/Quote.php
index dbf49c9..848c939 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address.php
index 1e5be3b..d57c2b0 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend.php
index 576488d..3f762ab 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Child.php
index 13787bc..146134d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Parent.php
index 848280c..aa10442 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Region.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Region.php
index 955596f..9418867 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Region.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Backend/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend.php
index 43eaa96..fde9a05 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Custbalance.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Custbalance.php
index 00141cc..34d1d9d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Custbalance.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Custbalance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Discount.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Discount.php
index 7eefe2b..aac2e57 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Grand.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Grand.php
index c3b8345..ecf9a96 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Shipping.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Shipping.php
index 4d32c87..7d19192 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Subtotal.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Subtotal.php
index 8e80a8e..674095f 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Tax.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Tax.php
index ec51052..d08d63d 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Attribute/Frontend/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Collection.php
index d58b62f..3b4f4d6 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item.php
index 0d5dcbd..56549bb 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item/Collection.php
index 8b19312..12240fb 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate.php
index 6872f31..b4efc2c 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate/Collection.php
index 38dcd2a..9fa3bf3 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Address/Rate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Collection.php
index e0f9f1d..0721de1 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Item.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Item.php
index 4091a257..f365c55 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Item.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Item/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Item/Collection.php
index 2b862de..ab43e4c 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Payment.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Payment.php
index 5bc5dbb..c200336 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Quote/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Quote/Payment/Collection.php
index 41d6ff3..adaff73 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Quote/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Quote/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Sale/Collection.php b/app/code/core/Mage/Sales/Model/Entity/Sale/Collection.php
index bced44c..95cb919 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Sale/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Sale/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Entity/Setup.php b/app/code/core/Mage/Sales/Model/Entity/Setup.php
index affa6a7..6857bc0 100644
--- a/app/code/core/Mage/Sales/Model/Entity/Setup.php
+++ b/app/code/core/Mage/Sales/Model/Entity/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Abstract.php
index 1ceee38..68d811f 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement.php b/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement.php
index 256e6ce..97d9fdb 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement/Collection.php
index df1efb3..5541747 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Billing/Agreement/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Collection/Abstract.php
index f64ed8d..d21618b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Order.php
index 7daa09c..6c444e2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Abstract.php
index c0759ed..3f20832 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Address.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Address.php
index 4d39483..5667e34 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Address.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Address/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Address/Collection.php
index 34e3939..75a9f14 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Billing.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Billing.php
index 814dcda..317a050 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Billing.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Child.php
index 8789a54..6f1eb31 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Parent.php
index 4be55da..b020d1e 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Shipping.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Shipping.php
index 240ef77..acc2c8f 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Attribute/Backend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection.php
index 1b9aac2..5704724 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection/Abstract.php
index 4fd4e71..7303bc9 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Comment/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Comment/Collection/Abstract.php
index 4fc0fea..e2e4c3c 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Comment/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Comment/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo.php
index 1701035..4a19d60 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Child.php
index fd34d5c..83dc83b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Parent.php
index 2cf200f..3d6d140 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Collection.php
index 11d7bc6..fe5aa39 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment.php
index 5c842f6..c41240e 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment/Collection.php
index 62e756e..e4c0dee 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Grid/Collection.php
index 1981d6e..04e41c0 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item.php
index 7431edd..6402b46 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item/Collection.php
index 985eb87..cf9f16f 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Creditmemo/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Grid/Collection.php
index b10b5a6..bf84569 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice.php
index 0cddd23..220a650 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Child.php
index 1edacde..56d7c0a 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Item.php
index 5f916df..3297c9a 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Order.php
index 9c7f351..c956215 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Parent.php
index 155c9cc..5ae50a2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Collection.php
index c35c1f9..1ff9895 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment.php
index cdb62c1..0dcdfcb 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment/Collection.php
index e4a08f2..9f45419 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Grid/Collection.php
index e1d9ab8..393ac13 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item.php
index 33ceeb2..db84063 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item/Collection.php
index f368692..6703f18 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Invoice/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Item.php
index 1b8060b..a4401b7 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Item/Collection.php
index 5770f57..ae96696 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment.php
index 9f147cc..6c78f64 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Collection.php
index e787f72..c2868f2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction.php
index 8438dfe..f8ca7f7 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction/Collection.php
index 2ef59a6..7988919 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Payment/Transaction/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment.php
index d0298bd..8670cb1 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Child.php
index c46875c..f59fd09 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Parent.php
index eb95e7a..da10539 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Collection.php
index 2b05bfd..3a40d1b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment.php
index b4d2a80..6a9a9c0 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment/Collection.php
index d7c927f..475edf2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Grid/Collection.php
index 812fb18..b371dbd 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item.php
index 43d7e05..1b4ea10 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item/Collection.php
index ef9c5dd..77af9b1 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track.php
index 6178a37..7d8dae6 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track/Collection.php
index 27bd8f2..32932d5 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Shipment/Track/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status.php
index 7064ef7..7f48102 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/Collection.php
index a12470e..53d30bb 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History.php
index 4b4689a..c2b03c8 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History/Collection.php
index bc7ffb8..00f8d83 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Status/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax.php
index 1d97b3f..dec7d22 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax/Collection.php
index 233751d..efe73db 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Order/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote.php
index 0e757d7..20ea261 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address.php
index 0a8dc12..b421b9d 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend.php
index e218dfc..60a47b5 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Child.php
index 0badb10..b557af9 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Parent.php
index b3acd49..d2f2009 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Region.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Region.php
index c31b225..4d2201a 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Region.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Backend/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend.php
index 467a05b..0bd66c2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Custbalance.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Custbalance.php
index aead2fc..1e9fab8 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Custbalance.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Custbalance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Discount.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Discount.php
index 7e15e3d..0686d28 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Grand.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Grand.php
index 90936bb..726e132 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Shipping.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Shipping.php
index 17c081f..93b9799 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Subtotal.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Subtotal.php
index 9d6e534..c08dd10 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Tax.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Tax.php
index 87d7c35..d527074 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Attribute/Frontend/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Collection.php
index fdadddb..bd5aed4 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item.php
index 46a6812..570a58c 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item/Collection.php
index aa5f7ca..6ba7a06 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate.php
index 2072437..a8d146b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate/Collection.php
index 03754fc..c932735 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Address/Rate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Collection.php
index 416feb2..4b9a827 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item.php
index 141c5b6..292f894 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Collection.php
index 96c89c5..6ede284 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option.php
index 53056a7..e8031f3 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option/Collection.php
index 821a8d7..ac15b4e 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Item/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment.php
index d430819..630ff8c 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment/Collection.php
index 812121c..fc02a01 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Quote/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile.php b/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile.php
index a8000cf..d42232b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile/Collection.php
index 207cfdf..ee4c9ce 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Recurring/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report.php b/app/code/core/Mage/Sales/Model/Mysql4/Report.php
index eb133d1..427f2fe 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Abstract.php
index cd311ea..c32eae2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers.php
index 917598f..6aaba64 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers/Collection.php
index 6691dc0..2cb031a 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Bestsellers/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Collection/Abstract.php
index 3dfd40e..1f8c9cf 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced.php
index 442846e..6f6a50b 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Invoiced.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Invoiced.php
index 675fe9e..a14ac51 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Invoiced.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Invoiced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Order.php
index 06b309e..5aa4566 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Invoiced/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order.php
index 3b976a1..1345361 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Collection.php
index 624a6bd..39b7c88 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Updatedat/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Updatedat/Collection.php
index 1bf8a92..1e93a3f 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Updatedat/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Order/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded.php
index a9ecf58..e784be2 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Order.php
index 2dc8499..bb68fd1 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Refunded.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Refunded.php
index 8531fe1..274e7e0 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Refunded.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Refunded/Collection/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping.php
index 85e5f06..087a3eb 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Order.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Order.php
index a47493c..1e474f1 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Shipment.php b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Shipment.php
index 74ed5c1..8cbddb3 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Report/Shipping/Collection/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Sale/Collection.php b/app/code/core/Mage/Sales/Model/Mysql4/Sale/Collection.php
index 95f6d1d..a2c3e1a 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Sale/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Sale/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Mysql4/Setup.php b/app/code/core/Mage/Sales/Model/Mysql4/Setup.php
index 12097bd..4ee47b3 100644
--- a/app/code/core/Mage/Sales/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Sales/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Observer.php b/app/code/core/Mage/Sales/Model/Observer.php
index 75a1fdc..4f7b273 100644
--- a/app/code/core/Mage/Sales/Model/Observer.php
+++ b/app/code/core/Mage/Sales/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order.php b/app/code/core/Mage/Sales/Model/Order.php
index 10dc3f0..1bed3d8 100644
--- a/app/code/core/Mage/Sales/Model/Order.php
+++ b/app/code/core/Mage/Sales/Model/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Address.php b/app/code/core/Mage/Sales/Model/Order/Address.php
index e654867..d6e5738 100644
--- a/app/code/core/Mage/Sales/Model/Order/Address.php
+++ b/app/code/core/Mage/Sales/Model/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Api.php b/app/code/core/Mage/Sales/Model/Order/Api.php
index e3427a1..d0e501c 100644
--- a/app/code/core/Mage/Sales/Model/Order/Api.php
+++ b/app/code/core/Mage/Sales/Model/Order/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Api/V2.php b/app/code/core/Mage/Sales/Model/Order/Api/V2.php
index 2a478e5..f95c8d0 100644
--- a/app/code/core/Mage/Sales/Model/Order/Api/V2.php
+++ b/app/code/core/Mage/Sales/Model/Order/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Config.php b/app/code/core/Mage/Sales/Model/Order/Config.php
index c50fa8b..81b06ea 100644
--- a/app/code/core/Mage/Sales/Model/Order/Config.php
+++ b/app/code/core/Mage/Sales/Model/Order/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo.php
index 2469520..d3d7712 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api.php
index 983118e..ee2c8aa 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api/V2.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api/V2.php
index 4beffa7..898c53b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api/V2.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Comment.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Comment.php
index d081973..fa30a92 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Config.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Config.php
index af97df6..a463ba1 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Config.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Item.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Item.php
index c993432..3f86d79 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Item.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Abstract.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Abstract.php
index 14b6d16..5fab478 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Cost.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Cost.php
index 1dab495..498b8c8 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Cost.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Cost.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Discount.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Discount.php
index 00b9e20..18f350a 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Grand.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Grand.php
index ca2d93d..78ca194 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Shipping.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Shipping.php
index 46a4a93..2bf95c3 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Subtotal.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Subtotal.php
index 490fea2..2debcc7 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Tax.php b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Tax.php
index 8869c72..1ff7640 100644
--- a/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Order/Creditmemo/Total/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice.php b/app/code/core/Mage/Sales/Model/Order/Invoice.php
index 7313210..9fbcc8c 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Api.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Api.php
index 8b127ab..1c95fb3 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Api.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Api/V2.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Api/V2.php
index f26ec20..316bf83 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Api/V2.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Comment.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Comment.php
index 3b0f901..cddfe25 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Config.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Config.php
index 319dc02..bbde2c8 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Config.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Item.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Item.php
index 6fd7f92..1d5c247 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Item.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Abstract.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Abstract.php
index ccfd6f0..44871b8 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Cost.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Cost.php
index 4d0c70a..db7175b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Cost.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Cost.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Discount.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Discount.php
index bf19649..af9a51b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Grand.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Grand.php
index 716baff..1addb2b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Shipping.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Shipping.php
index 0bd28fb..0434ccd 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Subtotal.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Subtotal.php
index dfef23c..dcc2d8c 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Tax.php b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Tax.php
index 234f522..73e091f 100644
--- a/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Order/Invoice/Total/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Item.php b/app/code/core/Mage/Sales/Model/Order/Item.php
index 5fba98a..97b0ddf 100644
--- a/app/code/core/Mage/Sales/Model/Order/Item.php
+++ b/app/code/core/Mage/Sales/Model/Order/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Payment.php b/app/code/core/Mage/Sales/Model/Order/Payment.php
index e447ed1..ff2523b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Payment/Transaction.php b/app/code/core/Mage/Sales/Model/Order/Payment/Transaction.php
index bdd2e67..5494322 100644
--- a/app/code/core/Mage/Sales/Model/Order/Payment/Transaction.php
+++ b/app/code/core/Mage/Sales/Model/Order/Payment/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Abstract.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Abstract.php
index 46103fb..0bd9328 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Creditmemo.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Creditmemo.php
index f930c34..6c939a6 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Invoice.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Invoice.php
index ce8cf7d..0cd9b08 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Invoice.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Abstract.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Abstract.php
index 48c8fe2..a37e033 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Default.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Default.php
index c4732fb..ff9536c 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Default.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Grouped.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Grouped.php
index 4450289..b91f172 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Grouped.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Creditmemo/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Default.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Default.php
index b5b5d96..e9487e0 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Default.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Grouped.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Grouped.php
index 3cf3a5b..9c095d7 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Grouped.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Invoice/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Shipment/Default.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Shipment/Default.php
index 1dcb932..37c5776 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Shipment/Default.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Items/Shipment/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment.php
index a2854e9..2787c40 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment/Packaging.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment/Packaging.php
index 2a8f42b..b8962d7 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment/Packaging.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Shipment/Packaging.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Pdf/Total/Default.php b/app/code/core/Mage/Sales/Model/Order/Pdf/Total/Default.php
index d54dec1..2c50967 100644
--- a/app/code/core/Mage/Sales/Model/Order/Pdf/Total/Default.php
+++ b/app/code/core/Mage/Sales/Model/Order/Pdf/Total/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment.php b/app/code/core/Mage/Sales/Model/Order/Shipment.php
index ebe36c1..e04f05e 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment/Api.php b/app/code/core/Mage/Sales/Model/Order/Shipment/Api.php
index c769320..f20a6fa 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment/Api.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment/Api/V2.php b/app/code/core/Mage/Sales/Model/Order/Shipment/Api/V2.php
index 443704e..5cff2af 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment/Api/V2.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment/Comment.php b/app/code/core/Mage/Sales/Model/Order/Shipment/Comment.php
index e9c7e05..567228d 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment/Item.php b/app/code/core/Mage/Sales/Model/Order/Shipment/Item.php
index 1c41ece2..1644a6b 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment/Item.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Shipment/Track.php b/app/code/core/Mage/Sales/Model/Order/Shipment/Track.php
index b682989..055323e 100644
--- a/app/code/core/Mage/Sales/Model/Order/Shipment/Track.php
+++ b/app/code/core/Mage/Sales/Model/Order/Shipment/Track.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Status.php b/app/code/core/Mage/Sales/Model/Order/Status.php
index 00758a9..b193481 100644
--- a/app/code/core/Mage/Sales/Model/Order/Status.php
+++ b/app/code/core/Mage/Sales/Model/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Status/History.php b/app/code/core/Mage/Sales/Model/Order/Status/History.php
index cbba96b..b65615f 100644
--- a/app/code/core/Mage/Sales/Model/Order/Status/History.php
+++ b/app/code/core/Mage/Sales/Model/Order/Status/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Tax.php b/app/code/core/Mage/Sales/Model/Order/Tax.php
index 02eeb3e..a1cf40c 100644
--- a/app/code/core/Mage/Sales/Model/Order/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Total.php b/app/code/core/Mage/Sales/Model/Order/Total.php
index 0796cc4..42df803 100644
--- a/app/code/core/Mage/Sales/Model/Order/Total.php
+++ b/app/code/core/Mage/Sales/Model/Order/Total.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Total/Abstract.php b/app/code/core/Mage/Sales/Model/Order/Total/Abstract.php
index 323954d..4a5b254 100644
--- a/app/code/core/Mage/Sales/Model/Order/Total/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Order/Total/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Order/Total/Config/Base.php b/app/code/core/Mage/Sales/Model/Order/Total/Config/Base.php
index 7ca3e46..c2de796 100644
--- a/app/code/core/Mage/Sales/Model/Order/Total/Config/Base.php
+++ b/app/code/core/Mage/Sales/Model/Order/Total/Config/Base.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Payment/Method/Billing/AgreementAbstract.php b/app/code/core/Mage/Sales/Model/Payment/Method/Billing/AgreementAbstract.php
index 1518bd4..4f42efe 100644
--- a/app/code/core/Mage/Sales/Model/Payment/Method/Billing/AgreementAbstract.php
+++ b/app/code/core/Mage/Sales/Model/Payment/Method/Billing/AgreementAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote.php b/app/code/core/Mage/Sales/Model/Quote.php
index 4a435cb..79687fc 100644
--- a/app/code/core/Mage/Sales/Model/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address.php b/app/code/core/Mage/Sales/Model/Quote/Address.php
index c08f5af..679c8a3 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Item.php b/app/code/core/Mage/Sales/Model/Quote/Address/Item.php
index 4de8a37..0cce9be 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Item.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Rate.php b/app/code/core/Mage/Sales/Model/Quote/Address/Rate.php
index c610875..44e8d12 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Rate.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total.php
index 1763f7e..d70980a 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Abstract.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Abstract.php
index 51f7011..b701af8 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Collector.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Collector.php
index 94db275..b8b6406 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Collector.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Collector.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Custbalance.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Custbalance.php
index 2cdae8b..0f71293 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Custbalance.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Custbalance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Discount.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Discount.php
index 9c3122e..230b457 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Grand.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Grand.php
index 106b4fa..5100d3a 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Msrp.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Msrp.php
index 21a514e..c19ed48 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Msrp.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Msrp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal.php
index 1ea986b..01612f3 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Collector.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Collector.php
index 3327c44..8977426 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Collector.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Collector.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Initial.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Initial.php
index d08c6bf..a55489e 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Initial.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Initial.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Trial.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Trial.php
index 7df5472..c6ad66f 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Trial.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Recurring/Trial.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/RecurringAbstract.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/RecurringAbstract.php
index c103052..ba2204a 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/RecurringAbstract.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/RecurringAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Shipping.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Shipping.php
index b09ce81..4ed5a9b 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Subtotal.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Subtotal.php
index 92b58bb..017be06 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Nominal/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Shipping.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Shipping.php
index 054ea27..ac1ace5 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Subtotal.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Subtotal.php
index b0c1ef9..1954d30 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Tax.php b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Tax.php
index 94f711a..3251169 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Address/Total/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Address/Total/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Config.php b/app/code/core/Mage/Sales/Model/Quote/Config.php
index 6b8ffea..12a473f 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Config.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Item.php b/app/code/core/Mage/Sales/Model/Quote/Item.php
index 55645cc..4d66578 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Item.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Item/Abstract.php b/app/code/core/Mage/Sales/Model/Quote/Item/Abstract.php
index e0096a4..513e48c 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Item/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Item/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Item/Option.php b/app/code/core/Mage/Sales/Model/Quote/Item/Option.php
index 0d32cc1..27aa097 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Item/Option.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Quote/Payment.php b/app/code/core/Mage/Sales/Model/Quote/Payment.php
index 7641a09..0f1dde9 100644
--- a/app/code/core/Mage/Sales/Model/Quote/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Quote/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Recurring/Profile.php b/app/code/core/Mage/Sales/Model/Recurring/Profile.php
index be617d1..cb59e42 100644
--- a/app/code/core/Mage/Sales/Model/Recurring/Profile.php
+++ b/app/code/core/Mage/Sales/Model/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Abstract.php
index 56a110e..f5ad1a2 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement.php b/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement.php
index 3e68f61..fdb09aa 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement/Collection.php
index 7f695d1..310da8b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Billing/Agreement/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Collection/Abstract.php
index b258440..3860e75 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Helper/Interface.php b/app/code/core/Mage/Sales/Model/Resource/Helper/Interface.php
index de33800..5c7e83c 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Helper/Interface.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Helper/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Helper/Mysql4.php b/app/code/core/Mage/Sales/Model/Resource/Helper/Mysql4.php
index 61824fc..1e18431 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Helper/Mysql4.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Helper/Mysql4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order.php b/app/code/core/Mage/Sales/Model/Resource/Order.php
index d5e0f2b..9f9a340 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Order/Abstract.php
index 54520bd..37a3087 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Address.php b/app/code/core/Mage/Sales/Model/Resource/Order/Address.php
index 6c4b28c..ab76b69 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Address.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Address/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Address/Collection.php
index 012f95e..9b3ea11 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Billing.php b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Billing.php
index 79deece..f687471 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Billing.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Child.php
index 5ba1f36..8d069ce 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Parent.php
index 77b9477..71cebe1 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Shipping.php b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Shipping.php
index c7aa4aa..a8cd959 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Attribute/Backend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Collection.php
index b950e48..6230072 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Order/Collection/Abstract.php
index 8cb1419..fc5c8fb 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Comment/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Order/Comment/Collection/Abstract.php
index 8a9c43d..0e41b89 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Comment/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Comment/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo.php
index f400b0a..e28e838 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Child.php
index 94e6a07..b3672a2 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Parent.php
index e096ab0..a4c24d4 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Collection.php
index 93279e2..69ecf29 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment.php
index 156cd42..fcc081d 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment/Collection.php
index eda3413..e6c2548 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Grid/Collection.php
index 4d1a635..06046d2 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item.php
index 61b083d..4b40080 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item/Collection.php
index b9d8eba..daec6e9 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Creditmemo/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Grid/Collection.php
index ef9d0d5..2d74005 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice.php
index ebc9fd4..3352a57 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Child.php
index a7a830a..2abf281 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Item.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Item.php
index e555b29..e57e641 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Order.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Order.php
index bebc43a..5d12035 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Parent.php
index b4b0149..ca23827 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Collection.php
index a4809c9..2fd23aa 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment.php
index 15ab045..e1a60f9 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment/Collection.php
index 4ce1818..d03eb72 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Grid/Collection.php
index d4053dc..b669ecc 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item.php
index 85da309..10f20fe 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item/Collection.php
index f81d8cf..05273f1 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Invoice/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Item.php b/app/code/core/Mage/Sales/Model/Resource/Order/Item.php
index 70f4fa9..9b00f8b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Item/Collection.php
index 2722cac..67a4d42 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Payment.php b/app/code/core/Mage/Sales/Model/Resource/Order/Payment.php
index d77f6d8..f1e2a60 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Collection.php
index 0eaac2b..4e88ad1 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction.php b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction.php
index 0a60910..8d8b13b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction/Collection.php
index bdfce15..25847cb 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Payment/Transaction/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment.php
index 84ee851..e674c78 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Child.php
index 2f97b03..8afb709 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Parent.php
index aa82d1c..8422e81 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Collection.php
index 18c91be..a5133a8 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment.php
index 28d8a4a..79eb0c9 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment/Collection.php
index 67879eb..69fdf27 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Comment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Grid/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Grid/Collection.php
index 2b98313..4cc449a 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Grid/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Grid/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item.php
index 2574706..68adf32 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item/Collection.php
index c647601..1fc779e 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track.php
index e219bb9..46a49c7 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track/Collection.php
index 916d99b..2bb264b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Shipment/Track/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Status.php b/app/code/core/Mage/Sales/Model/Resource/Order/Status.php
index eb99568..3e0fa76 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Status.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Status/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Status/Collection.php
index d6b4e39..658a6ee 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Status/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Status/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Status/History.php b/app/code/core/Mage/Sales/Model/Resource/Order/Status/History.php
index c5995d5..aa787d5 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Status/History.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Status/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Status/History/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Status/History/Collection.php
index db36a11..b7ad71f 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Status/History/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Status/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Tax.php b/app/code/core/Mage/Sales/Model/Resource/Order/Tax.php
index 81f1ab6..bee87b6 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Order/Tax/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Order/Tax/Collection.php
index 5e3ba90..044d0c8 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Order/Tax/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Order/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote.php b/app/code/core/Mage/Sales/Model/Resource/Quote.php
index 7c55f54..2f3aa47 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address.php
index 0401d38..03757d0 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend.php
index 42c9957..64d33e5 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Child.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Child.php
index cbe6e72..afef8c5 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Child.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Child.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Parent.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Parent.php
index f34097f..00cc998 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Parent.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Parent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Region.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Region.php
index 2fa4b3e..bfb398e 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Region.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Backend/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend.php
index b5416a8..340f224 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Custbalance.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Custbalance.php
index a65b971..5c19be3 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Custbalance.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Custbalance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Discount.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Discount.php
index 7a32e4a..e177d4a 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Discount.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Grand.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Grand.php
index 87dd009..01e92f5 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Grand.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Grand.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Shipping.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Shipping.php
index 1aa2dab..84c4c35 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Subtotal.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Subtotal.php
index 901119b..0bd042d 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Subtotal.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Tax.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Tax.php
index ef258ce..8c1d32f 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Tax.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Attribute/Frontend/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Collection.php
index 0371561..84e4d27 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item.php
index fdf7e17..f444277 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item/Collection.php
index edc01cb..1b9b95f 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate.php
index 7b55e66..f501688 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate/Collection.php
index b02b6c5..48f31e4 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Address/Rate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Collection.php
index 1b5f2d5..aa651ac 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Item.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Item.php
index a034ad0..7456609 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Item.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Collection.php
index c85693c..21c712c 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option.php
index b83659a..7511768 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option/Collection.php
index d464001..170602d 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Item/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Payment.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Payment.php
index 71ac940..b3c0f0e 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Payment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Quote/Payment/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Quote/Payment/Collection.php
index aa2b81a..fad1645 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Quote/Payment/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Quote/Payment/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile.php b/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile.php
index 3492e61..b962489 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile/Collection.php
index be8b8cb..c9ee72f 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Recurring/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report.php b/app/code/core/Mage/Sales/Model/Resource/Report.php
index c84e5d3..aa6897c 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Report/Abstract.php
index 82dd3da..4a1b156 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers.php b/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers.php
index 9b86729..b497da1 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers/Collection.php
index f5eef75..5fe905a 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Bestsellers/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Collection/Abstract.php b/app/code/core/Mage/Sales/Model/Resource/Report/Collection/Abstract.php
index d50349f..a208c40 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Collection/Abstract.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Collection/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced.php b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced.php
index 7930670..8603db4 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Invoiced.php b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Invoiced.php
index 0d309da..0f44bad 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Invoiced.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Invoiced.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Order.php b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Order.php
index 02aa921..c96ee05 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Invoiced/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Order.php b/app/code/core/Mage/Sales/Model/Resource/Report/Order.php
index d24d7e9..17172ec 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Collection.php
index 542c7ed..13027c3 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Createdat.php b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Createdat.php
index 71f6baf..aeb5b52 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Createdat.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Createdat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat.php b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat.php
index 09d9070..54b1f8c 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat/Collection.php
index 569e9ac..3335b7b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Order/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded.php b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded.php
index 42c7ad3..0ebf344 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Order.php b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Order.php
index 8be05fc..3b83499 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Refunded.php b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Refunded.php
index 0c1e28a..d84183b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Refunded.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Refunded/Collection/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping.php b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping.php
index f4f65cc..1d7dbf8 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Order.php b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Order.php
index ff04d47..f838004 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Order.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Shipment.php b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Shipment.php
index 78a9192..49c6490 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Shipment.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Report/Shipping/Collection/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Sale/Collection.php b/app/code/core/Mage/Sales/Model/Resource/Sale/Collection.php
index 6ff96a2..428bf8b 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Sale/Collection.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Sale/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Resource/Setup.php b/app/code/core/Mage/Sales/Model/Resource/Setup.php
index 042c8fd..47f7ec0 100644
--- a/app/code/core/Mage/Sales/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Sales/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Service/Order.php b/app/code/core/Mage/Sales/Model/Service/Order.php
index 2f9e9b4..f50874f 100644
--- a/app/code/core/Mage/Sales/Model/Service/Order.php
+++ b/app/code/core/Mage/Sales/Model/Service/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Service/Quote.php b/app/code/core/Mage/Sales/Model/Service/Quote.php
index 98c4b02..8b44e5d 100644
--- a/app/code/core/Mage/Sales/Model/Service/Quote.php
+++ b/app/code/core/Mage/Sales/Model/Service/Quote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/Model/Status/List.php b/app/code/core/Mage/Sales/Model/Status/List.php
index dc55246..6c05059 100644
--- a/app/code/core/Mage/Sales/Model/Status/List.php
+++ b/app/code/core/Mage/Sales/Model/Status/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/controllers/Billing/AgreementController.php b/app/code/core/Mage/Sales/controllers/Billing/AgreementController.php
index e371c95..ebb88a8 100644
--- a/app/code/core/Mage/Sales/controllers/Billing/AgreementController.php
+++ b/app/code/core/Mage/Sales/controllers/Billing/AgreementController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/controllers/DownloadController.php b/app/code/core/Mage/Sales/controllers/DownloadController.php
index 294080b..68d4ad6 100644
--- a/app/code/core/Mage/Sales/controllers/DownloadController.php
+++ b/app/code/core/Mage/Sales/controllers/DownloadController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/controllers/GuestController.php b/app/code/core/Mage/Sales/controllers/GuestController.php
index 0b5dd79..d598bab 100644
--- a/app/code/core/Mage/Sales/controllers/GuestController.php
+++ b/app/code/core/Mage/Sales/controllers/GuestController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/controllers/OrderController.php b/app/code/core/Mage/Sales/controllers/OrderController.php
index e004aa6..6704e8e 100644
--- a/app/code/core/Mage/Sales/controllers/OrderController.php
+++ b/app/code/core/Mage/Sales/controllers/OrderController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/controllers/Recurring/ProfileController.php b/app/code/core/Mage/Sales/controllers/Recurring/ProfileController.php
index cd0be85..5259002 100644
--- a/app/code/core/Mage/Sales/controllers/Recurring/ProfileController.php
+++ b/app/code/core/Mage/Sales/controllers/Recurring/ProfileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/data/sales_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Sales/data/sales_setup/data-install-1.6.0.0.php
index bf359df..5b09c63 100644
--- a/app/code/core/Mage/Sales/data/sales_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Sales/data/sales_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/data/sales_setup/data-upgrade-1.6.0.4-1.6.0.5.php b/app/code/core/Mage/Sales/data/sales_setup/data-upgrade-1.6.0.4-1.6.0.5.php
index 38e55e1..ea5e0ea 100644
--- a/app/code/core/Mage/Sales/data/sales_setup/data-upgrade-1.6.0.4-1.6.0.5.php
+++ b/app/code/core/Mage/Sales/data/sales_setup/data-upgrade-1.6.0.4-1.6.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/doc/test.php b/app/code/core/Mage/Sales/doc/test.php
index 6961dab..d89fc78 100644
--- a/app/code/core/Mage/Sales/doc/test.php
+++ b/app/code/core/Mage/Sales/doc/test.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 include "lib/Varien/Object.php";
diff --git a/app/code/core/Mage/Sales/etc/adminhtml.xml b/app/code/core/Mage/Sales/etc/adminhtml.xml
index a3561c4..41a757f 100644
--- a/app/code/core/Mage/Sales/etc/adminhtml.xml
+++ b/app/code/core/Mage/Sales/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/etc/api.xml b/app/code/core/Mage/Sales/etc/api.xml
index 6b2712b..9872b3e 100644
--- a/app/code/core/Mage/Sales/etc/api.xml
+++ b/app/code/core/Mage/Sales/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/etc/api2.xml b/app/code/core/Mage/Sales/etc/api2.xml
index a3d9203..25979be 100644
--- a/app/code/core/Mage/Sales/etc/api2.xml
+++ b/app/code/core/Mage/Sales/etc/api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/etc/config.xml b/app/code/core/Mage/Sales/etc/config.xml
index 5f86f21..a519aac 100644
--- a/app/code/core/Mage/Sales/etc/config.xml
+++ b/app/code/core/Mage/Sales/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/etc/system.xml b/app/code/core/Mage/Sales/etc/system.xml
index 7c967f0..b8f1bd4 100644
--- a/app/code/core/Mage/Sales/etc/system.xml
+++ b/app/code/core/Mage/Sales/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/etc/widget.xml b/app/code/core/Mage/Sales/etc/widget.xml
index 3377f8e..5785e17 100644
--- a/app/code/core/Mage/Sales/etc/widget.xml
+++ b/app/code/core/Mage/Sales/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/install-1.6.0.0.php b/app/code/core/Mage/Sales/sql/sales_setup/install-1.6.0.0.php
index 2b13044..6970bca 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.7.0.php
index e8ea0ae..37b9af4 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.8.11.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.8.11.php
index 8d30198..e4a12db 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.8.11.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.8.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.9.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.9.0.php
index e171ba6..7d57610 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.9.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-0.9.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-1.4.0.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-1.4.0.0.php
index 9b3cf70..7ba7cc8 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-1.4.0.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-install-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.6.2-0.7.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.6.2-0.7.0.php
index 9cdf017..7f4f8bd 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.6.2-0.7.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.6.2-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 1af89e9..5b12def 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 514599c..3c76845 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.2-0.7.3.php
index d6157ec..8438a0e 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 0b99695..5ca5e7f 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.0-0.8.1.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.0-0.8.1.php
index f698b2e..a050b4b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.0-0.8.1.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.0-0.8.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.1-0.8.2.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.1-0.8.2.php
index 4fef81b..4154436 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.1-0.8.2.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.1-0.8.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.11-0.8.12.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.11-0.8.12.php
index 846ab1d..edae6db 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.11-0.8.12.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.11-0.8.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.12-0.8.13.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.12-0.8.13.php
index 55cf564..ab4e813 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.12-0.8.13.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.12-0.8.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.13-0.8.14.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.13-0.8.14.php
index 221d405..9a3fbf7 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.13-0.8.14.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.13-0.8.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.14-0.8.15.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.14-0.8.15.php
index 4fd64fc..7311c96 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.14-0.8.15.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.14-0.8.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.15-0.8.16.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.15-0.8.16.php
index c2ddacf..dfde549 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.15-0.8.16.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.15-0.8.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.16-0.8.17.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.16-0.8.17.php
index c49d424..454582d 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.16-0.8.17.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.16-0.8.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.17-0.8.18.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.17-0.8.18.php
index 0976889..98b234c 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.17-0.8.18.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.17-0.8.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.18-0.8.19.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.18-0.8.19.php
index c0f7172..462ea31 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.18-0.8.19.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.18-0.8.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.19-0.8.20.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.19-0.8.20.php
index b4721c4..6f1e4b2 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.19-0.8.20.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.19-0.8.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.2-0.8.3.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.2-0.8.3.php
index 7d24dc2..2637b31 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.2-0.8.3.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.2-0.8.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.20-0.8.21.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.20-0.8.21.php
index 8a7b124..0b3cb96 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.20-0.8.21.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.20-0.8.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.21-0.8.22.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.21-0.8.22.php
index 0d6bb62..5f4c125 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.21-0.8.22.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.21-0.8.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.22-0.8.23.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.22-0.8.23.php
index bae6d2d..d10fcaf 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.22-0.8.23.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.22-0.8.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.23-0.8.24.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.23-0.8.24.php
index 77e55a4..3f88be2 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.23-0.8.24.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.23-0.8.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.24-0.8.25.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.24-0.8.25.php
index 48c7149..a8316db 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.24-0.8.25.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.24-0.8.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.25-0.8.26.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.25-0.8.26.php
index f80ca6b..df7972e 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.25-0.8.26.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.25-0.8.26.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.26-0.8.27.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.26-0.8.27.php
index 0d888e5..260a7b9 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.26-0.8.27.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.26-0.8.27.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.27-0.8.28.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.27-0.8.28.php
index 205c74f..1d53b8b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.27-0.8.28.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.27-0.8.28.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.28-0.8.29.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.28-0.8.29.php
index fc3e2c3..b7475fa 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.28-0.8.29.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.28-0.8.29.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.29-0.9.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.29-0.9.0.php
index 54dcca8..05f66e1 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.29-0.9.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.29-0.9.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.3-0.8.4.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.3-0.8.4.php
index f8f4713..15f653b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.3-0.8.4.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.3-0.8.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.6-0.8.7.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.6-0.8.7.php
index 7d24dc2..2637b31 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.6-0.8.7.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.6-0.8.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.7-0.8.8.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.7-0.8.8.php
index 9a37b11..b365796 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.7-0.8.8.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.7-0.8.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.8-0.8.9.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.8-0.8.9.php
index 8615a23..742f884 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.8-0.8.9.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.8.8-0.8.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 $installer = $this;
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.0-0.9.1.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.0-0.9.1.php
index 5e66ea4..cc135d2 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.0-0.9.1.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.0-0.9.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.1-0.9.2.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.1-0.9.2.php
index ff04728..8cbd8c2 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.1-0.9.2.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.1-0.9.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.10-0.9.11.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.10-0.9.11.php
index 0b060ed..a753b42 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.10-0.9.11.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.10-0.9.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.11-0.9.12.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.11-0.9.12.php
index 059d6c0..dfb3514 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.11-0.9.12.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.11-0.9.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.12-0.9.13.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.12-0.9.13.php
index 17da974..9be770c 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.12-0.9.13.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.12-0.9.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.13-0.9.14.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.13-0.9.14.php
index a85c7d8..a1dfbb6 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.13-0.9.14.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.13-0.9.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.14-0.9.15.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.14-0.9.15.php
index f964207..1de4586 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.14-0.9.15.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.14-0.9.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.15-0.9.16.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.15-0.9.16.php
index b802bca..b974e60 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.15-0.9.16.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.15-0.9.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.16-0.9.17.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.16-0.9.17.php
index 5137ee5..5bba024 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.16-0.9.17.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.16-0.9.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.17-0.9.18.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.17-0.9.18.php
index ad79c04..e52d156 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.17-0.9.18.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.17-0.9.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.18-0.9.19.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.18-0.9.19.php
index 0ca7c9a..700c788 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.18-0.9.19.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.18-0.9.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.19-0.9.20.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.19-0.9.20.php
index 2db390b..63049b9 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.19-0.9.20.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.19-0.9.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.2-0.9.3.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.2-0.9.3.php
index 15d97fd..b699d07 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.2-0.9.3.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.2-0.9.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.20-0.9.21.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.20-0.9.21.php
index 83a4ef2..770e366 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.20-0.9.21.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.20-0.9.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.21-0.9.22.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.21-0.9.22.php
index 5129cf1..240f79b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.21-0.9.22.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.21-0.9.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.22-0.9.23.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.22-0.9.23.php
index f285c53..72d5bb1 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.22-0.9.23.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.22-0.9.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.23-0.9.24.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.23-0.9.24.php
index e481630..08cdae7 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.23-0.9.24.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.23-0.9.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.24-0.9.25.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.24-0.9.25.php
index d42c894..2929869 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.24-0.9.25.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.24-0.9.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.25-0.9.26.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.25-0.9.26.php
index 5e16379..41ba745 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.25-0.9.26.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.25-0.9.26.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.26-0.9.27.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.26-0.9.27.php
index 0637ea8..8ad595b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.26-0.9.27.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.26-0.9.27.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.27-0.9.28.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.27-0.9.28.php
index bc2b357..1f71061 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.27-0.9.28.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.27-0.9.28.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.28-0.9.29.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.28-0.9.29.php
index b8031b7..59bbbb0 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.28-0.9.29.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.28-0.9.29.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.29-0.9.30.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.29-0.9.30.php
index 2d28a50..af8cd1b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.29-0.9.30.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.29-0.9.30.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.3-0.9.4.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.3-0.9.4.php
index d0fbb8b..a99df6e 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.3-0.9.4.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.3-0.9.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.30-0.9.31.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.30-0.9.31.php
index 3d85e1e..bebae70 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.30-0.9.31.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.30-0.9.31.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.31-0.9.32.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.31-0.9.32.php
index 97067df..bdf50dc 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.31-0.9.32.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.31-0.9.32.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.32-0.9.33.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.32-0.9.33.php
index 3060098..479aacb 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.32-0.9.33.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.32-0.9.33.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.33-0.9.34.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.33-0.9.34.php
index ff30b9a..c77d07a5 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.33-0.9.34.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.33-0.9.34.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.34-0.9.35.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.34-0.9.35.php
index 81a596e..ce21648 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.34-0.9.35.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.34-0.9.35.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.35-0.9.36.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.35-0.9.36.php
index c147f44..063de07 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.35-0.9.36.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.35-0.9.36.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.36-0.9.37.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.36-0.9.37.php
index f82aea9..cbd638b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.36-0.9.37.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.36-0.9.37.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.37-0.9.38.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.37-0.9.38.php
index 0cd4174..f0687b4 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.37-0.9.38.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.37-0.9.38.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.38-0.9.39.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.38-0.9.39.php
index 502087d..9906839 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.38-0.9.39.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.38-0.9.39.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.39-0.9.40.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.39-0.9.40.php
index 14ec98f..be17d09 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.39-0.9.40.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.39-0.9.40.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.4-0.9.5.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.4-0.9.5.php
index 4c76abb..d8d997b 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.4-0.9.5.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.4-0.9.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.40-0.9.41.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.40-0.9.41.php
index a6a5e96..c9d3b06 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.40-0.9.41.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.40-0.9.41.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.41-0.9.42.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.41-0.9.42.php
index 7d0cd38..19eaf2d 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.41-0.9.42.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.41-0.9.42.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.42-0.9.43.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.42-0.9.43.php
index d39ac40..158517a 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.42-0.9.43.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.42-0.9.43.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.43-0.9.44.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.43-0.9.44.php
index 73cbf4e..9ec28ae 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.43-0.9.44.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.43-0.9.44.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.44-0.9.45.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.44-0.9.45.php
index 698d63b..47e4942 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.44-0.9.45.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.44-0.9.45.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.45-0.9.46.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.45-0.9.46.php
index ccc069a..a643bc6 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.45-0.9.46.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.45-0.9.46.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.46-0.9.47.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.46-0.9.47.php
index 52b206e..788aec4 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.46-0.9.47.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.46-0.9.47.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.47-0.9.48.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.47-0.9.48.php
index d740281..24b6893 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.47-0.9.48.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.47-0.9.48.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.48-0.9.49.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.48-0.9.49.php
index 2918d55..0478823 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.48-0.9.49.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.48-0.9.49.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.49-0.9.50.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.49-0.9.50.php
index 57aef04..4435009 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.49-0.9.50.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.49-0.9.50.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.5-0.9.6.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.5-0.9.6.php
index 285fbca..ce888a3 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.5-0.9.6.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.5-0.9.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.50-0.9.51.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.50-0.9.51.php
index 4d0211c..6e33ce4 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.50-0.9.51.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.50-0.9.51.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.51-0.9.52.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.51-0.9.52.php
index 1e83790..0a091a0 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.51-0.9.52.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.51-0.9.52.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.52-0.9.53.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.52-0.9.53.php
index 35fcb4d..a8f09ca 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.52-0.9.53.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.52-0.9.53.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.53-0.9.54.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.53-0.9.54.php
index aedd43e..f34cdd1 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.53-0.9.54.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.53-0.9.54.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.54-0.9.55.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.54-0.9.55.php
index 60b0fdb..6a63734 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.54-0.9.55.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.54-0.9.55.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.55-0.9.56.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.55-0.9.56.php
index 0e9994a..399d527 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.55-0.9.56.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.55-0.9.56.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.6-0.9.7.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.6-0.9.7.php
index 0c0fa2f..dd86b78 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.6-0.9.7.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.6-0.9.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.7-0.9.8.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.7-0.9.8.php
index e50a448..726ca26 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.7-0.9.8.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.7-0.9.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.8-0.9.9.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.8-0.9.9.php
index 1812399..2397fb0 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.8-0.9.9.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.8-0.9.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.9-0.9.10.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.9-0.9.10.php
index cd809e8..4a5bfc6 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.9-0.9.10.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-0.9.9-0.9.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.3.99-1.4.0.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.3.99-1.4.0.0.php
index f16ba5d..b9b6515 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.3.99-1.4.0.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.3.99-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
index 94b9507..6e32290 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
index b6fc149..2ff6b72 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.15-1.4.0.16.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.15-1.4.0.16.php
index 87ff98c..db1e168 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.15-1.4.0.16.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.15-1.4.0.16.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.16-1.4.0.17.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.16-1.4.0.17.php
index 9e52cf8..42037c3 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.16-1.4.0.17.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.16-1.4.0.17.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.17-1.4.0.18.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.17-1.4.0.18.php
index d100fc2..6462b89 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.17-1.4.0.18.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.17-1.4.0.18.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.18-1.4.0.19.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.18-1.4.0.19.php
index 12888f7..898f2b9 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.18-1.4.0.19.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.18-1.4.0.19.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.19-1.4.0.20.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.19-1.4.0.20.php
index 87ebe31..a9556de 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.19-1.4.0.20.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.19-1.4.0.20.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
index 039de54..f2ee583 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.2-1.4.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.20-1.4.0.21.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.20-1.4.0.21.php
index 3c4884a..c2d84b3 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.20-1.4.0.21.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.20-1.4.0.21.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.21-1.4.0.22.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.21-1.4.0.22.php
index 32455ae..75b809a 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.21-1.4.0.22.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.21-1.4.0.22.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.22-1.4.0.23.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.22-1.4.0.23.php
index f55a114..8b70ebc 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.22-1.4.0.23.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.22-1.4.0.23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.23-1.4.0.24.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.23-1.4.0.24.php
index 1105d13..23afdae 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.23-1.4.0.24.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.23-1.4.0.24.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /* @var $installer Mage_Sales_Model_Entity_Setup */
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.24-1.4.0.25.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.24-1.4.0.25.php
index 807e568..82a9311 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.24-1.4.0.25.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.24-1.4.0.25.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /* @var $installer Mage_Sales_Model_Entity_Setup */
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.3-1.4.0.4.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.3-1.4.0.4.php
index 49c5f59..097e924 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.3-1.4.0.4.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.3-1.4.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.4-1.4.0.5.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.4-1.4.0.5.php
index 13b5e60..cda8e7f 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.4-1.4.0.5.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.4-1.4.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.5-1.4.0.6.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.5-1.4.0.6.php
index 223f286..6cd2518 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.5-1.4.0.6.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.5-1.4.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.6-1.4.0.7.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.6-1.4.0.7.php
index 218a758..669d9d3 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.6-1.4.0.7.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.6-1.4.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.7-1.4.0.8.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.7-1.4.0.8.php
index 3206922..e309e79 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.7-1.4.0.8.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.7-1.4.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.8-1.4.0.15.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.8-1.4.0.15.php
index af94e56..84502af 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.8-1.4.0.15.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.4.0.8-1.4.0.15.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 11496dc..3d05f5c 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.0-1.6.0.1.php
index ad022fc..2023d93 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.1-1.6.0.2.php
index 11f66e5..8056724 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.2-1.6.0.3.php
index f837e1c..a03f369 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.3-1.6.0.4.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.3-1.6.0.4.php
index ec036e0..81e274f 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.3-1.6.0.4.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.3-1.6.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.4-1.6.0.5.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.4-1.6.0.5.php
index dcf3206..61d5a15 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.4-1.6.0.5.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.4-1.6.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.5-1.6.0.6.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.5-1.6.0.6.php
index 7bcc3f1..ab0d8dd 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.5-1.6.0.6.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.5-1.6.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.6-1.6.0.7.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.6-1.6.0.7.php
index d8c11da8..6eb342a 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.6-1.6.0.7.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.6-1.6.0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.7-1.6.0.8.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.7-1.6.0.8.php
index c82600a..720095e 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.7-1.6.0.8.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.7-1.6.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.8-1.6.0.9.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.8-1.6.0.9.php
index 591a75a..762952d 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.8-1.6.0.9.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.8-1.6.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.9-1.6.0.10.php b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.9-1.6.0.10.php
index c17f05e..89bbbad 100644
--- a/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.9-1.6.0.10.php
+++ b/app/code/core/Mage/Sales/sql/sales_setup/upgrade-1.6.0.9-1.6.0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sales
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Exception.php b/app/code/core/Mage/SalesRule/Exception.php
index 01b1ba6..702bebc 100644
--- a/app/code/core/Mage/SalesRule/Exception.php
+++ b/app/code/core/Mage/SalesRule/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Helper/Coupon.php b/app/code/core/Mage/SalesRule/Helper/Coupon.php
index c0a4848..d1cbaca 100644
--- a/app/code/core/Mage/SalesRule/Helper/Coupon.php
+++ b/app/code/core/Mage/SalesRule/Helper/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Helper/Data.php b/app/code/core/Mage/SalesRule/Helper/Data.php
index 77d0826..9cc3e8a 100644
--- a/app/code/core/Mage/SalesRule/Helper/Data.php
+++ b/app/code/core/Mage/SalesRule/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Coupon.php b/app/code/core/Mage/SalesRule/Model/Coupon.php
index 07b4ab5..3caf0a4 100644
--- a/app/code/core/Mage/SalesRule/Model/Coupon.php
+++ b/app/code/core/Mage/SalesRule/Model/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Coupon/Codegenerator.php b/app/code/core/Mage/SalesRule/Model/Coupon/Codegenerator.php
index 6b08832..520995e 100644
--- a/app/code/core/Mage/SalesRule/Model/Coupon/Codegenerator.php
+++ b/app/code/core/Mage/SalesRule/Model/Coupon/Codegenerator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Coupon/CodegeneratorInterface.php b/app/code/core/Mage/SalesRule/Model/Coupon/CodegeneratorInterface.php
index bde98e5..2e23243 100644
--- a/app/code/core/Mage/SalesRule/Model/Coupon/CodegeneratorInterface.php
+++ b/app/code/core/Mage/SalesRule/Model/Coupon/CodegeneratorInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php b/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
index 2b918fa..a9683a0 100644
--- a/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
+++ b/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon.php
index d37afc1..c1e7c31 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Collection.php
index c91e83a..b1ad0d6 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Usage.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Usage.php
index bc9ecf6..863179b 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Usage.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Coupon/Usage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Collection.php
index 5101289..dc3ec57 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Rule.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Rule.php
index 25516ec..80563ac 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Rule.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Updatedat/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Updatedat/Collection.php
index 7271630..6397b20 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Updatedat/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Report/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule.php
index ab16aed..9bb13fa 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Collection.php
index f740246..83f99d3 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer.php
index b3a23c4..2ac9aba 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer/Collection.php
index 31133e2..102e67e 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product.php
index b578fb5..d56adee 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product/Collection.php b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product/Collection.php
index f1fc528..834ddd9 100644
--- a/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Mysql4/Rule/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Observer.php b/app/code/core/Mage/SalesRule/Model/Observer.php
index fd39454..b85ae2c 100644
--- a/app/code/core/Mage/SalesRule/Model/Observer.php
+++ b/app/code/core/Mage/SalesRule/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Quote/Discount.php b/app/code/core/Mage/SalesRule/Model/Quote/Discount.php
index 18dd2f6..6e10d3b 100644
--- a/app/code/core/Mage/SalesRule/Model/Quote/Discount.php
+++ b/app/code/core/Mage/SalesRule/Model/Quote/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Quote/Freeshipping.php b/app/code/core/Mage/SalesRule/Model/Quote/Freeshipping.php
index 083c405..fa968d4 100644
--- a/app/code/core/Mage/SalesRule/Model/Quote/Freeshipping.php
+++ b/app/code/core/Mage/SalesRule/Model/Quote/Freeshipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Quote/Nominal/Discount.php b/app/code/core/Mage/SalesRule/Model/Quote/Nominal/Discount.php
index ff7c5bc..ca5627a 100644
--- a/app/code/core/Mage/SalesRule/Model/Quote/Nominal/Discount.php
+++ b/app/code/core/Mage/SalesRule/Model/Quote/Nominal/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Coupon.php b/app/code/core/Mage/SalesRule/Model/Resource/Coupon.php
index 9914c71..5911769 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Coupon.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Coupon.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Collection.php
index acae292..90ef9bd 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Usage.php b/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Usage.php
index fe7db1b..82034c2 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Usage.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Coupon/Usage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Collection.php
index 814b58e..91a688a 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule.php
index dc82a27..ce96e74 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
index 395f6cf..bfda23b 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Updatedat.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Updatedat.php
index edc4608..65bf032 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Updatedat.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Updatedat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Updatedat/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Updatedat/Collection.php
index 7bdf6c0..1fff299 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Updatedat/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule.php
index 7fcbf97..fd4d2e5 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Collection.php
index ca3b22e..0131dfe 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer.php
index 06a23f3..37cbdb6 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer/Collection.php
index a71da0c..1938208 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product.php
index f1fc061..9c948ad 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product/Collection.php b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product/Collection.php
index 3cab41a..798d9e5 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Rule/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule.php b/app/code/core/Mage/SalesRule/Model/Rule.php
index 146bb06..78b5dc4 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Action/Collection.php b/app/code/core/Mage/SalesRule/Model/Rule/Action/Collection.php
index 83b03e3..eefc6a3 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Action/Collection.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Action/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Action/Product.php b/app/code/core/Mage/SalesRule/Model/Rule/Action/Product.php
index bc88c7a..f4cf573 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Action/Product.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Action/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Address.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Address.php
index 1635527..d47423e 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Address.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Combine.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Combine.php
index e43560f..2e3bf1d 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Combine.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Combine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product.php
index e78549e..fdc5475 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Attribute/Assigned.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Attribute/Assigned.php
index 2005425..6fc181c 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Attribute/Assigned.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Attribute/Assigned.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Combine.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Combine.php
index 897298c..df995ee 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Combine.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Combine.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Found.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Found.php
index 94a707b..65f77e7 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Found.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Found.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Subselect.php b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Subselect.php
index c6a4a27..979d0a6 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Subselect.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Condition/Product/Subselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Customer.php b/app/code/core/Mage/SalesRule/Model/Rule/Customer.php
index 051dff9..5c8c811 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Customer.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Rule/Product.php b/app/code/core/Mage/SalesRule/Model/Rule/Product.php
index bae8d3e..87dc9a5 100644
--- a/app/code/core/Mage/SalesRule/Model/Rule/Product.php
+++ b/app/code/core/Mage/SalesRule/Model/Rule/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/System/Config/Source/Coupon/Format.php b/app/code/core/Mage/SalesRule/Model/System/Config/Source/Coupon/Format.php
index c056e03..4e12286 100644
--- a/app/code/core/Mage/SalesRule/Model/System/Config/Source/Coupon/Format.php
+++ b/app/code/core/Mage/SalesRule/Model/System/Config/Source/Coupon/Format.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/Model/Validator.php b/app/code/core/Mage/SalesRule/Model/Validator.php
index 9ef922a..ddb0fef 100644
--- a/app/code/core/Mage/SalesRule/Model/Validator.php
+++ b/app/code/core/Mage/SalesRule/Model/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/etc/adminhtml.xml b/app/code/core/Mage/SalesRule/etc/adminhtml.xml
index 050b10b..4653330 100644
--- a/app/code/core/Mage/SalesRule/etc/adminhtml.xml
+++ b/app/code/core/Mage/SalesRule/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/SalesRule/etc/config.xml b/app/code/core/Mage/SalesRule/etc/config.xml
index 83aa0c0..be6c707 100644
--- a/app/code/core/Mage/SalesRule/etc/config.xml
+++ b/app/code/core/Mage/SalesRule/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/SalesRule/etc/system.xml b/app/code/core/Mage/SalesRule/etc/system.xml
index 793aa40..e49f5ce 100644
--- a/app/code/core/Mage/SalesRule/etc/system.xml
+++ b/app/code/core/Mage/SalesRule/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/install-1.6.0.0.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/install-1.6.0.0.php
index 3b40b91..3ddec7f 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-0.7.0.php
index 08726df..0a5bf69 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-1.4.0.0.0.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-1.4.0.0.0.php
index d21d976..80cfc33 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-1.4.0.0.0.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-install-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 61f703c..4d76051 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 690ed21..f58a65f 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.10-0.7.11.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.10-0.7.11.php
index 6c93feb..918cbf9 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.10-0.7.11.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.10-0.7.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.11-0.7.12.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.11-0.7.12.php
index 9e9156d..0784072 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.11-0.7.12.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.11-0.7.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 10a9ff9..91bfb93 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
index ee2fa5a..4d5415f 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 39ce5c2..2190e8f 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 071f738..cd6bd9b 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
index afaa372..dd3e532 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
index dadaf27..8ad8c95 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
index d45f1f5..60e3c77 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
index f7ebd96..65cdd82 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
index 6e7c954..7cec424 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
index 8d67409..0d48d43 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
index 3b85fc9..fdcb533 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
index 117ffa7..168cfc0 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
index 3a58ba0..b091e7b 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
index 1d3b96b..3e731f9 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index d66f98b..4168e78 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.0-1.6.0.1.php
index f6ce990..f2b0d63 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.1-1.6.0.2.php
index 24b1b95..dc7c023 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.2-1.6.0.3.php
index a55d4bf..c4df8e1 100644
--- a/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/SalesRule/sql/salesrule_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_SalesRule
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Block/Send.php b/app/code/core/Mage/Sendfriend/Block/Send.php
index a7a5456..4473e09 100644
--- a/app/code/core/Mage/Sendfriend/Block/Send.php
+++ b/app/code/core/Mage/Sendfriend/Block/Send.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Helper/Data.php b/app/code/core/Mage/Sendfriend/Helper/Data.php
index c8f645f..fb2f6cf 100644
--- a/app/code/core/Mage/Sendfriend/Helper/Data.php
+++ b/app/code/core/Mage/Sendfriend/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend.php b/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend.php
index f9ebdaa..f9a9b9d 100644
--- a/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend.php
+++ b/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend/Collection.php b/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend/Collection.php
index 35f7a93..e7d3414 100644
--- a/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend/Collection.php
+++ b/app/code/core/Mage/Sendfriend/Model/Mysql4/Sendfriend/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Mysql4/Setup.php b/app/code/core/Mage/Sendfriend/Model/Mysql4/Setup.php
index d032bab..265364f 100644
--- a/app/code/core/Mage/Sendfriend/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Sendfriend/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Observer.php b/app/code/core/Mage/Sendfriend/Model/Observer.php
index 2cf0553..b5d5100 100644
--- a/app/code/core/Mage/Sendfriend/Model/Observer.php
+++ b/app/code/core/Mage/Sendfriend/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend.php b/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend.php
index 9b92eaa..6f74e72 100644
--- a/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend.php
+++ b/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend/Collection.php b/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend/Collection.php
index b2ec6c2..dde9123 100644
--- a/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend/Collection.php
+++ b/app/code/core/Mage/Sendfriend/Model/Resource/Sendfriend/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Resource/Setup.php b/app/code/core/Mage/Sendfriend/Model/Resource/Setup.php
index 2b83c6a..6727d19 100644
--- a/app/code/core/Mage/Sendfriend/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Sendfriend/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/Model/Sendfriend.php b/app/code/core/Mage/Sendfriend/Model/Sendfriend.php
index 0ef2492..6a19368 100644
--- a/app/code/core/Mage/Sendfriend/Model/Sendfriend.php
+++ b/app/code/core/Mage/Sendfriend/Model/Sendfriend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/controllers/ProductController.php b/app/code/core/Mage/Sendfriend/controllers/ProductController.php
index f7385e4..4f624ea 100644
--- a/app/code/core/Mage/Sendfriend/controllers/ProductController.php
+++ b/app/code/core/Mage/Sendfriend/controllers/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/etc/config.xml b/app/code/core/Mage/Sendfriend/etc/config.xml
index b097a3c..5b21374 100644
--- a/app/code/core/Mage/Sendfriend/etc/config.xml
+++ b/app/code/core/Mage/Sendfriend/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sendfriend/etc/system.xml b/app/code/core/Mage/Sendfriend/etc/system.xml
index e3f3a92..6f43d9c 100644
--- a/app/code/core/Mage/Sendfriend/etc/system.xml
+++ b/app/code/core/Mage/Sendfriend/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/install-1.6.0.0.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/install-1.6.0.0.php
index 7e97592..0c21a5c 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-install-0.7.0.php
index e92cb73..20c3bfe 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 48a70fb..ef8452c 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.2-0.7.3.php
index d2a9635..68c058e 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.3-0.7.4.php
index c18357d..b4aed92 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index cac39a1..cb3a643 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
index b20272a..e311a38 100644
--- a/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Sendfriend/sql/sendfriend_setup/mysql4-upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sendfriend
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Block/Tracking/Ajax.php b/app/code/core/Mage/Shipping/Block/Tracking/Ajax.php
index 40a9b05..514d4af 100644
--- a/app/code/core/Mage/Shipping/Block/Tracking/Ajax.php
+++ b/app/code/core/Mage/Shipping/Block/Tracking/Ajax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Block/Tracking/Popup.php b/app/code/core/Mage/Shipping/Block/Tracking/Popup.php
index 1900ef7..8774808 100644
--- a/app/code/core/Mage/Shipping/Block/Tracking/Popup.php
+++ b/app/code/core/Mage/Shipping/Block/Tracking/Popup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Exception.php b/app/code/core/Mage/Shipping/Exception.php
index 9a0e3de..1c5c8cc 100644
--- a/app/code/core/Mage/Shipping/Exception.php
+++ b/app/code/core/Mage/Shipping/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Helper/Data.php b/app/code/core/Mage/Shipping/Helper/Data.php
index 615ef4e..903e926 100644
--- a/app/code/core/Mage/Shipping/Helper/Data.php
+++ b/app/code/core/Mage/Shipping/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Abstract.php b/app/code/core/Mage/Shipping/Model/Carrier/Abstract.php
index 95e0c57..4b3caed 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Abstract.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Flatrate.php b/app/code/core/Mage/Shipping/Model/Carrier/Flatrate.php
index a9e39d8..0bf329c 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Flatrate.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Flatrate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Freeshipping.php b/app/code/core/Mage/Shipping/Model/Carrier/Freeshipping.php
index 4753c1e..5ac0c1d 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Freeshipping.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Freeshipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Interface.php b/app/code/core/Mage/Shipping/Model/Carrier/Interface.php
index a7d4b76..93ed61c 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Interface.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Pickup.php b/app/code/core/Mage/Shipping/Model/Carrier/Pickup.php
index ef2c7b2..71c0e6a 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Pickup.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Pickup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Carrier/Tablerate.php b/app/code/core/Mage/Shipping/Model/Carrier/Tablerate.php
index 43c49d5d..6f68bd7 100644
--- a/app/code/core/Mage/Shipping/Model/Carrier/Tablerate.php
+++ b/app/code/core/Mage/Shipping/Model/Carrier/Tablerate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Config.php b/app/code/core/Mage/Shipping/Model/Config.php
index 25e6368..fc48853 100644
--- a/app/code/core/Mage/Shipping/Model/Config.php
+++ b/app/code/core/Mage/Shipping/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Info.php b/app/code/core/Mage/Shipping/Model/Info.php
index 5156db0..1ab0e7c 100644
--- a/app/code/core/Mage/Shipping/Model/Info.php
+++ b/app/code/core/Mage/Shipping/Model/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate.php b/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate.php
index c4ffcf2..f42012e 100644
--- a/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate.php
+++ b/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate/Collection.php b/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate/Collection.php
index 21d0bb8..91d79bb 100644
--- a/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate/Collection.php
+++ b/app/code/core/Mage/Shipping/Model/Mysql4/Carrier/Tablerate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Abstract.php b/app/code/core/Mage/Shipping/Model/Rate/Abstract.php
index 0871b2b..58fda75 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Abstract.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Request.php b/app/code/core/Mage/Shipping/Model/Rate/Request.php
index c3ac600..5c6271e 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Request.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Result.php b/app/code/core/Mage/Shipping/Model/Rate/Result.php
index b5b4077..d5b0187 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Result.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Result/Abstract.php b/app/code/core/Mage/Shipping/Model/Rate/Result/Abstract.php
index 278f99c..f2cfa2e 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Result/Abstract.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Result/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Result/Error.php b/app/code/core/Mage/Shipping/Model/Rate/Result/Error.php
index 7834814..aa95b71 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Result/Error.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Result/Error.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Rate/Result/Method.php b/app/code/core/Mage/Shipping/Model/Rate/Result/Method.php
index f4a40ea..31bb779 100644
--- a/app/code/core/Mage/Shipping/Model/Rate/Result/Method.php
+++ b/app/code/core/Mage/Shipping/Model/Rate/Result/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate.php b/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate.php
index a0697bc..97cf7d6 100644
--- a/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate.php
+++ b/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate/Collection.php b/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate/Collection.php
index 79cd38e..a6a6f66 100644
--- a/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate/Collection.php
+++ b/app/code/core/Mage/Shipping/Model/Resource/Carrier/Tablerate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Shipment/Request.php b/app/code/core/Mage/Shipping/Model/Shipment/Request.php
index e1489e1..e6d3cd9 100644
--- a/app/code/core/Mage/Shipping/Model/Shipment/Request.php
+++ b/app/code/core/Mage/Shipping/Model/Shipment/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Shipment/Return.php b/app/code/core/Mage/Shipping/Model/Shipment/Return.php
index cc43b29..5e7a6dc 100644
--- a/app/code/core/Mage/Shipping/Model/Shipment/Return.php
+++ b/app/code/core/Mage/Shipping/Model/Shipment/Return.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Shipping.php b/app/code/core/Mage/Shipping/Model/Shipping.php
index 51f00f2..4b53512 100644
--- a/app/code/core/Mage/Shipping/Model/Shipping.php
+++ b/app/code/core/Mage/Shipping/Model/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Source/HandlingAction.php b/app/code/core/Mage/Shipping/Model/Source/HandlingAction.php
index 1a766f3..8a7cdf4 100644
--- a/app/code/core/Mage/Shipping/Model/Source/HandlingAction.php
+++ b/app/code/core/Mage/Shipping/Model/Source/HandlingAction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Shipping_Model_Source_HandlingAction
diff --git a/app/code/core/Mage/Shipping/Model/Source/HandlingType.php b/app/code/core/Mage/Shipping/Model/Source/HandlingType.php
index a66ed7f..7c2232e 100644
--- a/app/code/core/Mage/Shipping/Model/Source/HandlingType.php
+++ b/app/code/core/Mage/Shipping/Model/Source/HandlingType.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Shipping_Model_Source_HandlingType
diff --git a/app/code/core/Mage/Shipping/Model/Tracking/Result.php b/app/code/core/Mage/Shipping/Model/Tracking/Result.php
index 6356e00..8316918 100644
--- a/app/code/core/Mage/Shipping/Model/Tracking/Result.php
+++ b/app/code/core/Mage/Shipping/Model/Tracking/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Tracking/Result/Abstract.php b/app/code/core/Mage/Shipping/Model/Tracking/Result/Abstract.php
index 4534165..ac0abe1 100644
--- a/app/code/core/Mage/Shipping/Model/Tracking/Result/Abstract.php
+++ b/app/code/core/Mage/Shipping/Model/Tracking/Result/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Tracking/Result/Error.php b/app/code/core/Mage/Shipping/Model/Tracking/Result/Error.php
index 38b662d..5485299 100644
--- a/app/code/core/Mage/Shipping/Model/Tracking/Result/Error.php
+++ b/app/code/core/Mage/Shipping/Model/Tracking/Result/Error.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/Model/Tracking/Result/Status.php b/app/code/core/Mage/Shipping/Model/Tracking/Result/Status.php
index 9faf370..c5ecbd0 100644
--- a/app/code/core/Mage/Shipping/Model/Tracking/Result/Status.php
+++ b/app/code/core/Mage/Shipping/Model/Tracking/Result/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/controllers/ShippingController.php b/app/code/core/Mage/Shipping/controllers/ShippingController.php
index 2c8334b..c329130 100644
--- a/app/code/core/Mage/Shipping/controllers/ShippingController.php
+++ b/app/code/core/Mage/Shipping/controllers/ShippingController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/controllers/TrackingController.php b/app/code/core/Mage/Shipping/controllers/TrackingController.php
index 3ecdd4d..6d0bd0c 100644
--- a/app/code/core/Mage/Shipping/controllers/TrackingController.php
+++ b/app/code/core/Mage/Shipping/controllers/TrackingController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/etc/adminhtml.xml b/app/code/core/Mage/Shipping/etc/adminhtml.xml
index 3adce7a..e025136 100644
--- a/app/code/core/Mage/Shipping/etc/adminhtml.xml
+++ b/app/code/core/Mage/Shipping/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Shipping/etc/config.xml b/app/code/core/Mage/Shipping/etc/config.xml
index 67888b2..3706efb 100644
--- a/app/code/core/Mage/Shipping/etc/config.xml
+++ b/app/code/core/Mage/Shipping/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Shipping/etc/system.xml b/app/code/core/Mage/Shipping/etc/system.xml
index 498c6a2..d76a7d2 100644
--- a/app/code/core/Mage/Shipping/etc/system.xml
+++ b/app/code/core/Mage/Shipping/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Shipping/sql/shipping_setup/install-1.6.0.0.php b/app/code/core/Mage/Shipping/sql/shipping_setup/install-1.6.0.0.php
index eb800b9..22882fd 100644
--- a/app/code/core/Mage/Shipping/sql/shipping_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Shipping/sql/shipping_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-install-0.7.0.php
index 2c078de..9f21196 100644
--- a/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index aae9f3a..e550826 100644
--- a/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Shipping/sql/shipping_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shipping
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Helper/Data.php b/app/code/core/Mage/Sitemap/Helper/Data.php
index 14beffc..4062781 100644
--- a/app/code/core/Mage/Sitemap/Helper/Data.php
+++ b/app/code/core/Mage/Sitemap/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Category.php b/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Category.php
index ed916f5..065de45 100644
--- a/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Category.php
+++ b/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Product.php b/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Product.php
index cd80ece..090e6cb 100644
--- a/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Product.php
+++ b/app/code/core/Mage/Sitemap/Model/Mysql4/Catalog/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Mysql4/Cms/Page.php b/app/code/core/Mage/Sitemap/Model/Mysql4/Cms/Page.php
index 5d3d485..a1f47ad 100644
--- a/app/code/core/Mage/Sitemap/Model/Mysql4/Cms/Page.php
+++ b/app/code/core/Mage/Sitemap/Model/Mysql4/Cms/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap.php b/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap.php
index 158dcdd..a75bb18 100644
--- a/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap.php
+++ b/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap/Collection.php b/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap/Collection.php
index 12d70ac..4ab9228 100644
--- a/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap/Collection.php
+++ b/app/code/core/Mage/Sitemap/Model/Mysql4/Sitemap/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Observer.php b/app/code/core/Mage/Sitemap/Model/Observer.php
index fbc8e1f..2e929f8 100644
--- a/app/code/core/Mage/Sitemap/Model/Observer.php
+++ b/app/code/core/Mage/Sitemap/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Abstract.php b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Abstract.php
index b78410c..d2dedd1 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Abstract.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Category.php b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Category.php
index a6a8c4e..a41e4a9 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Category.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Product.php b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Product.php
index 7e2aca2..cf69344 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Product.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Catalog/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Cms/Page.php b/app/code/core/Mage/Sitemap/Model/Resource/Cms/Page.php
index d5f66be..328457d 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Cms/Page.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Cms/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Sitemap.php b/app/code/core/Mage/Sitemap/Model/Resource/Sitemap.php
index bea917c..74b2ed9 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Sitemap.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Resource/Sitemap/Collection.php b/app/code/core/Mage/Sitemap/Model/Resource/Sitemap/Collection.php
index a9db7f4..99bfb09 100644
--- a/app/code/core/Mage/Sitemap/Model/Resource/Sitemap/Collection.php
+++ b/app/code/core/Mage/Sitemap/Model/Resource/Sitemap/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/Model/Sitemap.php b/app/code/core/Mage/Sitemap/Model/Sitemap.php
index f06777d..a82974d 100644
--- a/app/code/core/Mage/Sitemap/Model/Sitemap.php
+++ b/app/code/core/Mage/Sitemap/Model/Sitemap.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/etc/adminhtml.xml b/app/code/core/Mage/Sitemap/etc/adminhtml.xml
index 84b1ab2..c378b10 100644
--- a/app/code/core/Mage/Sitemap/etc/adminhtml.xml
+++ b/app/code/core/Mage/Sitemap/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sitemap/etc/config.xml b/app/code/core/Mage/Sitemap/etc/config.xml
index c337373..4279fa4 100644
--- a/app/code/core/Mage/Sitemap/etc/config.xml
+++ b/app/code/core/Mage/Sitemap/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sitemap/etc/system.xml b/app/code/core/Mage/Sitemap/etc/system.xml
index af57504..4b14719 100644
--- a/app/code/core/Mage/Sitemap/etc/system.xml
+++ b/app/code/core/Mage/Sitemap/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Sitemap/sql/sitemap_setup/install-1.6.0.0.php b/app/code/core/Mage/Sitemap/sql/sitemap_setup/install-1.6.0.0.php
index 0293210..5dc2c9c 100644
--- a/app/code/core/Mage/Sitemap/sql/sitemap_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Sitemap/sql/sitemap_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-install-0.7.0.php
index 0c811ec..e4be823 100644
--- a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 4495048..11a9ca6 100644
--- a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 174b941..e9f6ecc 100644
--- a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 9540c3f..1401c66 100644
--- a/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Sitemap/sql/sitemap_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Sitemap
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/All.php b/app/code/core/Mage/Tag/Block/All.php
index 51fc858..63cf6b5 100644
--- a/app/code/core/Mage/Tag/Block/All.php
+++ b/app/code/core/Mage/Tag/Block/All.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Customer/Edit.php b/app/code/core/Mage/Tag/Block/Customer/Edit.php
index 9515a04..13182fe 100644
--- a/app/code/core/Mage/Tag/Block/Customer/Edit.php
+++ b/app/code/core/Mage/Tag/Block/Customer/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Customer/Recent.php b/app/code/core/Mage/Tag/Block/Customer/Recent.php
index 6cbccd5..a1e1cfc 100644
--- a/app/code/core/Mage/Tag/Block/Customer/Recent.php
+++ b/app/code/core/Mage/Tag/Block/Customer/Recent.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Customer/Tags.php b/app/code/core/Mage/Tag/Block/Customer/Tags.php
index 5d2f610..c639d07 100644
--- a/app/code/core/Mage/Tag/Block/Customer/Tags.php
+++ b/app/code/core/Mage/Tag/Block/Customer/Tags.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Customer/View.php b/app/code/core/Mage/Tag/Block/Customer/View.php
index 7588759..2a99e5c 100644
--- a/app/code/core/Mage/Tag/Block/Customer/View.php
+++ b/app/code/core/Mage/Tag/Block/Customer/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Popular.php b/app/code/core/Mage/Tag/Block/Popular.php
index 40c82a6..1dc9336 100644
--- a/app/code/core/Mage/Tag/Block/Popular.php
+++ b/app/code/core/Mage/Tag/Block/Popular.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Product/List.php b/app/code/core/Mage/Tag/Block/Product/List.php
index 5af8d94..b6a43b0 100644
--- a/app/code/core/Mage/Tag/Block/Product/List.php
+++ b/app/code/core/Mage/Tag/Block/Product/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Block/Product/Result.php b/app/code/core/Mage/Tag/Block/Product/Result.php
index 29d74d2..f881ea0 100644
--- a/app/code/core/Mage/Tag/Block/Product/Result.php
+++ b/app/code/core/Mage/Tag/Block/Product/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Helper/Data.php b/app/code/core/Mage/Tag/Helper/Data.php
index a05d475..4400d13 100644
--- a/app/code/core/Mage/Tag/Helper/Data.php
+++ b/app/code/core/Mage/Tag/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Api.php b/app/code/core/Mage/Tag/Model/Api.php
index dbbb621..583dab2 100644
--- a/app/code/core/Mage/Tag/Model/Api.php
+++ b/app/code/core/Mage/Tag/Model/Api.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Api/V2.php b/app/code/core/Mage/Tag/Model/Api/V2.php
index 50977aa..e40b6b3 100644
--- a/app/code/core/Mage/Tag/Model/Api/V2.php
+++ b/app/code/core/Mage/Tag/Model/Api/V2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Entity/Customer/Collection.php b/app/code/core/Mage/Tag/Model/Entity/Customer/Collection.php
index fe7712b..6f81e59 100644
--- a/app/code/core/Mage/Tag/Model/Entity/Customer/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Entity/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Indexer/Summary.php b/app/code/core/Mage/Tag/Model/Indexer/Summary.php
index 15a5ae2..15eb114 100644
--- a/app/code/core/Mage/Tag/Model/Indexer/Summary.php
+++ b/app/code/core/Mage/Tag/Model/Indexer/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Customer/Collection.php b/app/code/core/Mage/Tag/Model/Mysql4/Customer/Collection.php
index 2741c53..32f2c3a 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Customer/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Indexer/Summary.php b/app/code/core/Mage/Tag/Model/Mysql4/Indexer/Summary.php
index a3197ec..57c55ff 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Indexer/Summary.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Indexer/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Popular/Collection.php b/app/code/core/Mage/Tag/Model/Mysql4/Popular/Collection.php
index 30d8748..c77ebc3 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Popular/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Popular/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Product/Collection.php b/app/code/core/Mage/Tag/Model/Mysql4/Product/Collection.php
index b0bc275..9b5d8b1 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Product/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Tag.php b/app/code/core/Mage/Tag/Model/Mysql4/Tag.php
index 4dfc136..cd5d331 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Tag.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Tag/Collection.php b/app/code/core/Mage/Tag/Model/Mysql4/Tag/Collection.php
index ec1c3ad..81a2163 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Tag/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Tag/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Mysql4/Tag/Relation.php b/app/code/core/Mage/Tag/Model/Mysql4/Tag/Relation.php
index ce69171..6d95261 100644
--- a/app/code/core/Mage/Tag/Model/Mysql4/Tag/Relation.php
+++ b/app/code/core/Mage/Tag/Model/Mysql4/Tag/Relation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Customer/Collection.php b/app/code/core/Mage/Tag/Model/Resource/Customer/Collection.php
index b307a02..a086365 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Customer/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Customer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Indexer/Summary.php b/app/code/core/Mage/Tag/Model/Resource/Indexer/Summary.php
index f03e333..26a2768 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Indexer/Summary.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Indexer/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Popular/Collection.php b/app/code/core/Mage/Tag/Model/Resource/Popular/Collection.php
index ce57ef4..fcee657 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Popular/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Popular/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Product/Collection.php b/app/code/core/Mage/Tag/Model/Resource/Product/Collection.php
index 148042e..32c00e9 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Product/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Tag.php b/app/code/core/Mage/Tag/Model/Resource/Tag.php
index b3f5849..6012a22 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Tag.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Tag/Collection.php b/app/code/core/Mage/Tag/Model/Resource/Tag/Collection.php
index 13403c4..b3f1e43 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Tag/Collection.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Tag/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Resource/Tag/Relation.php b/app/code/core/Mage/Tag/Model/Resource/Tag/Relation.php
index c1eadca..f2c09fe 100644
--- a/app/code/core/Mage/Tag/Model/Resource/Tag/Relation.php
+++ b/app/code/core/Mage/Tag/Model/Resource/Tag/Relation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Session.php b/app/code/core/Mage/Tag/Model/Session.php
index 7ef6a72..be4aa1c 100644
--- a/app/code/core/Mage/Tag/Model/Session.php
+++ b/app/code/core/Mage/Tag/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Tag.php b/app/code/core/Mage/Tag/Model/Tag.php
index 3873f0f..26fda6e 100644
--- a/app/code/core/Mage/Tag/Model/Tag.php
+++ b/app/code/core/Mage/Tag/Model/Tag.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/Model/Tag/Relation.php b/app/code/core/Mage/Tag/Model/Tag/Relation.php
index 151f098..9d397ac 100644
--- a/app/code/core/Mage/Tag/Model/Tag/Relation.php
+++ b/app/code/core/Mage/Tag/Model/Tag/Relation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/controllers/CustomerController.php b/app/code/core/Mage/Tag/controllers/CustomerController.php
index 955888e..c8410f2 100644
--- a/app/code/core/Mage/Tag/controllers/CustomerController.php
+++ b/app/code/core/Mage/Tag/controllers/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/controllers/IndexController.php b/app/code/core/Mage/Tag/controllers/IndexController.php
index 665cb45..65595dd 100644
--- a/app/code/core/Mage/Tag/controllers/IndexController.php
+++ b/app/code/core/Mage/Tag/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/controllers/ListController.php b/app/code/core/Mage/Tag/controllers/ListController.php
index 352249a..95161f6 100644
--- a/app/code/core/Mage/Tag/controllers/ListController.php
+++ b/app/code/core/Mage/Tag/controllers/ListController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/controllers/ProductController.php b/app/code/core/Mage/Tag/controllers/ProductController.php
index ac8e4c3..055855c 100644
--- a/app/code/core/Mage/Tag/controllers/ProductController.php
+++ b/app/code/core/Mage/Tag/controllers/ProductController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/etc/adminhtml.xml b/app/code/core/Mage/Tag/etc/adminhtml.xml
index 4d6854f..aa26611 100644
--- a/app/code/core/Mage/Tag/etc/adminhtml.xml
+++ b/app/code/core/Mage/Tag/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tag/etc/api.xml b/app/code/core/Mage/Tag/etc/api.xml
index a1d22aa..a3c6403 100644
--- a/app/code/core/Mage/Tag/etc/api.xml
+++ b/app/code/core/Mage/Tag/etc/api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tag/etc/config.xml b/app/code/core/Mage/Tag/etc/config.xml
index 70da7fe..86f0ccb 100644
--- a/app/code/core/Mage/Tag/etc/config.xml
+++ b/app/code/core/Mage/Tag/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/install-1.6.0.0.php b/app/code/core/Mage/Tag/sql/tag_setup/install-1.6.0.0.php
index c38589f..26051a9 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-install-0.7.0.php
index b3e303b..264a24a 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.0-0.7.1.php
index b181a1c..1d0dd1f 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.1-0.7.2.php
index f3c410e..3f0e1a5 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 3c00e9d..251c546 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.3-0.7.4.php
index dbee242..b7d5d3d 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.4-0.7.5.php
index 7ff3c8f..c22ce71 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 87d2813..2ae9d48 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 6fb06d7..ab6d32f 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 7efd1dc..52b269c 100644
--- a/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Tag/sql/tag_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tag
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Adminhtml/Frontend/Region/Updater.php b/app/code/core/Mage/Tax/Block/Adminhtml/Frontend/Region/Updater.php
index e6508fe..ac52322 100644
--- a/app/code/core/Mage/Tax/Block/Adminhtml/Frontend/Region/Updater.php
+++ b/app/code/core/Mage/Tax/Block/Adminhtml/Frontend/Region/Updater.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Adminhtml/Notifications.php b/app/code/core/Mage/Tax/Block/Adminhtml/Notifications.php
index 95a38d6..6007bdc 100644
--- a/app/code/core/Mage/Tax/Block/Adminhtml/Notifications.php
+++ b/app/code/core/Mage/Tax/Block/Adminhtml/Notifications.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Checkout/Discount.php b/app/code/core/Mage/Tax/Block/Checkout/Discount.php
index 3803848..8706d9f 100644
--- a/app/code/core/Mage/Tax/Block/Checkout/Discount.php
+++ b/app/code/core/Mage/Tax/Block/Checkout/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Checkout/Grandtotal.php b/app/code/core/Mage/Tax/Block/Checkout/Grandtotal.php
index 6ee0e64..19fa2fd 100644
--- a/app/code/core/Mage/Tax/Block/Checkout/Grandtotal.php
+++ b/app/code/core/Mage/Tax/Block/Checkout/Grandtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Checkout/Shipping.php b/app/code/core/Mage/Tax/Block/Checkout/Shipping.php
index 31f3fb2..d619558 100644
--- a/app/code/core/Mage/Tax/Block/Checkout/Shipping.php
+++ b/app/code/core/Mage/Tax/Block/Checkout/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Checkout/Subtotal.php b/app/code/core/Mage/Tax/Block/Checkout/Subtotal.php
index 65971f9..0aa88e1 100644
--- a/app/code/core/Mage/Tax/Block/Checkout/Subtotal.php
+++ b/app/code/core/Mage/Tax/Block/Checkout/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Checkout/Tax.php b/app/code/core/Mage/Tax/Block/Checkout/Tax.php
index 9115415..f84be37 100644
--- a/app/code/core/Mage/Tax/Block/Checkout/Tax.php
+++ b/app/code/core/Mage/Tax/Block/Checkout/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Block/Sales/Order/Tax.php b/app/code/core/Mage/Tax/Block/Sales/Order/Tax.php
index e28b7db..ba1a4f88 100644
--- a/app/code/core/Mage/Tax/Block/Sales/Order/Tax.php
+++ b/app/code/core/Mage/Tax/Block/Sales/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Exception.php b/app/code/core/Mage/Tax/Exception.php
index 041fab9..02ba248 100644
--- a/app/code/core/Mage/Tax/Exception.php
+++ b/app/code/core/Mage/Tax/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Helper/Data.php b/app/code/core/Mage/Tax/Helper/Data.php
index 867496b..d16d06d 100644
--- a/app/code/core/Mage/Tax/Helper/Data.php
+++ b/app/code/core/Mage/Tax/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Calculation.php b/app/code/core/Mage/Tax/Model/Calculation.php
index d2d7c88..f9712d3 100644
--- a/app/code/core/Mage/Tax/Model/Calculation.php
+++ b/app/code/core/Mage/Tax/Model/Calculation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Calculation/Rate.php b/app/code/core/Mage/Tax/Model/Calculation/Rate.php
index 8b4bc28..117fb50 100644
--- a/app/code/core/Mage/Tax/Model/Calculation/Rate.php
+++ b/app/code/core/Mage/Tax/Model/Calculation/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Calculation/Rate/Title.php b/app/code/core/Mage/Tax/Model/Calculation/Rate/Title.php
index c6ac542..6bc59a0 100644
--- a/app/code/core/Mage/Tax/Model/Calculation/Rate/Title.php
+++ b/app/code/core/Mage/Tax/Model/Calculation/Rate/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Calculation/Rule.php b/app/code/core/Mage/Tax/Model/Calculation/Rule.php
index 69cc469..a43f988 100644
--- a/app/code/core/Mage/Tax/Model/Calculation/Rule.php
+++ b/app/code/core/Mage/Tax/Model/Calculation/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Class.php b/app/code/core/Mage/Tax/Model/Class.php
index bef22d7..b573276 100644
--- a/app/code/core/Mage/Tax/Model/Class.php
+++ b/app/code/core/Mage/Tax/Model/Class.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Class/Source/Customer.php b/app/code/core/Mage/Tax/Model/Class/Source/Customer.php
index 3fa8a09..68df668 100644
--- a/app/code/core/Mage/Tax/Model/Class/Source/Customer.php
+++ b/app/code/core/Mage/Tax/Model/Class/Source/Customer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Class/Source/Product.php b/app/code/core/Mage/Tax/Model/Class/Source/Product.php
index 4785901..b57c46f 100644
--- a/app/code/core/Mage/Tax/Model/Class/Source/Product.php
+++ b/app/code/core/Mage/Tax/Model/Class/Source/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Config.php b/app/code/core/Mage/Tax/Model/Config.php
index 6e8f40d..046b6eb 100644
--- a/app/code/core/Mage/Tax/Model/Config.php
+++ b/app/code/core/Mage/Tax/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Config/Notification.php b/app/code/core/Mage/Tax/Model/Config/Notification.php
index 32cb7f4..c49c361 100644
--- a/app/code/core/Mage/Tax/Model/Config/Notification.php
+++ b/app/code/core/Mage/Tax/Model/Config/Notification.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Config/Price/Include.php b/app/code/core/Mage/Tax/Model/Config/Price/Include.php
index e841b53..53d5311 100644
--- a/app/code/core/Mage/Tax/Model/Config/Price/Include.php
+++ b/app/code/core/Mage/Tax/Model/Config/Price/Include.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Tax_Model_Config_Price_Include extends Mage_Core_Model_Config_Data
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation.php
index ea3f721..f7a67b0 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Collection.php
index 158a44a..57f257f 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate.php
index 16aa343..561ba30 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Collection.php
index ec185f7..d4a2c26 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title.php
index 28b6006..c95357c 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title/Collection.php
index 62ff811..5c3f4be 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rate/Title/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule.php
index a2324fb..f10d1fe 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule/Collection.php
index 5295767..45628f6 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Calculation/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Class.php b/app/code/core/Mage/Tax/Model/Mysql4/Class.php
index ebecb3d..a2f23e5 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Class.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Class.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Class/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Class/Collection.php
index f656337..e73b944 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Class/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Class/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Report/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Report/Collection.php
index bcc6ae5..43c9abd 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Report/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Report/Tax.php b/app/code/core/Mage/Tax/Model/Mysql4/Report/Tax.php
index a9d0111..ed586f5 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Report/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Report/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Report/Updatedat/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Report/Updatedat/Collection.php
index 8b047a5..70c493c 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Report/Updatedat/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Report/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax.php b/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax.php
index 883235c..d0c10bf 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax/Collection.php b/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax/Collection.php
index cb30263..35abda3 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Sales/Order/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Mysql4/Setup.php b/app/code/core/Mage/Tax/Model/Mysql4/Setup.php
index 82640f2..dbb5bb0 100644
--- a/app/code/core/Mage/Tax/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Tax/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Observer.php b/app/code/core/Mage/Tax/Model/Observer.php
index bccf49d..34caeba 100644
--- a/app/code/core/Mage/Tax/Model/Observer.php
+++ b/app/code/core/Mage/Tax/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation.php b/app/code/core/Mage/Tax/Model/Resource/Calculation.php
index 49294b5..163a640 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Collection.php
index a6bb9cc..1151625 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate.php
index 8da23ff..8d306bf 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Collection.php
index 55fa8e4..c2c035b 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title.php
index ea829ed..9ecf513 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title/Collection.php
index 33300eb..d3b9ad0 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rate/Title/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule.php
index 36fcefa..8a12f7a 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule/Collection.php
index ccebacf..987fcdd 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Calculation/Rule/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Class.php b/app/code/core/Mage/Tax/Model/Resource/Class.php
index d8db538..0c37b06 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Class.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Class.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Class/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Class/Collection.php
index de3e02b..a0bd1af 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Class/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Class/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Report/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Report/Collection.php
index 2bc26a3..2e4d773 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Report/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Report/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Report/Tax.php b/app/code/core/Mage/Tax/Model/Resource/Report/Tax.php
index 688335f..ddf8835 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Report/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Report/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Createdat.php b/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Createdat.php
index 69c9f64..e0e1a5e 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Createdat.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Createdat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Updatedat.php b/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Updatedat.php
index a047c63..a5b9684 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Updatedat.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Report/Tax/Updatedat.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Report/Updatedat/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Report/Updatedat/Collection.php
index 0857a94..aa2c2d3 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Report/Updatedat/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Report/Updatedat/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax.php b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax.php
index 300a477..2e3ebd0 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Collection.php
index c5a2513..fea3c14 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item.php b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item.php
index 8eeec05..8d0a5b2 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item/Collection.php b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item/Collection.php
index d4a5bc6..aa39b2d 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item/Collection.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Sales/Order/Tax/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Resource/Setup.php b/app/code/core/Mage/Tax/Model/Resource/Setup.php
index 3ea0515..b3ac9ba 100644
--- a/app/code/core/Mage/Tax/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Tax/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Order/Tax.php b/app/code/core/Mage/Tax/Model/Sales/Order/Tax.php
index bce75b0..bfb33bf 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Order/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Order/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Order/Tax/Item.php b/app/code/core/Mage/Tax/Model/Sales/Order/Tax/Item.php
index c1b6039..f6876b7 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Order/Tax/Item.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Order/Tax/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Pdf/Grandtotal.php b/app/code/core/Mage/Tax/Model/Sales/Pdf/Grandtotal.php
index 606f02a..6201bc5 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Pdf/Grandtotal.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Pdf/Grandtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Pdf/Shipping.php b/app/code/core/Mage/Tax/Model/Sales/Pdf/Shipping.php
index ac58f7b..4cabdff 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Pdf/Shipping.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Pdf/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Pdf/Subtotal.php b/app/code/core/Mage/Tax/Model/Sales/Pdf/Subtotal.php
index c81237e..44e4013 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Pdf/Subtotal.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Pdf/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Pdf/Tax.php b/app/code/core/Mage/Tax/Model/Sales/Pdf/Tax.php
index 2aa4570..92ad1ca 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Pdf/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Pdf/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Discount.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Discount.php
index 9359ed1..f31120e 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Discount.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Discount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Subtotal.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Subtotal.php
index 3c55543..fe5e2d9 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Subtotal.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Tax.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Tax.php
index 7aef504..0cfa8d0 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Nominal/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Shipping.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Shipping.php
index e2c989d..7f9a81c 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Shipping.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Subtotal.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Subtotal.php
index 489d9e0..5276472 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Subtotal.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Tax.php b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Tax.php
index 46bcbf6..dd0f4ff 100644
--- a/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Tax.php
+++ b/app/code/core/Mage/Tax/Model/Sales/Total/Quote/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/Algorithm.php b/app/code/core/Mage/Tax/Model/System/Config/Source/Algorithm.php
index f485674..32138c1 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/Algorithm.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/Algorithm.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/Apply.php b/app/code/core/Mage/Tax/Model/System/Config/Source/Apply.php
index d813b13..19f56d7 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/Apply.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/Apply.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/PriceType.php b/app/code/core/Mage/Tax/Model/System/Config/Source/PriceType.php
index c3ae09d..9c23db0 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/PriceType.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/PriceType.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Country.php b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Country.php
index 3553578..871cc8c 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Country.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Display/Type.php b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Display/Type.php
index dd6197c..34b16fb 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Display/Type.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Display/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Region.php b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Region.php
index 43d057b..368fc9d 100644
--- a/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Region.php
+++ b/app/code/core/Mage/Tax/Model/System/Config/Source/Tax/Region.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/data/tax_setup/data-install-1.6.0.0.php b/app/code/core/Mage/Tax/data/tax_setup/data-install-1.6.0.0.php
index d46900a..dcd835b 100644
--- a/app/code/core/Mage/Tax/data/tax_setup/data-install-1.6.0.0.php
+++ b/app/code/core/Mage/Tax/data/tax_setup/data-install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /** @var $installer Mage_Tax_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Tax/etc/adminhtml.xml b/app/code/core/Mage/Tax/etc/adminhtml.xml
index d719ce6..82364f1 100644
--- a/app/code/core/Mage/Tax/etc/adminhtml.xml
+++ b/app/code/core/Mage/Tax/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tax/etc/config.xml b/app/code/core/Mage/Tax/etc/config.xml
index ac8cf9f..5428c9a 100644
--- a/app/code/core/Mage/Tax/etc/config.xml
+++ b/app/code/core/Mage/Tax/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tax/etc/system.xml b/app/code/core/Mage/Tax/etc/system.xml
index 5140821..3ec71c9 100644
--- a/app/code/core/Mage/Tax/etc/system.xml
+++ b/app/code/core/Mage/Tax/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/install-1.6.0.0.php b/app/code/core/Mage/Tax/sql/tax_setup/install-1.6.0.0.php
index 377da30..cf5fd71 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /** @var $installer Mage_Tax_Model_Resource_Setup */
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-0.7.0.php
index c09e750..a7b8ae6 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-1.4.0.0.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-1.4.0.0.php
index 2932fac..13ca3fd 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-1.4.0.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-install-1.4.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.6.1-0.7.0.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.6.1-0.7.0.php
index 7fa4f65..fbf8566 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.6.1-0.7.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.6.1-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.0-0.7.1.php
index e06c892..1efcf4a 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.1-0.7.2.php
index eca128a..09ab689 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.10-0.7.11.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.10-0.7.11.php
index ed06c6b..ba684a2 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.10-0.7.11.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.10-0.7.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.11-0.7.12.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.11-0.7.12.php
index 61b13cd..88f01c6 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.11-0.7.12.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.11-0.7.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.12-0.7.13.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.12-0.7.13.php
index b7cf02f..d5d23d8 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.12-0.7.13.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.12-0.7.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.2-0.7.3.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.2-0.7.3.php
index 4ffc36d..1e71f76 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.2-0.7.3.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.2-0.7.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.3-0.7.4.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.3-0.7.4.php
index 49fbffa..41a5442 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.3-0.7.4.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.3-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.4-0.7.5.php
index c367e8a..49ef95c 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.5-0.7.6.php
index 0a11190..bbca961 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.6-0.7.7.php
index c34c022..9ac7b59 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 077fe59..621c06f 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.8-0.7.9.php
index ccbd74e..f7c94d9 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.9-0.7.10.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.9-0.7.10.php
index 4e6224b..12e09e3 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.9-0.7.10.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-0.7.9-0.7.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.3.9-1.4.0.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.3.9-1.4.0.php
index 21175d5..a933369 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.3.9-1.4.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.3.9-1.4.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
index 77a0712..c9ae62f 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.0-1.4.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
index 02fb422..7518cc1 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.4.0.1-1.4.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index d3fbcbb..3d05c24 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.0-1.6.0.1.php
index a56b2b3..c63a36c 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.1-1.6.0.2.php
index 048b926..495c5f1 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.2-1.6.0.3.php
index 6ca1c88..6055719 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.3-1.6.0.4.php b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.3-1.6.0.4.php
index 7241979..e7d598a 100644
--- a/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.3-1.6.0.4.php
+++ b/app/code/core/Mage/Tax/sql/tax_setup/upgrade-1.6.0.3-1.6.0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Tax
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Block/Abstract.php b/app/code/core/Mage/Uploader/Block/Abstract.php
index 5e9aadf..1a83585 100644
--- a/app/code/core/Mage/Uploader/Block/Abstract.php
+++ b/app/code/core/Mage/Uploader/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Block/Multiple.php b/app/code/core/Mage/Uploader/Block/Multiple.php
index 769072c..2f7bba3 100644
--- a/app/code/core/Mage/Uploader/Block/Multiple.php
+++ b/app/code/core/Mage/Uploader/Block/Multiple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Block/Single.php b/app/code/core/Mage/Uploader/Block/Single.php
index 4cfb705..485a880 100644
--- a/app/code/core/Mage/Uploader/Block/Single.php
+++ b/app/code/core/Mage/Uploader/Block/Single.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Helper/Data.php b/app/code/core/Mage/Uploader/Helper/Data.php
index cbc7dda..265d387 100644
--- a/app/code/core/Mage/Uploader/Helper/Data.php
+++ b/app/code/core/Mage/Uploader/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Helper/File.php b/app/code/core/Mage/Uploader/Helper/File.php
index d963887..e1022b5 100644
--- a/app/code/core/Mage/Uploader/Helper/File.php
+++ b/app/code/core/Mage/Uploader/Helper/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Model/Config/Abstract.php b/app/code/core/Mage/Uploader/Model/Config/Abstract.php
index f463526..2c27c1d 100644
--- a/app/code/core/Mage/Uploader/Model/Config/Abstract.php
+++ b/app/code/core/Mage/Uploader/Model/Config/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Model/Config/Browsebutton.php b/app/code/core/Mage/Uploader/Model/Config/Browsebutton.php
index f69de27..b752857 100644
--- a/app/code/core/Mage/Uploader/Model/Config/Browsebutton.php
+++ b/app/code/core/Mage/Uploader/Model/Config/Browsebutton.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Model/Config/Misc.php b/app/code/core/Mage/Uploader/Model/Config/Misc.php
index fbe4168..27d0d9b 100644
--- a/app/code/core/Mage/Uploader/Model/Config/Misc.php
+++ b/app/code/core/Mage/Uploader/Model/Config/Misc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/Model/Config/Uploader.php b/app/code/core/Mage/Uploader/Model/Config/Uploader.php
index afee8d0..8c5ac8c 100644
--- a/app/code/core/Mage/Uploader/Model/Config/Uploader.php
+++ b/app/code/core/Mage/Uploader/Model/Config/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Uploader/etc/config.xml b/app/code/core/Mage/Uploader/etc/config.xml
index fdd8270..0489dda 100644
--- a/app/code/core/Mage/Uploader/etc/config.xml
+++ b/app/code/core/Mage/Uploader/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Uploader/etc/jstranslator.xml b/app/code/core/Mage/Uploader/etc/jstranslator.xml
index 23ebcc1..9b8818a 100644
--- a/app/code/core/Mage/Uploader/etc/jstranslator.xml
+++ b/app/code/core/Mage/Uploader/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Usa/Block/Adminhtml/Dhl/Unitofmeasure.php b/app/code/core/Mage/Usa/Block/Adminhtml/Dhl/Unitofmeasure.php
index 8dd2459..5235118 100644
--- a/app/code/core/Mage/Usa/Block/Adminhtml/Dhl/Unitofmeasure.php
+++ b/app/code/core/Mage/Usa/Block/Adminhtml/Dhl/Unitofmeasure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Helper/Data.php b/app/code/core/Mage/Usa/Helper/Data.php
index 6f28031..882725c 100644
--- a/app/code/core/Mage/Usa/Helper/Data.php
+++ b/app/code/core/Mage/Usa/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract.php
index 99f8270..39f2a4b 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Backend/Abstract.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Backend/Abstract.php
index 665ac3b..29186ce 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Backend/Abstract.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Backend/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Mode.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Mode.php
index dc738b1..e8e9622 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Mode.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Requesttype.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Requesttype.php
index 687b669..f6966d0 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Requesttype.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Abstract/Source/Requesttype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl.php
index f9b99c0..2ff0d65 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Abstract.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Abstract.php
index 1c378f2..2022776 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Abstract.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International.php
index a2fc736..e916429 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Contenttype.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Contenttype.php
index b8dbb11..bf2cd51 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Contenttype.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Contenttype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Abstract.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Abstract.php
index 56666ca..443f7c9 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Abstract.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Doc.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Doc.php
index 0f567d7..9d89bf1 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Doc.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Doc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freedoc.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freedoc.php
index 11f6db0..4cee0e8 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freedoc.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freedoc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freenondoc.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freenondoc.php
index 40e5c4e..0e0ba51 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freenondoc.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Freenondoc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Nondoc.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Nondoc.php
index e73e2d9..1cc2bcc 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Nondoc.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Nondoc.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Size.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Size.php
index 35ae170..6074cfa 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Size.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Size.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Unitofmeasure.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Unitofmeasure.php
index 51afea5..e62e95a 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Unitofmeasure.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/International/Source/Method/Unitofmeasure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf.php
index 388cf0e..be9f14e 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/Page.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/Page.php
index c4f86ba..c910975 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/Page.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/PageBuilder.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/PageBuilder.php
index 6f4c5d9..2871f67 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/PageBuilder.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Label/Pdf/PageBuilder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Dutypaymenttype.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Dutypaymenttype.php
index a85b67c..ea6408b 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Dutypaymenttype.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Dutypaymenttype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Freemethod.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Freemethod.php
index 5f22863..49bce58 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Freemethod.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Freemethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Method.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Method.php
index 6af5f0a..99e65c7 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Method.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Rounding.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Rounding.php
index 434447f..c955176 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Rounding.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Rounding.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Value.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Value.php
index 7529f5f..60d85f4 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Value.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Protection/Value.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Shipmenttype.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Shipmenttype.php
index c2e23cc..d8d945b 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Shipmenttype.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Dhl/Source/Shipmenttype.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex.php
index beaaca3..bece202 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Dropoff.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Dropoff.php
index 74c55b7..88dd53a 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Dropoff.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Dropoff.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Freemethod.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Freemethod.php
index 6af6bf7..5e94825 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Freemethod.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Freemethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Method.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Method.php
index 8fb2bfe..23c339e 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Method.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Packaging.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Packaging.php
index 19afd8e..a76770c 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Packaging.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Packaging.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Unitofmeasure.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Unitofmeasure.php
index ebe6991..24e29e8 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Unitofmeasure.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Fedex/Source/Unitofmeasure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups.php
index 3ce6236..f9a7789 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Freemethod.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Freemethod.php
index d844e62..ab7c370 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Freemethod.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Freemethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/OriginShipment.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/OriginShipment.php
index 4d7e1c0..d0ecce8 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/OriginShipment.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/OriginShipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Type.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Type.php
index fe03362..930f7de 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Type.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Backend/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Container.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Container.php
index 46622e2..2459c1e 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Container.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/DestType.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/DestType.php
index 24385f2..2c9d074 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/DestType.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/DestType.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Freemethod.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Freemethod.php
index 77a5960..42218be 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Freemethod.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Freemethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Method.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Method.php
index c53bba9..64ba42b 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Method.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Mode.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Mode.php
index 65ba4ed..42a26ef 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Mode.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Mode.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/OriginShipment.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/OriginShipment.php
index 72be9a8..a5af14f 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/OriginShipment.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/OriginShipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Pickup.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Pickup.php
index 3927cfc..a8ded1a 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Pickup.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Pickup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Type.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Type.php
index bf7b9c0..4193a72 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Type.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Unitofmeasure.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Unitofmeasure.php
index 4e3dbb9..9840cbe 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Unitofmeasure.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Ups/Source/Unitofmeasure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps.php
index f87ff74..09c4515 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Container.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Container.php
index 38c122e..df20b92 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Container.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Freemethod.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Freemethod.php
index d5f52bf..d154ab3 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Freemethod.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Freemethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Machinable.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Machinable.php
index 8ef6139..0b20be1 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Machinable.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Machinable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Method.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Method.php
index 1bd27cb..1fbba90 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Method.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Size.php b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Size.php
index f874265..f479a51 100644
--- a/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Size.php
+++ b/app/code/core/Mage/Usa/Model/Shipping/Carrier/Usps/Source/Size.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/etc/config.xml b/app/code/core/Mage/Usa/etc/config.xml
index 0685cf4..ef0f1a3 100644
--- a/app/code/core/Mage/Usa/etc/config.xml
+++ b/app/code/core/Mage/Usa/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Usa/etc/dhl/international/countries.xml b/app/code/core/Mage/Usa/etc/dhl/international/countries.xml
index 19851a6..52b153b 100644
--- a/app/code/core/Mage/Usa/etc/dhl/international/countries.xml
+++ b/app/code/core/Mage/Usa/etc/dhl/international/countries.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Usa/etc/system.xml b/app/code/core/Mage/Usa/etc/system.xml
index 7bc0af9..157a035 100644
--- a/app/code/core/Mage/Usa/etc/system.xml
+++ b/app/code/core/Mage/Usa/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -125,6 +125,7 @@
                         <gateway_url translate="label">
                             <label>Gateway URL</label>
                             <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_gatewayurl</backend_model>
                             <sort_order>20</sort_order>
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
@@ -766,6 +767,7 @@
                         <gateway_xml_url translate="label">
                             <label>Gateway XML URL</label>
                             <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_gatewayurl</backend_model>
                             <sort_order>22</sort_order>
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
@@ -774,6 +776,7 @@
                         <tracking_xml_url translate="label">
                             <label>Tracking XML URL</label>
                             <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_gatewayurl</backend_model>
                             <sort_order>24</sort_order>
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
@@ -782,6 +785,7 @@
                         <shipconfirm_xml_url translate="label">
                             <label>Shipping Confirm XML URL</label>
                             <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_gatewayurl</backend_model>
                             <sort_order>26</sort_order>
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
@@ -790,6 +794,7 @@
                         <shipaccept_xml_url translate="label">
                             <label>Shipping Accept XML URL</label>
                             <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_gatewayurl</backend_model>
                             <sort_order>28</sort_order>
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
diff --git a/app/code/core/Mage/Usa/sql/usa_setup/install-1.6.0.0.php b/app/code/core/Mage/Usa/sql/usa_setup/install-1.6.0.0.php
index 4baeb7f..ab630e9 100644
--- a/app/code/core/Mage/Usa/sql/usa_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Usa/sql/usa_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/sql/usa_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Usa/sql/usa_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 5a32ff5..0cc2dcf 100644
--- a/app/code/core/Mage/Usa/sql/usa_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Usa/sql/usa_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.0-1.6.0.1.php b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.0-1.6.0.1.php
index 2b3cf5d..4663c1c 100644
--- a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.0-1.6.0.1.php
+++ b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.0-1.6.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.1-1.6.0.2.php b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.1-1.6.0.2.php
index 732d117..d282159 100644
--- a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.1-1.6.0.2.php
+++ b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.1-1.6.0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.2-1.6.0.3.php b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.2-1.6.0.3.php
index 98cf43f..3f4cf02 100644
--- a/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.2-1.6.0.3.php
+++ b/app/code/core/Mage/Usa/sql/usa_setup/upgrade-1.6.0.2-1.6.0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Usa
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Block/Element/Weee/Tax.php b/app/code/core/Mage/Weee/Block/Element/Weee/Tax.php
index eec2e49..a7a58b8 100644
--- a/app/code/core/Mage/Weee/Block/Element/Weee/Tax.php
+++ b/app/code/core/Mage/Weee/Block/Element/Weee/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Block/Renderer/Weee/Tax.php b/app/code/core/Mage/Weee/Block/Renderer/Weee/Tax.php
index fb7c50a..fe741b0 100644
--- a/app/code/core/Mage/Weee/Block/Renderer/Weee/Tax.php
+++ b/app/code/core/Mage/Weee/Block/Renderer/Weee/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Helper/Data.php b/app/code/core/Mage/Weee/Helper/Data.php
index c11ee28..f628910 100644
--- a/app/code/core/Mage/Weee/Helper/Data.php
+++ b/app/code/core/Mage/Weee/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Attribute/Backend/Weee/Tax.php b/app/code/core/Mage/Weee/Model/Attribute/Backend/Weee/Tax.php
index a9ad22d..055c631 100644
--- a/app/code/core/Mage/Weee/Model/Attribute/Backend/Weee/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Attribute/Backend/Weee/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Config/Source/Display.php b/app/code/core/Mage/Weee/Model/Config/Source/Display.php
index f73fb72..30abc96 100644
--- a/app/code/core/Mage/Weee/Model/Config/Source/Display.php
+++ b/app/code/core/Mage/Weee/Model/Config/Source/Display.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Weee_Model_Config_Source_Display
diff --git a/app/code/core/Mage/Weee/Model/Config/Source/Fpt/Tax.php b/app/code/core/Mage/Weee/Model/Config/Source/Fpt/Tax.php
index 8d9900a..fc77c23 100644
--- a/app/code/core/Mage/Weee/Model/Config/Source/Fpt/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Config/Source/Fpt/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Weee_Model_Config_Source_Fpt_Tax
diff --git a/app/code/core/Mage/Weee/Model/Mysql4/Attribute/Backend/Weee/Tax.php b/app/code/core/Mage/Weee/Model/Mysql4/Attribute/Backend/Weee/Tax.php
index 150d21f..e91bec1 100644
--- a/app/code/core/Mage/Weee/Model/Mysql4/Attribute/Backend/Weee/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Mysql4/Attribute/Backend/Weee/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Mysql4/Setup.php b/app/code/core/Mage/Weee/Model/Mysql4/Setup.php
index 5b774de..bcf8a41 100644
--- a/app/code/core/Mage/Weee/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/Weee/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Mysql4/Tax.php b/app/code/core/Mage/Weee/Model/Mysql4/Tax.php
index 63464b6..80ad200 100644
--- a/app/code/core/Mage/Weee/Model/Mysql4/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Mysql4/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Observer.php b/app/code/core/Mage/Weee/Model/Observer.php
index 823a4d7..f9ae9b3 100644
--- a/app/code/core/Mage/Weee/Model/Observer.php
+++ b/app/code/core/Mage/Weee/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Resource/Attribute/Backend/Weee/Tax.php b/app/code/core/Mage/Weee/Model/Resource/Attribute/Backend/Weee/Tax.php
index 9538967..4e7a379 100644
--- a/app/code/core/Mage/Weee/Model/Resource/Attribute/Backend/Weee/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Resource/Attribute/Backend/Weee/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Resource/Setup.php b/app/code/core/Mage/Weee/Model/Resource/Setup.php
index fc6f325..f2e1d9f 100644
--- a/app/code/core/Mage/Weee/Model/Resource/Setup.php
+++ b/app/code/core/Mage/Weee/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Resource/Tax.php b/app/code/core/Mage/Weee/Model/Resource/Tax.php
index eedd60c..9669fe2 100644
--- a/app/code/core/Mage/Weee/Model/Resource/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Resource/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Tax.php b/app/code/core/Mage/Weee/Model/Tax.php
index 7d954cc..7acf2c4 100644
--- a/app/code/core/Mage/Weee/Model/Tax.php
+++ b/app/code/core/Mage/Weee/Model/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Total/Creditmemo/Weee.php b/app/code/core/Mage/Weee/Model/Total/Creditmemo/Weee.php
index 7de066c..1727f9d 100644
--- a/app/code/core/Mage/Weee/Model/Total/Creditmemo/Weee.php
+++ b/app/code/core/Mage/Weee/Model/Total/Creditmemo/Weee.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Total/Invoice/Weee.php b/app/code/core/Mage/Weee/Model/Total/Invoice/Weee.php
index fc4a31c..1c225c4 100644
--- a/app/code/core/Mage/Weee/Model/Total/Invoice/Weee.php
+++ b/app/code/core/Mage/Weee/Model/Total/Invoice/Weee.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Total/Quote/Nominal/Weee.php b/app/code/core/Mage/Weee/Model/Total/Quote/Nominal/Weee.php
index 3aa3911..4ab73c3 100644
--- a/app/code/core/Mage/Weee/Model/Total/Quote/Nominal/Weee.php
+++ b/app/code/core/Mage/Weee/Model/Total/Quote/Nominal/Weee.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/Model/Total/Quote/Weee.php b/app/code/core/Mage/Weee/Model/Total/Quote/Weee.php
index 88825d1..25cabb1 100644
--- a/app/code/core/Mage/Weee/Model/Total/Quote/Weee.php
+++ b/app/code/core/Mage/Weee/Model/Total/Quote/Weee.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/etc/config.xml b/app/code/core/Mage/Weee/etc/config.xml
index 2eb9887..a7604c4 100644
--- a/app/code/core/Mage/Weee/etc/config.xml
+++ b/app/code/core/Mage/Weee/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Weee/etc/system.xml b/app/code/core/Mage/Weee/etc/system.xml
index 59a2e54..9933cee 100644
--- a/app/code/core/Mage/Weee/etc/system.xml
+++ b/app/code/core/Mage/Weee/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/install-1.6.0.0.php b/app/code/core/Mage/Weee/sql/weee_setup/install-1.6.0.0.php
index 23345ed..196a91c 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-install-0.1.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-install-0.1.php
index 9bca0a5..228b6a7 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-install-0.1.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-install-0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.1-0.2.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.1-0.2.php
index 64909c6..3825a92 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.1-0.2.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.1-0.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.10-0.11.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.10-0.11.php
index fbd1df5..26d0be9 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.10-0.11.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.10-0.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.11-0.12.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.11-0.12.php
index 066433e..b494a05 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.11-0.12.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.11-0.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.12-0.13.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.12-0.13.php
index 5ba6f32..d8caed4 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.12-0.13.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.12-0.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.2-0.3.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.2-0.3.php
index 35c415b..12f90e1 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.2-0.3.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.2-0.3.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.3-0.4.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.3-0.4.php
index fb2ed1b..3886692 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.3-0.4.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.3-0.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.4-0.5.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.4-0.5.php
index 51d493c..35f5fab 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.4-0.5.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.4-0.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.5-0.6.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.5-0.6.php
index 45b41a6..4589499 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.5-0.6.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.5-0.6.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.6-0.7.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.6-0.7.php
index 6c2172c..cb82cac 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.6-0.7.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.6-0.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.7-0.8.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.7-0.8.php
index 274fa92..0fd1abd 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.7-0.8.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.7-0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.8-0.9.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.8-0.9.php
index b8ae212..e78c2e2 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.8-0.9.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.8-0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.9-0.10.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.9-0.10.php
index 9c3ca54..d36fa9f 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.9-0.10.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-0.9-0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index e27db5c..299e4ff 100644
--- a/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Weee/sql/weee_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget.php
index efc2893..50b28ad 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Chooser.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Chooser.php
index 903177a..8ae402e 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Chooser.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Form.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Form.php
index 3736ddf..646d57f 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Form.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance.php
index 94e0dad..8c288b5 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit.php
index 92dbc2f..73869f8 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Block.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Block.php
index 321ae23..a4a949e 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Block.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Block.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Layout.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Layout.php
index 80f5119..ef56e5b 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Layout.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Template.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Template.php
index 43d3b86..0657229 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Template.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Chooser/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Form.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Form.php
index 7a9b158..490107d 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Form.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main.php
index 20fa4d6..9ec0981 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main/Layout.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main/Layout.php
index 7f93d46..3b090d0 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main/Layout.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Main/Layout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Properties.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Properties.php
index a7bf78e..a6f2903 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Properties.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Properties.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
index da3f696..12a9be9 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tabs.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tabs.php
index d6a6545..d45f108 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tabs.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Grid.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Grid.php
index c196c50..42f20a3 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Grid.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Instance/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Options.php b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Options.php
index bb32230..f3f0b0c 100644
--- a/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Options.php
+++ b/app/code/core/Mage/Widget/Block/Adminhtml/Widget/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Block/Interface.php b/app/code/core/Mage/Widget/Block/Interface.php
index 4b78224c..759fdbd 100644
--- a/app/code/core/Mage/Widget/Block/Interface.php
+++ b/app/code/core/Mage/Widget/Block/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Helper/Data.php b/app/code/core/Mage/Widget/Helper/Data.php
index d494e26..053d9fa 100644
--- a/app/code/core/Mage/Widget/Helper/Data.php
+++ b/app/code/core/Mage/Widget/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Mysql4/Widget.php b/app/code/core/Mage/Widget/Model/Mysql4/Widget.php
index 9b71d9e..d275d2e 100644
--- a/app/code/core/Mage/Widget/Model/Mysql4/Widget.php
+++ b/app/code/core/Mage/Widget/Model/Mysql4/Widget.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance.php b/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance.php
index ec32549..6d28c04 100644
--- a/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance.php
+++ b/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance/Collection.php b/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance/Collection.php
index 5620390..3282c9f 100644
--- a/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance/Collection.php
+++ b/app/code/core/Mage/Widget/Model/Mysql4/Widget/Instance/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Observer.php b/app/code/core/Mage/Widget/Model/Observer.php
index 539ef49..794e5d6 100644
--- a/app/code/core/Mage/Widget/Model/Observer.php
+++ b/app/code/core/Mage/Widget/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Resource/Widget.php b/app/code/core/Mage/Widget/Model/Resource/Widget.php
index a1182ac..b997104 100644
--- a/app/code/core/Mage/Widget/Model/Resource/Widget.php
+++ b/app/code/core/Mage/Widget/Model/Resource/Widget.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Resource/Widget/Instance.php b/app/code/core/Mage/Widget/Model/Resource/Widget/Instance.php
index a77e2e6..2914e77 100644
--- a/app/code/core/Mage/Widget/Model/Resource/Widget/Instance.php
+++ b/app/code/core/Mage/Widget/Model/Resource/Widget/Instance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Resource/Widget/Instance/Collection.php b/app/code/core/Mage/Widget/Model/Resource/Widget/Instance/Collection.php
index b80ed5d..2a3e93b 100644
--- a/app/code/core/Mage/Widget/Model/Resource/Widget/Instance/Collection.php
+++ b/app/code/core/Mage/Widget/Model/Resource/Widget/Instance/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Template/Filter.php b/app/code/core/Mage/Widget/Model/Template/Filter.php
index 0d11289..05ae106 100644
--- a/app/code/core/Mage/Widget/Model/Template/Filter.php
+++ b/app/code/core/Mage/Widget/Model/Template/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Widget.php b/app/code/core/Mage/Widget/Model/Widget.php
index 33bc9e4..1ef9274 100644
--- a/app/code/core/Mage/Widget/Model/Widget.php
+++ b/app/code/core/Mage/Widget/Model/Widget.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Widget/Config.php b/app/code/core/Mage/Widget/Model/Widget/Config.php
index 039e344..def9a35 100644
--- a/app/code/core/Mage/Widget/Model/Widget/Config.php
+++ b/app/code/core/Mage/Widget/Model/Widget/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/Model/Widget/Instance.php b/app/code/core/Mage/Widget/Model/Widget/Instance.php
index e302aeb..02ef9bf 100644
--- a/app/code/core/Mage/Widget/Model/Widget/Instance.php
+++ b/app/code/core/Mage/Widget/Model/Widget/Instance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/controllers/Adminhtml/Widget/InstanceController.php b/app/code/core/Mage/Widget/controllers/Adminhtml/Widget/InstanceController.php
index bdffd69..6f1d498 100644
--- a/app/code/core/Mage/Widget/controllers/Adminhtml/Widget/InstanceController.php
+++ b/app/code/core/Mage/Widget/controllers/Adminhtml/Widget/InstanceController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -167,7 +167,7 @@ class Mage_Widget_Adminhtml_Widget_InstanceController extends Mage_Adminhtml_Con
     public function saveAction()
     {
         $widgetInstance = $this->_initWidgetInstance();
-        if (!$widgetInstance) {
+        if (!$widgetInstance || !$this->_validatePostData($widgetInstance, $this->getRequest()->getPost())) {
             $this->_redirect('*/*/');
             return;
         }
@@ -320,4 +320,44 @@ class Mage_Widget_Adminhtml_Widget_InstanceController extends Mage_Adminhtml_Con
         }
         return $result;
     }
+
+    /**
+     * Validates update xml post data
+     *
+     * @param $widgetInstance
+     * @param $data
+     * @return bool
+     */
+    protected function _validatePostData($widgetInstance, $data)
+    {
+        $errorNo = true;
+        if (!empty($data['widget_instance']) && is_array($data['widget_instance'])) {
+            /** @var $validatorCustomLayout Mage_Adminhtml_Model_LayoutUpdate_Validator */
+            $validatorCustomLayout = Mage::getModel('adminhtml/layoutUpdate_validator');
+            foreach ($data['widget_instance'] as $pageGroup) {
+                try {
+                    if (
+                        !empty($pageGroup['page_group'])
+                        && !empty($pageGroup[$pageGroup['page_group']]['template'])
+                        && !empty($pageGroup[$pageGroup['page_group']]['block'])
+                        && !$validatorCustomLayout->isValid($widgetInstance->generateLayoutUpdateXml(
+                            $pageGroup[$pageGroup['page_group']]['block'],
+                            $pageGroup[$pageGroup['page_group']]['template']))
+                    ) {
+                        $errorNo = false;
+                    }
+                } catch (Exception $exception) {
+                    Mage::logException($exception);
+                    $this->_getSession()->addError(
+                        $this->__('An error occurred during POST data validation: %s', $exception->getMessage())
+                    );
+                    $errorNo = false;
+                }
+            }
+            foreach ($validatorCustomLayout->getMessages() as $message) {
+                $this->_getSession()->addError($message);
+            }
+        }
+        return $errorNo;
+    }
 }
diff --git a/app/code/core/Mage/Widget/controllers/Adminhtml/WidgetController.php b/app/code/core/Mage/Widget/controllers/Adminhtml/WidgetController.php
index 3771520..637d2d7 100644
--- a/app/code/core/Mage/Widget/controllers/Adminhtml/WidgetController.php
+++ b/app/code/core/Mage/Widget/controllers/Adminhtml/WidgetController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/etc/adminhtml.xml b/app/code/core/Mage/Widget/etc/adminhtml.xml
index a0ad34b..0c66645 100644
--- a/app/code/core/Mage/Widget/etc/adminhtml.xml
+++ b/app/code/core/Mage/Widget/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Widget/etc/config.xml b/app/code/core/Mage/Widget/etc/config.xml
index d7b486c..caf6195 100644
--- a/app/code/core/Mage/Widget/etc/config.xml
+++ b/app/code/core/Mage/Widget/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Widget/etc/jstranslator.xml b/app/code/core/Mage/Widget/etc/jstranslator.xml
index 8753058..57abb4b 100644
--- a/app/code/core/Mage/Widget/etc/jstranslator.xml
+++ b/app/code/core/Mage/Widget/etc/jstranslator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Widget/sql/widget_setup/install-1.6.0.0.php b/app/code/core/Mage/Widget/sql/widget_setup/install-1.6.0.0.php
index 6c5c4e5..3b607ab 100644
--- a/app/code/core/Mage/Widget/sql/widget_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Widget/sql/widget_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/sql/widget_setup/mysql4-install-1.4.0.0.0.php b/app/code/core/Mage/Widget/sql/widget_setup/mysql4-install-1.4.0.0.0.php
index d45ef44..9ba3264 100644
--- a/app/code/core/Mage/Widget/sql/widget_setup/mysql4-install-1.4.0.0.0.php
+++ b/app/code/core/Mage/Widget/sql/widget_setup/mysql4-install-1.4.0.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Widget/sql/widget_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Widget/sql/widget_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 108961b..7672922 100644
--- a/app/code/core/Mage/Widget/sql/widget_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Widget/sql/widget_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Abstract.php b/app/code/core/Mage/Wishlist/Block/Abstract.php
index 05debad..994ba19 100644
--- a/app/code/core/Mage/Wishlist/Block/Abstract.php
+++ b/app/code/core/Mage/Wishlist/Block/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Sharing.php b/app/code/core/Mage/Wishlist/Block/Customer/Sharing.php
index 3beb03a..32b9cc1 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Sharing.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Sharing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Sidebar.php b/app/code/core/Mage/Wishlist/Block/Customer/Sidebar.php
index 3d7bd05..e6db54e 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Sidebar.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist.php
index 59812f5..959b056 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Button.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Button.php
index 95a7510..73e41c5 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Button.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Button.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column.php
index a8cfd24..538d3f5 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Cart.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Cart.php
index 361cb64..8e1dccb 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Cart.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Comment.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Comment.php
index ca5fdbd..1509edb 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Comment.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Comment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Image.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Image.php
index bac2ca7..2d29178 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Image.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Remove.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Remove.php
index 57ac20f..24e837a 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Remove.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Column/Remove.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Options.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Options.php
index 382f69c..ea4bf52 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Options.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Item/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Items.php b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Items.php
index ec4e17f..0c20d05 100644
--- a/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Items.php
+++ b/app/code/core/Mage/Wishlist/Block/Customer/Wishlist/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Item/Configure.php b/app/code/core/Mage/Wishlist/Block/Item/Configure.php
index bebf860..e07ac9a 100644
--- a/app/code/core/Mage/Wishlist/Block/Item/Configure.php
+++ b/app/code/core/Mage/Wishlist/Block/Item/Configure.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Links.php b/app/code/core/Mage/Wishlist/Block/Links.php
index ce56c0e..c5f06c1 100644
--- a/app/code/core/Mage/Wishlist/Block/Links.php
+++ b/app/code/core/Mage/Wishlist/Block/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Render/Item/Price.php b/app/code/core/Mage/Wishlist/Block/Render/Item/Price.php
index 8b6d5e5..d30f651 100644
--- a/app/code/core/Mage/Wishlist/Block/Render/Item/Price.php
+++ b/app/code/core/Mage/Wishlist/Block/Render/Item/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Share/Email/Items.php b/app/code/core/Mage/Wishlist/Block/Share/Email/Items.php
index 6105545..cde7826 100644
--- a/app/code/core/Mage/Wishlist/Block/Share/Email/Items.php
+++ b/app/code/core/Mage/Wishlist/Block/Share/Email/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Share/Email/Rss.php b/app/code/core/Mage/Wishlist/Block/Share/Email/Rss.php
index a263592..2945490 100644
--- a/app/code/core/Mage/Wishlist/Block/Share/Email/Rss.php
+++ b/app/code/core/Mage/Wishlist/Block/Share/Email/Rss.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Block/Share/Wishlist.php b/app/code/core/Mage/Wishlist/Block/Share/Wishlist.php
index 8815809..0146551 100644
--- a/app/code/core/Mage/Wishlist/Block/Share/Wishlist.php
+++ b/app/code/core/Mage/Wishlist/Block/Share/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Controller/Abstract.php b/app/code/core/Mage/Wishlist/Controller/Abstract.php
index c17882c..871d80c 100644
--- a/app/code/core/Mage/Wishlist/Controller/Abstract.php
+++ b/app/code/core/Mage/Wishlist/Controller/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Helper/Data.php b/app/code/core/Mage/Wishlist/Helper/Data.php
index af6654a..734e59e 100644
--- a/app/code/core/Mage/Wishlist/Helper/Data.php
+++ b/app/code/core/Mage/Wishlist/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Config.php b/app/code/core/Mage/Wishlist/Model/Config.php
index 76912ff..5a12a9a 100644
--- a/app/code/core/Mage/Wishlist/Model/Config.php
+++ b/app/code/core/Mage/Wishlist/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Config/Source/Summary.php b/app/code/core/Mage/Wishlist/Model/Config/Source/Summary.php
index f59ae68..61708dc 100644
--- a/app/code/core/Mage/Wishlist/Model/Config/Source/Summary.php
+++ b/app/code/core/Mage/Wishlist/Model/Config/Source/Summary.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Wishlist_Model_Config_Source_Summary
diff --git a/app/code/core/Mage/Wishlist/Model/Item.php b/app/code/core/Mage/Wishlist/Model/Item.php
index 9b11448..606bebb 100644
--- a/app/code/core/Mage/Wishlist/Model/Item.php
+++ b/app/code/core/Mage/Wishlist/Model/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Item/Option.php b/app/code/core/Mage/Wishlist/Model/Item/Option.php
index dc80000..a4d0093 100644
--- a/app/code/core/Mage/Wishlist/Model/Item/Option.php
+++ b/app/code/core/Mage/Wishlist/Model/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Item.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Item.php
index 715e0ab..9561895 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Item.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Collection.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Collection.php
index eb4933e..4c29b89 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option.php
index 796b072..481deaa 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option/Collection.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option/Collection.php
index e4ad688..01c010d 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Item/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Product/Collection.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Product/Collection.php
index 6e970fe..c1e5c15 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Product/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist.php
index 4031c69..76d615e 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist/Collection.php b/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist/Collection.php
index e81f53e..6f7bd69 100644
--- a/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Mysql4/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Observer.php b/app/code/core/Mage/Wishlist/Model/Observer.php
index cc5759d..f6b55f5 100644
--- a/app/code/core/Mage/Wishlist/Model/Observer.php
+++ b/app/code/core/Mage/Wishlist/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Item.php b/app/code/core/Mage/Wishlist/Model/Resource/Item.php
index b395a9f..32f98d0 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Item.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Item/Collection.php b/app/code/core/Mage/Wishlist/Model/Resource/Item/Collection.php
index ba00318..654d48f 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Item/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Item/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Item/Option.php b/app/code/core/Mage/Wishlist/Model/Resource/Item/Option.php
index 39aa0fa..c8ec839 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Item/Option.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Item/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Item/Option/Collection.php b/app/code/core/Mage/Wishlist/Model/Resource/Item/Option/Collection.php
index 330c16a..ff62181 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Item/Option/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Item/Option/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Product/Collection.php b/app/code/core/Mage/Wishlist/Model/Resource/Product/Collection.php
index 1a2466b..66428b1 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Product/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Product/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Wishlist.php b/app/code/core/Mage/Wishlist/Model/Resource/Wishlist.php
index 86c1988..d74823d 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Wishlist.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Resource/Wishlist/Collection.php b/app/code/core/Mage/Wishlist/Model/Resource/Wishlist/Collection.php
index 30be431..0934ba9 100644
--- a/app/code/core/Mage/Wishlist/Model/Resource/Wishlist/Collection.php
+++ b/app/code/core/Mage/Wishlist/Model/Resource/Wishlist/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Session.php b/app/code/core/Mage/Wishlist/Model/Session.php
index 1d4ad24..8e25521 100644
--- a/app/code/core/Mage/Wishlist/Model/Session.php
+++ b/app/code/core/Mage/Wishlist/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/Model/Wishlist.php b/app/code/core/Mage/Wishlist/Model/Wishlist.php
index 0a648b5..63a80de 100644
--- a/app/code/core/Mage/Wishlist/Model/Wishlist.php
+++ b/app/code/core/Mage/Wishlist/Model/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/controllers/IndexController.php b/app/code/core/Mage/Wishlist/controllers/IndexController.php
index 926adb3..88d77e5 100644
--- a/app/code/core/Mage/Wishlist/controllers/IndexController.php
+++ b/app/code/core/Mage/Wishlist/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/controllers/SharedController.php b/app/code/core/Mage/Wishlist/controllers/SharedController.php
index ae03354..0d6f91a 100644
--- a/app/code/core/Mage/Wishlist/controllers/SharedController.php
+++ b/app/code/core/Mage/Wishlist/controllers/SharedController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/etc/adminhtml.xml b/app/code/core/Mage/Wishlist/etc/adminhtml.xml
index 17b9bd7..0f71c32 100644
--- a/app/code/core/Mage/Wishlist/etc/adminhtml.xml
+++ b/app/code/core/Mage/Wishlist/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Wishlist/etc/config.xml b/app/code/core/Mage/Wishlist/etc/config.xml
index 1e5926d..2ecdada 100644
--- a/app/code/core/Mage/Wishlist/etc/config.xml
+++ b/app/code/core/Mage/Wishlist/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Wishlist/etc/system.xml b/app/code/core/Mage/Wishlist/etc/system.xml
index 4acef25..c26f58c 100644
--- a/app/code/core/Mage/Wishlist/etc/system.xml
+++ b/app/code/core/Mage/Wishlist/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/install-1.6.0.0.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/install-1.6.0.0.php
index 081004b..2c193b3 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-install-0.7.0.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-install-0.7.0.php
index 073718a..026e0bd 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-install-0.7.0.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-install-0.7.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.0-0.7.1.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.0-0.7.1.php
index 8f67fe0..ec7e34b 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.0-0.7.1.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.0-0.7.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.1-0.7.2.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.1-0.7.2.php
index 8a3a70e..b9c4793 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.1-0.7.2.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.1-0.7.2.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.2-0.7.4.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.2-0.7.4.php
index 7fb2414..bc74802 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.2-0.7.4.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.2-0.7.4.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.4-0.7.5.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.4-0.7.5.php
index def613a..134412e 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.4-0.7.5.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.4-0.7.5.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.5-0.7.6.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.5-0.7.6.php
index d8dbdf3..fe4224c 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.5-0.7.6.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.5-0.7.6.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.6-0.7.7.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.6-0.7.7.php
index 0c4df0e..0a6374c 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.6-0.7.7.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.6-0.7.7.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.7-0.7.8.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.7-0.7.8.php
index 4315261..710d817 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.7-0.7.8.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.7-0.7.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.8-0.7.9.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.8-0.7.9.php
index 7f0496c..54da1e6 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.8-0.7.9.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-0.7.8-0.7.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 80fb243..989ab51 100644
--- a/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/Wishlist/sql/wishlist_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Wishlist
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit.php
index 9936783..8a45cec 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Form.php
index 2015990..ab7e466 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tab/Settings.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tab/Settings.php
index 94f8b6c..dce6d80 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tab/Settings.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tab/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tabs.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tabs.php
index 6a68567..32f3db3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Admin/Application/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Config.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Config.php
index c3133f6..02be10c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Config.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard.php
index 6fd144a..69b55db 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/BestSellers.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/BestSellers.php
index 48b5452..1839bf5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/BestSellers.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/BestSellers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/Customers.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/Customers.php
index 2a2080c..7f04893 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/Customers.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/Customers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphAmountsData.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphAmountsData.php
index 0ba9ee7..ecbc2e3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphAmountsData.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphAmountsData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphDataAbstract.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphDataAbstract.php
index 6d925a9..f2fac98 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphDataAbstract.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphDataAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphInfo.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphInfo.php
index edee370..f2cec19 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphInfo.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphInfo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphOrderData.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphOrderData.php
index af94c38..a3b2de5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphOrderData.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphOrderData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphTotalsData.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphTotalsData.php
index b6efc54..fe8d171 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphTotalsData.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/GraphTotalsData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastOrders.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastOrders.php
index 81f7f5f..055175e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastOrders.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastOrders.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastSearchTerms.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastSearchTerms.php
index 71ff0a8..544c878 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastSearchTerms.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/LastSearchTerms.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/MostViewedProducts.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/MostViewedProducts.php
index 9bf4f64..4ebe24d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/MostViewedProducts.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/MostViewedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/NewCustomers.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/NewCustomers.php
index 9d4d747..6b9da3e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/NewCustomers.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/NewCustomers.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/SalesInfo.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/SalesInfo.php
index 961abaa..bd9cd34 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/SalesInfo.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/SalesInfo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/StoreSwitcher.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/StoreSwitcher.php
index a703ddb..b492f18 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/StoreSwitcher.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/StoreSwitcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/TopSearchTerms.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/TopSearchTerms.php
index 15c5ca9..2089e17 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/TopSearchTerms.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Dashboard/TopSearchTerms.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Loginform.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Loginform.php
index 885e8b5..2fafba1 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Loginform.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Connect/Loginform.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/History.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/History.php
index 337ee7b..01a4135 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/History.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/History/Grid.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/History/Grid.php
index 20f33ce..8b48420 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/History/Grid.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/History/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile.php
index 0690891..b408aa3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit.php
index ba9528f..d116c9e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Form.php
index b84530c..9880b98 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Submission.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Submission.php
index b9fa444..6898f5d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Submission.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Submission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Cache.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Cache.php
index 1d397f8..27aa31f 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Cache.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Content.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Content.php
index 84444d6..e713ef9 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Content.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design.php
index f02f52c..f1614fa 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion.php
index eca5386..9f1cc0d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Images.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Images.php
index 20cb38e..4e65aa4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Images.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Images.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Tabs.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Tabs.php
index eb20604..6c964bf 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Themes.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Themes.php
index 8c310d3..da11160 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Themes.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Accordion/Themes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Images.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Images.php
index 2134372..d8fb117 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Images.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Images.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Preview.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Preview.php
index 3572665..3795548 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Preview.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Preview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Themes.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Themes.php
index 87dd4ef..1c60cf6 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Themes.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Design/Themes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Flurryanalytics.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Flurryanalytics.php
index a085f4b..87c6147 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Flurryanalytics.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Flurryanalytics.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/General.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/General.php
index 9116ba2..d788e4f 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/General.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/General.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Notification.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Notification.php
index 809a099..e2c8b43 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Notification.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Notification.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/OfflineCatalog.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/OfflineCatalog.php
index 5c5ac4c..097337c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/OfflineCatalog.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/OfflineCatalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Payment.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Payment.php
index cef97b3..9ac9620 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Payment.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Settings.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Settings.php
index 4edceec..70cc879 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Settings.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Social.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Social.php
index a1437b5..63d7cb9 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Social.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Social.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Submission/History.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Submission/History.php
index 595f317..f5659f8 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Submission/History.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tab/Submission/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tabs.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tabs.php
index d9f6a02..5e0ae65 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Edit/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Addrow.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Addrow.php
index 06ec651..30c82cb 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Addrow.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Addrow.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Color.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Color.php
index 1c496c2..16254a3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Color.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Color.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Country.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Country.php
index 6cd6c27..fda7d12 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Country.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Country.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Datetime.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Datetime.php
index 4406295..5c6464a 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Datetime.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Font.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Font.php
index fee232f..01abbd3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Font.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Font.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Image.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Image.php
index 5bfb361..993de89 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Image.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Page.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Page.php
index a303af9..f9752f8 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Page.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Tabs.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Tabs.php
index 88d0b75..283b4a6 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Theme.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Theme.php
index 2353fbf..34a2544 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Theme.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Form/Element/Theme.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid.php
index 2e19213..9cffddc 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Bool.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Bool.php
index 25742dc..e0dea94 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Bool.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Bool.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Type.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Type.php
index 80b08fe..d298a7d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Type.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Grid/Renderer/Type.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Content.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Content.php
index 2b8ff9d..6e93cbe 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Content.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Tabitems.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Tabitems.php
index ba43de7..10dad00 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Tabitems.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Preview/Tabitems.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission.php
index f856b35..0e3042c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Form.php
index 5bb8ee7..3b5109d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Androidmarket.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Androidmarket.php
index 4838e46..b569ee0 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Androidmarket.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Androidmarket.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Istore.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Istore.php
index a864f1a..36b8371 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Istore.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Renderer/Country/Istore.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container.php
index 3686641..c0b5e3e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container/Submission.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container/Submission.php
index 48027bb..86a937c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container/Submission.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tab/Container/Submission.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tabs.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tabs.php
index 3e3f159..6bcbb3c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Submission/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Widget/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Widget/Form.php
index 0255454..bd75921 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Widget/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Mobile/Widget/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue.php
index 0c76702..fe0c39c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit.php
index 331d36d..f6e6d6c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit/Form.php
index d729d31..5e473e9 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid.php
index e7b5087..266f5d1 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Action.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Action.php
index b9222eb..019a09c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Action.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Application.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Application.php
index 26d1ef6..fb1b0f0 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Application.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Application.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Id.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Id.php
index 4e650df..12089f3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Id.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Id.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Msgtitle.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Msgtitle.php
index 036f3be..27e3853 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Msgtitle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Msgtitle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Pushtitle.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Pushtitle.php
index 8fb2569..7d34e13 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Pushtitle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Pushtitle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Status.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Status.php
index e1e0041..93be261 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Status.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Status.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Template.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Template.php
index c8c9654..051a3f9 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Template.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Queue/Grid/Renderer/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template.php
index 84f81dc..887b762 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit.php
index 44a4b03..bf03c29 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit/Form.php
index df48394..ec6a9db 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid.php
index ed084d6..da136ca 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Application.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Application.php
index 5bce83a..4bb8e86 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Application.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Application.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Name.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Name.php
index 07b98b3..10d2d95 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Name.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Grid/Renderer/Name.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview.php
index 09d530b..ad193b4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview/Form.php b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview/Form.php
index b4cf49c..0a1cb6a 100644
--- a/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Adminhtml/Template/Preview/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart.php b/app/code/core/Mage/XmlConnect/Block/Cart.php
index c38b837..d23f177 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals.php
index ee7ea92..a39b893 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Default.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Default.php
index e46dc0d..1419ceb 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Default.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Grandtotal.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Grandtotal.php
index d206e9a..ef56f47 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Grandtotal.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Grandtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Default.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Default.php
index b5442ab..24358e4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Default.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Giftcardaccount.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Giftcardaccount.php
index 7b84d1f..fec05f1 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Giftcardaccount.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Nodes/Giftcardaccount.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Shipping.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Shipping.php
index e7b344c..1c37ffc 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Shipping.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Subtotal.php b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Subtotal.php
index 7c946b0..594b419 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Subtotal.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/CartTotals/Subtotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Crosssell.php b/app/code/core/Mage/XmlConnect/Block/Cart/Crosssell.php
index 1a4d1a4..7e256b8 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Crosssell.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Info.php b/app/code/core/Mage/XmlConnect/Block/Cart/Info.php
index ae8d663..c706daf 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Info.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer.php b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer.php
index 39bf514..eae41a4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Configurable.php b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Configurable.php
index 67093c3..ba22b25 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Configurable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Grouped.php b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Grouped.php
index a1fddea..555ce94 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Grouped.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Item/Renderer/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Items.php b/app/code/core/Mage/XmlConnect/Block/Cart/Items.php
index ff9c765..5e75040 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Items.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Details.php b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Details.php
index 0382de1..5e3ea6b 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Details.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/OrderDetails.php b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/OrderDetails.php
index 15d2282..cc40acb 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/OrderDetails.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/OrderDetails.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Review.php b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Review.php
index 545b039..f19d36e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Review.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Shippingmethods.php b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Shippingmethods.php
index 056efd3..036ffab 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Shippingmethods.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mecl/Shippingmethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mep/Totals.php b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mep/Totals.php
index f29c095..5eac243 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mep/Totals.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Paypal/Mep/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cart/Totals.php b/app/code/core/Mage/XmlConnect/Block/Cart/Totals.php
index 1bc8ef7..6157084 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cart/Totals.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cart/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog.php b/app/code/core/Mage/XmlConnect/Block/Catalog.php
index 2b47e38..51fb417 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Category.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Category.php
index 9774b4b..d8d87c2 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Category.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Category/Info.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Category/Info.php
index d6d7679..f5deba4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Category/Info.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Category/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Filters.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Filters.php
index 03b19e7..934e548 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Filters.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Filters.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product.php
index aa1edd6..a2d44cd 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Attributes.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Attributes.php
index 2ee7645..252eda7 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Attributes.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Gallery.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Gallery.php
index c46732a..e4aea11 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Gallery.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice.php
index 25d5c8f..0747898 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Bundle.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Bundle.php
index 47d723d..ce3ce48 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Bundle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Default.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Default.php
index 7c9c0cc..dfe62ac 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Default.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Giftcard.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Giftcard.php
index b9b5973..a7d1954 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Giftcard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/ItemPrice/Giftcard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/List.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/List.php
index 2eae2bb..b571451 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options.php
index 8e4d16a..dd4b58d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Bundle.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Bundle.php
index 05c1e40..2a16973 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Bundle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Configurable.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Configurable.php
index c8a22a3..6895943 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Configurable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Downloadable.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Downloadable.php
index c6cce6f..0b797d3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Downloadable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Giftcard.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Giftcard.php
index 7abb367..1788aef 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Giftcard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Giftcard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Grouped.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Grouped.php
index 164f149..100f1c5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Grouped.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Simple.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Simple.php
index 7cc8d80..ce34d45 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Simple.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Virtual.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Virtual.php
index 5ba5c0c..f5bff01 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Virtual.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Options/Virtual.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price.php
index 4bb76b2..17891f1 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Bundle.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Bundle.php
index d8e1547..b66c817 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Bundle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Default.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Default.php
index 2263f42..bea3905 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Default.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Giftcard.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Giftcard.php
index 5d4445a..d5cd2e5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Giftcard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Price/Giftcard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Related.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Related.php
index 5eb030f..f027367 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Related.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Related.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review.php
index 40b1624..ea11f16 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review/List.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review/List.php
index d30540b..9b351f5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Product/Review/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Search.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Search.php
index fd33475..1100aee 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Search.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Catalog/Search/Suggest.php b/app/code/core/Mage/XmlConnect/Block/Catalog/Search/Suggest.php
index b008726..686c4c3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Catalog/Search/Suggest.php
+++ b/app/code/core/Mage/XmlConnect/Block/Catalog/Search/Suggest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Billing.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Billing.php
index 5f3f95b..4e823f2 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Billing.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Form.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Form.php
index 2b5f48c..e00833a 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Shipping.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Shipping.php
index cfef70c..290b391 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Shipping.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Address/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Agreements.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Agreements.php
index 5395562..00314fa 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Agreements.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Agreements.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer.php
index 1df463c..24021c7 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Bundle.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Bundle.php
index 1df8892..07037d6 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Bundle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Configurable.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Configurable.php
index 37293ec..d8c626e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Configurable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Downloadable.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Downloadable.php
index c7d1731..12d1dbe 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Downloadable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Giftcard.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Giftcard.php
index cff65c7..c081127 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Giftcard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Giftcard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Grouped.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Grouped.php
index dd37f82..cb45ad3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Grouped.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Cart/Item/Renderer/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address.php
index dcdf7d8..f641467 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/Form.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/Form.php
index 9561518..75cb553 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/List.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/List.php
index d08f3d1..06da3b5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Address/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Review.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Review.php
index c36a709..476ece3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Review.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Onepage/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review.php
index 969e4dc..3d8d283 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review/Info.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review/Info.php
index d4b5557..770adf2 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review/Info.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Order/Review/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Authorizenet.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Authorizenet.php
index fb70861..c11c7ea 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Authorizenet.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Authorizenet.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Ccsave.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Ccsave.php
index eef876a..0f90769 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Ccsave.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Ccsave.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Checkmo.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Checkmo.php
index addc652..e7521df 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Checkmo.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Checkmo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Authorizenet.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Authorizenet.php
index 74ed1ad..c7de430 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Authorizenet.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Authorizenet.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Ccsave.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Ccsave.php
index f6ae560..e85fc1b 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Ccsave.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Ccsave.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Checkmo.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Checkmo.php
index ac6f06e..a09e6da 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Checkmo.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Checkmo.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Free.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Free.php
index 31c5724..dfdb4b3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Free.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Free.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Abstract.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Abstract.php
index 11a29c7..850075c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Express.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Express.php
index 90f1362..c1c764d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Express.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Express.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Mecl.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Mecl.php
index a58a3e8..120d559 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Mecl.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Paypal/Mecl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Authorizenet.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Authorizenet.php
index ed860e1..de2b8b4 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Authorizenet.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Authorizenet.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypal/Direct.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypal/Direct.php
index 6144ee0..670a4bb 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypal/Direct.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypal/Direct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypaluk/Direct.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypaluk/Direct.php
index 77d4863..7756f54 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypaluk/Direct.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Paypaluk/Direct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Verisign.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Verisign.php
index 24da840..4739cd5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Verisign.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Pbridge/Verisign.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Purchaseorder.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Purchaseorder.php
index 4423369..593bd09 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Purchaseorder.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Info/Purchaseorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/List.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/List.php
index 4a4dfee..a2d3071 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/ListApi23.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/ListApi23.php
index 360ef75..d353d3f 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/ListApi23.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/ListApi23.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Direct.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Direct.php
index 3f00228..710acc8 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Direct.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Direct.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Payflow.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Payflow.php
index 8f1efe6..27052ab 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Payflow.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Paypal/Payflow.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Abstract.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Abstract.php
index 1cf560c..c365c44 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Authorizenet.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Authorizenet.php
index 2621d15..f1ce3a8 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Authorizenet.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Authorizenet.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypal.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypal.php
index 59bab44..f82d52e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypal.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypal.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypaluk.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypaluk.php
index 1ad72a0..867ee68 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypaluk.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Paypaluk.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Verisign.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Verisign.php
index fe58c64..3f7b3ee 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Verisign.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Pbridge/Verisign.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Purchaseorder.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Purchaseorder.php
index 2d1f114..981891f 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Purchaseorder.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Payment/Method/Purchaseorder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Pbridge/Result.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Pbridge/Result.php
index de65943..05ef13d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Pbridge/Result.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Pbridge/Result.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/Available.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/Available.php
index 8844ae9..d6157e3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/Available.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/Available.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/AvailableList.php b/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/AvailableList.php
index 167e4a5..91b76f1 100644
--- a/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/AvailableList.php
+++ b/app/code/core/Mage/XmlConnect/Block/Checkout/Shipping/Method/AvailableList.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Cms/Page.php b/app/code/core/Mage/XmlConnect/Block/Cms/Page.php
index 1aa4050..88b5523 100644
--- a/app/code/core/Mage/XmlConnect/Block/Cms/Page.php
+++ b/app/code/core/Mage/XmlConnect/Block/Cms/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Configuration.php b/app/code/core/Mage/XmlConnect/Block/Configuration.php
index 3fac9df..515faea 100644
--- a/app/code/core/Mage/XmlConnect/Block/Configuration.php
+++ b/app/code/core/Mage/XmlConnect/Block/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Address/Form.php b/app/code/core/Mage/XmlConnect/Block/Customer/Address/Form.php
index 71224ed..226f337 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Address/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Address/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Address/List.php b/app/code/core/Mage/XmlConnect/Block/Customer/Address/List.php
index 251a8fe..8f5f6dc 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Address/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Address/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Downloads.php b/app/code/core/Mage/XmlConnect/Block/Customer/Downloads.php
index 5377cee..ab74471 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Downloads.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Downloads.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form.php
index 8f91daa..19c494e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Boolean.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Boolean.php
index be1c469..44b947c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Boolean.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Boolean.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Date.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Date.php
index 416b62a..3a97a7d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Date.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/File.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/File.php
index cd29ddc..ca25e08 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/File.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Image.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Image.php
index 1d839f0..940f6ba 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Image.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiline.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiline.php
index 0048223..2a1bec9 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiline.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiselect.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiselect.php
index 151128f..e7055fc 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiselect.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Select.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Select.php
index 0b1506f..8591d46 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Select.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Text.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Text.php
index 883abb6..d010596 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Text.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Textarea.php b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Textarea.php
index 28322c6..93d5cca 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Textarea.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Form/Renderer/Textarea.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/GiftcardCheck.php b/app/code/core/Mage/XmlConnect/Block/Customer/GiftcardCheck.php
index 5880b8e..7fc480e 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/GiftcardCheck.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/GiftcardCheck.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Details.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Details.php
index af788f7..b62e33d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Details.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Details.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Bundle.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Bundle.php
index b2974a7..2d1e484 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Bundle.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Default.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Default.php
index 1b6a5c5..323abc5 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Default.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Downloadable.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Downloadable.php
index 15341cb..2f30e05 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Downloadable.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Giftcard.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Giftcard.php
index c120d61..b4d86d3 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Giftcard.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Giftcard.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Grouped.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Grouped.php
index d01d329..cb55a05 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Grouped.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Item/Renderer/Grouped.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Items.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Items.php
index 97dbf85..50e0b37 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Items.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/List.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/List.php
index 9c107e4..aa74228 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/List.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/List.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals.php
index 1e7756e..432303c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance.php
index 830a0e4..d048531 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance/Refunded.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance/Refunded.php
index 932cf42..545e179 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance/Refunded.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Customerbalance/Refunded.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Giftcards.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Giftcards.php
index bcf2963..dc4f02c 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Giftcards.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Giftcards.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Tax.php b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Tax.php
index a5d542e..920aad7 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Tax.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Order/Totals/Tax.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Customer/Storecredit.php b/app/code/core/Mage/XmlConnect/Block/Customer/Storecredit.php
index 8d487f3..d2e6249 100644
--- a/app/code/core/Mage/XmlConnect/Block/Customer/Storecredit.php
+++ b/app/code/core/Mage/XmlConnect/Block/Customer/Storecredit.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Home.php b/app/code/core/Mage/XmlConnect/Block/Home.php
index e3bd84c..32c1384 100644
--- a/app/code/core/Mage/XmlConnect/Block/Home.php
+++ b/app/code/core/Mage/XmlConnect/Block/Home.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Homebanners.php b/app/code/core/Mage/XmlConnect/Block/Homebanners.php
index a7ccbe9..aaaf287 100644
--- a/app/code/core/Mage/XmlConnect/Block/Homebanners.php
+++ b/app/code/core/Mage/XmlConnect/Block/Homebanners.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Localization.php b/app/code/core/Mage/XmlConnect/Block/Localization.php
index 1e49708..86b61ff 100644
--- a/app/code/core/Mage/XmlConnect/Block/Localization.php
+++ b/app/code/core/Mage/XmlConnect/Block/Localization.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Review/Form.php b/app/code/core/Mage/XmlConnect/Block/Review/Form.php
index 03c95b6..265463d 100644
--- a/app/code/core/Mage/XmlConnect/Block/Review/Form.php
+++ b/app/code/core/Mage/XmlConnect/Block/Review/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/ShoppingCart.php b/app/code/core/Mage/XmlConnect/Block/ShoppingCart.php
index ec2aa9f..a2babf5 100644
--- a/app/code/core/Mage/XmlConnect/Block/ShoppingCart.php
+++ b/app/code/core/Mage/XmlConnect/Block/ShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Block/Wishlist.php b/app/code/core/Mage/XmlConnect/Block/Wishlist.php
index 9a52b3c..d1a6313 100644
--- a/app/code/core/Mage/XmlConnect/Block/Wishlist.php
+++ b/app/code/core/Mage/XmlConnect/Block/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Controller/Action.php b/app/code/core/Mage/XmlConnect/Controller/Action.php
index 34e92ba..41fc041 100644
--- a/app/code/core/Mage/XmlConnect/Controller/Action.php
+++ b/app/code/core/Mage/XmlConnect/Controller/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Controller/AdminAction.php b/app/code/core/Mage/XmlConnect/Controller/AdminAction.php
index 8572dc0..e462176 100644
--- a/app/code/core/Mage/XmlConnect/Controller/AdminAction.php
+++ b/app/code/core/Mage/XmlConnect/Controller/AdminAction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/AdminApplication.php b/app/code/core/Mage/XmlConnect/Helper/AdminApplication.php
index 091672f..f621479 100644
--- a/app/code/core/Mage/XmlConnect/Helper/AdminApplication.php
+++ b/app/code/core/Mage/XmlConnect/Helper/AdminApplication.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Adminhtml/Dashboard/Order.php b/app/code/core/Mage/XmlConnect/Helper/Adminhtml/Dashboard/Order.php
index d5b3b16..da8d0fb 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Adminhtml/Dashboard/Order.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Adminhtml/Dashboard/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Android.php b/app/code/core/Mage/XmlConnect/Helper/Android.php
index ced49fb..01eaf32 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Android.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Android.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Catalog/Category/Image.php b/app/code/core/Mage/XmlConnect/Helper/Catalog/Category/Image.php
index 44402b3..8f589aa 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Catalog/Category/Image.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Catalog/Category/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Catalog/Product/Image.php b/app/code/core/Mage/XmlConnect/Helper/Catalog/Product/Image.php
index 99cc9b5..7bc14b4 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Catalog/Product/Image.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Catalog/Product/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Customer/Form/Renderer.php b/app/code/core/Mage/XmlConnect/Helper/Customer/Form/Renderer.php
index 5b9f070..3c22e1c 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Customer/Form/Renderer.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Customer/Form/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Customer/Order.php b/app/code/core/Mage/XmlConnect/Helper/Customer/Order.php
index d17a939..823001f 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Customer/Order.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Customer/Order.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Data.php b/app/code/core/Mage/XmlConnect/Helper/Data.php
index a26e8aa..d35fbb6 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Data.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Data.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Device/Abstract.php b/app/code/core/Mage/XmlConnect/Helper/Device/Abstract.php
index 36a002c..e402060 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Device/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Device/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/app/code/core/Mage/XmlConnect/Helper/Image.php b/app/code/core/Mage/XmlConnect/Helper/Image.php
index 2f810b4..6f6fef7 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Image.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Ipad.php b/app/code/core/Mage/XmlConnect/Helper/Ipad.php
index c4cd5f9..5bef7be 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Ipad.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Ipad.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Iphone.php b/app/code/core/Mage/XmlConnect/Helper/Iphone.php
index b89c634..025710a 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Iphone.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Iphone.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/OfflineCatalog.php b/app/code/core/Mage/XmlConnect/Helper/OfflineCatalog.php
index 06a9bca..080e45f 100644
--- a/app/code/core/Mage/XmlConnect/Helper/OfflineCatalog.php
+++ b/app/code/core/Mage/XmlConnect/Helper/OfflineCatalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Payment.php b/app/code/core/Mage/XmlConnect/Helper/Payment.php
index 8495b3f..3c126e6 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Payment.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Theme.php b/app/code/core/Mage/XmlConnect/Helper/Theme.php
index ec1a2ee..44988f0 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Theme.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Theme.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Helper/Translate.php b/app/code/core/Mage/XmlConnect/Helper/Translate.php
index 14ad9b1..69be2e0 100644
--- a/app/code/core/Mage/XmlConnect/Helper/Translate.php
+++ b/app/code/core/Mage/XmlConnect/Helper/Translate.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Catalog.php b/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Catalog.php
index 4ce2e06..af5669b 100644
--- a/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Catalog.php
+++ b/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Category.php b/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Category.php
index 0e80f18..31d1cf5 100644
--- a/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Category.php
+++ b/app/code/core/Mage/XmlConnect/Model/Adminhtml/Search/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Baseurl.php b/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Baseurl.php
index 5bc6542..9812cb0 100644
--- a/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Baseurl.php
+++ b/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Baseurl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Currency/Default.php b/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Currency/Default.php
index a32fb88..229ab36 100644
--- a/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Currency/Default.php
+++ b/app/code/core/Mage/XmlConnect/Model/Adminhtml/System/Config/Backend/Currency/Default.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Application.php b/app/code/core/Mage/XmlConnect/Model/Application.php
index fa78ad1..84c8a44 100644
--- a/app/code/core/Mage/XmlConnect/Model/Application.php
+++ b/app/code/core/Mage/XmlConnect/Model/Application.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Image.php b/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Image.php
index 70c6ce8..cf2d2dc 100644
--- a/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Image.php
+++ b/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Media/Config.php b/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Media/Config.php
index 01552fe..f1ca1cd 100644
--- a/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Media/Config.php
+++ b/app/code/core/Mage/XmlConnect/Model/Catalog/Category/Media/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/ConfigData.php b/app/code/core/Mage/XmlConnect/Model/ConfigData.php
index e08ac12..75a039d 100644
--- a/app/code/core/Mage/XmlConnect/Model/ConfigData.php
+++ b/app/code/core/Mage/XmlConnect/Model/ConfigData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Configuration.php b/app/code/core/Mage/XmlConnect/Model/Configuration.php
index 7637dc8..da9ad94 100644
--- a/app/code/core/Mage/XmlConnect/Model/Configuration.php
+++ b/app/code/core/Mage/XmlConnect/Model/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Device/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Device/Abstract.php
index dfa7059..0b05dc6 100644
--- a/app/code/core/Mage/XmlConnect/Model/Device/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Device/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Device/Android.php b/app/code/core/Mage/XmlConnect/Model/Device/Android.php
index 1334d30..0a304ec 100644
--- a/app/code/core/Mage/XmlConnect/Model/Device/Android.php
+++ b/app/code/core/Mage/XmlConnect/Model/Device/Android.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Device/Ipad.php b/app/code/core/Mage/XmlConnect/Model/Device/Ipad.php
index 02d7b0d..8436495 100644
--- a/app/code/core/Mage/XmlConnect/Model/Device/Ipad.php
+++ b/app/code/core/Mage/XmlConnect/Model/Device/Ipad.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Device/Iphone.php b/app/code/core/Mage/XmlConnect/Model/Device/Iphone.php
index 6676249..6ba8a9a 100644
--- a/app/code/core/Mage/XmlConnect/Model/Device/Iphone.php
+++ b/app/code/core/Mage/XmlConnect/Model/Device/Iphone.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/History.php b/app/code/core/Mage/XmlConnect/Model/History.php
index f352e77..94404d7 100644
--- a/app/code/core/Mage/XmlConnect/Model/History.php
+++ b/app/code/core/Mage/XmlConnect/Model/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/ImageAction.php b/app/code/core/Mage/XmlConnect/Model/ImageAction.php
index 5df9b6f..a245baa 100644
--- a/app/code/core/Mage/XmlConnect/Model/ImageAction.php
+++ b/app/code/core/Mage/XmlConnect/Model/ImageAction.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/ImageLimits.php b/app/code/core/Mage/XmlConnect/Model/ImageLimits.php
index c0b3baf..3a837e7 100644
--- a/app/code/core/Mage/XmlConnect/Model/ImageLimits.php
+++ b/app/code/core/Mage/XmlConnect/Model/ImageLimits.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/ImageLimits/Abstract.php b/app/code/core/Mage/XmlConnect/Model/ImageLimits/Abstract.php
index 582602a..d52cde1 100644
--- a/app/code/core/Mage/XmlConnect/Model/ImageLimits/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/ImageLimits/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Images.php b/app/code/core/Mage/XmlConnect/Model/Images.php
index 6caecf7..45a68c5 100644
--- a/app/code/core/Mage/XmlConnect/Model/Images.php
+++ b/app/code/core/Mage/XmlConnect/Model/Images.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Application.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Application.php
index 346865d..528feb8 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Application.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Application.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Application/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Application/Collection.php
index 1b2644b..c6e0eca 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Application/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Application/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Cms/Page/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Cms/Page/Collection.php
index 6089791..ae78bbc 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Cms/Page/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Cms/Page/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData.php
index 83cf1be..b2f9556 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData/Collection.php
index e4e5164..86641bf 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/ConfigData/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Filter/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Filter/Collection.php
index 160d957..47eb8b5 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Filter/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Filter/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/History.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/History.php
index 87db75d..910dacb 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/History.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/History/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/History/Collection.php
index 35172ae..9b380ef 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/History/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue.php
index 568d102..8fb0578 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue/Collection.php
index b3eb25c..75a3f94 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Queue/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Setup.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Setup.php
index 083415b..d6e08a1 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Setup.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Template.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Template.php
index bed347a..961f068 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Template.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Mysql4/Template/Collection.php b/app/code/core/Mage/XmlConnect/Model/Mysql4/Template/Collection.php
index 19b51a4..da66dc4 100644
--- a/app/code/core/Mage/XmlConnect/Model/Mysql4/Template/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Mysql4/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Observer.php b/app/code/core/Mage/XmlConnect/Model/Observer.php
index 816f91e..462d2ef 100644
--- a/app/code/core/Mage/XmlConnect/Model/Observer.php
+++ b/app/code/core/Mage/XmlConnect/Model/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog.php
index fdbc2dc..91b51d5 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Abstract.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Abstract.php
index dece534..bba2351 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category.php
index 838489f..e4679f5 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/Category.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/Category.php
index d86257e..2f877f2 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/Category.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/Category.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/IndexCategory.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/IndexCategory.php
index 9949aff..bd257d1 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/IndexCategory.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Category/IndexCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Config.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Config.php
index 21828e2..f39919a 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Config.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Home.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Home.php
index 1392f41..37a1bb0 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Home.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Home.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Homebanners.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Homebanners.php
index fa9bcfb..b7cfa53 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Homebanners.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Homebanners.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product.php
index ad5a921..9c717d0 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Gallery.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Gallery.php
index 892c061..5b1954c 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Gallery.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Product.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Product.php
index f53f7e2..3fedc70 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Product.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Review.php b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Review.php
index 32bc6f3..328adc3 100644
--- a/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Review.php
+++ b/app/code/core/Mage/XmlConnect/Model/OfflineCatalog/Product/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Config.php b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Config.php
index 4fdbf8d..c3c9a20 100644
--- a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Config.php
+++ b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mecl.php b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mecl.php
index 8d1b264..6a4b7c6 100644
--- a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mecl.php
+++ b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mecl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mep.php b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mep.php
index cac94a8..fa82264 100644
--- a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mep.php
+++ b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Mep.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Pro.php b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Pro.php
index 1bb8be5..e150990 100644
--- a/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Pro.php
+++ b/app/code/core/Mage/XmlConnect/Model/Payment/Method/Paypal/Pro.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Paypal/Mecl/Checkout.php b/app/code/core/Mage/XmlConnect/Model/Paypal/Mecl/Checkout.php
index f347452..abd9106 100644
--- a/app/code/core/Mage/XmlConnect/Model/Paypal/Mecl/Checkout.php
+++ b/app/code/core/Mage/XmlConnect/Model/Paypal/Mecl/Checkout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Paypal/Mep/Checkout.php b/app/code/core/Mage/XmlConnect/Model/Paypal/Mep/Checkout.php
index b195d05..da27a59 100644
--- a/app/code/core/Mage/XmlConnect/Model/Paypal/Mep/Checkout.php
+++ b/app/code/core/Mage/XmlConnect/Model/Paypal/Mep/Checkout.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Preview/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Preview/Abstract.php
index 2daf2de..51fdfd2 100644
--- a/app/code/core/Mage/XmlConnect/Model/Preview/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Preview/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Preview/Android.php b/app/code/core/Mage/XmlConnect/Model/Preview/Android.php
index 81f9918..928bc5d 100644
--- a/app/code/core/Mage/XmlConnect/Model/Preview/Android.php
+++ b/app/code/core/Mage/XmlConnect/Model/Preview/Android.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Preview/Ipad.php b/app/code/core/Mage/XmlConnect/Model/Preview/Ipad.php
index 7dce74c..46e55ac 100644
--- a/app/code/core/Mage/XmlConnect/Model/Preview/Ipad.php
+++ b/app/code/core/Mage/XmlConnect/Model/Preview/Ipad.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Preview/Iphone.php b/app/code/core/Mage/XmlConnect/Model/Preview/Iphone.php
index 5e859a7..926604e 100644
--- a/app/code/core/Mage/XmlConnect/Model/Preview/Iphone.php
+++ b/app/code/core/Mage/XmlConnect/Model/Preview/Iphone.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Queue.php b/app/code/core/Mage/XmlConnect/Model/Queue.php
index b6e9b4d..bec702a 100644
--- a/app/code/core/Mage/XmlConnect/Model/Queue.php
+++ b/app/code/core/Mage/XmlConnect/Model/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Application.php b/app/code/core/Mage/XmlConnect/Model/Resource/Application.php
index 01da8ee..552140b 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Application.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Application.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Application/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Application/Collection.php
index cd93f96..c817c72 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Application/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Application/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/CategorySearch/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/CategorySearch/Collection.php
index 38f900a..7e495d5 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/CategorySearch/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/CategorySearch/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Cms/Page/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Cms/Page/Collection.php
index 4c0ef28..b482067 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Cms/Page/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Cms/Page/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData.php b/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData.php
index 93dcbfd..7f97f9c 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData/Collection.php
index 9deecad..5b7156c 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/ConfigData/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Filter/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Filter/Collection.php
index 8dc2ce7..0180962 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Filter/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Filter/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/History.php b/app/code/core/Mage/XmlConnect/Model/Resource/History.php
index 98177d3..7065134 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/History.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/History/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/History/Collection.php
index bfc907c..2080ed3 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/History/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/History/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Images.php b/app/code/core/Mage/XmlConnect/Model/Resource/Images.php
index a877a52..159659a 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Images.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Images.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Images/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Images/Collection.php
index 4bf2ff4..8493e8f 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Images/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Images/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Queue.php b/app/code/core/Mage/XmlConnect/Model/Resource/Queue.php
index 733833c..c5ce773 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Queue.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Queue.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Queue/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Queue/Collection.php
index e51139f..3920336 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Queue/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Queue/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Setup.php b/app/code/core/Mage/XmlConnect/Model/Resource/Setup.php
index 4def746..1a19c82 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Setup.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Setup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Template.php b/app/code/core/Mage/XmlConnect/Model/Resource/Template.php
index c997234..3774de7 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Template.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Resource/Template/Collection.php b/app/code/core/Mage/XmlConnect/Model/Resource/Template/Collection.php
index 29f2f50..a3a2ab4 100644
--- a/app/code/core/Mage/XmlConnect/Model/Resource/Template/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Resource/Template/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Element.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Element.php
index eb30398..a4f1568 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Element.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form.php
index e088c30..3decf45 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Abstract.php
index bea6713..a493107 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Abstract.php
index 0d5b8cf..0e274f7 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Checkbox.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Checkbox.php
index f6ae71e..1d34307 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Checkbox.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Collection.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Collection.php
index 38757c1..5e55724 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Collection.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/CountryListSelect.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/CountryListSelect.php
index f9d96da..6bbe4ee 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/CountryListSelect.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/CountryListSelect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Custom.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Custom.php
index c21c6df..046935e 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Custom.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Custom.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Date.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Date.php
index 9c98fc0..5a58169 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Date.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Email.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Email.php
index 501cbde..ecdaf78 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Email.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Email.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Fieldset.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Fieldset.php
index ffebc3d..48ada4a 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Fieldset.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/File.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/File.php
index d688624..b93234a 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/File.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Image.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Image.php
index 8617055..f9936de 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Image.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiline.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiline.php
index d97dc84..fdf71b3 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiline.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiline.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiselect.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiselect.php
index 7a177b2..c084ed2 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiselect.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Password.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Password.php
index 07aa245..2dfc405 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Password.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Password.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Renderer/Interface.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Renderer/Interface.php
index 7794d0a..dc20ed3 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Renderer/Interface.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Renderer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Select.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Select.php
index 06736a3..40d485f 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Select.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Text.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Text.php
index aeaa34c..7ebff01 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Text.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Textarea.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Textarea.php
index 0316506..cfcc0c8 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Textarea.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Textarea.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator.php
index 8e3c801..5823404 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Abstract.php
index 51b9ee2..d134d5e 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Rule.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Rule.php
index 63cb39e..d997228 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Rule.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Form/Element/Validator/Rule.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message.php
index deaa0b8..24aacba 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Abstract.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Abstract.php
index 1bc9a3a..a5691f6 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Abstract.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Error.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Error.php
index 80c1a1d..94b68d3 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Error.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Error.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Success.php b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Success.php
index 04da719..f0b3caa 100644
--- a/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Success.php
+++ b/app/code/core/Mage/XmlConnect/Model/Simplexml/Message/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Tabs.php b/app/code/core/Mage/XmlConnect/Model/Tabs.php
index 48f930a..fc1a71f 100644
--- a/app/code/core/Mage/XmlConnect/Model/Tabs.php
+++ b/app/code/core/Mage/XmlConnect/Model/Tabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Template.php b/app/code/core/Mage/XmlConnect/Model/Template.php
index 74b4248..d65a417 100644
--- a/app/code/core/Mage/XmlConnect/Model/Template.php
+++ b/app/code/core/Mage/XmlConnect/Model/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/Model/Theme.php b/app/code/core/Mage/XmlConnect/Model/Theme.php
index 5ab06de..4c20844 100644
--- a/app/code/core/Mage/XmlConnect/Model/Theme.php
+++ b/app/code/core/Mage/XmlConnect/Model/Theme.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Admin/ApplicationController.php b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Admin/ApplicationController.php
index 3403abb..e2eea5f 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Admin/ApplicationController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Admin/ApplicationController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/ConfigController.php b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/ConfigController.php
index e01cd0c..9ea83b1 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/ConfigController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/ConfigController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/DashboardController.php b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/DashboardController.php
index 1f65604..93f5676 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/DashboardController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/DashboardController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/UserController.php b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/UserController.php
index d023296..df282fd 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/UserController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/Connect/UserController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/MobileController.php b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/MobileController.php
index ce5fd61..d1c26ba 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Adminhtml/MobileController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Adminhtml/MobileController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/CartController.php b/app/code/core/Mage/XmlConnect/controllers/CartController.php
index 9864219..5f27aa7 100644
--- a/app/code/core/Mage/XmlConnect/controllers/CartController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/CartController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/CatalogController.php b/app/code/core/Mage/XmlConnect/controllers/CatalogController.php
index 9b0fc96..dfa528a 100644
--- a/app/code/core/Mage/XmlConnect/controllers/CatalogController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/CatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/CheckoutController.php b/app/code/core/Mage/XmlConnect/controllers/CheckoutController.php
index 4dea725..eb29794 100644
--- a/app/code/core/Mage/XmlConnect/controllers/CheckoutController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/CheckoutController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/CmsController.php b/app/code/core/Mage/XmlConnect/controllers/CmsController.php
index 1197b37..98057ca 100644
--- a/app/code/core/Mage/XmlConnect/controllers/CmsController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/CmsController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/ConfigurationController.php b/app/code/core/Mage/XmlConnect/controllers/ConfigurationController.php
index f8bf691..e93d02b 100644
--- a/app/code/core/Mage/XmlConnect/controllers/ConfigurationController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/ConfigurationController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/CustomerController.php b/app/code/core/Mage/XmlConnect/controllers/CustomerController.php
index 6c97c27..6f3b57d 100644
--- a/app/code/core/Mage/XmlConnect/controllers/CustomerController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/CustomerController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/HomebannersController.php b/app/code/core/Mage/XmlConnect/controllers/HomebannersController.php
index ae6b4ff..05e16bb 100644
--- a/app/code/core/Mage/XmlConnect/controllers/HomebannersController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/HomebannersController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/IndexController.php b/app/code/core/Mage/XmlConnect/controllers/IndexController.php
index d733169..ec1e0f0 100644
--- a/app/code/core/Mage/XmlConnect/controllers/IndexController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/IndexController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/LocalizationController.php b/app/code/core/Mage/XmlConnect/controllers/LocalizationController.php
index 94fbce2..f6a70fd 100644
--- a/app/code/core/Mage/XmlConnect/controllers/LocalizationController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/LocalizationController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/OfflineCatalogController.php b/app/code/core/Mage/XmlConnect/controllers/OfflineCatalogController.php
index c71f560..f95a62c 100644
--- a/app/code/core/Mage/XmlConnect/controllers/OfflineCatalogController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/OfflineCatalogController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Paypal/MeclController.php b/app/code/core/Mage/XmlConnect/controllers/Paypal/MeclController.php
index b42e0cd..cfaca76 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Paypal/MeclController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Paypal/MeclController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/Paypal/MepController.php b/app/code/core/Mage/XmlConnect/controllers/Paypal/MepController.php
index 2da2a14..067c0c2 100644
--- a/app/code/core/Mage/XmlConnect/controllers/Paypal/MepController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/Paypal/MepController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/PbridgeController.php b/app/code/core/Mage/XmlConnect/controllers/PbridgeController.php
index 660c8ca..b9a18f9 100644
--- a/app/code/core/Mage/XmlConnect/controllers/PbridgeController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/PbridgeController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/ReviewController.php b/app/code/core/Mage/XmlConnect/controllers/ReviewController.php
index fd089d3..7446d7e 100644
--- a/app/code/core/Mage/XmlConnect/controllers/ReviewController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/ReviewController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/controllers/WishlistController.php b/app/code/core/Mage/XmlConnect/controllers/WishlistController.php
index 44d2617..f31dadb 100644
--- a/app/code/core/Mage/XmlConnect/controllers/WishlistController.php
+++ b/app/code/core/Mage/XmlConnect/controllers/WishlistController.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/etc/adminhtml.xml b/app/code/core/Mage/XmlConnect/etc/adminhtml.xml
index 65808a7..0b656da 100644
--- a/app/code/core/Mage/XmlConnect/etc/adminhtml.xml
+++ b/app/code/core/Mage/XmlConnect/etc/adminhtml.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/config.xml b/app/code/core/Mage/XmlConnect/etc/config.xml
index 69b28b1..5c9f300 100644
--- a/app/code/core/Mage/XmlConnect/etc/config.xml
+++ b/app/code/core/Mage/XmlConnect/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/system.xml b/app/code/core/Mage/XmlConnect/etc/system.xml
index 900dbf2..77225dc 100644
--- a/app/code/core/Mage/XmlConnect/etc/system.xml
+++ b/app/code/core/Mage/XmlConnect/etc/system.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/themes/custom.xml b/app/code/core/Mage/XmlConnect/etc/themes/custom.xml
index cf40aef..f088caf 100644
--- a/app/code/core/Mage/XmlConnect/etc/themes/custom.xml
+++ b/app/code/core/Mage/XmlConnect/etc/themes/custom.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/themes/default.xml b/app/code/core/Mage/XmlConnect/etc/themes/default.xml
index ea64254..cb94654 100644
--- a/app/code/core/Mage/XmlConnect/etc/themes/default.xml
+++ b/app/code/core/Mage/XmlConnect/etc/themes/default.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/themes/funk_leaf.xml b/app/code/core/Mage/XmlConnect/etc/themes/funk_leaf.xml
index d8d7b58..655109e 100644
--- a/app/code/core/Mage/XmlConnect/etc/themes/funk_leaf.xml
+++ b/app/code/core/Mage/XmlConnect/etc/themes/funk_leaf.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/themes/hot_red.xml b/app/code/core/Mage/XmlConnect/etc/themes/hot_red.xml
index bb69e5b..6d2d556 100644
--- a/app/code/core/Mage/XmlConnect/etc/themes/hot_red.xml
+++ b/app/code/core/Mage/XmlConnect/etc/themes/hot_red.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/etc/themes/sky_blue.xml b/app/code/core/Mage/XmlConnect/etc/themes/sky_blue.xml
index 8ef905c..5d05ea0 100644
--- a/app/code/core/Mage/XmlConnect/etc/themes/sky_blue.xml
+++ b/app/code/core/Mage/XmlConnect/etc/themes/sky_blue.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/install-1.6.0.0.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/install-1.6.0.0.php
index b41e099..ea7a416 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/install-1.6.0.0.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/install-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.4.0.13-1.4.0.14.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.4.0.13-1.4.0.14.php
index a954914..eeeaded 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.4.0.13-1.4.0.14.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.4.0.13-1.4.0.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.5.9.9-1.6.0.0.php
index 02f887b..f815949 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php
index 6bc6dc2..3c20a82 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-install-1.4.0.8.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-install-1.4.0.8.php
index dc6acbc..d684804 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-install-1.4.0.8.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-install-1.4.0.8.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.10-1.4.0.11.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.10-1.4.0.11.php
index 05033a0..48d5aa7 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.10-1.4.0.11.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.10-1.4.0.11.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.11-1.4.0.12.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.11-1.4.0.12.php
index 5ebc1f2..23d9577 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.11-1.4.0.12.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.11-1.4.0.12.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.12-1.4.0.13.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.12-1.4.0.13.php
index f49e02b..1219236 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.12-1.4.0.13.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.12-1.4.0.13.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.13-1.4.0.14.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.13-1.4.0.14.php
index c4d5104..b06213a 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.13-1.4.0.14.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.13-1.4.0.14.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.8-1.4.0.9.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.8-1.4.0.9.php
index 31452a7..6a06203 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.8-1.4.0.9.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.8-1.4.0.9.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.9-1.4.0.10.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.9-1.4.0.10.php
index d412b83..bdff935 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.9-1.4.0.10.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.4.0.9-1.4.0.10.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
index 8e981bf..a0e587d 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/mysql4-upgrade-1.5.9.9-1.6.0.0.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/upgrade-1.6.0.0-1.6.0.0.1.php b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/upgrade-1.6.0.0-1.6.0.0.1.php
index 065ff92..19c0443 100644
--- a/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/upgrade-1.6.0.0-1.6.0.0.1.php
+++ b/app/code/core/Mage/XmlConnect/sql/xmlconnect_setup/upgrade-1.6.0.0-1.6.0.0.1.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/etc/theme.xml b/app/design/adminhtml/default/default/etc/theme.xml
index d0b262c..8e9e140 100644
--- a/app/design/adminhtml/default/default/etc/theme.xml
+++ b/app/design/adminhtml/default/default/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/admin.xml b/app/design/adminhtml/default/default/layout/admin.xml
index 2bde2a0..68a102d 100644
--- a/app/design/adminhtml/default/default/layout/admin.xml
+++ b/app/design/adminhtml/default/default/layout/admin.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/adminnotification.xml b/app/design/adminhtml/default/default/layout/adminnotification.xml
index 4853939..e2a2da6 100644
--- a/app/design/adminhtml/default/default/layout/adminnotification.xml
+++ b/app/design/adminhtml/default/default/layout/adminnotification.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/api2.xml b/app/design/adminhtml/default/default/layout/api2.xml
index becbb90..6f27395 100644
--- a/app/design/adminhtml/default/default/layout/api2.xml
+++ b/app/design/adminhtml/default/default/layout/api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/authorizenet.xml b/app/design/adminhtml/default/default/layout/authorizenet.xml
index e5c98ba..76fffec 100644
--- a/app/design/adminhtml/default/default/layout/authorizenet.xml
+++ b/app/design/adminhtml/default/default/layout/authorizenet.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/layout/bundle.xml b/app/design/adminhtml/default/default/layout/bundle.xml
index 92e771a..2a314b8 100644
--- a/app/design/adminhtml/default/default/layout/bundle.xml
+++ b/app/design/adminhtml/default/default/layout/bundle.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/captcha.xml b/app/design/adminhtml/default/default/layout/captcha.xml
index 43fdc04..21eb2c0 100644
--- a/app/design/adminhtml/default/default/layout/captcha.xml
+++ b/app/design/adminhtml/default/default/layout/captcha.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/layout/catalog.xml b/app/design/adminhtml/default/default/layout/catalog.xml
index ac5e46e..2a529b1 100644
--- a/app/design/adminhtml/default/default/layout/catalog.xml
+++ b/app/design/adminhtml/default/default/layout/catalog.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/centinel.xml b/app/design/adminhtml/default/default/layout/centinel.xml
index c1fc6ed..48974af 100644
--- a/app/design/adminhtml/default/default/layout/centinel.xml
+++ b/app/design/adminhtml/default/default/layout/centinel.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/layout/cms.xml b/app/design/adminhtml/default/default/layout/cms.xml
index f776062..f4e73d9 100644
--- a/app/design/adminhtml/default/default/layout/cms.xml
+++ b/app/design/adminhtml/default/default/layout/cms.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/compiler.xml b/app/design/adminhtml/default/default/layout/compiler.xml
index f3ef5e2..5b8c879 100644
--- a/app/design/adminhtml/default/default/layout/compiler.xml
+++ b/app/design/adminhtml/default/default/layout/compiler.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/connect.xml b/app/design/adminhtml/default/default/layout/connect.xml
index d3a3847..1637ddc 100644
--- a/app/design/adminhtml/default/default/layout/connect.xml
+++ b/app/design/adminhtml/default/default/layout/connect.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/currencysymbol.xml b/app/design/adminhtml/default/default/layout/currencysymbol.xml
index 51265b8..65b4c48 100644
--- a/app/design/adminhtml/default/default/layout/currencysymbol.xml
+++ b/app/design/adminhtml/default/default/layout/currencysymbol.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/customer.xml b/app/design/adminhtml/default/default/layout/customer.xml
index 262cf1d..98b5519 100644
--- a/app/design/adminhtml/default/default/layout/customer.xml
+++ b/app/design/adminhtml/default/default/layout/customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/dataflow.xml b/app/design/adminhtml/default/default/layout/dataflow.xml
index a4cd6e0..8dcf67a 100644
--- a/app/design/adminhtml/default/default/layout/dataflow.xml
+++ b/app/design/adminhtml/default/default/layout/dataflow.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/downloadable.xml b/app/design/adminhtml/default/default/layout/downloadable.xml
index e24d4c3..f4b6db5 100644
--- a/app/design/adminhtml/default/default/layout/downloadable.xml
+++ b/app/design/adminhtml/default/default/layout/downloadable.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/giftmessage.xml b/app/design/adminhtml/default/default/layout/giftmessage.xml
index b8b9df3..b3b4340 100644
--- a/app/design/adminhtml/default/default/layout/giftmessage.xml
+++ b/app/design/adminhtml/default/default/layout/giftmessage.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/importexport.xml b/app/design/adminhtml/default/default/layout/importexport.xml
index 318bc8d..6773045 100644
--- a/app/design/adminhtml/default/default/layout/importexport.xml
+++ b/app/design/adminhtml/default/default/layout/importexport.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/index.xml b/app/design/adminhtml/default/default/layout/index.xml
index 3ddd4ed..4edb455 100644
--- a/app/design/adminhtml/default/default/layout/index.xml
+++ b/app/design/adminhtml/default/default/layout/index.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/main.xml b/app/design/adminhtml/default/default/layout/main.xml
index 550086d..d1eda5d 100644
--- a/app/design/adminhtml/default/default/layout/main.xml
+++ b/app/design/adminhtml/default/default/layout/main.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/layout/moneybookers.xml b/app/design/adminhtml/default/default/layout/moneybookers.xml
index 9fcd1f6..df1ed19 100644
--- a/app/design/adminhtml/default/default/layout/moneybookers.xml
+++ b/app/design/adminhtml/default/default/layout/moneybookers.xml
@@ -15,7 +15,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/newsletter.xml b/app/design/adminhtml/default/default/layout/newsletter.xml
index 3a3dbd9..abda88c 100644
--- a/app/design/adminhtml/default/default/layout/newsletter.xml
+++ b/app/design/adminhtml/default/default/layout/newsletter.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/oauth.xml b/app/design/adminhtml/default/default/layout/oauth.xml
index 85cda1c..dd1d548 100644
--- a/app/design/adminhtml/default/default/layout/oauth.xml
+++ b/app/design/adminhtml/default/default/layout/oauth.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/pagecache.xml b/app/design/adminhtml/default/default/layout/pagecache.xml
index 38fe396..018b492 100644
--- a/app/design/adminhtml/default/default/layout/pagecache.xml
+++ b/app/design/adminhtml/default/default/layout/pagecache.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/promo.xml b/app/design/adminhtml/default/default/layout/promo.xml
index 33c5ceb..7865ab7 100644
--- a/app/design/adminhtml/default/default/layout/promo.xml
+++ b/app/design/adminhtml/default/default/layout/promo.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/report.xml b/app/design/adminhtml/default/default/layout/report.xml
index 0eab7f3..b1ee2aa 100644
--- a/app/design/adminhtml/default/default/layout/report.xml
+++ b/app/design/adminhtml/default/default/layout/report.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/rss.xml b/app/design/adminhtml/default/default/layout/rss.xml
index 74c0b87..538492a 100644
--- a/app/design/adminhtml/default/default/layout/rss.xml
+++ b/app/design/adminhtml/default/default/layout/rss.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/sales.xml b/app/design/adminhtml/default/default/layout/sales.xml
index 43bd8c0..9f9d6b0 100644
--- a/app/design/adminhtml/default/default/layout/sales.xml
+++ b/app/design/adminhtml/default/default/layout/sales.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/search.xml b/app/design/adminhtml/default/default/layout/search.xml
index fd31e72..4391b57 100644
--- a/app/design/adminhtml/default/default/layout/search.xml
+++ b/app/design/adminhtml/default/default/layout/search.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/tag.xml b/app/design/adminhtml/default/default/layout/tag.xml
index e403492..1d7ac81 100644
--- a/app/design/adminhtml/default/default/layout/tag.xml
+++ b/app/design/adminhtml/default/default/layout/tag.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/tax.xml b/app/design/adminhtml/default/default/layout/tax.xml
index 5889501..fd5973a 100644
--- a/app/design/adminhtml/default/default/layout/tax.xml
+++ b/app/design/adminhtml/default/default/layout/tax.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/widget.xml b/app/design/adminhtml/default/default/layout/widget.xml
index 2673199..68c8e71 100644
--- a/app/design/adminhtml/default/default/layout/widget.xml
+++ b/app/design/adminhtml/default/default/layout/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/layout/xmlconnect.xml b/app/design/adminhtml/default/default/layout/xmlconnect.xml
index c345297..72a1c5a 100644
--- a/app/design/adminhtml/default/default/layout/xmlconnect.xml
+++ b/app/design/adminhtml/default/default/layout/xmlconnect.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/adminhtml/default/default/template/access_denied.phtml b/app/design/adminhtml/default/default/template/access_denied.phtml
index 0b56686..fe6ab94 100644
--- a/app/design/adminhtml/default/default/template/access_denied.phtml
+++ b/app/design/adminhtml/default/default/template/access_denied.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/role_users_grid_js.phtml b/app/design/adminhtml/default/default/template/api/role_users_grid_js.phtml
index fba1bf0..820e2d6 100644
--- a/app/design/adminhtml/default/default/template/api/role_users_grid_js.phtml
+++ b/app/design/adminhtml/default/default/template/api/role_users_grid_js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/roleinfo.phtml b/app/design/adminhtml/default/default/template/api/roleinfo.phtml
index 4e0ad3b..21f7e1e 100644
--- a/app/design/adminhtml/default/default/template/api/roleinfo.phtml
+++ b/app/design/adminhtml/default/default/template/api/roleinfo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Adminhtml_Block_Api_Tab_Roleinfo */
diff --git a/app/design/adminhtml/default/default/template/api/roles.phtml b/app/design/adminhtml/default/default/template/api/roles.phtml
index 9a943d8..b36c54c 100644
--- a/app/design/adminhtml/default/default/template/api/roles.phtml
+++ b/app/design/adminhtml/default/default/template/api/roles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/rolesedit.phtml b/app/design/adminhtml/default/default/template/api/rolesedit.phtml
index 69fd345..47d4c1d 100644
--- a/app/design/adminhtml/default/default/template/api/rolesedit.phtml
+++ b/app/design/adminhtml/default/default/template/api/rolesedit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/rolesusers.phtml b/app/design/adminhtml/default/default/template/api/rolesusers.phtml
index 886db70..a3e87f1 100644
--- a/app/design/adminhtml/default/default/template/api/rolesusers.phtml
+++ b/app/design/adminhtml/default/default/template/api/rolesusers.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/user_roles_grid_js.phtml b/app/design/adminhtml/default/default/template/api/user_roles_grid_js.phtml
index db13ba4..ac14c4e 100644
--- a/app/design/adminhtml/default/default/template/api/user_roles_grid_js.phtml
+++ b/app/design/adminhtml/default/default/template/api/user_roles_grid_js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/userinfo.phtml b/app/design/adminhtml/default/default/template/api/userinfo.phtml
index 874e308..a06c3ac 100644
--- a/app/design/adminhtml/default/default/template/api/userinfo.phtml
+++ b/app/design/adminhtml/default/default/template/api/userinfo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/usernroles.phtml b/app/design/adminhtml/default/default/template/api/usernroles.phtml
index 6ac9b78..43482cb 100644
--- a/app/design/adminhtml/default/default/template/api/usernroles.phtml
+++ b/app/design/adminhtml/default/default/template/api/usernroles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/userroles.phtml b/app/design/adminhtml/default/default/template/api/userroles.phtml
index 844caac..c2c5891 100644
--- a/app/design/adminhtml/default/default/template/api/userroles.phtml
+++ b/app/design/adminhtml/default/default/template/api/userroles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api/users.phtml b/app/design/adminhtml/default/default/template/api/users.phtml
index f8e9c14..e81bef6 100644
--- a/app/design/adminhtml/default/default/template/api/users.phtml
+++ b/app/design/adminhtml/default/default/template/api/users.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api2/attribute/buttons.phtml b/app/design/adminhtml/default/default/template/api2/attribute/buttons.phtml
index bfc3b23..79bf064 100644
--- a/app/design/adminhtml/default/default/template/api2/attribute/buttons.phtml
+++ b/app/design/adminhtml/default/default/template/api2/attribute/buttons.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Api2_Block_Adminhtml_Attribute_Buttons */
diff --git a/app/design/adminhtml/default/default/template/api2/attribute/resource.phtml b/app/design/adminhtml/default/default/template/api2/attribute/resource.phtml
index 9b240d5..4ed775d 100644
--- a/app/design/adminhtml/default/default/template/api2/attribute/resource.phtml
+++ b/app/design/adminhtml/default/default/template/api2/attribute/resource.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api2/permissions/user/edit/tab/roles/js.phtml b/app/design/adminhtml/default/default/template/api2/permissions/user/edit/tab/roles/js.phtml
index 6f68ec2..cd6e3de 100644
--- a/app/design/adminhtml/default/default/template/api2/permissions/user/edit/tab/roles/js.phtml
+++ b/app/design/adminhtml/default/default/template/api2/permissions/user/edit/tab/roles/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api2/role/buttons.phtml b/app/design/adminhtml/default/default/template/api2/role/buttons.phtml
index b205858..1a40636 100644
--- a/app/design/adminhtml/default/default/template/api2/role/buttons.phtml
+++ b/app/design/adminhtml/default/default/template/api2/role/buttons.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/api2/role/users_grid_js.phtml b/app/design/adminhtml/default/default/template/api2/role/users_grid_js.phtml
index 205057c..7b017f8 100644
--- a/app/design/adminhtml/default/default/template/api2/role/users_grid_js.phtml
+++ b/app/design/adminhtml/default/default/template/api2/role/users_grid_js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/authorizenet/directpost/iframe.phtml b/app/design/adminhtml/default/default/template/authorizenet/directpost/iframe.phtml
index d55f17c..afa0133 100644
--- a/app/design/adminhtml/default/default/template/authorizenet/directpost/iframe.phtml
+++ b/app/design/adminhtml/default/default/template/authorizenet/directpost/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/authorizenet/directpost/info.phtml b/app/design/adminhtml/default/default/template/authorizenet/directpost/info.phtml
index 65216a2..b257822 100644
--- a/app/design/adminhtml/default/default/template/authorizenet/directpost/info.phtml
+++ b/app/design/adminhtml/default/default/template/authorizenet/directpost/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/backup/dialogs.phtml b/app/design/adminhtml/default/default/template/backup/dialogs.phtml
index 3c582ae..74b7222 100644
--- a/app/design/adminhtml/default/default/template/backup/dialogs.phtml
+++ b/app/design/adminhtml/default/default/template/backup/dialogs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/backup/left.phtml b/app/design/adminhtml/default/default/template/backup/left.phtml
index 70f40c3..71c7116 100644
--- a/app/design/adminhtml/default/default/template/backup/left.phtml
+++ b/app/design/adminhtml/default/default/template/backup/left.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/backup/list.phtml b/app/design/adminhtml/default/default/template/backup/list.phtml
index 0ffc909..f231160 100644
--- a/app/design/adminhtml/default/default/template/backup/list.phtml
+++ b/app/design/adminhtml/default/default/template/backup/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/bundle.phtml b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/bundle.phtml
index 2a2d25e..f500e77 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/bundle.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/bundle.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/checkbox.phtml b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/checkbox.phtml
index b34dbec..8df429e 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/checkbox.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/checkbox.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/multi.phtml b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/multi.phtml
index 5c0f9dd..a499748 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/multi.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/multi.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/radio.phtml b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/radio.phtml
index 9f3b0eb..593c8a9 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/radio.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/radio.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/select.phtml b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/select.phtml
index 4aa6962..799e6e5 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/select.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/composite/fieldset/options/type/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle.phtml b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle.phtml
index f802cda..977f455 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option.phtml b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option.phtml
index 3831a8a..5f61168 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/search.phtml b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/search.phtml
index 1fb9d73..d785096 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/search.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/search.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/selection.phtml b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/selection.phtml
index 96fc678..0ae808e 100644
--- a/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/selection.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/product/edit/bundle/option/selection.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/create/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/create/items/renderer.phtml
index 676f8bc..9e7b5e2 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/create/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/create/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/view/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/view/items/renderer.phtml
index 2872d0b..2ed6f03 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/view/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/creditmemo/view/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/invoice/create/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/invoice/create/items/renderer.phtml
index e4088cc..200b200 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/invoice/create/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/invoice/create/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/invoice/view/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/invoice/view/items/renderer.phtml
index 95281a2..f8b6707 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/invoice/view/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/invoice/view/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/order/view/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/order/view/items/renderer.phtml
index cd4a35d..fc5e123 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/order/view/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/order/view/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/shipment/create/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/shipment/create/items/renderer.phtml
index a49026a..9307104 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/shipment/create/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/shipment/create/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/bundle/sales/shipment/view/items/renderer.phtml b/app/design/adminhtml/default/default/template/bundle/sales/shipment/view/items/renderer.phtml
index 9b12d4d..b61b0e4 100644
--- a/app/design/adminhtml/default/default/template/bundle/sales/shipment/view/items/renderer.phtml
+++ b/app/design/adminhtml/default/default/template/bundle/sales/shipment/view/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/captcha/zend.phtml b/app/design/adminhtml/default/default/template/captcha/zend.phtml
index 2ce9523..037e6ad 100644
--- a/app/design/adminhtml/default/default/template/captcha/zend.phtml
+++ b/app/design/adminhtml/default/default/template/captcha/zend.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/category/checkboxes/tree.phtml b/app/design/adminhtml/default/default/template/catalog/category/checkboxes/tree.phtml
index fac75c2..7cdbc33 100644
--- a/app/design/adminhtml/default/default/template/catalog/category/checkboxes/tree.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/category/checkboxes/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/category/edit.phtml b/app/design/adminhtml/default/default/template/catalog/category/edit.phtml
index 196e476..4a05e09 100644
--- a/app/design/adminhtml/default/default/template/catalog/category/edit.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/category/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/category/edit/form.phtml b/app/design/adminhtml/default/default/template/catalog/category/edit/form.phtml
index 025fda4..328ba78 100644
--- a/app/design/adminhtml/default/default/template/catalog/category/edit/form.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/category/edit/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/category/tree.phtml b/app/design/adminhtml/default/default/template/catalog/category/tree.phtml
index 861ee2d..4ad6e8b 100644
--- a/app/design/adminhtml/default/default/template/catalog/category/tree.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/category/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/category/widget/tree.phtml b/app/design/adminhtml/default/default/template/catalog/category/widget/tree.phtml
index 7496f7e..1f9421b 100644
--- a/app/design/adminhtml/default/default/template/catalog/category/widget/tree.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/category/widget/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/form/renderer/fieldset/element.phtml b/app/design/adminhtml/default/default/template/catalog/form/renderer/fieldset/element.phtml
index a809836..9e56b4a 100644
--- a/app/design/adminhtml/default/default/template/catalog/form/renderer/fieldset/element.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/form/renderer/fieldset/element.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product.phtml b/app/design/adminhtml/default/default/template/catalog/product.phtml
index 10478fe..0e718f4 100644
--- a/app/design/adminhtml/default/default/template/catalog/product.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/js.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/js.phtml
index bbc7bc5..2bcc51c 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/js.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/new/created.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/new/created.phtml
index d95e110..68d5244 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/new/created.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/new/created.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/options.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/options.phtml
index f1229a5..950a15a 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/options.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main.phtml
index 9741ef5..7b8ff27 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/attribute.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/attribute.phtml
index 1740cc2..97d42fa 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/attribute.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/attribute.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/group.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/group.phtml
index b6a4552..695c0fe 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/group.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/main/tree/group.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/add.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/add.phtml
index 9fb7b3c..3584666 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/add.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/add.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/main.phtml b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/main.phtml
index 99c189a..21b06f9 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/main.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/attribute/set/toolbar/main.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/configure.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/configure.phtml
index d9b5c6f..d74667d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/configure.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/configure.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
index adea847..5452fe7 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/grouped.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/grouped.phtml
index 3bb4090..e827f96 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/grouped.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/grouped.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options.phtml
index 67c557c..baba0da 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/js.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/js.phtml
index 871b3c0..5b3f5f3 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/js.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/date.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/date.phtml
index d242b36..8bb4d15 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/date.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/date.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/default.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/default.phtml
index bcaa30d..0a81ed5 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/default.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/file.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/file.phtml
index 8f48d00..32be199 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/file.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/file.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/select.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/select.phtml
index b892248..432358d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/select.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/text.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/text.phtml
index 7f4c292..57f90c9 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/text.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/options/type/text.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/qty.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/qty.phtml
index e00becb..34b7452 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/qty.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/qty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/created.phtml b/app/design/adminhtml/default/default/template/catalog/product/created.phtml
index 302c234..92b4cf2 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/created.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/created.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit.phtml
index 6a232a0..e6a4a69 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/action/attribute.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/action/attribute.phtml
index a56532b..1c53443 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/action/attribute.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/action/attribute.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/action/inventory.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/action/inventory.phtml
index 76c978c..97eb62f 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/action/inventory.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/action/inventory.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/action/websites.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/action/websites.phtml
index 3ed5102..6ca06e4 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/action/websites.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/action/websites.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/categories.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/categories.phtml
index 600d3f5..5d97b91 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/categories.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/categories.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options.phtml
index e243aff..1a27c3c 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options/option.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options/option.phtml
index 1181918..104a95d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options/option.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options/option.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/date.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/date.phtml
index 33cad06..fc46e65 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/date.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/date.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/file.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/file.phtml
index 3d124e8..9d08278 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/file.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/file.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/select.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/select.phtml
index a5f1380..7dbed10 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/select.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/text.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/text.phtml
index e9fb6a8..1d27c08 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/text.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/options/type/text.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/price/group.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/price/group.phtml
index 8427ede..c730280 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/price/group.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/price/group.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/price/tier.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/price/tier.phtml
index 12d29a8..4d93148 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/price/tier.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/price/tier.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Adminhtml_Block_Catalog_Product_Edit_Tab_Price_Tier */
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/serializer.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/serializer.phtml
index 188ec71..32024df 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/serializer.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/serializer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/super/config.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/super/config.phtml
index 134871d..e41b765 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/super/config.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/super/config.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/edit/websites.phtml b/app/design/adminhtml/default/default/template/catalog/product/edit/websites.phtml
index 91f5278..6ba0bb3 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/edit/websites.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/edit/websites.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml b/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
index 500349f..cc62210 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/js.phtml b/app/design/adminhtml/default/default/template/catalog/product/js.phtml
index 8359658..61d766d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/js.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/price.phtml b/app/design/adminhtml/default/default/template/catalog/product/price.phtml
index 057e9fd..ffcb2b0 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/price.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/tab/alert.phtml b/app/design/adminhtml/default/default/template/catalog/product/tab/alert.phtml
index e33ff87..a76ef4d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/tab/alert.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/tab/alert.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml b/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
index 4a612a1..a0fd72d 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/widget/chooser/container.phtml b/app/design/adminhtml/default/default/template/catalog/product/widget/chooser/container.phtml
index 58aeb5a..5a7f33e 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/widget/chooser/container.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/widget/chooser/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/catalog/wysiwyg/js.phtml b/app/design/adminhtml/default/default/template/catalog/wysiwyg/js.phtml
index 159bac2..88344de 100644
--- a/app/design/adminhtml/default/default/template/catalog/wysiwyg/js.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/wysiwyg/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/centinel/authentication/complete.phtml b/app/design/adminhtml/default/default/template/centinel/authentication/complete.phtml
index 11c9d68..f636d87 100644
--- a/app/design/adminhtml/default/default/template/centinel/authentication/complete.phtml
+++ b/app/design/adminhtml/default/default/template/centinel/authentication/complete.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/centinel/authentication/start.phtml b/app/design/adminhtml/default/default/template/centinel/authentication/start.phtml
index e1ea943..75d773f 100644
--- a/app/design/adminhtml/default/default/template/centinel/authentication/start.phtml
+++ b/app/design/adminhtml/default/default/template/centinel/authentication/start.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/centinel/validation/form.phtml b/app/design/adminhtml/default/default/template/centinel/validation/form.phtml
index 7829f06..7bef294 100644
--- a/app/design/adminhtml/default/default/template/centinel/validation/form.phtml
+++ b/app/design/adminhtml/default/default/template/centinel/validation/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/content.phtml b/app/design/adminhtml/default/default/template/cms/browser/content.phtml
index 2adf437..1553922 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/content.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/content.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/content/files.phtml b/app/design/adminhtml/default/default/template/cms/browser/content/files.phtml
index edff349..30e589b 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/content/files.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/content/files.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/content/newfolder.phtml b/app/design/adminhtml/default/default/template/cms/browser/content/newfolder.phtml
index 817c9e2..dc0cb77 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/content/newfolder.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/content/newfolder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/content/uploader.phtml b/app/design/adminhtml/default/default/template/cms/browser/content/uploader.phtml
index e9e6113..80be893 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/content/uploader.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/content/uploader.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/js.phtml b/app/design/adminhtml/default/default/template/cms/browser/js.phtml
index acc8b7f..5694b57 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/js.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/browser/tree.phtml b/app/design/adminhtml/default/default/template/cms/browser/tree.phtml
index 7d642d2..45f128e 100644
--- a/app/design/adminhtml/default/default/template/cms/browser/tree.phtml
+++ b/app/design/adminhtml/default/default/template/cms/browser/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/cms/page/edit/form/renderer/content.phtml b/app/design/adminhtml/default/default/template/cms/page/edit/form/renderer/content.phtml
index da1c322..c36e108 100644
--- a/app/design/adminhtml/default/default/template/cms/page/edit/form/renderer/content.phtml
+++ b/app/design/adminhtml/default/default/template/cms/page/edit/form/renderer/content.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/coming.phtml b/app/design/adminhtml/default/default/template/coming.phtml
index b04a3e0..836e227 100644
--- a/app/design/adminhtml/default/default/template/coming.phtml
+++ b/app/design/adminhtml/default/default/template/coming.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/compiler/process.phtml b/app/design/adminhtml/default/default/template/compiler/process.phtml
index 9c3e811..8c3dd16 100644
--- a/app/design/adminhtml/default/default/template/compiler/process.phtml
+++ b/app/design/adminhtml/default/default/template/compiler/process.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/authors.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/authors.phtml
index 52c0c55..241479ee 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/authors.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/authors.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/contents.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/contents.phtml
index 8c3a699..2d4d8eb 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/contents.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/contents.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/depends.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/depends.phtml
index 7f1a9bc..4526155 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/depends.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/depends.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/load.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/load.phtml
index 1fb8c23..5c8e603 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/load.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/load.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/package.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/package.phtml
index b5e094d..8ebcf3f 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/package.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/package.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/connect/extension/custom/release.phtml b/app/design/adminhtml/default/default/template/connect/extension/custom/release.phtml
index 9823c33..b5d8d45 100644
--- a/app/design/adminhtml/default/default/template/connect/extension/custom/release.phtml
+++ b/app/design/adminhtml/default/default/template/connect/extension/custom/release.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml b/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
index 546096a..597f641 100644
--- a/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
+++ b/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/edit/js.phtml b/app/design/adminhtml/default/default/template/customer/edit/js.phtml
index b8dc20b..c518161 100644
--- a/app/design/adminhtml/default/default/template/customer/edit/js.phtml
+++ b/app/design/adminhtml/default/default/template/customer/edit/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/edit/tab/account/form/renderer/group.phtml b/app/design/adminhtml/default/default/template/customer/edit/tab/account/form/renderer/group.phtml
index 1f1b8de..dc9c9ef 100644
--- a/app/design/adminhtml/default/default/template/customer/edit/tab/account/form/renderer/group.phtml
+++ b/app/design/adminhtml/default/default/template/customer/edit/tab/account/form/renderer/group.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/edit/tab/view/grid/item.phtml b/app/design/adminhtml/default/default/template/customer/edit/tab/view/grid/item.phtml
index a1a579b..fcd39fd 100644
--- a/app/design/adminhtml/default/default/template/customer/edit/tab/view/grid/item.phtml
+++ b/app/design/adminhtml/default/default/template/customer/edit/tab/view/grid/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/customer/online.phtml b/app/design/adminhtml/default/default/template/customer/online.phtml
index 4139e98..4b4f613 100644
--- a/app/design/adminhtml/default/default/template/customer/online.phtml
+++ b/app/design/adminhtml/default/default/template/customer/online.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/sales/order/create/address/form/renderer/vat.phtml b/app/design/adminhtml/default/default/template/customer/sales/order/create/address/form/renderer/vat.phtml
index 125e2281..b2ebf3e 100644
--- a/app/design/adminhtml/default/default/template/customer/sales/order/create/address/form/renderer/vat.phtml
+++ b/app/design/adminhtml/default/default/template/customer/sales/order/create/address/form/renderer/vat.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/system/config/validatevat.phtml b/app/design/adminhtml/default/default/template/customer/system/config/validatevat.phtml
index 91a5eab..e18f68e 100644
--- a/app/design/adminhtml/default/default/template/customer/system/config/validatevat.phtml
+++ b/app/design/adminhtml/default/default/template/customer/system/config/validatevat.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml b/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
index 12580dd..4e41e32 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/cart.phtml b/app/design/adminhtml/default/default/template/customer/tab/cart.phtml
index 3f95532..1153dde 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/cart.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/newsletter.phtml b/app/design/adminhtml/default/default/template/customer/tab/newsletter.phtml
index daf7d13..83550f3 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/newsletter.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/newsletter.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/view.phtml b/app/design/adminhtml/default/default/template/customer/tab/view.phtml
index d5cb518..cd23a75 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/view.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/view/sales.phtml b/app/design/adminhtml/default/default/template/customer/tab/view/sales.phtml
index 31a5e1e..57473d6 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/view/sales.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/view/sales.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/wishlist.phtml b/app/design/adminhtml/default/default/template/customer/tab/wishlist.phtml
index 9b99025..5706051 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/wishlist.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/wishlist.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/graph.phtml b/app/design/adminhtml/default/default/template/dashboard/graph.phtml
index d03f769..926d354 100644
--- a/app/design/adminhtml/default/default/template/dashboard/graph.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/graph.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*
diff --git a/app/design/adminhtml/default/default/template/dashboard/graph/disabled.phtml b/app/design/adminhtml/default/default/template/dashboard/graph/disabled.phtml
index 14038dc..7d8a096 100644
--- a/app/design/adminhtml/default/default/template/dashboard/graph/disabled.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/graph/disabled.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/grid.phtml b/app/design/adminhtml/default/default/template/dashboard/grid.phtml
index 349b210..7ca8a02 100644
--- a/app/design/adminhtml/default/default/template/dashboard/grid.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/index.phtml b/app/design/adminhtml/default/default/template/dashboard/index.phtml
index 8c42e8b..d04d824 100644
--- a/app/design/adminhtml/default/default/template/dashboard/index.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/index.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/salebar.phtml b/app/design/adminhtml/default/default/template/dashboard/salebar.phtml
index 1c692cd..93ca8eb 100644
--- a/app/design/adminhtml/default/default/template/dashboard/salebar.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/salebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/searches.phtml b/app/design/adminhtml/default/default/template/dashboard/searches.phtml
index cb3638a..10b5570 100644
--- a/app/design/adminhtml/default/default/template/dashboard/searches.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/searches.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/store/switcher.phtml b/app/design/adminhtml/default/default/template/dashboard/store/switcher.phtml
index 190330b..f30d28f 100644
--- a/app/design/adminhtml/default/default/template/dashboard/store/switcher.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/store/switcher.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/dashboard/totalbar.phtml b/app/design/adminhtml/default/default/template/dashboard/totalbar.phtml
index 91ab125..fdeb030 100644
--- a/app/design/adminhtml/default/default/template/dashboard/totalbar.phtml
+++ b/app/design/adminhtml/default/default/template/dashboard/totalbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/directory/js/optional_zip_countries.phtml b/app/design/adminhtml/default/default/template/directory/js/optional_zip_countries.phtml
index fb87d10..6db17cd 100644
--- a/app/design/adminhtml/default/default/template/directory/js/optional_zip_countries.phtml
+++ b/app/design/adminhtml/default/default/template/directory/js/optional_zip_countries.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/product/composite/fieldset/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/product/composite/fieldset/downloadable.phtml
index e55720c..52ace18 100644
--- a/app/design/adminhtml/default/default/template/downloadable/product/composite/fieldset/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/product/composite/fieldset/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable.phtml
index 774b4eb..810dc4e 100644
--- a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/links.phtml b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/links.phtml
index 0e777e8..ce977eb 100644
--- a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/links.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/samples.phtml b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/samples.phtml
index 41126be..b65520c 100644
--- a/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/samples.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/product/edit/downloadable/samples.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/creditmemo/name.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/creditmemo/name.phtml
index 3c6dce2..39e8232 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/creditmemo/name.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/creditmemo/name.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/invoice/name.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/invoice/name.phtml
index 82a2094..bacc83b 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/invoice/name.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/invoice/name.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/name.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/name.phtml
index 7220161..3ce4367 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/name.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/items/column/downloadable/name.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/create/items/renderer/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/create/items/renderer/downloadable.phtml
index ba28418..3d974b7 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/create/items/renderer/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/create/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/view/items/renderer/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/view/items/renderer/downloadable.phtml
index 503fa80..3171412 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/view/items/renderer/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/order/creditmemo/view/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/create/items/renderer/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/create/items/renderer/downloadable.phtml
index a2b728d..640303e 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/create/items/renderer/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/create/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/view/items/renderer/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/view/items/renderer/downloadable.phtml
index 798144b..d367f7f 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/view/items/renderer/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/order/invoice/view/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/downloadable/sales/order/view/items/renderer/downloadable.phtml b/app/design/adminhtml/default/default/template/downloadable/sales/order/view/items/renderer/downloadable.phtml
index 00ad381..d42ae8b 100644
--- a/app/design/adminhtml/default/default/template/downloadable/sales/order/view/items/renderer/downloadable.phtml
+++ b/app/design/adminhtml/default/default/template/downloadable/sales/order/view/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/eav/attribute/edit/js.phtml b/app/design/adminhtml/default/default/template/eav/attribute/edit/js.phtml
index 1740cc2..97d42fa 100644
--- a/app/design/adminhtml/default/default/template/eav/attribute/edit/js.phtml
+++ b/app/design/adminhtml/default/default/template/eav/attribute/edit/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/eav/attribute/options.phtml b/app/design/adminhtml/default/default/template/eav/attribute/options.phtml
index 18b025f..fec559c 100644
--- a/app/design/adminhtml/default/default/template/eav/attribute/options.phtml
+++ b/app/design/adminhtml/default/default/template/eav/attribute/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/email/order/items.phtml b/app/design/adminhtml/default/default/template/email/order/items.phtml
index 85895bf..f946351 100644
--- a/app/design/adminhtml/default/default/template/email/order/items.phtml
+++ b/app/design/adminhtml/default/default/template/email/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/empty.phtml b/app/design/adminhtml/default/default/template/empty.phtml
index af26430..657e025 100644
--- a/app/design/adminhtml/default/default/template/empty.phtml
+++ b/app/design/adminhtml/default/default/template/empty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/example.phtml b/app/design/adminhtml/default/default/template/example.phtml
index d9d28de..96b4e3e 100644
--- a/app/design/adminhtml/default/default/template/example.phtml
+++ b/app/design/adminhtml/default/default/template/example.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/forgotpassword.phtml b/app/design/adminhtml/default/default/template/forgotpassword.phtml
index 7404de7..d472837 100644
--- a/app/design/adminhtml/default/default/template/forgotpassword.phtml
+++ b/app/design/adminhtml/default/default/template/forgotpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/formkey.phtml b/app/design/adminhtml/default/default/template/formkey.phtml
index dbc21e9..2a09c4b 100644
--- a/app/design/adminhtml/default/default/template/formkey.phtml
+++ b/app/design/adminhtml/default/default/template/formkey.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/form.phtml b/app/design/adminhtml/default/default/template/giftmessage/form.phtml
index 3403d42..ec7249e 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/form.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/giftoptionsform.phtml b/app/design/adminhtml/default/default/template/giftmessage/giftoptionsform.phtml
index 0fac360..42a068a 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/giftoptionsform.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/giftoptionsform.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/helper.phtml b/app/design/adminhtml/default/default/template/giftmessage/helper.phtml
index c3202bc..e3c9397 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/helper.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/helper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/popup.phtml b/app/design/adminhtml/default/default/template/giftmessage/popup.phtml
index b850b8d..425a372 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/popup.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/giftoptions.phtml b/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/giftoptions.phtml
index effc7dd..c90ca82 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/giftoptions.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/giftoptions.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/items.phtml b/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/items.phtml
index a90a19c..46e5f6f 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/items.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/sales/order/create/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/giftoptions.phtml b/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/giftoptions.phtml
index 74e7046..d8e692f 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/giftoptions.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/giftoptions.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/items.phtml b/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/items.phtml
index f3d3e49..5e0bbbf 100644
--- a/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/items.phtml
+++ b/app/design/adminhtml/default/default/template/giftmessage/sales/order/view/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/googlebase/captcha.phtml b/app/design/adminhtml/default/default/template/googlebase/captcha.phtml
index e69f1af..1956b56 100644
--- a/app/design/adminhtml/default/default/template/googlebase/captcha.phtml
+++ b/app/design/adminhtml/default/default/template/googlebase/captcha.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/googlebase/items.phtml b/app/design/adminhtml/default/default/template/googlebase/items.phtml
index 7145f2d..f511c49 100644
--- a/app/design/adminhtml/default/default/template/googlebase/items.phtml
+++ b/app/design/adminhtml/default/default/template/googlebase/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/googlebase/types/edit/attributes.phtml b/app/design/adminhtml/default/default/template/googlebase/types/edit/attributes.phtml
index 041faef..29a45cc 100644
--- a/app/design/adminhtml/default/default/template/googlebase/types/edit/attributes.phtml
+++ b/app/design/adminhtml/default/default/template/googlebase/types/edit/attributes.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/busy.phtml b/app/design/adminhtml/default/default/template/importexport/busy.phtml
index 9d430ac..1d72e64 100644
--- a/app/design/adminhtml/default/default/template/importexport/busy.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/busy.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/export/form/after.phtml b/app/design/adminhtml/default/default/template/importexport/export/form/after.phtml
index 418ecf5..bd31f8c 100644
--- a/app/design/adminhtml/default/default/template/importexport/export/form/after.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/export/form/after.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/export/form/before.phtml b/app/design/adminhtml/default/default/template/importexport/export/form/before.phtml
index 01b4f15..b101256 100644
--- a/app/design/adminhtml/default/default/template/importexport/export/form/before.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/export/form/before.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/import/form/after.phtml b/app/design/adminhtml/default/default/template/importexport/import/form/after.phtml
index a09a14e..0b55bd4 100644
--- a/app/design/adminhtml/default/default/template/importexport/import/form/after.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/import/form/after.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/import/form/before.phtml b/app/design/adminhtml/default/default/template/importexport/import/form/before.phtml
index c143717..4ad335c 100644
--- a/app/design/adminhtml/default/default/template/importexport/import/form/before.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/import/form/before.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/importexport/import/frame/result.phtml b/app/design/adminhtml/default/default/template/importexport/import/frame/result.phtml
index aa567fb..dda93851 100644
--- a/app/design/adminhtml/default/default/template/importexport/import/frame/result.phtml
+++ b/app/design/adminhtml/default/default/template/importexport/import/frame/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/index/notifications.phtml b/app/design/adminhtml/default/default/template/index/notifications.phtml
index 49d9488..8055216 100644
--- a/app/design/adminhtml/default/default/template/index/notifications.phtml
+++ b/app/design/adminhtml/default/default/template/index/notifications.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/login.phtml b/app/design/adminhtml/default/default/template/login.phtml
index 8661806..49c2b81 100644
--- a/app/design/adminhtml/default/default/template/login.phtml
+++ b/app/design/adminhtml/default/default/template/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/media/editor.phtml b/app/design/adminhtml/default/default/template/media/editor.phtml
index 2dd4978..ce4d475 100644
--- a/app/design/adminhtml/default/default/template/media/editor.phtml
+++ b/app/design/adminhtml/default/default/template/media/editor.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/media/uploader.phtml b/app/design/adminhtml/default/default/template/media/uploader.phtml
index c8e5745..6b567d72 100644
--- a/app/design/adminhtml/default/default/template/media/uploader.phtml
+++ b/app/design/adminhtml/default/default/template/media/uploader.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/moneybookers/info.phtml b/app/design/adminhtml/default/default/template/moneybookers/info.phtml
index a414669..6a4dda9 100644
--- a/app/design/adminhtml/default/default/template/moneybookers/info.phtml
+++ b/app/design/adminhtml/default/default/template/moneybookers/info.phtml
@@ -14,7 +14,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/moneybookers/jsinit.phtml b/app/design/adminhtml/default/default/template/moneybookers/jsinit.phtml
index 3c0b003..4718247 100644
--- a/app/design/adminhtml/default/default/template/moneybookers/jsinit.phtml
+++ b/app/design/adminhtml/default/default/template/moneybookers/jsinit.phtml
@@ -14,7 +14,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/moneybookers/pdf/info.phtml b/app/design/adminhtml/default/default/template/moneybookers/pdf/info.phtml
index 4276aa7..52ebe94 100644
--- a/app/design/adminhtml/default/default/template/moneybookers/pdf/info.phtml
+++ b/app/design/adminhtml/default/default/template/moneybookers/pdf/info.phtml
@@ -14,7 +14,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/preview/iframeswitcher.phtml b/app/design/adminhtml/default/default/template/newsletter/preview/iframeswitcher.phtml
index 651f6d8..d3198b1 100644
--- a/app/design/adminhtml/default/default/template/newsletter/preview/iframeswitcher.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/preview/iframeswitcher.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/preview/store.phtml b/app/design/adminhtml/default/default/template/newsletter/preview/store.phtml
index a69df07..e5a11b9 100644
--- a/app/design/adminhtml/default/default/template/newsletter/preview/store.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/preview/store.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/problem/list.phtml b/app/design/adminhtml/default/default/template/newsletter/problem/list.phtml
index b0ec458..91b1c27 100644
--- a/app/design/adminhtml/default/default/template/newsletter/problem/list.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/problem/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/queue/edit.phtml b/app/design/adminhtml/default/default/template/newsletter/queue/edit.phtml
index 1b1cf11..a846daa 100644
--- a/app/design/adminhtml/default/default/template/newsletter/queue/edit.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/queue/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Adminhtml_Block_Newsletter_Queue_Edit */
diff --git a/app/design/adminhtml/default/default/template/newsletter/queue/list.phtml b/app/design/adminhtml/default/default/template/newsletter/queue/list.phtml
index af168d7..014a1e9 100644
--- a/app/design/adminhtml/default/default/template/newsletter/queue/list.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/queue/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/queue/preview.phtml b/app/design/adminhtml/default/default/template/newsletter/queue/preview.phtml
index dc6cc7f..ff74f18 100644
--- a/app/design/adminhtml/default/default/template/newsletter/queue/preview.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/queue/preview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/subscriber/list.phtml b/app/design/adminhtml/default/default/template/newsletter/subscriber/list.phtml
index 1d55570..684e61d 100644
--- a/app/design/adminhtml/default/default/template/newsletter/subscriber/list.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/subscriber/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/template/edit.phtml b/app/design/adminhtml/default/default/template/newsletter/template/edit.phtml
index 8cb622e..b949390 100644
--- a/app/design/adminhtml/default/default/template/newsletter/template/edit.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/template/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Adminhtml_Block_Newsletter_Template_Edit */
diff --git a/app/design/adminhtml/default/default/template/newsletter/template/list.phtml b/app/design/adminhtml/default/default/template/newsletter/template/list.phtml
index dc91302..2e889c0 100644
--- a/app/design/adminhtml/default/default/template/newsletter/template/list.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/template/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/newsletter/template/preview.phtml b/app/design/adminhtml/default/default/template/newsletter/template/preview.phtml
index dc6cc7f..ff74f18 100644
--- a/app/design/adminhtml/default/default/template/newsletter/template/preview.phtml
+++ b/app/design/adminhtml/default/default/template/newsletter/template/preview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/notification/baseurl.phtml b/app/design/adminhtml/default/default/template/notification/baseurl.phtml
index 7bc6ebb..d68e053 100644
--- a/app/design/adminhtml/default/default/template/notification/baseurl.phtml
+++ b/app/design/adminhtml/default/default/template/notification/baseurl.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/notification/curl.phtml b/app/design/adminhtml/default/default/template/notification/curl.phtml
index d97ce32..2c209fd 100644
--- a/app/design/adminhtml/default/default/template/notification/curl.phtml
+++ b/app/design/adminhtml/default/default/template/notification/curl.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/notification/formkey.phtml b/app/design/adminhtml/default/default/template/notification/formkey.phtml
index 0845e69..977d577 100644
--- a/app/design/adminhtml/default/default/template/notification/formkey.phtml
+++ b/app/design/adminhtml/default/default/template/notification/formkey.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/notification/security.phtml b/app/design/adminhtml/default/default/template/notification/security.phtml
index 2187cd8..4845f52 100644
--- a/app/design/adminhtml/default/default/template/notification/security.phtml
+++ b/app/design/adminhtml/default/default/template/notification/security.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/notification/survey.phtml b/app/design/adminhtml/default/default/template/notification/survey.phtml
index 9f47dd1..90c1cb3 100644
--- a/app/design/adminhtml/default/default/template/notification/survey.phtml
+++ b/app/design/adminhtml/default/default/template/notification/survey.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/notification/symlink.phtml b/app/design/adminhtml/default/default/template/notification/symlink.phtml
index 32cf121..5450570 100644
--- a/app/design/adminhtml/default/default/template/notification/symlink.phtml
+++ b/app/design/adminhtml/default/default/template/notification/symlink.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/notification/toolbar.phtml b/app/design/adminhtml/default/default/template/notification/toolbar.phtml
index b9d8c94..29f61a1 100644
--- a/app/design/adminhtml/default/default/template/notification/toolbar.phtml
+++ b/app/design/adminhtml/default/default/template/notification/toolbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/notification/window.phtml b/app/design/adminhtml/default/default/template/notification/window.phtml
index 4e8af47..1590005 100644
--- a/app/design/adminhtml/default/default/template/notification/window.phtml
+++ b/app/design/adminhtml/default/default/template/notification/window.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/button-simple.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/button-simple.phtml
index 0df3c6b..870ff2c 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/button-simple.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/button-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/button.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/button.phtml
index 8781689..81dfda9 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/button.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/button.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/confirm-simple.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/confirm-simple.phtml
index 4136ff8..e82b09f 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/confirm-simple.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/confirm-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/confirm.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/confirm.phtml
index 7d936d5..60dd922 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/confirm.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/confirm.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/form/login-simple.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/form/login-simple.phtml
index 01876ef..10548ff 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/form/login-simple.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/form/login-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/form/login.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/form/login.phtml
index eedb59e..f7c6e8a 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/form/login.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/head-simple.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/head-simple.phtml
index b6e2173..55c9a50 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/head-simple.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/head-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/reject-simple.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/reject-simple.phtml
index ffc4929..aa77daa 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/reject-simple.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/reject-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/oauth/authorize/reject.phtml b/app/design/adminhtml/default/default/template/oauth/authorize/reject.phtml
index dbfddd8..5379e39 100644
--- a/app/design/adminhtml/default/default/template/oauth/authorize/reject.phtml
+++ b/app/design/adminhtml/default/default/template/oauth/authorize/reject.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/overlay_popup.phtml b/app/design/adminhtml/default/default/template/overlay_popup.phtml
index b423c40..89cd8ad 100644
--- a/app/design/adminhtml/default/default/template/overlay_popup.phtml
+++ b/app/design/adminhtml/default/default/template/overlay_popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page.phtml b/app/design/adminhtml/default/default/template/page.phtml
index 7e21ab3..1f09ff4 100644
--- a/app/design/adminhtml/default/default/template/page.phtml
+++ b/app/design/adminhtml/default/default/template/page.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/footer.phtml b/app/design/adminhtml/default/default/template/page/footer.phtml
index c3da577..cbb2532 100644
--- a/app/design/adminhtml/default/default/template/page/footer.phtml
+++ b/app/design/adminhtml/default/default/template/page/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/head.phtml b/app/design/adminhtml/default/default/template/page/head.phtml
index 6ce2757..3d33044 100644
--- a/app/design/adminhtml/default/default/template/page/head.phtml
+++ b/app/design/adminhtml/default/default/template/page/head.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/header.phtml b/app/design/adminhtml/default/default/template/page/header.phtml
index b28dbbd..c8ab3ca 100644
--- a/app/design/adminhtml/default/default/template/page/header.phtml
+++ b/app/design/adminhtml/default/default/template/page/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/page/js/calendar.phtml b/app/design/adminhtml/default/default/template/page/js/calendar.phtml
index 0bb6723..d55b1b1 100644
--- a/app/design/adminhtml/default/default/template/page/js/calendar.phtml
+++ b/app/design/adminhtml/default/default/template/page/js/calendar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/js/translate.phtml b/app/design/adminhtml/default/default/template/page/js/translate.phtml
index 1e5e08e..46b2adf 100644
--- a/app/design/adminhtml/default/default/template/page/js/translate.phtml
+++ b/app/design/adminhtml/default/default/template/page/js/translate.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/menu.phtml b/app/design/adminhtml/default/default/template/page/menu.phtml
index dc7de48..75eeb27 100644
--- a/app/design/adminhtml/default/default/template/page/menu.phtml
+++ b/app/design/adminhtml/default/default/template/page/menu.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/page/notices.phtml b/app/design/adminhtml/default/default/template/page/notices.phtml
index 74d1350..0c3c863 100644
--- a/app/design/adminhtml/default/default/template/page/notices.phtml
+++ b/app/design/adminhtml/default/default/template/page/notices.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/pagecache/cache/additional.phtml b/app/design/adminhtml/default/default/template/pagecache/cache/additional.phtml
index 54ec7f8..7c6951f 100644
--- a/app/design/adminhtml/default/default/template/pagecache/cache/additional.phtml
+++ b/app/design/adminhtml/default/default/template/pagecache/cache/additional.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paygate/form/cc.phtml b/app/design/adminhtml/default/default/template/paygate/form/cc.phtml
index 910bdd8..6791f5f 100644
--- a/app/design/adminhtml/default/default/template/paygate/form/cc.phtml
+++ b/app/design/adminhtml/default/default/template/paygate/form/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paygate/info/cc.phtml b/app/design/adminhtml/default/default/template/paygate/info/cc.phtml
index a5443be..5204767 100644
--- a/app/design/adminhtml/default/default/template/paygate/info/cc.phtml
+++ b/app/design/adminhtml/default/default/template/paygate/info/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paygate/info/pdf.phtml b/app/design/adminhtml/default/default/template/paygate/info/pdf.phtml
index 4158217..4d044cb 100644
--- a/app/design/adminhtml/default/default/template/paygate/info/pdf.phtml
+++ b/app/design/adminhtml/default/default/template/paygate/info/pdf.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/form/banktransfer.phtml b/app/design/adminhtml/default/default/template/payment/form/banktransfer.phtml
index c81c1da..3d7aec2 100644
--- a/app/design/adminhtml/default/default/template/payment/form/banktransfer.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/banktransfer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/form/cashondelivery.phtml b/app/design/adminhtml/default/default/template/payment/form/cashondelivery.phtml
index eb98bc7..81b2835 100644
--- a/app/design/adminhtml/default/default/template/payment/form/cashondelivery.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/cashondelivery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/payment/form/cc.phtml b/app/design/adminhtml/default/default/template/payment/form/cc.phtml
index 0d59718..ee1befb 100644
--- a/app/design/adminhtml/default/default/template/payment/form/cc.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/form/ccsave.phtml b/app/design/adminhtml/default/default/template/payment/form/ccsave.phtml
index 4743781..19de2a7 100644
--- a/app/design/adminhtml/default/default/template/payment/form/ccsave.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/ccsave.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/form/checkmo.phtml b/app/design/adminhtml/default/default/template/payment/form/checkmo.phtml
index 2ce1ce1..6a3b2d0 100644
--- a/app/design/adminhtml/default/default/template/payment/form/checkmo.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/checkmo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/form/purchaseorder.phtml b/app/design/adminhtml/default/default/template/payment/form/purchaseorder.phtml
index 1acc0c8..8e13211 100644
--- a/app/design/adminhtml/default/default/template/payment/form/purchaseorder.phtml
+++ b/app/design/adminhtml/default/default/template/payment/form/purchaseorder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/banktransfer.phtml b/app/design/adminhtml/default/default/template/payment/info/banktransfer.phtml
index 4f33c82..12f493e 100644
--- a/app/design/adminhtml/default/default/template/payment/info/banktransfer.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/banktransfer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/checkmo.phtml b/app/design/adminhtml/default/default/template/payment/info/checkmo.phtml
index a158f4a..be40c9a 100644
--- a/app/design/adminhtml/default/default/template/payment/info/checkmo.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/checkmo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/default.phtml b/app/design/adminhtml/default/default/template/payment/info/default.phtml
index dc6ebc8..63ef633 100644
--- a/app/design/adminhtml/default/default/template/payment/info/default.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/pdf/checkmo.phtml b/app/design/adminhtml/default/default/template/payment/info/pdf/checkmo.phtml
index 99500ed..5e612c8 100644
--- a/app/design/adminhtml/default/default/template/payment/info/pdf/checkmo.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/pdf/checkmo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/pdf/default.phtml b/app/design/adminhtml/default/default/template/payment/info/pdf/default.phtml
index bd85269..c56b8c3 100644
--- a/app/design/adminhtml/default/default/template/payment/info/pdf/default.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/pdf/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/pdf/purchaseorder.phtml b/app/design/adminhtml/default/default/template/payment/info/pdf/purchaseorder.phtml
index a73b5aa..570ad1c 100644
--- a/app/design/adminhtml/default/default/template/payment/info/pdf/purchaseorder.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/pdf/purchaseorder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/payment/info/purchaseorder.phtml b/app/design/adminhtml/default/default/template/payment/info/purchaseorder.phtml
index 342cc39..334ad0e 100644
--- a/app/design/adminhtml/default/default/template/payment/info/purchaseorder.phtml
+++ b/app/design/adminhtml/default/default/template/payment/info/purchaseorder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/api_wizard.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/api_wizard.phtml
index 67cc767..189abc4 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/api_wizard.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/api_wizard.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/bml_api_wizard.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/bml_api_wizard.phtml
index 4ebeb52..ea60094 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/bml_api_wizard.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/bml_api_wizard.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/global.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/global.phtml
index f55c688..d4e1135 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/global.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/global.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/hint.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/hint.phtml
index 0b84df7..797ac68 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/hint.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/hint.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/store.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/store.phtml
index 71df239..a3f646d 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/store.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/fieldset/store.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/advanced.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/advanced.phtml
index 27e78c7..a2ec82c 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/advanced.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/advanced.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/info.phtml b/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/info.phtml
index b02fdf2..4047c21 100644
--- a/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/info.phtml
+++ b/app/design/adminhtml/default/default/template/paypal/system/config/payflowlink/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/role_users_grid_js.phtml b/app/design/adminhtml/default/default/template/permissions/role_users_grid_js.phtml
index 83e9f69..08fc533 100644
--- a/app/design/adminhtml/default/default/template/permissions/role_users_grid_js.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/role_users_grid_js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/roleinfo.phtml b/app/design/adminhtml/default/default/template/permissions/roleinfo.phtml
index dba7ae3..8581d74 100644
--- a/app/design/adminhtml/default/default/template/permissions/roleinfo.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/roleinfo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/roles.phtml b/app/design/adminhtml/default/default/template/permissions/roles.phtml
index acda080..15b2810 100644
--- a/app/design/adminhtml/default/default/template/permissions/roles.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/roles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/rolesedit.phtml b/app/design/adminhtml/default/default/template/permissions/rolesedit.phtml
index ee31ce4..25c461a 100644
--- a/app/design/adminhtml/default/default/template/permissions/rolesedit.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/rolesedit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/rolesusers.phtml b/app/design/adminhtml/default/default/template/permissions/rolesusers.phtml
index 886db70..a3e87f1 100644
--- a/app/design/adminhtml/default/default/template/permissions/rolesusers.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/rolesusers.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/user_roles_grid_js.phtml b/app/design/adminhtml/default/default/template/permissions/user_roles_grid_js.phtml
index acb2ace..a25af4d 100644
--- a/app/design/adminhtml/default/default/template/permissions/user_roles_grid_js.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/user_roles_grid_js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/userinfo.phtml b/app/design/adminhtml/default/default/template/permissions/userinfo.phtml
index 874e308..a06c3ac 100644
--- a/app/design/adminhtml/default/default/template/permissions/userinfo.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/userinfo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/usernroles.phtml b/app/design/adminhtml/default/default/template/permissions/usernroles.phtml
index 6ac9b78..43482cb 100644
--- a/app/design/adminhtml/default/default/template/permissions/usernroles.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/usernroles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/userroles.phtml b/app/design/adminhtml/default/default/template/permissions/userroles.phtml
index 844caac..c2c5891 100644
--- a/app/design/adminhtml/default/default/template/permissions/userroles.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/userroles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/permissions/users.phtml b/app/design/adminhtml/default/default/template/permissions/users.phtml
index f8e9c14..e81bef6 100644
--- a/app/design/adminhtml/default/default/template/permissions/users.phtml
+++ b/app/design/adminhtml/default/default/template/permissions/users.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/poll/answers/list.phtml b/app/design/adminhtml/default/default/template/poll/answers/list.phtml
index d82b38d..aab4a7a 100644
--- a/app/design/adminhtml/default/default/template/poll/answers/list.phtml
+++ b/app/design/adminhtml/default/default/template/poll/answers/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/popup.phtml b/app/design/adminhtml/default/default/template/popup.phtml
index e340690..7644af5 100644
--- a/app/design/adminhtml/default/default/template/popup.phtml
+++ b/app/design/adminhtml/default/default/template/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/promo/fieldset.phtml b/app/design/adminhtml/default/default/template/promo/fieldset.phtml
index 9172841..105abca 100644
--- a/app/design/adminhtml/default/default/template/promo/fieldset.phtml
+++ b/app/design/adminhtml/default/default/template/promo/fieldset.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/promo/form.phtml b/app/design/adminhtml/default/default/template/promo/form.phtml
index e7c75b8..d7935ed 100644
--- a/app/design/adminhtml/default/default/template/promo/form.phtml
+++ b/app/design/adminhtml/default/default/template/promo/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/promo/js.phtml b/app/design/adminhtml/default/default/template/promo/js.phtml
index 3f25845..afe925a 100644
--- a/app/design/adminhtml/default/default/template/promo/js.phtml
+++ b/app/design/adminhtml/default/default/template/promo/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/promo/salesrulejs.phtml b/app/design/adminhtml/default/default/template/promo/salesrulejs.phtml
index 6777827..51ba1cf 100644
--- a/app/design/adminhtml/default/default/template/promo/salesrulejs.phtml
+++ b/app/design/adminhtml/default/default/template/promo/salesrulejs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/rating/detailed.phtml b/app/design/adminhtml/default/default/template/rating/detailed.phtml
index 2336662..652658c 100644
--- a/app/design/adminhtml/default/default/template/rating/detailed.phtml
+++ b/app/design/adminhtml/default/default/template/rating/detailed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/rating/options.phtml b/app/design/adminhtml/default/default/template/rating/options.phtml
index acda652..3a96faf 100644
--- a/app/design/adminhtml/default/default/template/rating/options.phtml
+++ b/app/design/adminhtml/default/default/template/rating/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/rating/stars/detailed.phtml b/app/design/adminhtml/default/default/template/rating/stars/detailed.phtml
index 6b2ec65..9e19dcc 100644
--- a/app/design/adminhtml/default/default/template/rating/stars/detailed.phtml
+++ b/app/design/adminhtml/default/default/template/rating/stars/detailed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/rating/stars/summary.phtml b/app/design/adminhtml/default/default/template/rating/stars/summary.phtml
index 4843a1d..2cc6d27 100644
--- a/app/design/adminhtml/default/default/template/rating/stars/summary.phtml
+++ b/app/design/adminhtml/default/default/template/rating/stars/summary.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/grid.phtml b/app/design/adminhtml/default/default/template/report/grid.phtml
index 062581f..53d85be 100644
--- a/app/design/adminhtml/default/default/template/report/grid.phtml
+++ b/app/design/adminhtml/default/default/template/report/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/grid/container.phtml b/app/design/adminhtml/default/default/template/report/grid/container.phtml
index 0952342..1536469 100644
--- a/app/design/adminhtml/default/default/template/report/grid/container.phtml
+++ b/app/design/adminhtml/default/default/template/report/grid/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/refresh/statistics.phtml b/app/design/adminhtml/default/default/template/report/refresh/statistics.phtml
index 54587cd..ab8fee1 100644
--- a/app/design/adminhtml/default/default/template/report/refresh/statistics.phtml
+++ b/app/design/adminhtml/default/default/template/report/refresh/statistics.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/store/switcher.phtml b/app/design/adminhtml/default/default/template/report/store/switcher.phtml
index 494420c..1040282 100644
--- a/app/design/adminhtml/default/default/template/report/store/switcher.phtml
+++ b/app/design/adminhtml/default/default/template/report/store/switcher.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/store/switcher/enhanced.phtml b/app/design/adminhtml/default/default/template/report/store/switcher/enhanced.phtml
index 08920aa..fdd02a8 100644
--- a/app/design/adminhtml/default/default/template/report/store/switcher/enhanced.phtml
+++ b/app/design/adminhtml/default/default/template/report/store/switcher/enhanced.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/report/wishlist.phtml b/app/design/adminhtml/default/default/template/report/wishlist.phtml
index fee2dc2..826f4ae 100644
--- a/app/design/adminhtml/default/default/template/report/wishlist.phtml
+++ b/app/design/adminhtml/default/default/template/report/wishlist.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/resetforgottenpassword.phtml b/app/design/adminhtml/default/default/template/resetforgottenpassword.phtml
index 75af779..8f0bbb4 100644
--- a/app/design/adminhtml/default/default/template/resetforgottenpassword.phtml
+++ b/app/design/adminhtml/default/default/template/resetforgottenpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/review/add.phtml b/app/design/adminhtml/default/default/template/review/add.phtml
index bcde410..f2fbf1f 100644
--- a/app/design/adminhtml/default/default/template/review/add.phtml
+++ b/app/design/adminhtml/default/default/template/review/add.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/billing/agreement/form.phtml b/app/design/adminhtml/default/default/template/sales/billing/agreement/form.phtml
index 560a7e3..084293a 100644
--- a/app/design/adminhtml/default/default/template/sales/billing/agreement/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/billing/agreement/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/billing/agreement/view/form.phtml b/app/design/adminhtml/default/default/template/sales/billing/agreement/view/form.phtml
index 6896f77..35e7cd2 100644
--- a/app/design/adminhtml/default/default/template/sales/billing/agreement/view/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/billing/agreement/view/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/billing/agreement/view/tab/info.phtml b/app/design/adminhtml/default/default/template/sales/billing/agreement/view/tab/info.phtml
index ef15f0e..3ad606d 100644
--- a/app/design/adminhtml/default/default/template/sales/billing/agreement/view/tab/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/billing/agreement/view/tab/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/items/column/name.phtml b/app/design/adminhtml/default/default/template/sales/items/column/name.phtml
index 49c7361..f2270bf 100644
--- a/app/design/adminhtml/default/default/template/sales/items/column/name.phtml
+++ b/app/design/adminhtml/default/default/template/sales/items/column/name.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/items/column/qty.phtml b/app/design/adminhtml/default/default/template/sales/items/column/qty.phtml
index 9478617..09680d6 100644
--- a/app/design/adminhtml/default/default/template/sales/items/column/qty.phtml
+++ b/app/design/adminhtml/default/default/template/sales/items/column/qty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/items/renderer/default.phtml
index 9849bb6..f51d2a1 100644
--- a/app/design/adminhtml/default/default/template/sales/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/address/form.phtml b/app/design/adminhtml/default/default/template/sales/order/address/form.phtml
index 45bd5f6..f93335a 100644
--- a/app/design/adminhtml/default/default/template/sales/order/address/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/address/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/comments/view.phtml b/app/design/adminhtml/default/default/template/sales/order/comments/view.phtml
index 12b572a..eeba910 100644
--- a/app/design/adminhtml/default/default/template/sales/order/comments/view.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/comments/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/abstract.phtml b/app/design/adminhtml/default/default/template/sales/order/create/abstract.phtml
index c933653..98f7f7d 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/abstract.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/abstract.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/billing/method/form.phtml b/app/design/adminhtml/default/default/template/sales/order/create/billing/method/form.phtml
index 6360f48..d2f53b5 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/billing/method/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/billing/method/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/comment.phtml b/app/design/adminhtml/default/default/template/sales/order/create/comment.phtml
index 94b3337..3ab99d9 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/comment.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/comment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/coupons/form.phtml b/app/design/adminhtml/default/default/template/sales/order/create/coupons/form.phtml
index c7163bd..db9e3cf 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/coupons/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/coupons/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/data.phtml b/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
index ba48199..82f8a66 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/form.phtml b/app/design/adminhtml/default/default/template/sales/order/create/form.phtml
index 3771c84..dfb6cbc 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/form/account.phtml b/app/design/adminhtml/default/default/template/sales/order/create/form/account.phtml
index 8fc1e42..ba94fd8 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/form/account.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/form/account.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/form/address.phtml b/app/design/adminhtml/default/default/template/sales/order/create/form/address.phtml
index aa9bb60..f51831d 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/form/address.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/form/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 if($this->getIsShipping()):
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/giftmessage.phtml b/app/design/adminhtml/default/default/template/sales/order/create/giftmessage.phtml
index 0283892..ece3f69 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/giftmessage.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/giftmessage.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/items.phtml b/app/design/adminhtml/default/default/template/sales/order/create/items.phtml
index ca72c33..bde2b8f 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/items/grid.phtml b/app/design/adminhtml/default/default/template/sales/order/create/items/grid.phtml
index ae84020..5b88e93 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/items/grid.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/items/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/js.phtml b/app/design/adminhtml/default/default/template/sales/order/create/js.phtml
index 54df1a0..c5ec60b 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/js.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/newsletter/form.phtml b/app/design/adminhtml/default/default/template/sales/order/create/newsletter/form.phtml
index 0dff829..41d06e3 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/newsletter/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/newsletter/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/shipping/method/form.phtml b/app/design/adminhtml/default/default/template/sales/order/create/shipping/method/form.phtml
index 98fc39b..653c66e 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/shipping/method/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/shipping/method/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/sidebar.phtml b/app/design/adminhtml/default/default/template/sales/order/create/sidebar.phtml
index 2870d98..d363ea7 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/sidebar.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/sidebar/items.phtml b/app/design/adminhtml/default/default/template/sales/order/create/sidebar/items.phtml
index aefdab3..11082b5 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/sidebar/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/sidebar/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/store/select.phtml b/app/design/adminhtml/default/default/template/sales/order/create/store/select.phtml
index 72dc430..1f0a92e 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/store/select.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/store/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals.phtml
index 835000a..ef4b01b 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals/default.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals/default.phtml
index 9fce1e1..6c3dd60 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals/grandtotal.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals/grandtotal.phtml
index 913cec8..fd29b5d 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals/grandtotal.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals/grandtotal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals/shipping.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals/shipping.phtml
index 6500b79..beda420 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals/shipping.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals/subtotal.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals/subtotal.phtml
index 5203554..a65dde2 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals/subtotal.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals/subtotal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/totals/tax.phtml b/app/design/adminhtml/default/default/template/sales/order/create/totals/tax.phtml
index dd1761d..47fdbb3 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/totals/tax.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/totals/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/form.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/form.phtml
index 4151bc6..958c4d0 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items.phtml
index b265f22..0c0933b 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/configurable.phtml
index 43a265c..913d76e 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/default.phtml
index 7e6393e..85ad92c 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/totals/adjustments.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/totals/adjustments.phtml
index 386bd49..a7fda7e 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/totals/adjustments.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/create/totals/adjustments.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/form.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/form.phtml
index 536409a..69195b6 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items.phtml
index 1fe9104..6aea8e1 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/configurable.phtml
index 9f6025b..1e3a34f 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/default.phtml
index f07d22c..6781f5c 100644
--- a/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/creditmemo/view/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/giftoptions.phtml b/app/design/adminhtml/default/default/template/sales/order/giftoptions.phtml
index 820b66d..49dcac4 100644
--- a/app/design/adminhtml/default/default/template/sales/order/giftoptions.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/giftoptions.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/create/form.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/create/form.phtml
index 42e99c6..9d59590 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/create/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/create/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items.phtml
index 96c465e..4951dc8 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/configurable.phtml
index 4e23c4a..1c7d9a4 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/default.phtml
index 54b0822..d15cc30 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/create/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/create/tracking.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/create/tracking.phtml
index 140f966..18cab34 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/create/tracking.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/create/tracking.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/view/form.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/view/form.phtml
index bc13798..fddce20 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/view/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/view/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items.phtml
index f024efa..9134681 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/configurable.phtml
index 2174212..485c253 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/default.phtml
index 666896f..81bf260 100644
--- a/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/invoice/view/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/create/form.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/create/form.phtml
index 9b341d2..d854e2f 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/create/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/create/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items.phtml
index bba2628..c2646bb 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/configurable.phtml
index 359227e..8c8ea46 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/default.phtml
index a9f26ea..3e7b404 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/create/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/create/tracking.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/create/tracking.phtml
index 268e455..904aba6 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/create/tracking.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/create/tracking.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/grid.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/grid.phtml
index 82405ca..7993ef1 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/grid.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/packed.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/packed.phtml
index 4e3a3a5..48c2e93 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/packed.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/packed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/popup.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/popup.phtml
index be037d0..7dbc82a 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/popup.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/packaging/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/tracking/info.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/tracking/info.phtml
index f5a2340..5da5fb4 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/tracking/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/tracking/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/view/form.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/view/form.phtml
index 2c0b5e0..05f0713 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/view/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/view/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items.phtml
index 06c4214..eb99aeb 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/configurable.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/configurable.phtml
index 9efe0e2..e60d1f3 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/default.phtml
index b275341..e668fd6 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/view/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/shipment/view/tracking.phtml b/app/design/adminhtml/default/default/template/sales/order/shipment/view/tracking.phtml
index 9c62b1d..93483f5 100644
--- a/app/design/adminhtml/default/default/template/sales/order/shipment/view/tracking.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/shipment/view/tracking.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totalbar.phtml b/app/design/adminhtml/default/default/template/sales/order/totalbar.phtml
index 83bf0b9..216e6e4 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totalbar.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totalbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals.phtml b/app/design/adminhtml/default/default/template/sales/order/totals.phtml
index 355f5c9..95830e8 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/discount.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/discount.phtml
index 410c00d..d8e9734 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/discount.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/discount.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/due.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/due.phtml
index a976f06..53f5d42 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/due.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/due.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/footer.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/footer.phtml
index 96d5853..5dc06ef 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/footer.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/grand.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/grand.phtml
index 54dddbc..13329c5 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/grand.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/grand.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/item.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/item.phtml
index d7d594b..a91d7a1 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/item.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/main.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/main.phtml
index 2a7f94b..e01cfa7 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/main.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/main.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/paid.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/paid.phtml
index 88dbd3e..1552199 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/paid.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/paid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/refunded.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/refunded.phtml
index 71c4b66..7c84745 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/refunded.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/refunded.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/shipping.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/shipping.phtml
index bdbc2c8..6eae45e 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/shipping.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/subtotal.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/subtotal.phtml
index 40d3b1e..d40cdc1 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/subtotal.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/subtotal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/totals/tax.phtml b/app/design/adminhtml/default/default/template/sales/order/totals/tax.phtml
index c2c6d18..a570ff0 100644
--- a/app/design/adminhtml/default/default/template/sales/order/totals/tax.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/totals/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Adminhtml_Block_Sales_Order_Totals_Tax */
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/form.phtml b/app/design/adminhtml/default/default/template/sales/order/view/form.phtml
index dd85a0a..1992ea2 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/form.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/giftmessage.phtml b/app/design/adminhtml/default/default/template/sales/order/view/giftmessage.phtml
index 2f65c55..45660f0 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/giftmessage.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/giftmessage.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/history.phtml b/app/design/adminhtml/default/default/template/sales/order/view/history.phtml
index 48b834f..555d8fc 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/history.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/history.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/info.phtml b/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
index a5b04c3..dcf7d6a 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/items.phtml b/app/design/adminhtml/default/default/template/sales/order/view/items.phtml
index 3789776..1a042ad 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/items.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/items/renderer/default.phtml b/app/design/adminhtml/default/default/template/sales/order/view/items/renderer/default.phtml
index dd3fc62..1b0ad4f 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/items/renderer/default.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/tab/history.phtml b/app/design/adminhtml/default/default/template/sales/order/view/tab/history.phtml
index 2b952ec..6755e65 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/tab/history.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/tab/history.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/tab/info.phtml b/app/design/adminhtml/default/default/template/sales/order/view/tab/info.phtml
index 3f12001..441ca89 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/tab/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/tab/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/tracking.phtml b/app/design/adminhtml/default/default/template/sales/order/view/tracking.phtml
index 4f7795c..722e80f 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/tracking.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/tracking.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/payment/form/billing/agreement.phtml b/app/design/adminhtml/default/default/template/sales/payment/form/billing/agreement.phtml
index 2790beb..5b0747b 100644
--- a/app/design/adminhtml/default/default/template/sales/payment/form/billing/agreement.phtml
+++ b/app/design/adminhtml/default/default/template/sales/payment/form/billing/agreement.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/recurring/profile/view.phtml b/app/design/adminhtml/default/default/template/sales/recurring/profile/view.phtml
index bd9628a..3605529 100644
--- a/app/design/adminhtml/default/default/template/sales/recurring/profile/view.phtml
+++ b/app/design/adminhtml/default/default/template/sales/recurring/profile/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/recurring/profile/view/info.phtml b/app/design/adminhtml/default/default/template/sales/recurring/profile/view/info.phtml
index c56ecf7..0ab1904 100644
--- a/app/design/adminhtml/default/default/template/sales/recurring/profile/view/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/recurring/profile/view/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/sales/transactions/detail.phtml b/app/design/adminhtml/default/default/template/sales/transactions/detail.phtml
index 694b61e..5b29583 100644
--- a/app/design/adminhtml/default/default/template/sales/transactions/detail.phtml
+++ b/app/design/adminhtml/default/default/template/sales/transactions/detail.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/store/switcher.phtml b/app/design/adminhtml/default/default/template/store/switcher.phtml
index 8e87d47..197825e 100644
--- a/app/design/adminhtml/default/default/template/store/switcher.phtml
+++ b/app/design/adminhtml/default/default/template/store/switcher.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/store/switcher/enhanced.phtml b/app/design/adminhtml/default/default/template/store/switcher/enhanced.phtml
index aee1f1d..dee2442 100644
--- a/app/design/adminhtml/default/default/template/store/switcher/enhanced.phtml
+++ b/app/design/adminhtml/default/default/template/store/switcher/enhanced.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset.phtml b/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset.phtml
index 24c62c3..e26b1e6 100644
--- a/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset.phtml
+++ b/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset/element.phtml b/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset/element.phtml
index 9456636..d3dd058 100644
--- a/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset/element.phtml
+++ b/app/design/adminhtml/default/default/template/store/switcher/form/renderer/fieldset/element.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/autocomplete.phtml b/app/design/adminhtml/default/default/template/system/autocomplete.phtml
index 7f51358..63e22c9 100644
--- a/app/design/adminhtml/default/default/template/system/autocomplete.phtml
+++ b/app/design/adminhtml/default/default/template/system/autocomplete.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/cache/additional.phtml b/app/design/adminhtml/default/default/template/system/cache/additional.phtml
index 0f9ba4d..b70719e 100644
--- a/app/design/adminhtml/default/default/template/system/cache/additional.phtml
+++ b/app/design/adminhtml/default/default/template/system/cache/additional.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/cache/edit.phtml b/app/design/adminhtml/default/default/template/system/cache/edit.phtml
index 8cf83c6..951bf64 100644
--- a/app/design/adminhtml/default/default/template/system/cache/edit.phtml
+++ b/app/design/adminhtml/default/default/template/system/cache/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/cache/notifications.phtml b/app/design/adminhtml/default/default/template/system/cache/notifications.phtml
index f4def4b..d816889 100644
--- a/app/design/adminhtml/default/default/template/system/cache/notifications.phtml
+++ b/app/design/adminhtml/default/default/template/system/cache/notifications.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/edit.phtml b/app/design/adminhtml/default/default/template/system/config/edit.phtml
index 18e2fb0..09891a8 100644
--- a/app/design/adminhtml/default/default/template/system/config/edit.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/form/field/array.phtml b/app/design/adminhtml/default/default/template/system/config/form/field/array.phtml
index 69e2db6..081e0a4 100644
--- a/app/design/adminhtml/default/default/template/system/config/form/field/array.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/form/field/array.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/js.phtml b/app/design/adminhtml/default/default/template/system/config/js.phtml
index ff3f1dc..dc45a46 100644
--- a/app/design/adminhtml/default/default/template/system/config/js.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/switcher.phtml b/app/design/adminhtml/default/default/template/system/config/switcher.phtml
index f6fcdaa..9678e25 100644
--- a/app/design/adminhtml/default/default/template/system/config/switcher.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/switcher.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Core_Block_Template */ ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/system/storage/media/synchronize.phtml b/app/design/adminhtml/default/default/template/system/config/system/storage/media/synchronize.phtml
index b8a56ea..4f41dd3 100644
--- a/app/design/adminhtml/default/default/template/system/config/system/storage/media/synchronize.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/system/storage/media/synchronize.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/config/tabs.phtml b/app/design/adminhtml/default/default/template/system/config/tabs.phtml
index 68e74a6..1f72749 100644
--- a/app/design/adminhtml/default/default/template/system/config/tabs.phtml
+++ b/app/design/adminhtml/default/default/template/system/config/tabs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/convert/profile/process.phtml b/app/design/adminhtml/default/default/template/system/convert/profile/process.phtml
index b29f373..ddf7f8f 100644
--- a/app/design/adminhtml/default/default/template/system/convert/profile/process.phtml
+++ b/app/design/adminhtml/default/default/template/system/convert/profile/process.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/convert/profile/run.phtml b/app/design/adminhtml/default/default/template/system/convert/profile/run.phtml
index 07557de..5cd3ee1 100644
--- a/app/design/adminhtml/default/default/template/system/convert/profile/run.phtml
+++ b/app/design/adminhtml/default/default/template/system/convert/profile/run.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/convert/profile/upload.phtml b/app/design/adminhtml/default/default/template/system/convert/profile/upload.phtml
index a8e1d72..b54f961 100644
--- a/app/design/adminhtml/default/default/template/system/convert/profile/upload.phtml
+++ b/app/design/adminhtml/default/default/template/system/convert/profile/upload.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/convert/profile/wizard.phtml b/app/design/adminhtml/default/default/template/system/convert/profile/wizard.phtml
index 9f67ae4..38b070e 100644
--- a/app/design/adminhtml/default/default/template/system/convert/profile/wizard.phtml
+++ b/app/design/adminhtml/default/default/template/system/convert/profile/wizard.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml b/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
index 0dfd023..744e6ab 100644
--- a/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
+++ b/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/currency/rate/services.phtml b/app/design/adminhtml/default/default/template/system/currency/rate/services.phtml
index 8001fe1..0b5c8ce 100644
--- a/app/design/adminhtml/default/default/template/system/currency/rate/services.phtml
+++ b/app/design/adminhtml/default/default/template/system/currency/rate/services.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/currency/rates.phtml b/app/design/adminhtml/default/default/template/system/currency/rates.phtml
index e91ceb9..d800d62 100644
--- a/app/design/adminhtml/default/default/template/system/currency/rates.phtml
+++ b/app/design/adminhtml/default/default/template/system/currency/rates.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/design/edit.phtml b/app/design/adminhtml/default/default/template/system/design/edit.phtml
index 9f06a16..61625c6 100644
--- a/app/design/adminhtml/default/default/template/system/design/edit.phtml
+++ b/app/design/adminhtml/default/default/template/system/design/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/design/index.phtml b/app/design/adminhtml/default/default/template/system/design/index.phtml
index 030343a..fdcdcaa 100644
--- a/app/design/adminhtml/default/default/template/system/design/index.phtml
+++ b/app/design/adminhtml/default/default/template/system/design/index.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/email/template/edit.phtml b/app/design/adminhtml/default/default/template/system/email/template/edit.phtml
index 510d454..2295297 100644
--- a/app/design/adminhtml/default/default/template/system/email/template/edit.phtml
+++ b/app/design/adminhtml/default/default/template/system/email/template/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/email/template/list.phtml b/app/design/adminhtml/default/default/template/system/email/template/list.phtml
index 9e6d5ac..23f1f1b 100644
--- a/app/design/adminhtml/default/default/template/system/email/template/list.phtml
+++ b/app/design/adminhtml/default/default/template/system/email/template/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/email/template/preview.phtml b/app/design/adminhtml/default/default/template/system/email/template/preview.phtml
index 7a75f87..2692dac 100644
--- a/app/design/adminhtml/default/default/template/system/email/template/preview.phtml
+++ b/app/design/adminhtml/default/default/template/system/email/template/preview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/info.phtml b/app/design/adminhtml/default/default/template/system/info.phtml
index 49e8943..fa541e7a 100644
--- a/app/design/adminhtml/default/default/template/system/info.phtml
+++ b/app/design/adminhtml/default/default/template/system/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/shipping/applicable_country.phtml b/app/design/adminhtml/default/default/template/system/shipping/applicable_country.phtml
index 7c19998..11b6ad9 100644
--- a/app/design/adminhtml/default/default/template/system/shipping/applicable_country.phtml
+++ b/app/design/adminhtml/default/default/template/system/shipping/applicable_country.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/shipping/ups.phtml b/app/design/adminhtml/default/default/template/system/shipping/ups.phtml
index e9a6203..afc2f9d 100644
--- a/app/design/adminhtml/default/default/template/system/shipping/ups.phtml
+++ b/app/design/adminhtml/default/default/template/system/shipping/ups.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/system/store/cell.phtml b/app/design/adminhtml/default/default/template/system/store/cell.phtml
index 59d6ae8..2c2a325 100644
--- a/app/design/adminhtml/default/default/template/system/store/cell.phtml
+++ b/app/design/adminhtml/default/default/template/system/store/cell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 $object = $this->getObject();
diff --git a/app/design/adminhtml/default/default/template/system/store/container.phtml b/app/design/adminhtml/default/default/template/system/store/container.phtml
index 05b96de..5b6983c 100644
--- a/app/design/adminhtml/default/default/template/system/store/container.phtml
+++ b/app/design/adminhtml/default/default/template/system/store/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/store/tree.phtml b/app/design/adminhtml/default/default/template/system/store/tree.phtml
index e3a389c..681158e 100644
--- a/app/design/adminhtml/default/default/template/system/store/tree.phtml
+++ b/app/design/adminhtml/default/default/template/system/store/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/system/variable/js.phtml b/app/design/adminhtml/default/default/template/system/variable/js.phtml
index 85543f6..0d3c6c3 100644
--- a/app/design/adminhtml/default/default/template/system/variable/js.phtml
+++ b/app/design/adminhtml/default/default/template/system/variable/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tag/edit/container.phtml b/app/design/adminhtml/default/default/template/tag/edit/container.phtml
index a1617c2..6611bd9 100644
--- a/app/design/adminhtml/default/default/template/tag/edit/container.phtml
+++ b/app/design/adminhtml/default/default/template/tag/edit/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tag/index.phtml b/app/design/adminhtml/default/default/template/tag/index.phtml
index ab25141..a5af5f9 100644
--- a/app/design/adminhtml/default/default/template/tag/index.phtml
+++ b/app/design/adminhtml/default/default/template/tag/index.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/class/page/edit.phtml b/app/design/adminhtml/default/default/template/tax/class/page/edit.phtml
index f8b22f7..20e21fe 100644
--- a/app/design/adminhtml/default/default/template/tax/class/page/edit.phtml
+++ b/app/design/adminhtml/default/default/template/tax/class/page/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/importExport.phtml b/app/design/adminhtml/default/default/template/tax/importExport.phtml
index 9380836..98539ba 100644
--- a/app/design/adminhtml/default/default/template/tax/importExport.phtml
+++ b/app/design/adminhtml/default/default/template/tax/importExport.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/notifications.phtml b/app/design/adminhtml/default/default/template/tax/notifications.phtml
index e11ed88..5044c7e 100644
--- a/app/design/adminhtml/default/default/template/tax/notifications.phtml
+++ b/app/design/adminhtml/default/default/template/tax/notifications.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Tax_Block_Adminhtml_Notifications */
diff --git a/app/design/adminhtml/default/default/template/tax/rate/form.phtml b/app/design/adminhtml/default/default/template/tax/rate/form.phtml
index 5da025e..f19330e 100644
--- a/app/design/adminhtml/default/default/template/tax/rate/form.phtml
+++ b/app/design/adminhtml/default/default/template/tax/rate/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/rate/title.phtml b/app/design/adminhtml/default/default/template/tax/rate/title.phtml
index 6bde11c..61dde10 100644
--- a/app/design/adminhtml/default/default/template/tax/rate/title.phtml
+++ b/app/design/adminhtml/default/default/template/tax/rate/title.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/class/add.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/class/add.phtml
index dbdae86..62882c6 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/class/add.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/class/add.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/class/save.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/class/save.phtml
index 2585a37..ba24ead 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/class/save.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/class/save.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/rate/add.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/rate/add.phtml
index 01affe4..41d5e30 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/rate/add.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/rate/add.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/rate/save.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/rate/save.phtml
index e937f4b..29c3574 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/rate/save.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/rate/save.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/rule/add.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/rule/add.phtml
index 10835d2..57f4672 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/rule/add.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/rule/add.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/tax/toolbar/rule/save.phtml b/app/design/adminhtml/default/default/template/tax/toolbar/rule/save.phtml
index 1738eb2..0e4596b 100644
--- a/app/design/adminhtml/default/default/template/tax/toolbar/rule/save.phtml
+++ b/app/design/adminhtml/default/default/template/tax/toolbar/rule/save.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/urlrewrite/categories.phtml b/app/design/adminhtml/default/default/template/urlrewrite/categories.phtml
index 52470b2..52de2de 100644
--- a/app/design/adminhtml/default/default/template/urlrewrite/categories.phtml
+++ b/app/design/adminhtml/default/default/template/urlrewrite/categories.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/urlrewrite/edit.phtml b/app/design/adminhtml/default/default/template/urlrewrite/edit.phtml
index 3797db6..6a81b7b 100644
--- a/app/design/adminhtml/default/default/template/urlrewrite/edit.phtml
+++ b/app/design/adminhtml/default/default/template/urlrewrite/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/urlrewrite/selector.phtml b/app/design/adminhtml/default/default/template/urlrewrite/selector.phtml
index 1e6ab04..9a3401b 100644
--- a/app/design/adminhtml/default/default/template/urlrewrite/selector.phtml
+++ b/app/design/adminhtml/default/default/template/urlrewrite/selector.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/adminhtml/default/default/template/usa/dhl/unitofmeasure.phtml b/app/design/adminhtml/default/default/template/usa/dhl/unitofmeasure.phtml
index d81a2d1..32f472f 100644
--- a/app/design/adminhtml/default/default/template/usa/dhl/unitofmeasure.phtml
+++ b/app/design/adminhtml/default/default/template/usa/dhl/unitofmeasure.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/weee/renderer/tax.phtml b/app/design/adminhtml/default/default/template/weee/renderer/tax.phtml
index 09bd359..d6b360c 100644
--- a/app/design/adminhtml/default/default/template/weee/renderer/tax.phtml
+++ b/app/design/adminhtml/default/default/template/weee/renderer/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/accordion.phtml b/app/design/adminhtml/default/default/template/widget/accordion.phtml
index 1b1d11a..ef5059e 100644
--- a/app/design/adminhtml/default/default/template/widget/accordion.phtml
+++ b/app/design/adminhtml/default/default/template/widget/accordion.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/breadcrumbs.phtml b/app/design/adminhtml/default/default/template/widget/breadcrumbs.phtml
index 3ad9230..e69436d 100644
--- a/app/design/adminhtml/default/default/template/widget/breadcrumbs.phtml
+++ b/app/design/adminhtml/default/default/template/widget/breadcrumbs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form.phtml b/app/design/adminhtml/default/default/template/widget/form.phtml
index 6ad1651..65a9056 100644
--- a/app/design/adminhtml/default/default/template/widget/form.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/container.phtml b/app/design/adminhtml/default/default/template/widget/form/container.phtml
index 376ca2a..a4042df 100644
--- a/app/design/adminhtml/default/default/template/widget/form/container.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/element.phtml b/app/design/adminhtml/default/default/template/widget/form/element.phtml
index b16d001..7f00741 100644
--- a/app/design/adminhtml/default/default/template/widget/form/element.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/element.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/element/gallery.phtml b/app/design/adminhtml/default/default/template/widget/form/element/gallery.phtml
index d8506c7..256e741 100644
--- a/app/design/adminhtml/default/default/template/widget/form/element/gallery.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/element/gallery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/renderer/element.phtml b/app/design/adminhtml/default/default/template/widget/form/renderer/element.phtml
index c79efb1..12222ce 100644
--- a/app/design/adminhtml/default/default/template/widget/form/renderer/element.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/renderer/element.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset.phtml b/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset.phtml
index 6d58280..389d2dc 100644
--- a/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset/element.phtml b/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset/element.phtml
index ea509ac..ccc6433 100644
--- a/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset/element.phtml
+++ b/app/design/adminhtml/default/default/template/widget/form/renderer/fieldset/element.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/grid.phtml b/app/design/adminhtml/default/default/template/widget/grid.phtml
index 5d7ae0c..d44daff 100644
--- a/app/design/adminhtml/default/default/template/widget/grid.phtml
+++ b/app/design/adminhtml/default/default/template/widget/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/grid/container.phtml b/app/design/adminhtml/default/default/template/widget/grid/container.phtml
index 05b96de..5b6983c 100644
--- a/app/design/adminhtml/default/default/template/widget/grid/container.phtml
+++ b/app/design/adminhtml/default/default/template/widget/grid/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/grid/massaction.phtml b/app/design/adminhtml/default/default/template/widget/grid/massaction.phtml
index 262a978..0a1b7f1 100644
--- a/app/design/adminhtml/default/default/template/widget/grid/massaction.phtml
+++ b/app/design/adminhtml/default/default/template/widget/grid/massaction.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/grid/serializer.phtml b/app/design/adminhtml/default/default/template/widget/grid/serializer.phtml
index 4512d0d..e16c664 100644
--- a/app/design/adminhtml/default/default/template/widget/grid/serializer.phtml
+++ b/app/design/adminhtml/default/default/template/widget/grid/serializer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/instance/edit/layout.phtml b/app/design/adminhtml/default/default/template/widget/instance/edit/layout.phtml
index f63eb6c..ad19a52 100644
--- a/app/design/adminhtml/default/default/template/widget/instance/edit/layout.phtml
+++ b/app/design/adminhtml/default/default/template/widget/instance/edit/layout.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/instance/js.phtml b/app/design/adminhtml/default/default/template/widget/instance/js.phtml
index ccb72ba..d0322d6 100644
--- a/app/design/adminhtml/default/default/template/widget/instance/js.phtml
+++ b/app/design/adminhtml/default/default/template/widget/instance/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/tabs.phtml b/app/design/adminhtml/default/default/template/widget/tabs.phtml
index 3edcb40..59cf757 100644
--- a/app/design/adminhtml/default/default/template/widget/tabs.phtml
+++ b/app/design/adminhtml/default/default/template/widget/tabs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/tabshoriz.phtml b/app/design/adminhtml/default/default/template/widget/tabshoriz.phtml
index 9ca465b..baa73b2 100644
--- a/app/design/adminhtml/default/default/template/widget/tabshoriz.phtml
+++ b/app/design/adminhtml/default/default/template/widget/tabshoriz.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/tabsleft.phtml b/app/design/adminhtml/default/default/template/widget/tabsleft.phtml
index ba88a48..58974ba 100644
--- a/app/design/adminhtml/default/default/template/widget/tabsleft.phtml
+++ b/app/design/adminhtml/default/default/template/widget/tabsleft.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/widget/view/container.phtml b/app/design/adminhtml/default/default/template/widget/view/container.phtml
index 4c7a87d..0dc0113 100644
--- a/app/design/adminhtml/default/default/template/widget/view/container.phtml
+++ b/app/design/adminhtml/default/default/template/widget/view/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/content.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/content.phtml
index edea361..5c513de 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/content.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/content.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design.phtml
index 2a4d885..13e4c94 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/autocomplete.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/autocomplete.phtml
index b1905f6..f6819b2 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/autocomplete.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/autocomplete.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/image_edit.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/image_edit.phtml
index 00010c8..f758f72 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/image_edit.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/image_edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_android.phtml
index 1a30824..0ab806b 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_ipad.phtml
index 03a2a82..5183032 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_iphone.phtml
index 0b70951..dbaccd2 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/images_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/banner_rotator.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/banner_rotator.phtml
index 97f71f8..4c6f8f2 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/banner_rotator.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/banner_rotator.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_android.phtml
index 0daadcd..1173de4 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_hor_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_hor_ipad.phtml
index 9348d33..9503144 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_hor_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_hor_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_ipad.phtml
index 1697e18..4362908 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_iphone.phtml
index 339eda2..4c322d3 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/catalog_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_android.phtml
index 6875dbf..d07aab3 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_hor_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_hor_ipad.phtml
index 12a7bf1..32dcd2e 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_hor_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_hor_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_ipad.phtml
index ab1793e..ee333ae 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_iphone.phtml
index ca87a33..8d718be 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/home_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/productinfo_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/productinfo_iphone.phtml
index f0912b1..439d37e 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/productinfo_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/productinfo_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_android.phtml
index a735c2a..7e0cc34 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_ipad.phtml
index 1d427c8..20d9e09 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_iphone.phtml
index 42c4893..281d22f 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview/tab_items_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_android.phtml
index d03d303..b978a7b 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_ipad.phtml
index a7bbe97..83dc062 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_iphone.phtml
index b1a424c..3edcd1d 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/design/preview_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/offlinecatalog.phtml b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/offlinecatalog.phtml
index 7605950..7ab3c9d 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/offlinecatalog.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/edit/tab/offlinecatalog.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/addrow.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/addrow.phtml
index 510ed0c..3ac138a 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/addrow.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/addrow.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_android.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_android.phtml
index 939a8e4..f9d5493 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_android.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_android.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_ipad.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_ipad.phtml
index 93e1f6d..46a2252 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_ipad.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_ipad.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_iphone.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_iphone.phtml
index d243e3b..4aa691b 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_iphone.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/app_tabs_iphone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/androidmarket.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/androidmarket.phtml
index b11d701..361d159 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/androidmarket.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/androidmarket.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/istore.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/istore.phtml
index d988bde..cf70f70 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/istore.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/country/istore.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/form/element/themes.phtml b/app/design/adminhtml/default/default/template/xmlconnect/form/element/themes.phtml
index 7b502a5..567d148 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/form/element/themes.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/form/element/themes.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/mobile/notification_helper.phtml b/app/design/adminhtml/default/default/template/xmlconnect/mobile/notification_helper.phtml
index 875154d..600c244 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/mobile/notification_helper.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/mobile/notification_helper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/submission/app_icons_preview.phtml b/app/design/adminhtml/default/default/template/xmlconnect/submission/app_icons_preview.phtml
index e248dfa..1cfc931 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/submission/app_icons_preview.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/submission/app_icons_preview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/submission/container.phtml b/app/design/adminhtml/default/default/template/xmlconnect/submission/container.phtml
index d1e79c6..d84cc88 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/submission/container.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/submission/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/adminhtml/default/default/template/xmlconnect/template/preview.phtml b/app/design/adminhtml/default/default/template/xmlconnect/template/preview.phtml
index f07de6a..e5ea529 100644
--- a/app/design/adminhtml/default/default/template/xmlconnect/template/preview.phtml
+++ b/app/design/adminhtml/default/default/template/xmlconnect/template/preview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/etc/theme.xml b/app/design/frontend/base/default/etc/theme.xml
index 25ee54b..c219554 100644
--- a/app/design/frontend/base/default/etc/theme.xml
+++ b/app/design/frontend/base/default/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/etc/widget.xml b/app/design/frontend/base/default/etc/widget.xml
index 78d974d..331c40b 100644
--- a/app/design/frontend/base/default/etc/widget.xml
+++ b/app/design/frontend/base/default/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/authorizenet.xml b/app/design/frontend/base/default/layout/authorizenet.xml
index fe880bb..8587101 100644
--- a/app/design/frontend/base/default/layout/authorizenet.xml
+++ b/app/design/frontend/base/default/layout/authorizenet.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/bml.xml b/app/design/frontend/base/default/layout/bml.xml
index 9edeb5c..e4a4745 100644
--- a/app/design/frontend/base/default/layout/bml.xml
+++ b/app/design/frontend/base/default/layout/bml.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/bundle.xml b/app/design/frontend/base/default/layout/bundle.xml
index c085963..a2907fa 100644
--- a/app/design/frontend/base/default/layout/bundle.xml
+++ b/app/design/frontend/base/default/layout/bundle.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/captcha.xml b/app/design/frontend/base/default/layout/captcha.xml
index 7c09b29..1b9e76b 100644
--- a/app/design/frontend/base/default/layout/captcha.xml
+++ b/app/design/frontend/base/default/layout/captcha.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/catalog.xml b/app/design/frontend/base/default/layout/catalog.xml
index 97c9ebd..d682f03 100644
--- a/app/design/frontend/base/default/layout/catalog.xml
+++ b/app/design/frontend/base/default/layout/catalog.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/catalog_msrp.xml b/app/design/frontend/base/default/layout/catalog_msrp.xml
index b48cbb5..88e53af 100644
--- a/app/design/frontend/base/default/layout/catalog_msrp.xml
+++ b/app/design/frontend/base/default/layout/catalog_msrp.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/cataloginventory.xml b/app/design/frontend/base/default/layout/cataloginventory.xml
index a9432f9..084ff4b 100644
--- a/app/design/frontend/base/default/layout/cataloginventory.xml
+++ b/app/design/frontend/base/default/layout/cataloginventory.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/catalogsearch.xml b/app/design/frontend/base/default/layout/catalogsearch.xml
index dd173c5..c2d8476 100644
--- a/app/design/frontend/base/default/layout/catalogsearch.xml
+++ b/app/design/frontend/base/default/layout/catalogsearch.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/centinel.xml b/app/design/frontend/base/default/layout/centinel.xml
index 89628ff..b80749d 100644
--- a/app/design/frontend/base/default/layout/centinel.xml
+++ b/app/design/frontend/base/default/layout/centinel.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/checkout.xml b/app/design/frontend/base/default/layout/checkout.xml
index 8921b08..942fa93 100644
--- a/app/design/frontend/base/default/layout/checkout.xml
+++ b/app/design/frontend/base/default/layout/checkout.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/cms.xml b/app/design/frontend/base/default/layout/cms.xml
index 6913654..a7d853b 100644
--- a/app/design/frontend/base/default/layout/cms.xml
+++ b/app/design/frontend/base/default/layout/cms.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/contacts.xml b/app/design/frontend/base/default/layout/contacts.xml
index fca0942..b564883 100644
--- a/app/design/frontend/base/default/layout/contacts.xml
+++ b/app/design/frontend/base/default/layout/contacts.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/core.xml b/app/design/frontend/base/default/layout/core.xml
index d94e9cc..58d98f2 100644
--- a/app/design/frontend/base/default/layout/core.xml
+++ b/app/design/frontend/base/default/layout/core.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/customer.xml b/app/design/frontend/base/default/layout/customer.xml
index 6ef7c39..b1e3754 100644
--- a/app/design/frontend/base/default/layout/customer.xml
+++ b/app/design/frontend/base/default/layout/customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/directory.xml b/app/design/frontend/base/default/layout/directory.xml
index de466e0..3ac86c1 100644
--- a/app/design/frontend/base/default/layout/directory.xml
+++ b/app/design/frontend/base/default/layout/directory.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/downloadable.xml b/app/design/frontend/base/default/layout/downloadable.xml
index 21e5553..745a020 100644
--- a/app/design/frontend/base/default/layout/downloadable.xml
+++ b/app/design/frontend/base/default/layout/downloadable.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/googleanalytics.xml b/app/design/frontend/base/default/layout/googleanalytics.xml
index 5ff634d..3d3bd4d 100644
--- a/app/design/frontend/base/default/layout/googleanalytics.xml
+++ b/app/design/frontend/base/default/layout/googleanalytics.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/moneybookers.xml b/app/design/frontend/base/default/layout/moneybookers.xml
index b5f044b..71bf939 100644
--- a/app/design/frontend/base/default/layout/moneybookers.xml
+++ b/app/design/frontend/base/default/layout/moneybookers.xml
@@ -15,7 +15,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/newsletter.xml b/app/design/frontend/base/default/layout/newsletter.xml
index ecf15ab..5914afa 100644
--- a/app/design/frontend/base/default/layout/newsletter.xml
+++ b/app/design/frontend/base/default/layout/newsletter.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/oauth.xml b/app/design/frontend/base/default/layout/oauth.xml
index cc948eb..e4d98ad 100644
--- a/app/design/frontend/base/default/layout/oauth.xml
+++ b/app/design/frontend/base/default/layout/oauth.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/page.xml b/app/design/frontend/base/default/layout/page.xml
index 735c067..fbc1a9d 100644
--- a/app/design/frontend/base/default/layout/page.xml
+++ b/app/design/frontend/base/default/layout/page.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/pagecache.xml b/app/design/frontend/base/default/layout/pagecache.xml
index dbaddb2..6975101 100644
--- a/app/design/frontend/base/default/layout/pagecache.xml
+++ b/app/design/frontend/base/default/layout/pagecache.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/payment.xml b/app/design/frontend/base/default/layout/payment.xml
index 3672ac4..63bc0f2 100644
--- a/app/design/frontend/base/default/layout/payment.xml
+++ b/app/design/frontend/base/default/layout/payment.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/paypal.xml b/app/design/frontend/base/default/layout/paypal.xml
index 50ded60..e96f26d 100644
--- a/app/design/frontend/base/default/layout/paypal.xml
+++ b/app/design/frontend/base/default/layout/paypal.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/paypaluk.xml b/app/design/frontend/base/default/layout/paypaluk.xml
index 637a320..91866ed 100644
--- a/app/design/frontend/base/default/layout/paypaluk.xml
+++ b/app/design/frontend/base/default/layout/paypaluk.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/persistent.xml b/app/design/frontend/base/default/layout/persistent.xml
index 54755b9..dc0087a 100644
--- a/app/design/frontend/base/default/layout/persistent.xml
+++ b/app/design/frontend/base/default/layout/persistent.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/poll.xml b/app/design/frontend/base/default/layout/poll.xml
index 4493287..02f3a2c 100644
--- a/app/design/frontend/base/default/layout/poll.xml
+++ b/app/design/frontend/base/default/layout/poll.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/productalert.xml b/app/design/frontend/base/default/layout/productalert.xml
index e1891ee..aeac50d 100644
--- a/app/design/frontend/base/default/layout/productalert.xml
+++ b/app/design/frontend/base/default/layout/productalert.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/reports.xml b/app/design/frontend/base/default/layout/reports.xml
index b6d6930..cd7f6e1 100644
--- a/app/design/frontend/base/default/layout/reports.xml
+++ b/app/design/frontend/base/default/layout/reports.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/review.xml b/app/design/frontend/base/default/layout/review.xml
index f7c4724..053612d 100644
--- a/app/design/frontend/base/default/layout/review.xml
+++ b/app/design/frontend/base/default/layout/review.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/rss.xml b/app/design/frontend/base/default/layout/rss.xml
index 95a8abe..9a51801 100644
--- a/app/design/frontend/base/default/layout/rss.xml
+++ b/app/design/frontend/base/default/layout/rss.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/sales.xml b/app/design/frontend/base/default/layout/sales.xml
index 20bf542..e0b67ff 100644
--- a/app/design/frontend/base/default/layout/sales.xml
+++ b/app/design/frontend/base/default/layout/sales.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/sales/billing_agreement.xml b/app/design/frontend/base/default/layout/sales/billing_agreement.xml
index 44948dc..a163d08 100644
--- a/app/design/frontend/base/default/layout/sales/billing_agreement.xml
+++ b/app/design/frontend/base/default/layout/sales/billing_agreement.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/sales/recurring_profile.xml b/app/design/frontend/base/default/layout/sales/recurring_profile.xml
index cee90f5..54bb134 100644
--- a/app/design/frontend/base/default/layout/sales/recurring_profile.xml
+++ b/app/design/frontend/base/default/layout/sales/recurring_profile.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/sendfriend.xml b/app/design/frontend/base/default/layout/sendfriend.xml
index 6fdb2ad..b9bcc1e 100644
--- a/app/design/frontend/base/default/layout/sendfriend.xml
+++ b/app/design/frontend/base/default/layout/sendfriend.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/layout/shipping.xml b/app/design/frontend/base/default/layout/shipping.xml
index 71037af..e9e5b36 100644
--- a/app/design/frontend/base/default/layout/shipping.xml
+++ b/app/design/frontend/base/default/layout/shipping.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/tag.xml b/app/design/frontend/base/default/layout/tag.xml
index 4d7f692..50dfa39 100644
--- a/app/design/frontend/base/default/layout/tag.xml
+++ b/app/design/frontend/base/default/layout/tag.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/weee.xml b/app/design/frontend/base/default/layout/weee.xml
index 55dc8ce..2e5455f 100644
--- a/app/design/frontend/base/default/layout/weee.xml
+++ b/app/design/frontend/base/default/layout/weee.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/wishlist.xml b/app/design/frontend/base/default/layout/wishlist.xml
index 83cc839..efc15fe 100644
--- a/app/design/frontend/base/default/layout/wishlist.xml
+++ b/app/design/frontend/base/default/layout/wishlist.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/layout/xmlconnect.xml b/app/design/frontend/base/default/layout/xmlconnect.xml
index 046f0f4..e297981 100644
--- a/app/design/frontend/base/default/layout/xmlconnect.xml
+++ b/app/design/frontend/base/default/layout/xmlconnect.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/base/default/template/authorizenet/directpost/form.phtml b/app/design/frontend/base/default/template/authorizenet/directpost/form.phtml
index 040e991..1e9c00d 100644
--- a/app/design/frontend/base/default/template/authorizenet/directpost/form.phtml
+++ b/app/design/frontend/base/default/template/authorizenet/directpost/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/authorizenet/directpost/iframe.phtml b/app/design/frontend/base/default/template/authorizenet/directpost/iframe.phtml
index 4fafcad..200bfd7 100644
--- a/app/design/frontend/base/default/template/authorizenet/directpost/iframe.phtml
+++ b/app/design/frontend/base/default/template/authorizenet/directpost/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/authorizenet/directpost/info.phtml b/app/design/frontend/base/default/template/authorizenet/directpost/info.phtml
index 7113147..4c23ee4 100644
--- a/app/design/frontend/base/default/template/authorizenet/directpost/info.phtml
+++ b/app/design/frontend/base/default/template/authorizenet/directpost/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/list/partof.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/list/partof.phtml
index 73477b5..e405864 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/list/partof.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/list/partof.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/price.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/price.phtml
index 03e75a6..620834f 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/price.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/option_tierprices.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/option_tierprices.phtml
index cda079f..61b1a04 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/option_tierprices.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/option_tierprices.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/options/notice.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/options/notice.phtml
index d7281dd..4a93ec4 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/options/notice.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/options/notice.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/price.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/price.phtml
index 348be3d..a142a7a 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/price.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/tierprices.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/tierprices.phtml
index e538c43..32cb889 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/tierprices.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/tierprices.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle.phtml
index d6ab321..4de75a7 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/checkbox.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/checkbox.phtml
index ab7d0eb..8bc711d 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/checkbox.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/checkbox.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/multi.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/multi.phtml
index 695f051..510fea8 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/multi.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/multi.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/radio.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/radio.phtml
index 54a77f2..d958a23 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/radio.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/radio.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
index 9a5febd..2670c52 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/options.phtml b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/options.phtml
index 4e8243f..a4632d9 100644
--- a/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/options.phtml
+++ b/app/design/frontend/base/default/template/bundle/catalog/product/view/type/bundle/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/email/order/items/creditmemo/default.phtml b/app/design/frontend/base/default/template/bundle/email/order/items/creditmemo/default.phtml
index 2beb9d2..fb33484 100644
--- a/app/design/frontend/base/default/template/bundle/email/order/items/creditmemo/default.phtml
+++ b/app/design/frontend/base/default/template/bundle/email/order/items/creditmemo/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/email/order/items/invoice/default.phtml b/app/design/frontend/base/default/template/bundle/email/order/items/invoice/default.phtml
index c6ab006..48a4f6f 100644
--- a/app/design/frontend/base/default/template/bundle/email/order/items/invoice/default.phtml
+++ b/app/design/frontend/base/default/template/bundle/email/order/items/invoice/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/email/order/items/order/default.phtml b/app/design/frontend/base/default/template/bundle/email/order/items/order/default.phtml
index 1505e1a..53e0a11 100644
--- a/app/design/frontend/base/default/template/bundle/email/order/items/order/default.phtml
+++ b/app/design/frontend/base/default/template/bundle/email/order/items/order/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/email/order/items/shipment/default.phtml b/app/design/frontend/base/default/template/bundle/email/order/items/shipment/default.phtml
index 1b6e03c..a304ded 100644
--- a/app/design/frontend/base/default/template/bundle/email/order/items/shipment/default.phtml
+++ b/app/design/frontend/base/default/template/bundle/email/order/items/shipment/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/rss/catalog/product/price.phtml b/app/design/frontend/base/default/template/bundle/rss/catalog/product/price.phtml
index d3594e5..5ff1906 100644
--- a/app/design/frontend/base/default/template/bundle/rss/catalog/product/price.phtml
+++ b/app/design/frontend/base/default/template/bundle/rss/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/sales/order/creditmemo/items/renderer.phtml b/app/design/frontend/base/default/template/bundle/sales/order/creditmemo/items/renderer.phtml
index 071ec6e..75229c0 100644
--- a/app/design/frontend/base/default/template/bundle/sales/order/creditmemo/items/renderer.phtml
+++ b/app/design/frontend/base/default/template/bundle/sales/order/creditmemo/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/sales/order/invoice/items/renderer.phtml b/app/design/frontend/base/default/template/bundle/sales/order/invoice/items/renderer.phtml
index c87cd06..fb6e7cd 100644
--- a/app/design/frontend/base/default/template/bundle/sales/order/invoice/items/renderer.phtml
+++ b/app/design/frontend/base/default/template/bundle/sales/order/invoice/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/sales/order/items/renderer.phtml b/app/design/frontend/base/default/template/bundle/sales/order/items/renderer.phtml
index bfe9ffb..86616fa 100644
--- a/app/design/frontend/base/default/template/bundle/sales/order/items/renderer.phtml
+++ b/app/design/frontend/base/default/template/bundle/sales/order/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/bundle/sales/order/shipment/items/renderer.phtml b/app/design/frontend/base/default/template/bundle/sales/order/shipment/items/renderer.phtml
index 8560300..d252b7d 100644
--- a/app/design/frontend/base/default/template/bundle/sales/order/shipment/items/renderer.phtml
+++ b/app/design/frontend/base/default/template/bundle/sales/order/shipment/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/callouts/left_col.phtml b/app/design/frontend/base/default/template/callouts/left_col.phtml
index 98b2948..bfb551e 100644
--- a/app/design/frontend/base/default/template/callouts/left_col.phtml
+++ b/app/design/frontend/base/default/template/callouts/left_col.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/callouts/right_col.phtml b/app/design/frontend/base/default/template/callouts/right_col.phtml
index 98b2948..bfb551e 100644
--- a/app/design/frontend/base/default/template/callouts/right_col.phtml
+++ b/app/design/frontend/base/default/template/callouts/right_col.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/captcha/zend.phtml b/app/design/frontend/base/default/template/captcha/zend.phtml
index 7f9dd4c..375467b 100644
--- a/app/design/frontend/base/default/template/captcha/zend.phtml
+++ b/app/design/frontend/base/default/template/captcha/zend.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/category/page.phtml b/app/design/frontend/base/default/template/catalog/category/page.phtml
index 61c7c00..1d2733a 100644
--- a/app/design/frontend/base/default/template/catalog/category/page.phtml
+++ b/app/design/frontend/base/default/template/catalog/category/page.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  
diff --git a/app/design/frontend/base/default/template/catalog/category/view.phtml b/app/design/frontend/base/default/template/catalog/category/view.phtml
index 1aa13da..cfdbee1 100644
--- a/app/design/frontend/base/default/template/catalog/category/view.phtml
+++ b/app/design/frontend/base/default/template/catalog/category/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/category/widget/link/link_block.phtml b/app/design/frontend/base/default/template/catalog/category/widget/link/link_block.phtml
index 5193dc9..7514245 100644
--- a/app/design/frontend/base/default/template/catalog/category/widget/link/link_block.phtml
+++ b/app/design/frontend/base/default/template/catalog/category/widget/link/link_block.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/category/widget/link/link_inline.phtml b/app/design/frontend/base/default/template/catalog/category/widget/link/link_inline.phtml
index b3f8dfc..62026ce 100644
--- a/app/design/frontend/base/default/template/catalog/category/widget/link/link_inline.phtml
+++ b/app/design/frontend/base/default/template/catalog/category/widget/link/link_inline.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/layer/filter.phtml b/app/design/frontend/base/default/template/catalog/layer/filter.phtml
index 5d5545d..f0daa2d 100644
--- a/app/design/frontend/base/default/template/catalog/layer/filter.phtml
+++ b/app/design/frontend/base/default/template/catalog/layer/filter.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/layer/state.phtml b/app/design/frontend/base/default/template/catalog/layer/state.phtml
index e36955e..87b4c35 100644
--- a/app/design/frontend/base/default/template/catalog/layer/state.phtml
+++ b/app/design/frontend/base/default/template/catalog/layer/state.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/layer/view.phtml b/app/design/frontend/base/default/template/catalog/layer/view.phtml
index 4a68153..c9948c3 100644
--- a/app/design/frontend/base/default/template/catalog/layer/view.phtml
+++ b/app/design/frontend/base/default/template/catalog/layer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/msrp/popup.phtml b/app/design/frontend/base/default/template/catalog/msrp/popup.phtml
index f001880..7ea0985 100644
--- a/app/design/frontend/base/default/template/catalog/msrp/popup.phtml
+++ b/app/design/frontend/base/default/template/catalog/msrp/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/navigation/left.phtml b/app/design/frontend/base/default/template/catalog/navigation/left.phtml
index 637b024..97cf672 100644
--- a/app/design/frontend/base/default/template/catalog/navigation/left.phtml
+++ b/app/design/frontend/base/default/template/catalog/navigation/left.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/navigation/top.phtml b/app/design/frontend/base/default/template/catalog/navigation/top.phtml
index 01269ab..7bed6d6 100644
--- a/app/design/frontend/base/default/template/catalog/navigation/top.phtml
+++ b/app/design/frontend/base/default/template/catalog/navigation/top.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/compare/list.phtml b/app/design/frontend/base/default/template/catalog/product/compare/list.phtml
index 5032986..ecacce0 100644
--- a/app/design/frontend/base/default/template/catalog/product/compare/list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/compare/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Catalog_Block_Product_Compare_List */
diff --git a/app/design/frontend/base/default/template/catalog/product/compare/sidebar.phtml b/app/design/frontend/base/default/template/catalog/product/compare/sidebar.phtml
index 8ed969a..d31b36b 100644
--- a/app/design/frontend/base/default/template/catalog/product/compare/sidebar.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/compare/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Catalog_Block_Product_Compare_Sidebar */
diff --git a/app/design/frontend/base/default/template/catalog/product/gallery.phtml b/app/design/frontend/base/default/template/catalog/product/gallery.phtml
index f0b80b5..96de971 100644
--- a/app/design/frontend/base/default/template/catalog/product/gallery.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/gallery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/list.phtml b/app/design/frontend/base/default/template/catalog/product/list.phtml
index d0672fd..32e123b 100644
--- a/app/design/frontend/base/default/template/catalog/product/list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/list/related.phtml b/app/design/frontend/base/default/template/catalog/product/list/related.phtml
index 5b347be..76e2b7a 100644
--- a/app/design/frontend/base/default/template/catalog/product/list/related.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/list/related.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/list/toolbar.phtml b/app/design/frontend/base/default/template/catalog/product/list/toolbar.phtml
index 82e2525..7af64c4 100644
--- a/app/design/frontend/base/default/template/catalog/product/list/toolbar.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/list/toolbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/list/upsell.phtml b/app/design/frontend/base/default/template/catalog/product/list/upsell.phtml
index 69ca6d9..ec95e59 100644
--- a/app/design/frontend/base/default/template/catalog/product/list/upsell.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/list/upsell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/new.phtml b/app/design/frontend/base/default/template/catalog/product/new.phtml
index 867a3e4..9a5a679 100644
--- a/app/design/frontend/base/default/template/catalog/product/new.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/new.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/price.phtml b/app/design/frontend/base/default/template/catalog/product/price.phtml
index 55a3986..9b123eb 100644
--- a/app/design/frontend/base/default/template/catalog/product/price.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/price_msrp.phtml b/app/design/frontend/base/default/template/catalog/product/price_msrp.phtml
index 5fe4b10..c0d970a 100644
--- a/app/design/frontend/base/default/template/catalog/product/price_msrp.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/price_msrp.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/price_msrp_item.phtml b/app/design/frontend/base/default/template/catalog/product/price_msrp_item.phtml
index 6af0961..bb5f991 100644
--- a/app/design/frontend/base/default/template/catalog/product/price_msrp_item.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/price_msrp_item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/price_msrp_noform.phtml b/app/design/frontend/base/default/template/catalog/product/price_msrp_noform.phtml
index 6c6faec..f56f929 100644
--- a/app/design/frontend/base/default/template/catalog/product/price_msrp_noform.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/price_msrp_noform.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/price_msrp_rss.phtml b/app/design/frontend/base/default/template/catalog/product/price_msrp_rss.phtml
index 6ebb6ab..8ab619d 100644
--- a/app/design/frontend/base/default/template/catalog/product/price_msrp_rss.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/price_msrp_rss.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view.phtml b/app/design/frontend/base/default/template/catalog/product/view.phtml
index 615eba8..1cff993 100644
--- a/app/design/frontend/base/default/template/catalog/product/view.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/product/view/additional.phtml b/app/design/frontend/base/default/template/catalog/product/view/additional.phtml
index 88e60f7..807b74a 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/additional.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/additional.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/addto.phtml b/app/design/frontend/base/default/template/catalog/product/view/addto.phtml
index bdcac7b..9ca9b2a 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/addto.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/addto.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/addtocart.phtml b/app/design/frontend/base/default/template/catalog/product/view/addtocart.phtml
index 126b73c..81ae72b 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/addtocart.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/addtocart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/attributes.phtml b/app/design/frontend/base/default/template/catalog/product/view/attributes.phtml
index dba4f12..3e3302b 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/attributes.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/attributes.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/product/view/description.phtml b/app/design/frontend/base/default/template/catalog/product/view/description.phtml
index a13b166..f039b86 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/description.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/description.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/product/view/media.phtml b/app/design/frontend/base/default/template/catalog/product/view/media.phtml
index abcbf39..39c64b1 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/media.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/media.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options.phtml b/app/design/frontend/base/default/template/catalog/product/view/options.phtml
index 19847d0..3f22fe9 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Catalog_Block_Product_View_Options */
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/js.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/js.phtml
index 8d31c9f..288a950 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/js.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/type/date.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/type/date.phtml
index 4eed13b..f3a5ff3 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/type/date.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/type/date.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/type/default.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/type/default.phtml
index 781d144..ed35acd 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/type/default.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/type/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/type/file.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/type/file.phtml
index 5f1301b..3b02b3d 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/type/file.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/type/file.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/type/select.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/type/select.phtml
index ab5b11a..37395a4 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/type/select.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/type/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/type/text.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/type/text.phtml
index fc1f697..b603ab1 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/type/text.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/type/text.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/wrapper.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/wrapper.phtml
index e0b0394..ce802a4 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/wrapper.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/wrapper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/options/wrapper/bottom.phtml b/app/design/frontend/base/default/template/catalog/product/view/options/wrapper/bottom.phtml
index 73f9a0f..c3dba6f 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/options/wrapper/bottom.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/options/wrapper/bottom.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/price.phtml b/app/design/frontend/base/default/template/catalog/product/view/price.phtml
index 605b1f7..0cd1151 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/price.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  
diff --git a/app/design/frontend/base/default/template/catalog/product/view/price_clone.phtml b/app/design/frontend/base/default/template/catalog/product/view/price_clone.phtml
index d2501b2..c6a1ae2 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/price_clone.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/price_clone.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/tierprices.phtml b/app/design/frontend/base/default/template/catalog/product/view/tierprices.phtml
index 6f13564..717cab4 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/tierprices.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/tierprices.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/configurable.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/configurable.phtml
index 3c67638..b4843f7 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/configurable.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/default.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/default.phtml
index 55b3a60..8088217 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/default.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/grouped.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/grouped.phtml
index cae4b55..2e09b24 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/grouped.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/grouped.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/options/configurable.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/options/configurable.phtml
index 3290cd2..de0354c 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/options/configurable.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/options/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/simple.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/simple.phtml
index 3c67638..b4843f7 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/simple.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/view/type/virtual.phtml b/app/design/frontend/base/default/template/catalog/product/view/type/virtual.phtml
index 3c67638..b4843f7 100644
--- a/app/design/frontend/base/default/template/catalog/product/view/type/virtual.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/view/type/virtual.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/link/link_block.phtml b/app/design/frontend/base/default/template/catalog/product/widget/link/link_block.phtml
index 8655043..73cd819 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/link/link_block.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/link/link_block.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/link/link_inline.phtml b/app/design/frontend/base/default/template/catalog/product/widget/link/link_inline.phtml
index 4fbe27b..bbcca55 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/link/link_inline.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/link/link_inline.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_default_list.phtml b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_default_list.phtml
index b8207ed..6e0312b 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_default_list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_images_list.phtml b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_images_list.phtml
index 1130c21..1b1a1c0 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_images_list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_names_list.phtml b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_names_list.phtml
index 978e87a..bf92e13 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_names_list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/new/column/new_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_grid.phtml b/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_grid.phtml
index bd1f8d7..810c77e 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_grid.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_list.phtml b/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_list.phtml
index 8f0c37a..2f5b4fb 100644
--- a/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_list.phtml
+++ b/app/design/frontend/base/default/template/catalog/product/widget/new/content/new_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/rss/product/price.phtml b/app/design/frontend/base/default/template/catalog/rss/product/price.phtml
index 6652a5b..e0af7bd 100644
--- a/app/design/frontend/base/default/template/catalog/rss/product/price.phtml
+++ b/app/design/frontend/base/default/template/catalog/rss/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/seo/sitemap.phtml b/app/design/frontend/base/default/template/catalog/seo/sitemap.phtml
index 07791f8..870a50d 100644
--- a/app/design/frontend/base/default/template/catalog/seo/sitemap.phtml
+++ b/app/design/frontend/base/default/template/catalog/seo/sitemap.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/seo/sitemap/container.phtml b/app/design/frontend/base/default/template/catalog/seo/sitemap/container.phtml
index 1a2d4a4..30008b0 100644
--- a/app/design/frontend/base/default/template/catalog/seo/sitemap/container.phtml
+++ b/app/design/frontend/base/default/template/catalog/seo/sitemap/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalog/seo/tree.phtml b/app/design/frontend/base/default/template/catalog/seo/tree.phtml
index 3dcd87d..8e28839 100644
--- a/app/design/frontend/base/default/template/catalog/seo/tree.phtml
+++ b/app/design/frontend/base/default/template/catalog/seo/tree.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cataloginventory/qtyincrements.phtml b/app/design/frontend/base/default/template/cataloginventory/qtyincrements.phtml
index f301fa5..5b1b495 100644
--- a/app/design/frontend/base/default/template/cataloginventory/qtyincrements.phtml
+++ b/app/design/frontend/base/default/template/cataloginventory/qtyincrements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/cataloginventory/stockqty/composite.phtml b/app/design/frontend/base/default/template/cataloginventory/stockqty/composite.phtml
index 7490724..d998348 100644
--- a/app/design/frontend/base/default/template/cataloginventory/stockqty/composite.phtml
+++ b/app/design/frontend/base/default/template/cataloginventory/stockqty/composite.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/cataloginventory/stockqty/default.phtml b/app/design/frontend/base/default/template/cataloginventory/stockqty/default.phtml
index d964db1..a17fc65 100644
--- a/app/design/frontend/base/default/template/cataloginventory/stockqty/default.phtml
+++ b/app/design/frontend/base/default/template/cataloginventory/stockqty/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/catalogsearch/advanced/form.phtml b/app/design/frontend/base/default/template/catalogsearch/advanced/form.phtml
index 4c8ba02..0b5ff28 100644
--- a/app/design/frontend/base/default/template/catalogsearch/advanced/form.phtml
+++ b/app/design/frontend/base/default/template/catalogsearch/advanced/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalogsearch/advanced/result.phtml b/app/design/frontend/base/default/template/catalogsearch/advanced/result.phtml
index d2f5730..4862d3b 100644
--- a/app/design/frontend/base/default/template/catalogsearch/advanced/result.phtml
+++ b/app/design/frontend/base/default/template/catalogsearch/advanced/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalogsearch/form.mini.phtml b/app/design/frontend/base/default/template/catalogsearch/form.mini.phtml
index 9668dad..1791b4a 100644
--- a/app/design/frontend/base/default/template/catalogsearch/form.mini.phtml
+++ b/app/design/frontend/base/default/template/catalogsearch/form.mini.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Core_Block_Template */
diff --git a/app/design/frontend/base/default/template/catalogsearch/result.phtml b/app/design/frontend/base/default/template/catalogsearch/result.phtml
index 319b2f2..42d1c84 100644
--- a/app/design/frontend/base/default/template/catalogsearch/result.phtml
+++ b/app/design/frontend/base/default/template/catalogsearch/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/catalogsearch/term.phtml b/app/design/frontend/base/default/template/catalogsearch/term.phtml
index c00e127..bfc63fd 100644
--- a/app/design/frontend/base/default/template/catalogsearch/term.phtml
+++ b/app/design/frontend/base/default/template/catalogsearch/term.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/centinel/authentication.phtml b/app/design/frontend/base/default/template/centinel/authentication.phtml
index 84df48d..234a4d8 100644
--- a/app/design/frontend/base/default/template/centinel/authentication.phtml
+++ b/app/design/frontend/base/default/template/centinel/authentication.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/centinel/authentication/complete.phtml b/app/design/frontend/base/default/template/centinel/authentication/complete.phtml
index 4edda1e..33a8998 100644
--- a/app/design/frontend/base/default/template/centinel/authentication/complete.phtml
+++ b/app/design/frontend/base/default/template/centinel/authentication/complete.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/centinel/authentication/start.phtml b/app/design/frontend/base/default/template/centinel/authentication/start.phtml
index 30cf4b2..bc69cdd 100644
--- a/app/design/frontend/base/default/template/centinel/authentication/start.phtml
+++ b/app/design/frontend/base/default/template/centinel/authentication/start.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/centinel/logo.phtml b/app/design/frontend/base/default/template/centinel/logo.phtml
index acc57c7..b220b92 100644
--- a/app/design/frontend/base/default/template/centinel/logo.phtml
+++ b/app/design/frontend/base/default/template/centinel/logo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart.phtml b/app/design/frontend/base/default/template/checkout/cart.phtml
index 8971bc2..6237fce 100644
--- a/app/design/frontend/base/default/template/checkout/cart.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/coupon.phtml b/app/design/frontend/base/default/template/checkout/cart/coupon.phtml
index 71d7f11..77b1ff3 100644
--- a/app/design/frontend/base/default/template/checkout/cart/coupon.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/coupon.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/crosssell.phtml b/app/design/frontend/base/default/template/checkout/cart/crosssell.phtml
index 9dc8fc8..0e5d301 100644
--- a/app/design/frontend/base/default/template/checkout/cart/crosssell.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/crosssell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/item/configure/updatecart.phtml b/app/design/frontend/base/default/template/checkout/cart/item/configure/updatecart.phtml
index 5597a85..0c2eef7 100644
--- a/app/design/frontend/base/default/template/checkout/cart/item/configure/updatecart.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/item/configure/updatecart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/item/default.phtml b/app/design/frontend/base/default/template/checkout/cart/item/default.phtml
index 4a228e3..70879c9 100644
--- a/app/design/frontend/base/default/template/checkout/cart/item/default.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/noItems.phtml b/app/design/frontend/base/default/template/checkout/cart/noItems.phtml
index 2c33c27..a4cc929 100644
--- a/app/design/frontend/base/default/template/checkout/cart/noItems.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/noItems.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/render/default.phtml b/app/design/frontend/base/default/template/checkout/cart/render/default.phtml
index c1e951f..0b58173 100644
--- a/app/design/frontend/base/default/template/checkout/cart/render/default.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/render/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/checkout/cart/render/simple.phtml b/app/design/frontend/base/default/template/checkout/cart/render/simple.phtml
index 8850df5..e83ada4 100644
--- a/app/design/frontend/base/default/template/checkout/cart/render/simple.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/render/simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/checkout/cart/shipping.phtml b/app/design/frontend/base/default/template/checkout/cart/shipping.phtml
index 6656205..4eba584 100644
--- a/app/design/frontend/base/default/template/checkout/cart/shipping.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/sidebar.phtml b/app/design/frontend/base/default/template/checkout/cart/sidebar.phtml
index 9c7bd11..f667d94 100644
--- a/app/design/frontend/base/default/template/checkout/cart/sidebar.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/checkout/cart/sidebar/default.phtml b/app/design/frontend/base/default/template/checkout/cart/sidebar/default.phtml
index 9040870..7f70f65 100644
--- a/app/design/frontend/base/default/template/checkout/cart/sidebar/default.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/sidebar/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/cart/totals.phtml b/app/design/frontend/base/default/template/checkout/cart/totals.phtml
index da12570..ef8f5d5 100644
--- a/app/design/frontend/base/default/template/checkout/cart/totals.phtml
+++ b/app/design/frontend/base/default/template/checkout/cart/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/address/select.phtml b/app/design/frontend/base/default/template/checkout/multishipping/address/select.phtml
index 6181ff2..ffbef58 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/address/select.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/address/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/addresses.phtml b/app/design/frontend/base/default/template/checkout/multishipping/addresses.phtml
index 2cb7319..0d80686 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/addresses.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/addresses.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/agreements.phtml b/app/design/frontend/base/default/template/checkout/multishipping/agreements.phtml
index 09b61e1..1897112 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/agreements.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/agreements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/billing.phtml b/app/design/frontend/base/default/template/checkout/multishipping/billing.phtml
index 4ed77a5..0d573ba 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/billing.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/billing/items.phtml b/app/design/frontend/base/default/template/checkout/multishipping/billing/items.phtml
index 3d3436c..768ce3d 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/billing/items.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/billing/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/item/default.phtml b/app/design/frontend/base/default/template/checkout/multishipping/item/default.phtml
index 08d25ab..1be09ff 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/item/default.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/link.phtml b/app/design/frontend/base/default/template/checkout/multishipping/link.phtml
index 8cea5e6..daf28ae 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/link.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/link.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/overview.phtml b/app/design/frontend/base/default/template/checkout/multishipping/overview.phtml
index 49b136a..cd5646a 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/overview.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/overview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/overview/item.phtml b/app/design/frontend/base/default/template/checkout/multishipping/overview/item.phtml
index 7419646..5b94a3f 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/overview/item.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/overview/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/shipping.phtml b/app/design/frontend/base/default/template/checkout/multishipping/shipping.phtml
index d5a5131..8ad7221 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/shipping.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/state.phtml b/app/design/frontend/base/default/template/checkout/multishipping/state.phtml
index 79099b1..152f8d5 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/state.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/state.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/multishipping/success.phtml b/app/design/frontend/base/default/template/checkout/multishipping/success.phtml
index c23c5fe..ce6e64a 100644
--- a/app/design/frontend/base/default/template/checkout/multishipping/success.phtml
+++ b/app/design/frontend/base/default/template/checkout/multishipping/success.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage.phtml b/app/design/frontend/base/default/template/checkout/onepage.phtml
index 1b45324..60d5fe6 100644
--- a/app/design/frontend/base/default/template/checkout/onepage.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/agreements.phtml b/app/design/frontend/base/default/template/checkout/onepage/agreements.phtml
index 323b9c1..ee72b8e 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/agreements.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/agreements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/billing.phtml b/app/design/frontend/base/default/template/checkout/onepage/billing.phtml
index cf67652..a52cded 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/billing.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/failure.phtml b/app/design/frontend/base/default/template/checkout/onepage/failure.phtml
index 578d6eb..96d91a7 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/failure.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/failure.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/link.phtml b/app/design/frontend/base/default/template/checkout/onepage/link.phtml
index 6c12135..451667b 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/link.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/link.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/login.phtml b/app/design/frontend/base/default/template/checkout/onepage/login.phtml
index 789cff0..c998c15 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/login.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/payment.phtml b/app/design/frontend/base/default/template/checkout/onepage/payment.phtml
index 83189c9..31d9a0f 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/payment.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/payment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/payment/info.phtml b/app/design/frontend/base/default/template/checkout/onepage/payment/info.phtml
index 3a551c7..ff00fdd 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/payment/info.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/payment/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/payment/methods.phtml b/app/design/frontend/base/default/template/checkout/onepage/payment/methods.phtml
index d0273c9..dcfc213 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/payment/methods.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/payment/methods.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/progress.phtml b/app/design/frontend/base/default/template/checkout/onepage/progress.phtml
index f288979..74abaf3 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/progress.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/progress.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/progress/billing.phtml b/app/design/frontend/base/default/template/checkout/onepage/progress/billing.phtml
index 0f0967e..acca5e6 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/progress/billing.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/progress/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/progress/payment.phtml b/app/design/frontend/base/default/template/checkout/onepage/progress/payment.phtml
index 6e06e72..1dd50ec 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/progress/payment.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/progress/payment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/progress/shipping.phtml b/app/design/frontend/base/default/template/checkout/onepage/progress/shipping.phtml
index d7bf557..266d3c6 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/progress/shipping.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/progress/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/progress/shipping_method.phtml b/app/design/frontend/base/default/template/checkout/onepage/progress/shipping_method.phtml
index e9beceb..3a393a9 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/progress/shipping_method.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/progress/shipping_method.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/review.phtml b/app/design/frontend/base/default/template/checkout/onepage/review.phtml
index 278226a..4967c4c 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/review.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/review.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/review/button.phtml b/app/design/frontend/base/default/template/checkout/onepage/review/button.phtml
index 7495a22..eed4bf6 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/review/button.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/review/button.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/review/info.phtml b/app/design/frontend/base/default/template/checkout/onepage/review/info.phtml
index 6b3ac07..663b4e3 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/review/info.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/review/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/review/item.phtml b/app/design/frontend/base/default/template/checkout/onepage/review/item.phtml
index 674b138..e065ac9 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/review/totals.phtml b/app/design/frontend/base/default/template/checkout/onepage/review/totals.phtml
index fcedd0f..9fc8406 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/review/totals.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/review/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/checkout/onepage/shipping.phtml b/app/design/frontend/base/default/template/checkout/onepage/shipping.phtml
index 9950091..832d89b 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/shipping.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/shipping_method.phtml b/app/design/frontend/base/default/template/checkout/onepage/shipping_method.phtml
index fcd505a..ebee058 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/shipping_method.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/shipping_method.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/shipping_method/additional.phtml b/app/design/frontend/base/default/template/checkout/onepage/shipping_method/additional.phtml
index d127eb9..d1c2eec 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/shipping_method/additional.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/shipping_method/additional.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/onepage/shipping_method/available.phtml b/app/design/frontend/base/default/template/checkout/onepage/shipping_method/available.phtml
index 9c595ec..49f00bf 100644
--- a/app/design/frontend/base/default/template/checkout/onepage/shipping_method/available.phtml
+++ b/app/design/frontend/base/default/template/checkout/onepage/shipping_method/available.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/success.phtml b/app/design/frontend/base/default/template/checkout/success.phtml
index a2582ea..504ed72 100644
--- a/app/design/frontend/base/default/template/checkout/success.phtml
+++ b/app/design/frontend/base/default/template/checkout/success.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/total/default.phtml b/app/design/frontend/base/default/template/checkout/total/default.phtml
index 44345f4..36bf0bd 100644
--- a/app/design/frontend/base/default/template/checkout/total/default.phtml
+++ b/app/design/frontend/base/default/template/checkout/total/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/total/nominal.phtml b/app/design/frontend/base/default/template/checkout/total/nominal.phtml
index 63f37f4..b8ecb5f 100644
--- a/app/design/frontend/base/default/template/checkout/total/nominal.phtml
+++ b/app/design/frontend/base/default/template/checkout/total/nominal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/checkout/total/tax.phtml b/app/design/frontend/base/default/template/checkout/total/tax.phtml
index 774425d..86d52f6 100644
--- a/app/design/frontend/base/default/template/checkout/total/tax.phtml
+++ b/app/design/frontend/base/default/template/checkout/total/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/content.phtml b/app/design/frontend/base/default/template/cms/content.phtml
index 82de642..a67714e 100644
--- a/app/design/frontend/base/default/template/cms/content.phtml
+++ b/app/design/frontend/base/default/template/cms/content.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/content_heading.phtml b/app/design/frontend/base/default/template/cms/content_heading.phtml
index 9fd234f..6c8a365 100644
--- a/app/design/frontend/base/default/template/cms/content_heading.phtml
+++ b/app/design/frontend/base/default/template/cms/content_heading.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/default/home.phtml b/app/design/frontend/base/default/template/cms/default/home.phtml
index de531bb..b169910 100644
--- a/app/design/frontend/base/default/template/cms/default/home.phtml
+++ b/app/design/frontend/base/default/template/cms/default/home.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/default/no-route.phtml b/app/design/frontend/base/default/template/cms/default/no-route.phtml
index ed101dd..2f87cd2 100644
--- a/app/design/frontend/base/default/template/cms/default/no-route.phtml
+++ b/app/design/frontend/base/default/template/cms/default/no-route.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/meta.phtml b/app/design/frontend/base/default/template/cms/meta.phtml
index c2e4fca..c1c9c81 100644
--- a/app/design/frontend/base/default/template/cms/meta.phtml
+++ b/app/design/frontend/base/default/template/cms/meta.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/widget/link/link_block.phtml b/app/design/frontend/base/default/template/cms/widget/link/link_block.phtml
index 89597f4..1cf3983 100644
--- a/app/design/frontend/base/default/template/cms/widget/link/link_block.phtml
+++ b/app/design/frontend/base/default/template/cms/widget/link/link_block.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/widget/link/link_inline.phtml b/app/design/frontend/base/default/template/cms/widget/link/link_inline.phtml
index 1e30058..5d90e41 100644
--- a/app/design/frontend/base/default/template/cms/widget/link/link_inline.phtml
+++ b/app/design/frontend/base/default/template/cms/widget/link/link_inline.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/cms/widget/static_block/default.phtml b/app/design/frontend/base/default/template/cms/widget/static_block/default.phtml
index 8d13b44..4c6e08c 100644
--- a/app/design/frontend/base/default/template/cms/widget/static_block/default.phtml
+++ b/app/design/frontend/base/default/template/cms/widget/static_block/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/contacts/form.phtml b/app/design/frontend/base/default/template/contacts/form.phtml
index 8d59bd5..421cba8 100644
--- a/app/design/frontend/base/default/template/contacts/form.phtml
+++ b/app/design/frontend/base/default/template/contacts/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/core/formkey.phtml b/app/design/frontend/base/default/template/core/formkey.phtml
index 5638bac..70646dd 100644
--- a/app/design/frontend/base/default/template/core/formkey.phtml
+++ b/app/design/frontend/base/default/template/core/formkey.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/core/link.phtml b/app/design/frontend/base/default/template/core/link.phtml
index 3b10a14..bbc4c96 100644
--- a/app/design/frontend/base/default/template/core/link.phtml
+++ b/app/design/frontend/base/default/template/core/link.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/core/messages.phtml b/app/design/frontend/base/default/template/core/messages.phtml
index 1547485..8df0204 100644
--- a/app/design/frontend/base/default/template/core/messages.phtml
+++ b/app/design/frontend/base/default/template/core/messages.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/dashboard.phtml b/app/design/frontend/base/default/template/customer/account/dashboard.phtml
index 9bf548c..f024e75 100644
--- a/app/design/frontend/base/default/template/customer/account/dashboard.phtml
+++ b/app/design/frontend/base/default/template/customer/account/dashboard.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/dashboard/address.phtml b/app/design/frontend/base/default/template/customer/account/dashboard/address.phtml
index ec94035..8dc5019 100644
--- a/app/design/frontend/base/default/template/customer/account/dashboard/address.phtml
+++ b/app/design/frontend/base/default/template/customer/account/dashboard/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/dashboard/hello.phtml b/app/design/frontend/base/default/template/customer/account/dashboard/hello.phtml
index 97470a2..3a0df75 100644
--- a/app/design/frontend/base/default/template/customer/account/dashboard/hello.phtml
+++ b/app/design/frontend/base/default/template/customer/account/dashboard/hello.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/dashboard/info.phtml b/app/design/frontend/base/default/template/customer/account/dashboard/info.phtml
index 2168c53..6eaec83 100644
--- a/app/design/frontend/base/default/template/customer/account/dashboard/info.phtml
+++ b/app/design/frontend/base/default/template/customer/account/dashboard/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/dashboard/newsletter.phtml b/app/design/frontend/base/default/template/customer/account/dashboard/newsletter.phtml
index b9dc130..753b93e 100644
--- a/app/design/frontend/base/default/template/customer/account/dashboard/newsletter.phtml
+++ b/app/design/frontend/base/default/template/customer/account/dashboard/newsletter.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/link/back.phtml b/app/design/frontend/base/default/template/customer/account/link/back.phtml
index 2bbd963..41af8f7 100644
--- a/app/design/frontend/base/default/template/customer/account/link/back.phtml
+++ b/app/design/frontend/base/default/template/customer/account/link/back.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/account/navigation.phtml b/app/design/frontend/base/default/template/customer/account/navigation.phtml
index 5b46f0a..3dce6a6 100644
--- a/app/design/frontend/base/default/template/customer/account/navigation.phtml
+++ b/app/design/frontend/base/default/template/customer/account/navigation.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/address.phtml b/app/design/frontend/base/default/template/customer/address.phtml
index b624d92..a7f3f94 100644
--- a/app/design/frontend/base/default/template/customer/address.phtml
+++ b/app/design/frontend/base/default/template/customer/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/address/book.phtml b/app/design/frontend/base/default/template/customer/address/book.phtml
index fb10f25..5bcca95 100644
--- a/app/design/frontend/base/default/template/customer/address/book.phtml
+++ b/app/design/frontend/base/default/template/customer/address/book.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/address/edit.phtml b/app/design/frontend/base/default/template/customer/address/edit.phtml
index 180e51d..e91c02b 100644
--- a/app/design/frontend/base/default/template/customer/address/edit.phtml
+++ b/app/design/frontend/base/default/template/customer/address/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/balance.phtml b/app/design/frontend/base/default/template/customer/balance.phtml
index 264b8a9..52e0899 100644
--- a/app/design/frontend/base/default/template/customer/balance.phtml
+++ b/app/design/frontend/base/default/template/customer/balance.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/address.phtml b/app/design/frontend/base/default/template/customer/form/address.phtml
index c7ee371..1065b70 100644
--- a/app/design/frontend/base/default/template/customer/form/address.phtml
+++ b/app/design/frontend/base/default/template/customer/form/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/changepassword.phtml b/app/design/frontend/base/default/template/customer/form/changepassword.phtml
index a26cee3..f40e509 100644
--- a/app/design/frontend/base/default/template/customer/form/changepassword.phtml
+++ b/app/design/frontend/base/default/template/customer/form/changepassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/confirmation.phtml b/app/design/frontend/base/default/template/customer/form/confirmation.phtml
index 506e77c..13d2bf9 100644
--- a/app/design/frontend/base/default/template/customer/form/confirmation.phtml
+++ b/app/design/frontend/base/default/template/customer/form/confirmation.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/edit.phtml b/app/design/frontend/base/default/template/customer/form/edit.phtml
index c516664..09eb396 100644
--- a/app/design/frontend/base/default/template/customer/form/edit.phtml
+++ b/app/design/frontend/base/default/template/customer/form/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/forgotpassword.phtml b/app/design/frontend/base/default/template/customer/form/forgotpassword.phtml
index 78a3ee2..8a546f7 100644
--- a/app/design/frontend/base/default/template/customer/form/forgotpassword.phtml
+++ b/app/design/frontend/base/default/template/customer/form/forgotpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/login.phtml b/app/design/frontend/base/default/template/customer/form/login.phtml
index a0f3b6c..2dac4e9 100644
--- a/app/design/frontend/base/default/template/customer/form/login.phtml
+++ b/app/design/frontend/base/default/template/customer/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/mini.login.phtml b/app/design/frontend/base/default/template/customer/form/mini.login.phtml
index bd39171..737bf74 100644
--- a/app/design/frontend/base/default/template/customer/form/mini.login.phtml
+++ b/app/design/frontend/base/default/template/customer/form/mini.login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/newsletter.phtml b/app/design/frontend/base/default/template/customer/form/newsletter.phtml
index 0d3081b..1590cab 100644
--- a/app/design/frontend/base/default/template/customer/form/newsletter.phtml
+++ b/app/design/frontend/base/default/template/customer/form/newsletter.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/register.phtml b/app/design/frontend/base/default/template/customer/form/register.phtml
index c2760e6..b78e69b 100644
--- a/app/design/frontend/base/default/template/customer/form/register.phtml
+++ b/app/design/frontend/base/default/template/customer/form/register.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/form/resetforgottenpassword.phtml b/app/design/frontend/base/default/template/customer/form/resetforgottenpassword.phtml
index b092c86..66da5f8 100644
--- a/app/design/frontend/base/default/template/customer/form/resetforgottenpassword.phtml
+++ b/app/design/frontend/base/default/template/customer/form/resetforgottenpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/logout.phtml b/app/design/frontend/base/default/template/customer/logout.phtml
index 345670d..a180f0b 100644
--- a/app/design/frontend/base/default/template/customer/logout.phtml
+++ b/app/design/frontend/base/default/template/customer/logout.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/orders.phtml b/app/design/frontend/base/default/template/customer/orders.phtml
index 8f4566e..7229b7d 100644
--- a/app/design/frontend/base/default/template/customer/orders.phtml
+++ b/app/design/frontend/base/default/template/customer/orders.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/customer/widget/dob.phtml b/app/design/frontend/base/default/template/customer/widget/dob.phtml
index 738d7d4..5bb5ae3 100644
--- a/app/design/frontend/base/default/template/customer/widget/dob.phtml
+++ b/app/design/frontend/base/default/template/customer/widget/dob.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/customer/widget/gender.phtml b/app/design/frontend/base/default/template/customer/widget/gender.phtml
index c541f8c..d06370a 100644
--- a/app/design/frontend/base/default/template/customer/widget/gender.phtml
+++ b/app/design/frontend/base/default/template/customer/widget/gender.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/widget/name.phtml b/app/design/frontend/base/default/template/customer/widget/name.phtml
index 76bc033..96acf2d 100644
--- a/app/design/frontend/base/default/template/customer/widget/name.phtml
+++ b/app/design/frontend/base/default/template/customer/widget/name.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/customer/widget/taxvat.phtml b/app/design/frontend/base/default/template/customer/widget/taxvat.phtml
index 105d48c..a7870be 100644
--- a/app/design/frontend/base/default/template/customer/widget/taxvat.phtml
+++ b/app/design/frontend/base/default/template/customer/widget/taxvat.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/customer/wishlist.phtml b/app/design/frontend/base/default/template/customer/wishlist.phtml
index 4cbb9ac..9651726 100644
--- a/app/design/frontend/base/default/template/customer/wishlist.phtml
+++ b/app/design/frontend/base/default/template/customer/wishlist.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/directory/currency.phtml b/app/design/frontend/base/default/template/directory/currency.phtml
index 6c9a656..3aade12 100644
--- a/app/design/frontend/base/default/template/directory/currency.phtml
+++ b/app/design/frontend/base/default/template/directory/currency.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/directory/currency/switch.phtml b/app/design/frontend/base/default/template/directory/currency/switch.phtml
index 553711d..42fcf70 100644
--- a/app/design/frontend/base/default/template/directory/currency/switch.phtml
+++ b/app/design/frontend/base/default/template/directory/currency/switch.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/directory/js/optional_zip_countries.phtml b/app/design/frontend/base/default/template/directory/js/optional_zip_countries.phtml
index f8e3c26..582b6db 100644
--- a/app/design/frontend/base/default/template/directory/js/optional_zip_countries.phtml
+++ b/app/design/frontend/base/default/template/directory/js/optional_zip_countries.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/catalog/product/links.phtml b/app/design/frontend/base/default/template/downloadable/catalog/product/links.phtml
index 4cff7a6..1fe0033 100644
--- a/app/design/frontend/base/default/template/downloadable/catalog/product/links.phtml
+++ b/app/design/frontend/base/default/template/downloadable/catalog/product/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/catalog/product/samples.phtml b/app/design/frontend/base/default/template/downloadable/catalog/product/samples.phtml
index cdd7d1b..f1c63f1 100644
--- a/app/design/frontend/base/default/template/downloadable/catalog/product/samples.phtml
+++ b/app/design/frontend/base/default/template/downloadable/catalog/product/samples.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/downloadable/catalog/product/type.phtml b/app/design/frontend/base/default/template/downloadable/catalog/product/type.phtml
index 173d8ab..85c088f 100644
--- a/app/design/frontend/base/default/template/downloadable/catalog/product/type.phtml
+++ b/app/design/frontend/base/default/template/downloadable/catalog/product/type.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/downloadable/checkout/cart/item/default.phtml b/app/design/frontend/base/default/template/downloadable/checkout/cart/item/default.phtml
index 1143c6c..0a33c5a 100644
--- a/app/design/frontend/base/default/template/downloadable/checkout/cart/item/default.phtml
+++ b/app/design/frontend/base/default/template/downloadable/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/checkout/multishipping/item/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/checkout/multishipping/item/downloadable.phtml
index 0862fc5..d4ae76b 100644
--- a/app/design/frontend/base/default/template/downloadable/checkout/multishipping/item/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/checkout/multishipping/item/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/checkout/onepage/review/item.phtml b/app/design/frontend/base/default/template/downloadable/checkout/onepage/review/item.phtml
index a45b061..a49fbb0 100644
--- a/app/design/frontend/base/default/template/downloadable/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/base/default/template/downloadable/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/checkout/success.phtml b/app/design/frontend/base/default/template/downloadable/checkout/success.phtml
index fb192d3..fcb40cf 100644
--- a/app/design/frontend/base/default/template/downloadable/checkout/success.phtml
+++ b/app/design/frontend/base/default/template/downloadable/checkout/success.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/customer/products/list.phtml b/app/design/frontend/base/default/template/downloadable/customer/products/list.phtml
index d39d0dc..9defb94 100644
--- a/app/design/frontend/base/default/template/downloadable/customer/products/list.phtml
+++ b/app/design/frontend/base/default/template/downloadable/customer/products/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
index ce056bc..f575af1 100644
--- a/app/design/frontend/base/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/email/order/items/invoice/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/email/order/items/invoice/downloadable.phtml
index cc4df77..34ffa7a 100644
--- a/app/design/frontend/base/default/template/downloadable/email/order/items/invoice/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/email/order/items/invoice/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/email/order/items/order/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/email/order/items/order/downloadable.phtml
index ececd81..0f2fccd 100644
--- a/app/design/frontend/base/default/template/downloadable/email/order/items/order/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/email/order/items/order/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
index 51f16ad..5a212fb 100644
--- a/app/design/frontend/base/default/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
index ed24916..20f3518 100644
--- a/app/design/frontend/base/default/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/downloadable/sales/order/items/renderer/downloadable.phtml b/app/design/frontend/base/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
index 59eef81..71c93ee 100644
--- a/app/design/frontend/base/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
+++ b/app/design/frontend/base/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/creditmemo/items.phtml b/app/design/frontend/base/default/template/email/order/creditmemo/items.phtml
index c3c4590..7fc4713 100644
--- a/app/design/frontend/base/default/template/email/order/creditmemo/items.phtml
+++ b/app/design/frontend/base/default/template/email/order/creditmemo/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/invoice/items.phtml b/app/design/frontend/base/default/template/email/order/invoice/items.phtml
index 6406cdc..a24ccdc 100644
--- a/app/design/frontend/base/default/template/email/order/invoice/items.phtml
+++ b/app/design/frontend/base/default/template/email/order/invoice/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/items.phtml b/app/design/frontend/base/default/template/email/order/items.phtml
index 72d7a17..e842eeb 100644
--- a/app/design/frontend/base/default/template/email/order/items.phtml
+++ b/app/design/frontend/base/default/template/email/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/items/creditmemo/default.phtml b/app/design/frontend/base/default/template/email/order/items/creditmemo/default.phtml
index 4bda71e..7e7b9d3 100644
--- a/app/design/frontend/base/default/template/email/order/items/creditmemo/default.phtml
+++ b/app/design/frontend/base/default/template/email/order/items/creditmemo/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/items/invoice/default.phtml b/app/design/frontend/base/default/template/email/order/items/invoice/default.phtml
index 4bda71e..7e7b9d3 100644
--- a/app/design/frontend/base/default/template/email/order/items/invoice/default.phtml
+++ b/app/design/frontend/base/default/template/email/order/items/invoice/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/items/order/default.phtml b/app/design/frontend/base/default/template/email/order/items/order/default.phtml
index b464b0a..e292b36 100644
--- a/app/design/frontend/base/default/template/email/order/items/order/default.phtml
+++ b/app/design/frontend/base/default/template/email/order/items/order/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/items/shipment/default.phtml b/app/design/frontend/base/default/template/email/order/items/shipment/default.phtml
index ca67923..adad419 100644
--- a/app/design/frontend/base/default/template/email/order/items/shipment/default.phtml
+++ b/app/design/frontend/base/default/template/email/order/items/shipment/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/shipment/items.phtml b/app/design/frontend/base/default/template/email/order/shipment/items.phtml
index 125d11d..9893408 100644
--- a/app/design/frontend/base/default/template/email/order/shipment/items.phtml
+++ b/app/design/frontend/base/default/template/email/order/shipment/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/order/shipment/track.phtml b/app/design/frontend/base/default/template/email/order/shipment/track.phtml
index 32e7f08..862dccc 100644
--- a/app/design/frontend/base/default/template/email/order/shipment/track.phtml
+++ b/app/design/frontend/base/default/template/email/order/shipment/track.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/email/productalert/price.phtml b/app/design/frontend/base/default/template/email/productalert/price.phtml
index 115afc7..6b1a740 100644
--- a/app/design/frontend/base/default/template/email/productalert/price.phtml
+++ b/app/design/frontend/base/default/template/email/productalert/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/email/productalert/stock.phtml b/app/design/frontend/base/default/template/email/productalert/stock.phtml
index a89abef..a9f5230 100644
--- a/app/design/frontend/base/default/template/email/productalert/stock.phtml
+++ b/app/design/frontend/base/default/template/email/productalert/stock.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/giftmessage/inline.phtml b/app/design/frontend/base/default/template/giftmessage/inline.phtml
index c175380..f0cb014 100644
--- a/app/design/frontend/base/default/template/giftmessage/inline.phtml
+++ b/app/design/frontend/base/default/template/giftmessage/inline.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/googleanalytics/ga.phtml b/app/design/frontend/base/default/template/googleanalytics/ga.phtml
index 1201eed..01bf64b 100644
--- a/app/design/frontend/base/default/template/googleanalytics/ga.phtml
+++ b/app/design/frontend/base/default/template/googleanalytics/ga.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/blank.phtml b/app/design/frontend/base/default/template/moneybookers/blank.phtml
index 2e4b1ba..75cf483 100644
--- a/app/design/frontend/base/default/template/moneybookers/blank.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/blank.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/form.phtml b/app/design/frontend/base/default/template/moneybookers/form.phtml
index 97eb18d..999134d 100644
--- a/app/design/frontend/base/default/template/moneybookers/form.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/info.phtml b/app/design/frontend/base/default/template/moneybookers/info.phtml
index ff50156..06a713a 100644
--- a/app/design/frontend/base/default/template/moneybookers/info.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/payment.phtml b/app/design/frontend/base/default/template/moneybookers/payment.phtml
index d51be25..5a60d83 100644
--- a/app/design/frontend/base/default/template/moneybookers/payment.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/payment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/placeform.phtml b/app/design/frontend/base/default/template/moneybookers/placeform.phtml
index 85523bf..04c3393 100644
--- a/app/design/frontend/base/default/template/moneybookers/placeform.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/placeform.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/moneybookers/redirect.phtml b/app/design/frontend/base/default/template/moneybookers/redirect.phtml
index 3ba50a7..b07c86f 100644
--- a/app/design/frontend/base/default/template/moneybookers/redirect.phtml
+++ b/app/design/frontend/base/default/template/moneybookers/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/newsletter/subscribe.phtml b/app/design/frontend/base/default/template/newsletter/subscribe.phtml
index 7add9b9..c206ac7 100644
--- a/app/design/frontend/base/default/template/newsletter/subscribe.phtml
+++ b/app/design/frontend/base/default/template/newsletter/subscribe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/oauth/authorize/button-simple.phtml b/app/design/frontend/base/default/template/oauth/authorize/button-simple.phtml
index 06783fa..e1a37b3 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/button-simple.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/button-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/oauth/authorize/button.phtml b/app/design/frontend/base/default/template/oauth/authorize/button.phtml
index e31bd55..c286b2a 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/button.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/button.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/oauth/authorize/confirm-simple.phtml b/app/design/frontend/base/default/template/oauth/authorize/confirm-simple.phtml
index 364a152..b0261b6 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/confirm-simple.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/confirm-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/confirm.phtml b/app/design/frontend/base/default/template/oauth/authorize/confirm.phtml
index bcb6812..986df86 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/confirm.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/confirm.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/form/login-simple.phtml b/app/design/frontend/base/default/template/oauth/authorize/form/login-simple.phtml
index 1cf7fbf..29866f7 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/form/login-simple.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/form/login-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/form/login.phtml b/app/design/frontend/base/default/template/oauth/authorize/form/login.phtml
index fa05acf..b66515a 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/form/login.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/head-simple.phtml b/app/design/frontend/base/default/template/oauth/authorize/head-simple.phtml
index 439d176..20ffaf7 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/head-simple.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/head-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/reject-simple.phtml b/app/design/frontend/base/default/template/oauth/authorize/reject-simple.phtml
index eaaf642..38d4f89 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/reject-simple.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/reject-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/authorize/reject.phtml b/app/design/frontend/base/default/template/oauth/authorize/reject.phtml
index 448c80a..68cae0f 100644
--- a/app/design/frontend/base/default/template/oauth/authorize/reject.phtml
+++ b/app/design/frontend/base/default/template/oauth/authorize/reject.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/oauth/customer/token/list.phtml b/app/design/frontend/base/default/template/oauth/customer/token/list.phtml
index 4328f7c..e946594 100644
--- a/app/design/frontend/base/default/template/oauth/customer/token/list.phtml
+++ b/app/design/frontend/base/default/template/oauth/customer/token/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/page/1column.phtml b/app/design/frontend/base/default/template/page/1column.phtml
index 50d224a..021be9c 100644
--- a/app/design/frontend/base/default/template/page/1column.phtml
+++ b/app/design/frontend/base/default/template/page/1column.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/2columns-left.phtml b/app/design/frontend/base/default/template/page/2columns-left.phtml
index 31817e7..d5d1c86 100644
--- a/app/design/frontend/base/default/template/page/2columns-left.phtml
+++ b/app/design/frontend/base/default/template/page/2columns-left.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/2columns-right.phtml b/app/design/frontend/base/default/template/page/2columns-right.phtml
index f2c3872..ddfb0a2 100644
--- a/app/design/frontend/base/default/template/page/2columns-right.phtml
+++ b/app/design/frontend/base/default/template/page/2columns-right.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/3columns.phtml b/app/design/frontend/base/default/template/page/3columns.phtml
index 5492ce5..2eaa2d5 100644
--- a/app/design/frontend/base/default/template/page/3columns.phtml
+++ b/app/design/frontend/base/default/template/page/3columns.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/empty.phtml b/app/design/frontend/base/default/template/page/empty.phtml
index 7a7ba63..6df73d5 100644
--- a/app/design/frontend/base/default/template/page/empty.phtml
+++ b/app/design/frontend/base/default/template/page/empty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/breadcrumbs.phtml b/app/design/frontend/base/default/template/page/html/breadcrumbs.phtml
index 30d9715..ed45711 100644
--- a/app/design/frontend/base/default/template/page/html/breadcrumbs.phtml
+++ b/app/design/frontend/base/default/template/page/html/breadcrumbs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/cookienotice.phtml b/app/design/frontend/base/default/template/page/html/cookienotice.phtml
index 94bf857..7d1b2d8 100644
--- a/app/design/frontend/base/default/template/page/html/cookienotice.phtml
+++ b/app/design/frontend/base/default/template/page/html/cookienotice.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/footer.phtml b/app/design/frontend/base/default/template/page/html/footer.phtml
index 1c9e0e6..e7062f2 100644
--- a/app/design/frontend/base/default/template/page/html/footer.phtml
+++ b/app/design/frontend/base/default/template/page/html/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/head.phtml b/app/design/frontend/base/default/template/page/html/head.phtml
index afb3384..ef1b19a 100644
--- a/app/design/frontend/base/default/template/page/html/head.phtml
+++ b/app/design/frontend/base/default/template/page/html/head.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/header.phtml b/app/design/frontend/base/default/template/page/html/header.phtml
index 384e000..d2bdf7e 100644
--- a/app/design/frontend/base/default/template/page/html/header.phtml
+++ b/app/design/frontend/base/default/template/page/html/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/page/html/notices.phtml b/app/design/frontend/base/default/template/page/html/notices.phtml
index 61af04c..02f03ff 100644
--- a/app/design/frontend/base/default/template/page/html/notices.phtml
+++ b/app/design/frontend/base/default/template/page/html/notices.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/pager.phtml b/app/design/frontend/base/default/template/page/html/pager.phtml
index 9387f2b..7bacd80 100644
--- a/app/design/frontend/base/default/template/page/html/pager.phtml
+++ b/app/design/frontend/base/default/template/page/html/pager.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/top.links.phtml b/app/design/frontend/base/default/template/page/html/top.links.phtml
index c11e7a8..079b084 100644
--- a/app/design/frontend/base/default/template/page/html/top.links.phtml
+++ b/app/design/frontend/base/default/template/page/html/top.links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/topmenu.phtml b/app/design/frontend/base/default/template/page/html/topmenu.phtml
index c2043f0..ce836d9 100644
--- a/app/design/frontend/base/default/template/page/html/topmenu.phtml
+++ b/app/design/frontend/base/default/template/page/html/topmenu.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/html/wrapper.phtml b/app/design/frontend/base/default/template/page/html/wrapper.phtml
index 48d3834..0c1e9fb 100644
--- a/app/design/frontend/base/default/template/page/html/wrapper.phtml
+++ b/app/design/frontend/base/default/template/page/html/wrapper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/js/calendar.phtml b/app/design/frontend/base/default/template/page/js/calendar.phtml
index 1ba50c9..93e2600 100644
--- a/app/design/frontend/base/default/template/page/js/calendar.phtml
+++ b/app/design/frontend/base/default/template/page/js/calendar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/js/cookie.phtml b/app/design/frontend/base/default/template/page/js/cookie.phtml
index b884fc3..ed32514 100644
--- a/app/design/frontend/base/default/template/page/js/cookie.phtml
+++ b/app/design/frontend/base/default/template/page/js/cookie.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/popup.phtml b/app/design/frontend/base/default/template/page/popup.phtml
index 3012efa..2abe117 100644
--- a/app/design/frontend/base/default/template/page/popup.phtml
+++ b/app/design/frontend/base/default/template/page/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/print.phtml b/app/design/frontend/base/default/template/page/print.phtml
index 3e4ad15..10711bf 100644
--- a/app/design/frontend/base/default/template/page/print.phtml
+++ b/app/design/frontend/base/default/template/page/print.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/redirect.phtml b/app/design/frontend/base/default/template/page/redirect.phtml
index f6a25eb..ed60286 100644
--- a/app/design/frontend/base/default/template/page/redirect.phtml
+++ b/app/design/frontend/base/default/template/page/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/switch/flags.phtml b/app/design/frontend/base/default/template/page/switch/flags.phtml
index 00f1141..c4d34b1 100644
--- a/app/design/frontend/base/default/template/page/switch/flags.phtml
+++ b/app/design/frontend/base/default/template/page/switch/flags.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/switch/languages.phtml b/app/design/frontend/base/default/template/page/switch/languages.phtml
index 2d58359..070c9c7 100644
--- a/app/design/frontend/base/default/template/page/switch/languages.phtml
+++ b/app/design/frontend/base/default/template/page/switch/languages.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/switch/stores.phtml b/app/design/frontend/base/default/template/page/switch/stores.phtml
index 2563492..beb6e9b 100644
--- a/app/design/frontend/base/default/template/page/switch/stores.phtml
+++ b/app/design/frontend/base/default/template/page/switch/stores.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/template/container.phtml b/app/design/frontend/base/default/template/page/template/container.phtml
index 2ebc5a2..15d788d 100644
--- a/app/design/frontend/base/default/template/page/template/container.phtml
+++ b/app/design/frontend/base/default/template/page/template/container.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/template/links.phtml b/app/design/frontend/base/default/template/page/template/links.phtml
index 013be03..17f0b81 100644
--- a/app/design/frontend/base/default/template/page/template/links.phtml
+++ b/app/design/frontend/base/default/template/page/template/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/page/template/linksblock.phtml b/app/design/frontend/base/default/template/page/template/linksblock.phtml
index 5295353..f2bab6c 100644
--- a/app/design/frontend/base/default/template/page/template/linksblock.phtml
+++ b/app/design/frontend/base/default/template/page/template/linksblock.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/pagecache/cookie.phtml b/app/design/frontend/base/default/template/pagecache/cookie.phtml
index 171da33..9ce97c1 100644
--- a/app/design/frontend/base/default/template/pagecache/cookie.phtml
+++ b/app/design/frontend/base/default/template/pagecache/cookie.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paygate/form/cc.phtml b/app/design/frontend/base/default/template/paygate/form/cc.phtml
index bc4c370..6176941 100644
--- a/app/design/frontend/base/default/template/paygate/form/cc.phtml
+++ b/app/design/frontend/base/default/template/paygate/form/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paygate/info/cc.phtml b/app/design/frontend/base/default/template/paygate/info/cc.phtml
index eeb6079..0a652a7 100644
--- a/app/design/frontend/base/default/template/paygate/info/cc.phtml
+++ b/app/design/frontend/base/default/template/paygate/info/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/catalog/product/view/profile/options.phtml b/app/design/frontend/base/default/template/payment/catalog/product/view/profile/options.phtml
index ffa8485..ec5e051 100644
--- a/app/design/frontend/base/default/template/payment/catalog/product/view/profile/options.phtml
+++ b/app/design/frontend/base/default/template/payment/catalog/product/view/profile/options.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/catalog/product/view/profile/schedule.phtml b/app/design/frontend/base/default/template/payment/catalog/product/view/profile/schedule.phtml
index 2806779..6c38ae5 100644
--- a/app/design/frontend/base/default/template/payment/catalog/product/view/profile/schedule.phtml
+++ b/app/design/frontend/base/default/template/payment/catalog/product/view/profile/schedule.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/form/banktransfer.phtml b/app/design/frontend/base/default/template/payment/form/banktransfer.phtml
index 98eb0d2..f6b6d2d 100644
--- a/app/design/frontend/base/default/template/payment/form/banktransfer.phtml
+++ b/app/design/frontend/base/default/template/payment/form/banktransfer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/form/cashondelivery.phtml b/app/design/frontend/base/default/template/payment/form/cashondelivery.phtml
index b62837c..1f65295 100644
--- a/app/design/frontend/base/default/template/payment/form/cashondelivery.phtml
+++ b/app/design/frontend/base/default/template/payment/form/cashondelivery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/payment/form/cc.phtml b/app/design/frontend/base/default/template/payment/form/cc.phtml
index d305899..d3c102f 100644
--- a/app/design/frontend/base/default/template/payment/form/cc.phtml
+++ b/app/design/frontend/base/default/template/payment/form/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/form/ccsave.phtml b/app/design/frontend/base/default/template/payment/form/ccsave.phtml
index 1f364a6..ad94d48 100644
--- a/app/design/frontend/base/default/template/payment/form/ccsave.phtml
+++ b/app/design/frontend/base/default/template/payment/form/ccsave.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/form/checkmo.phtml b/app/design/frontend/base/default/template/payment/form/checkmo.phtml
index d5cb9e5..532c6c8 100644
--- a/app/design/frontend/base/default/template/payment/form/checkmo.phtml
+++ b/app/design/frontend/base/default/template/payment/form/checkmo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/form/purchaseorder.phtml b/app/design/frontend/base/default/template/payment/form/purchaseorder.phtml
index d1de677..9f60079 100644
--- a/app/design/frontend/base/default/template/payment/form/purchaseorder.phtml
+++ b/app/design/frontend/base/default/template/payment/form/purchaseorder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/info/banktransfer.phtml b/app/design/frontend/base/default/template/payment/info/banktransfer.phtml
index 3a23ea1..b6edbfb 100644
--- a/app/design/frontend/base/default/template/payment/info/banktransfer.phtml
+++ b/app/design/frontend/base/default/template/payment/info/banktransfer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/info/checkmo.phtml b/app/design/frontend/base/default/template/payment/info/checkmo.phtml
index 6b1326c..bd0ea28 100644
--- a/app/design/frontend/base/default/template/payment/info/checkmo.phtml
+++ b/app/design/frontend/base/default/template/payment/info/checkmo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/info/default.phtml b/app/design/frontend/base/default/template/payment/info/default.phtml
index b8d0041..2fb2911 100644
--- a/app/design/frontend/base/default/template/payment/info/default.phtml
+++ b/app/design/frontend/base/default/template/payment/info/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/payment/info/purchaseorder.phtml b/app/design/frontend/base/default/template/payment/info/purchaseorder.phtml
index 6647018..dbaf0c8 100644
--- a/app/design/frontend/base/default/template/payment/info/purchaseorder.phtml
+++ b/app/design/frontend/base/default/template/payment/info/purchaseorder.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/bml.phtml b/app/design/frontend/base/default/template/paypal/bml.phtml
index a82f177..0d6adbc 100644
--- a/app/design/frontend/base/default/template/paypal/bml.phtml
+++ b/app/design/frontend/base/default/template/paypal/bml.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/express/review.phtml b/app/design/frontend/base/default/template/paypal/express/review.phtml
index cfc3eb9..0cf7e06 100644
--- a/app/design/frontend/base/default/template/paypal/express/review.phtml
+++ b/app/design/frontend/base/default/template/paypal/express/review.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Express_Review */
diff --git a/app/design/frontend/base/default/template/paypal/express/review/details.phtml b/app/design/frontend/base/default/template/paypal/express/review/details.phtml
index 9b22367..852b7b7 100644
--- a/app/design/frontend/base/default/template/paypal/express/review/details.phtml
+++ b/app/design/frontend/base/default/template/paypal/express/review/details.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/express/review/shipping/method.phtml b/app/design/frontend/base/default/template/paypal/express/review/shipping/method.phtml
index 577b4f0..9d144bd 100644
--- a/app/design/frontend/base/default/template/paypal/express/review/shipping/method.phtml
+++ b/app/design/frontend/base/default/template/paypal/express/review/shipping/method.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Express_Review */
diff --git a/app/design/frontend/base/default/template/paypal/express/shortcut.phtml b/app/design/frontend/base/default/template/paypal/express/shortcut.phtml
index 26e0f1b..a207bad 100644
--- a/app/design/frontend/base/default/template/paypal/express/shortcut.phtml
+++ b/app/design/frontend/base/default/template/paypal/express/shortcut.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/hss/form.phtml b/app/design/frontend/base/default/template/paypal/hss/form.phtml
index c008271..f8a7a70 100644
--- a/app/design/frontend/base/default/template/paypal/hss/form.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/hss/iframe.phtml b/app/design/frontend/base/default/template/paypal/hss/iframe.phtml
index 86e67a9..7558fef 100644
--- a/app/design/frontend/base/default/template/paypal/hss/iframe.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/hss/info.phtml b/app/design/frontend/base/default/template/paypal/hss/info.phtml
index 2a514b4..3aee23b 100644
--- a/app/design/frontend/base/default/template/paypal/hss/info.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/hss/js.phtml b/app/design/frontend/base/default/template/paypal/hss/js.phtml
index 9592042..7bd7938 100644
--- a/app/design/frontend/base/default/template/paypal/hss/js.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/hss/redirect.phtml b/app/design/frontend/base/default/template/paypal/hss/redirect.phtml
index 1e5fcfa..2a52023 100644
--- a/app/design/frontend/base/default/template/paypal/hss/redirect.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/hss/review/button.phtml b/app/design/frontend/base/default/template/paypal/hss/review/button.phtml
index 19a6dfa..77861c8 100644
--- a/app/design/frontend/base/default/template/paypal/hss/review/button.phtml
+++ b/app/design/frontend/base/default/template/paypal/hss/review/button.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/partner/logo.phtml b/app/design/frontend/base/default/template/paypal/partner/logo.phtml
index 8951a20..6373672 100644
--- a/app/design/frontend/base/default/template/paypal/partner/logo.phtml
+++ b/app/design/frontend/base/default/template/paypal/partner/logo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/partner/us_logo.phtml b/app/design/frontend/base/default/template/paypal/partner/us_logo.phtml
index 7da9df5..7027d5a 100644
--- a/app/design/frontend/base/default/template/paypal/partner/us_logo.phtml
+++ b/app/design/frontend/base/default/template/paypal/partner/us_logo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/payflowadvanced/iframe.phtml b/app/design/frontend/base/default/template/paypal/payflowadvanced/iframe.phtml
index 2f63126..87d18ef 100644
--- a/app/design/frontend/base/default/template/paypal/payflowadvanced/iframe.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowadvanced/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Payflow_Advanced_Iframe */
diff --git a/app/design/frontend/base/default/template/paypal/payflowadvanced/info.phtml b/app/design/frontend/base/default/template/paypal/payflowadvanced/info.phtml
index 2116d24..3b2df93 100644
--- a/app/design/frontend/base/default/template/paypal/payflowadvanced/info.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowadvanced/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/payflowadvanced/redirect.phtml b/app/design/frontend/base/default/template/paypal/payflowadvanced/redirect.phtml
index b54e334..65aafc9 100644
--- a/app/design/frontend/base/default/template/paypal/payflowadvanced/redirect.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowadvanced/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/payflowlink/iframe.phtml b/app/design/frontend/base/default/template/paypal/payflowlink/iframe.phtml
index e671790..72494ce 100644
--- a/app/design/frontend/base/default/template/paypal/payflowlink/iframe.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowlink/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Payflow_Link_Iframe */
diff --git a/app/design/frontend/base/default/template/paypal/payflowlink/info.phtml b/app/design/frontend/base/default/template/paypal/payflowlink/info.phtml
index 1aa9452..7969fd3 100644
--- a/app/design/frontend/base/default/template/paypal/payflowlink/info.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowlink/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/payflowlink/redirect.phtml b/app/design/frontend/base/default/template/paypal/payflowlink/redirect.phtml
index 6b178e4..d58840a 100644
--- a/app/design/frontend/base/default/template/paypal/payflowlink/redirect.phtml
+++ b/app/design/frontend/base/default/template/paypal/payflowlink/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/paypal/payment/mark.phtml b/app/design/frontend/base/default/template/paypal/payment/mark.phtml
index 42c7117..fb3d694 100644
--- a/app/design/frontend/base/default/template/paypal/payment/mark.phtml
+++ b/app/design/frontend/base/default/template/paypal/payment/mark.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/paypal/payment/redirect.phtml b/app/design/frontend/base/default/template/paypal/payment/redirect.phtml
index 7dd901d..0e52805 100644
--- a/app/design/frontend/base/default/template/paypal/payment/redirect.phtml
+++ b/app/design/frontend/base/default/template/paypal/payment/redirect.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/persistent/checkout/onepage/billing.phtml b/app/design/frontend/base/default/template/persistent/checkout/onepage/billing.phtml
index 6ac3286..73b59d3 100644
--- a/app/design/frontend/base/default/template/persistent/checkout/onepage/billing.phtml
+++ b/app/design/frontend/base/default/template/persistent/checkout/onepage/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var Mage_Checkout_Block_Onepage_Billing $this */
diff --git a/app/design/frontend/base/default/template/persistent/checkout/onepage/login.phtml b/app/design/frontend/base/default/template/persistent/checkout/onepage/login.phtml
index 993ee61..3a1232f 100644
--- a/app/design/frontend/base/default/template/persistent/checkout/onepage/login.phtml
+++ b/app/design/frontend/base/default/template/persistent/checkout/onepage/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/persistent/customer/form/login.phtml b/app/design/frontend/base/default/template/persistent/customer/form/login.phtml
index 3e709ae..80553bf 100644
--- a/app/design/frontend/base/default/template/persistent/customer/form/login.phtml
+++ b/app/design/frontend/base/default/template/persistent/customer/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/persistent/customer/form/register.phtml b/app/design/frontend/base/default/template/persistent/customer/form/register.phtml
index ec185f8..2bc0884 100644
--- a/app/design/frontend/base/default/template/persistent/customer/form/register.phtml
+++ b/app/design/frontend/base/default/template/persistent/customer/form/register.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/persistent/remember_me.phtml b/app/design/frontend/base/default/template/persistent/remember_me.phtml
index 99401e5..dfd8b12 100644
--- a/app/design/frontend/base/default/template/persistent/remember_me.phtml
+++ b/app/design/frontend/base/default/template/persistent/remember_me.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/persistent/remember_me_tooltip.phtml b/app/design/frontend/base/default/template/persistent/remember_me_tooltip.phtml
index cbae9d0..78d5ca9 100644
--- a/app/design/frontend/base/default/template/persistent/remember_me_tooltip.phtml
+++ b/app/design/frontend/base/default/template/persistent/remember_me_tooltip.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/poll/active.phtml b/app/design/frontend/base/default/template/poll/active.phtml
index 2ccb839..bfe58a5 100644
--- a/app/design/frontend/base/default/template/poll/active.phtml
+++ b/app/design/frontend/base/default/template/poll/active.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/poll/result.phtml b/app/design/frontend/base/default/template/poll/result.phtml
index 0d91f03..c526824 100644
--- a/app/design/frontend/base/default/template/poll/result.phtml
+++ b/app/design/frontend/base/default/template/poll/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/productalert/price.phtml b/app/design/frontend/base/default/template/productalert/price.phtml
index f7d6208..a1c52a1 100644
--- a/app/design/frontend/base/default/template/productalert/price.phtml
+++ b/app/design/frontend/base/default/template/productalert/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/productalert/product/view.phtml b/app/design/frontend/base/default/template/productalert/product/view.phtml
index b038aab..e0fc020 100644
--- a/app/design/frontend/base/default/template/productalert/product/view.phtml
+++ b/app/design/frontend/base/default/template/productalert/product/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/productalert/stock.phtml b/app/design/frontend/base/default/template/productalert/stock.phtml
index f7d6208..a1c52a1 100644
--- a/app/design/frontend/base/default/template/productalert/stock.phtml
+++ b/app/design/frontend/base/default/template/productalert/stock.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/rating/detailed.phtml b/app/design/frontend/base/default/template/rating/detailed.phtml
index cbfb3d3..a95c5bb 100644
--- a/app/design/frontend/base/default/template/rating/detailed.phtml
+++ b/app/design/frontend/base/default/template/rating/detailed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/rating/empty.phtml b/app/design/frontend/base/default/template/rating/empty.phtml
index e75d359..0dbc6ad 100644
--- a/app/design/frontend/base/default/template/rating/empty.phtml
+++ b/app/design/frontend/base/default/template/rating/empty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/home_product_compared.phtml b/app/design/frontend/base/default/template/reports/home_product_compared.phtml
index 0f603e8..e403b29 100644
--- a/app/design/frontend/base/default/template/reports/home_product_compared.phtml
+++ b/app/design/frontend/base/default/template/reports/home_product_compared.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Reports_Block_Product_Compared */
diff --git a/app/design/frontend/base/default/template/reports/home_product_viewed.phtml b/app/design/frontend/base/default/template/reports/home_product_viewed.phtml
index f469b86..b978557 100644
--- a/app/design/frontend/base/default/template/reports/home_product_viewed.phtml
+++ b/app/design/frontend/base/default/template/reports/home_product_viewed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Reports_Block_Product_Viewed */
diff --git a/app/design/frontend/base/default/template/reports/product_compared.phtml b/app/design/frontend/base/default/template/reports/product_compared.phtml
index 19e37ba..a3fea56 100644
--- a/app/design/frontend/base/default/template/reports/product_compared.phtml
+++ b/app/design/frontend/base/default/template/reports/product_compared.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Reports_Block_Product_Compared */
diff --git a/app/design/frontend/base/default/template/reports/product_viewed.phtml b/app/design/frontend/base/default/template/reports/product_viewed.phtml
index 364966c..fdf8512 100644
--- a/app/design/frontend/base/default/template/reports/product_viewed.phtml
+++ b/app/design/frontend/base/default/template/reports/product_viewed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Reports_Block_Product_Viewed */
diff --git a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_default_list.phtml b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_default_list.phtml
index 376abe0..db08725 100644
--- a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_default_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_images_list.phtml b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_images_list.phtml
index 77cca2f..843e400 100644
--- a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_images_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_names_list.phtml b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_names_list.phtml
index 35ed13b..90b21d7 100644
--- a/app/design/frontend/base/default/template/reports/widget/compared/column/compared_names_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/compared/column/compared_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/compared/content/compared_grid.phtml b/app/design/frontend/base/default/template/reports/widget/compared/content/compared_grid.phtml
index 7fefbed..d351802 100644
--- a/app/design/frontend/base/default/template/reports/widget/compared/content/compared_grid.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/compared/content/compared_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/compared/content/compared_list.phtml b/app/design/frontend/base/default/template/reports/widget/compared/content/compared_list.phtml
index f9a5b07..301e0b2 100644
--- a/app/design/frontend/base/default/template/reports/widget/compared/content/compared_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/compared/content/compared_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_default_list.phtml b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_default_list.phtml
index 953354d..c51be8e 100644
--- a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_default_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_images_list.phtml b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_images_list.phtml
index 6c09adf..bf56015 100644
--- a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_images_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_names_list.phtml b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_names_list.phtml
index 2d2260b..482d206 100644
--- a/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_names_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/viewed/column/viewed_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_grid.phtml b/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_grid.phtml
index 3b48ec6..069edf3 100644
--- a/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_grid.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_list.phtml b/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_list.phtml
index 147b17b..20e9ba0 100644
--- a/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_list.phtml
+++ b/app/design/frontend/base/default/template/reports/widget/viewed/content/viewed_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/customer/list.phtml b/app/design/frontend/base/default/template/review/customer/list.phtml
index 2e983d6..3ba7d08 100644
--- a/app/design/frontend/base/default/template/review/customer/list.phtml
+++ b/app/design/frontend/base/default/template/review/customer/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/customer/recent.phtml b/app/design/frontend/base/default/template/review/customer/recent.phtml
index 3e3146e..ff92e7e 100644
--- a/app/design/frontend/base/default/template/review/customer/recent.phtml
+++ b/app/design/frontend/base/default/template/review/customer/recent.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/customer/view.phtml b/app/design/frontend/base/default/template/review/customer/view.phtml
index ece5d23..c706d7b 100644
--- a/app/design/frontend/base/default/template/review/customer/view.phtml
+++ b/app/design/frontend/base/default/template/review/customer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/form.phtml b/app/design/frontend/base/default/template/review/form.phtml
index 4f2fb0a..a42558c 100644
--- a/app/design/frontend/base/default/template/review/form.phtml
+++ b/app/design/frontend/base/default/template/review/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/helper/summary.phtml b/app/design/frontend/base/default/template/review/helper/summary.phtml
index 03579c6..571e6bf 100644
--- a/app/design/frontend/base/default/template/review/helper/summary.phtml
+++ b/app/design/frontend/base/default/template/review/helper/summary.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/helper/summary_short.phtml b/app/design/frontend/base/default/template/review/helper/summary_short.phtml
index a37bcf1..19837e9 100644
--- a/app/design/frontend/base/default/template/review/helper/summary_short.phtml
+++ b/app/design/frontend/base/default/template/review/helper/summary_short.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/product/view/count.phtml b/app/design/frontend/base/default/template/review/product/view/count.phtml
index a704dc6..093e2ca 100644
--- a/app/design/frontend/base/default/template/review/product/view/count.phtml
+++ b/app/design/frontend/base/default/template/review/product/view/count.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/product/view/list.phtml b/app/design/frontend/base/default/template/review/product/view/list.phtml
index f51fe9f..0b0c0a2 100644
--- a/app/design/frontend/base/default/template/review/product/view/list.phtml
+++ b/app/design/frontend/base/default/template/review/product/view/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/product/view/other.phtml b/app/design/frontend/base/default/template/review/product/view/other.phtml
index ed7fca5..b807214 100644
--- a/app/design/frontend/base/default/template/review/product/view/other.phtml
+++ b/app/design/frontend/base/default/template/review/product/view/other.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/review/view.phtml b/app/design/frontend/base/default/template/review/view.phtml
index f49d954..3530002 100644
--- a/app/design/frontend/base/default/template/review/view.phtml
+++ b/app/design/frontend/base/default/template/review/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/rss/list.phtml b/app/design/frontend/base/default/template/rss/list.phtml
index 64f19eb..33d59d4 100644
--- a/app/design/frontend/base/default/template/rss/list.phtml
+++ b/app/design/frontend/base/default/template/rss/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/rss/nofeed.phtml b/app/design/frontend/base/default/template/rss/nofeed.phtml
index 85131f3..65cb754 100644
--- a/app/design/frontend/base/default/template/rss/nofeed.phtml
+++ b/app/design/frontend/base/default/template/rss/nofeed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/rss/order/details.phtml b/app/design/frontend/base/default/template/rss/order/details.phtml
index 6820080..a2bb80c 100644
--- a/app/design/frontend/base/default/template/rss/order/details.phtml
+++ b/app/design/frontend/base/default/template/rss/order/details.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*
diff --git a/app/design/frontend/base/default/template/sales/billing/agreement/view.phtml b/app/design/frontend/base/default/template/sales/billing/agreement/view.phtml
index 5fa31e3..81ecde5 100644
--- a/app/design/frontend/base/default/template/sales/billing/agreement/view.phtml
+++ b/app/design/frontend/base/default/template/sales/billing/agreement/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/billing/agreements.phtml b/app/design/frontend/base/default/template/sales/billing/agreements.phtml
index 4c09a73..1b0098b 100644
--- a/app/design/frontend/base/default/template/sales/billing/agreements.phtml
+++ b/app/design/frontend/base/default/template/sales/billing/agreements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/guest/form.phtml b/app/design/frontend/base/default/template/sales/guest/form.phtml
index 9563082d..6775a9e 100644
--- a/app/design/frontend/base/default/template/sales/guest/form.phtml
+++ b/app/design/frontend/base/default/template/sales/guest/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/comments.phtml b/app/design/frontend/base/default/template/sales/order/comments.phtml
index 41d37f3..ea887fa 100644
--- a/app/design/frontend/base/default/template/sales/order/comments.phtml
+++ b/app/design/frontend/base/default/template/sales/order/comments.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/creditmemo.phtml b/app/design/frontend/base/default/template/sales/order/creditmemo.phtml
index 942fde9..7213315 100644
--- a/app/design/frontend/base/default/template/sales/order/creditmemo.phtml
+++ b/app/design/frontend/base/default/template/sales/order/creditmemo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/creditmemo/items.phtml b/app/design/frontend/base/default/template/sales/order/creditmemo/items.phtml
index bb5368e..612ba9b 100644
--- a/app/design/frontend/base/default/template/sales/order/creditmemo/items.phtml
+++ b/app/design/frontend/base/default/template/sales/order/creditmemo/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/creditmemo/items/renderer/default.phtml b/app/design/frontend/base/default/template/sales/order/creditmemo/items/renderer/default.phtml
index 335783a..c8604ef 100644
--- a/app/design/frontend/base/default/template/sales/order/creditmemo/items/renderer/default.phtml
+++ b/app/design/frontend/base/default/template/sales/order/creditmemo/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/details.phtml b/app/design/frontend/base/default/template/sales/order/details.phtml
index d8c0dba..e29601a 100644
--- a/app/design/frontend/base/default/template/sales/order/details.phtml
+++ b/app/design/frontend/base/default/template/sales/order/details.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/sales/order/history.phtml b/app/design/frontend/base/default/template/sales/order/history.phtml
index 46a4760..6f42e6c 100644
--- a/app/design/frontend/base/default/template/sales/order/history.phtml
+++ b/app/design/frontend/base/default/template/sales/order/history.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/info.phtml b/app/design/frontend/base/default/template/sales/order/info.phtml
index 35f28cd..6c13fa7 100644
--- a/app/design/frontend/base/default/template/sales/order/info.phtml
+++ b/app/design/frontend/base/default/template/sales/order/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/info/buttons.phtml b/app/design/frontend/base/default/template/sales/order/info/buttons.phtml
index 0abce4c..0c1366d 100644
--- a/app/design/frontend/base/default/template/sales/order/info/buttons.phtml
+++ b/app/design/frontend/base/default/template/sales/order/info/buttons.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/invoice.phtml b/app/design/frontend/base/default/template/sales/order/invoice.phtml
index cedb6c6..8aac8b5 100644
--- a/app/design/frontend/base/default/template/sales/order/invoice.phtml
+++ b/app/design/frontend/base/default/template/sales/order/invoice.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/invoice/items.phtml b/app/design/frontend/base/default/template/sales/order/invoice/items.phtml
index aa8a13e..c4a5c05 100644
--- a/app/design/frontend/base/default/template/sales/order/invoice/items.phtml
+++ b/app/design/frontend/base/default/template/sales/order/invoice/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/invoice/items/renderer/default.phtml b/app/design/frontend/base/default/template/sales/order/invoice/items/renderer/default.phtml
index e743d38..d7c61a2 100644
--- a/app/design/frontend/base/default/template/sales/order/invoice/items/renderer/default.phtml
+++ b/app/design/frontend/base/default/template/sales/order/invoice/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/items.phtml b/app/design/frontend/base/default/template/sales/order/items.phtml
index e621c58..c48bed9 100644
--- a/app/design/frontend/base/default/template/sales/order/items.phtml
+++ b/app/design/frontend/base/default/template/sales/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/items/renderer/default.phtml b/app/design/frontend/base/default/template/sales/order/items/renderer/default.phtml
index 73103df..906f609 100644
--- a/app/design/frontend/base/default/template/sales/order/items/renderer/default.phtml
+++ b/app/design/frontend/base/default/template/sales/order/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/print.phtml b/app/design/frontend/base/default/template/sales/order/print.phtml
index b55512f..0f45fdb 100644
--- a/app/design/frontend/base/default/template/sales/order/print.phtml
+++ b/app/design/frontend/base/default/template/sales/order/print.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/print/creditmemo.phtml b/app/design/frontend/base/default/template/sales/order/print/creditmemo.phtml
index 2007ee4..002c400 100644
--- a/app/design/frontend/base/default/template/sales/order/print/creditmemo.phtml
+++ b/app/design/frontend/base/default/template/sales/order/print/creditmemo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/print/invoice.phtml b/app/design/frontend/base/default/template/sales/order/print/invoice.phtml
index 7c4a928..1849408 100644
--- a/app/design/frontend/base/default/template/sales/order/print/invoice.phtml
+++ b/app/design/frontend/base/default/template/sales/order/print/invoice.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/print/shipment.phtml b/app/design/frontend/base/default/template/sales/order/print/shipment.phtml
index f39e273..23c30eb 100644
--- a/app/design/frontend/base/default/template/sales/order/print/shipment.phtml
+++ b/app/design/frontend/base/default/template/sales/order/print/shipment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/recent.phtml b/app/design/frontend/base/default/template/sales/order/recent.phtml
index bac0ace..4fe08db 100644
--- a/app/design/frontend/base/default/template/sales/order/recent.phtml
+++ b/app/design/frontend/base/default/template/sales/order/recent.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/shipment.phtml b/app/design/frontend/base/default/template/sales/order/shipment.phtml
index 95f8444..520bf3d 100644
--- a/app/design/frontend/base/default/template/sales/order/shipment.phtml
+++ b/app/design/frontend/base/default/template/sales/order/shipment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/shipment/items.phtml b/app/design/frontend/base/default/template/sales/order/shipment/items.phtml
index 07cb326..f7ea773 100644
--- a/app/design/frontend/base/default/template/sales/order/shipment/items.phtml
+++ b/app/design/frontend/base/default/template/sales/order/shipment/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/shipment/items/renderer/default.phtml b/app/design/frontend/base/default/template/sales/order/shipment/items/renderer/default.phtml
index 3ebc52a..92186c0 100644
--- a/app/design/frontend/base/default/template/sales/order/shipment/items/renderer/default.phtml
+++ b/app/design/frontend/base/default/template/sales/order/shipment/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/totals.phtml b/app/design/frontend/base/default/template/sales/order/totals.phtml
index 801b5d5..d7df265 100644
--- a/app/design/frontend/base/default/template/sales/order/totals.phtml
+++ b/app/design/frontend/base/default/template/sales/order/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/sales/order/trackinginfo.phtml b/app/design/frontend/base/default/template/sales/order/trackinginfo.phtml
index e6accb2..7c4a652 100644
--- a/app/design/frontend/base/default/template/sales/order/trackinginfo.phtml
+++ b/app/design/frontend/base/default/template/sales/order/trackinginfo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/order/view.phtml b/app/design/frontend/base/default/template/sales/order/view.phtml
index 6960860..c66a6b5 100644
--- a/app/design/frontend/base/default/template/sales/order/view.phtml
+++ b/app/design/frontend/base/default/template/sales/order/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/payment/form/billing/agreement.phtml b/app/design/frontend/base/default/template/sales/payment/form/billing/agreement.phtml
index d059ad0..c36cbb7 100644
--- a/app/design/frontend/base/default/template/sales/payment/form/billing/agreement.phtml
+++ b/app/design/frontend/base/default/template/sales/payment/form/billing/agreement.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/recurring/grid.phtml b/app/design/frontend/base/default/template/sales/recurring/grid.phtml
index 087fc8e..b2442fb 100644
--- a/app/design/frontend/base/default/template/sales/recurring/grid.phtml
+++ b/app/design/frontend/base/default/template/sales/recurring/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/recurring/profile/view.phtml b/app/design/frontend/base/default/template/sales/recurring/profile/view.phtml
index 4bf43a8..c91d1a1 100644
--- a/app/design/frontend/base/default/template/sales/recurring/profile/view.phtml
+++ b/app/design/frontend/base/default/template/sales/recurring/profile/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/recurring/profile/view/info.phtml b/app/design/frontend/base/default/template/sales/recurring/profile/view/info.phtml
index 2572355..d7c2c7f 100644
--- a/app/design/frontend/base/default/template/sales/recurring/profile/view/info.phtml
+++ b/app/design/frontend/base/default/template/sales/recurring/profile/view/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/recurring/profiles.phtml b/app/design/frontend/base/default/template/sales/recurring/profiles.phtml
index b78dfbe..1de80a9 100644
--- a/app/design/frontend/base/default/template/sales/recurring/profiles.phtml
+++ b/app/design/frontend/base/default/template/sales/recurring/profiles.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/reorder/sidebar.phtml b/app/design/frontend/base/default/template/sales/reorder/sidebar.phtml
index ac27581..38599eb 100644
--- a/app/design/frontend/base/default/template/sales/reorder/sidebar.phtml
+++ b/app/design/frontend/base/default/template/sales/reorder/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/sales/widget/guest/form.phtml b/app/design/frontend/base/default/template/sales/widget/guest/form.phtml
index 34ae396..a35b938 100644
--- a/app/design/frontend/base/default/template/sales/widget/guest/form.phtml
+++ b/app/design/frontend/base/default/template/sales/widget/guest/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Sales_Block_Widget_Guest_Form */
diff --git a/app/design/frontend/base/default/template/sendfriend/send.phtml b/app/design/frontend/base/default/template/sendfriend/send.phtml
index c14815b..fdf65a0 100644
--- a/app/design/frontend/base/default/template/sendfriend/send.phtml
+++ b/app/design/frontend/base/default/template/sendfriend/send.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Sendfriend_Block_Send */
diff --git a/app/design/frontend/base/default/template/shipping/tracking/ajax.phtml b/app/design/frontend/base/default/template/shipping/tracking/ajax.phtml
index 58927d5..3274865 100644
--- a/app/design/frontend/base/default/template/shipping/tracking/ajax.phtml
+++ b/app/design/frontend/base/default/template/shipping/tracking/ajax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/shipping/tracking/popup.phtml b/app/design/frontend/base/default/template/shipping/tracking/popup.phtml
index ef2f765..81ba2e1 100644
--- a/app/design/frontend/base/default/template/shipping/tracking/popup.phtml
+++ b/app/design/frontend/base/default/template/shipping/tracking/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/cloud.phtml b/app/design/frontend/base/default/template/tag/cloud.phtml
index b9b4a7f..ab98b2a 100644
--- a/app/design/frontend/base/default/template/tag/cloud.phtml
+++ b/app/design/frontend/base/default/template/tag/cloud.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/customer/recent.phtml b/app/design/frontend/base/default/template/tag/customer/recent.phtml
index 0f79734..c4d5476 100644
--- a/app/design/frontend/base/default/template/tag/customer/recent.phtml
+++ b/app/design/frontend/base/default/template/tag/customer/recent.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/customer/tags.phtml b/app/design/frontend/base/default/template/tag/customer/tags.phtml
index c17b519..5e865c7 100644
--- a/app/design/frontend/base/default/template/tag/customer/tags.phtml
+++ b/app/design/frontend/base/default/template/tag/customer/tags.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/customer/view.phtml b/app/design/frontend/base/default/template/tag/customer/view.phtml
index 6cf8d34..845c7f2 100644
--- a/app/design/frontend/base/default/template/tag/customer/view.phtml
+++ b/app/design/frontend/base/default/template/tag/customer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/list.phtml b/app/design/frontend/base/default/template/tag/list.phtml
index 03d7a72..61f3f13 100644
--- a/app/design/frontend/base/default/template/tag/list.phtml
+++ b/app/design/frontend/base/default/template/tag/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tag/popular.phtml b/app/design/frontend/base/default/template/tag/popular.phtml
index 32b3cc2..3ddc3db 100644
--- a/app/design/frontend/base/default/template/tag/popular.phtml
+++ b/app/design/frontend/base/default/template/tag/popular.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/tax/checkout/discount.phtml b/app/design/frontend/base/default/template/tax/checkout/discount.phtml
index 896d03e..0803035 100644
--- a/app/design/frontend/base/default/template/tax/checkout/discount.phtml
+++ b/app/design/frontend/base/default/template/tax/checkout/discount.phtml
@@ -20,6 +20,6 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
diff --git a/app/design/frontend/base/default/template/tax/checkout/grandtotal.phtml b/app/design/frontend/base/default/template/tax/checkout/grandtotal.phtml
index 194f51a..d2d9b42 100644
--- a/app/design/frontend/base/default/template/tax/checkout/grandtotal.phtml
+++ b/app/design/frontend/base/default/template/tax/checkout/grandtotal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/tax/checkout/shipping.phtml b/app/design/frontend/base/default/template/tax/checkout/shipping.phtml
index f4c3a28..7b453c7 100644
--- a/app/design/frontend/base/default/template/tax/checkout/shipping.phtml
+++ b/app/design/frontend/base/default/template/tax/checkout/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/tax/checkout/subtotal.phtml b/app/design/frontend/base/default/template/tax/checkout/subtotal.phtml
index 4053c40..1114e41 100644
--- a/app/design/frontend/base/default/template/tax/checkout/subtotal.phtml
+++ b/app/design/frontend/base/default/template/tax/checkout/subtotal.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/tax/checkout/tax.phtml b/app/design/frontend/base/default/template/tax/checkout/tax.phtml
index ddb0e5c..214daf7 100644
--- a/app/design/frontend/base/default/template/tax/checkout/tax.phtml
+++ b/app/design/frontend/base/default/template/tax/checkout/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/base/default/template/tax/order/tax.phtml b/app/design/frontend/base/default/template/tax/order/tax.phtml
index 84d07f8..adf381a 100644
--- a/app/design/frontend/base/default/template/tax/order/tax.phtml
+++ b/app/design/frontend/base/default/template/tax/order/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/button/share.phtml b/app/design/frontend/base/default/template/wishlist/button/share.phtml
index d4f3bfc..ed9ac65 100644
--- a/app/design/frontend/base/default/template/wishlist/button/share.phtml
+++ b/app/design/frontend/base/default/template/wishlist/button/share.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/button/tocart.phtml b/app/design/frontend/base/default/template/wishlist/button/tocart.phtml
index 9a85ec7..d75f073 100644
--- a/app/design/frontend/base/default/template/wishlist/button/tocart.phtml
+++ b/app/design/frontend/base/default/template/wishlist/button/tocart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/button/update.phtml b/app/design/frontend/base/default/template/wishlist/button/update.phtml
index fef1e8f..334dae6 100644
--- a/app/design/frontend/base/default/template/wishlist/button/update.phtml
+++ b/app/design/frontend/base/default/template/wishlist/button/update.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/email/items.phtml b/app/design/frontend/base/default/template/wishlist/email/items.phtml
index 1e36099..5bb466d 100644
--- a/app/design/frontend/base/default/template/wishlist/email/items.phtml
+++ b/app/design/frontend/base/default/template/wishlist/email/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Share_Email_Items */
diff --git a/app/design/frontend/base/default/template/wishlist/email/rss.phtml b/app/design/frontend/base/default/template/wishlist/email/rss.phtml
index 5f5c307..a17b045 100644
--- a/app/design/frontend/base/default/template/wishlist/email/rss.phtml
+++ b/app/design/frontend/base/default/template/wishlist/email/rss.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/item/column/cart.phtml b/app/design/frontend/base/default/template/wishlist/item/column/cart.phtml
index 7d9d4f1..c6ab0b8 100644
--- a/app/design/frontend/base/default/template/wishlist/item/column/cart.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/column/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/wishlist/item/column/image.phtml b/app/design/frontend/base/default/template/wishlist/item/column/image.phtml
index f10377b..e5612ee 100644
--- a/app/design/frontend/base/default/template/wishlist/item/column/image.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/column/image.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/wishlist/item/column/info.phtml b/app/design/frontend/base/default/template/wishlist/item/column/info.phtml
index 4ce7b5e..c04d6a1 100644
--- a/app/design/frontend/base/default/template/wishlist/item/column/info.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/column/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/wishlist/item/column/remove.phtml b/app/design/frontend/base/default/template/wishlist/item/column/remove.phtml
index 4e46bc7..b499791 100644
--- a/app/design/frontend/base/default/template/wishlist/item/column/remove.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/column/remove.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/base/default/template/wishlist/item/configure/addto.phtml b/app/design/frontend/base/default/template/wishlist/item/configure/addto.phtml
index 5feebaf..ae49055 100644
--- a/app/design/frontend/base/default/template/wishlist/item/configure/addto.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/configure/addto.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/item/list.phtml b/app/design/frontend/base/default/template/wishlist/item/list.phtml
index 4573cab..3f07859 100644
--- a/app/design/frontend/base/default/template/wishlist/item/list.phtml
+++ b/app/design/frontend/base/default/template/wishlist/item/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/options_list.phtml b/app/design/frontend/base/default/template/wishlist/options_list.phtml
index 51700f5..9ade6ef 100644
--- a/app/design/frontend/base/default/template/wishlist/options_list.phtml
+++ b/app/design/frontend/base/default/template/wishlist/options_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Wishlist_Item_Options */
diff --git a/app/design/frontend/base/default/template/wishlist/render/item/price.phtml b/app/design/frontend/base/default/template/wishlist/render/item/price.phtml
index cee2c15..c147de9 100644
--- a/app/design/frontend/base/default/template/wishlist/render/item/price.phtml
+++ b/app/design/frontend/base/default/template/wishlist/render/item/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Wishlist_Render_Item_Price */
diff --git a/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_item.phtml b/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_item.phtml
index 7e0224d..b47b860 100644
--- a/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_item.phtml
+++ b/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_rss.phtml b/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_rss.phtml
index 55fcaae..067bc00 100644
--- a/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_rss.phtml
+++ b/app/design/frontend/base/default/template/wishlist/render/item/price_msrp_rss.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/shared.phtml b/app/design/frontend/base/default/template/wishlist/shared.phtml
index e5980cd..19b1d8f 100644
--- a/app/design/frontend/base/default/template/wishlist/shared.phtml
+++ b/app/design/frontend/base/default/template/wishlist/shared.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Share_Wishlist */
diff --git a/app/design/frontend/base/default/template/wishlist/sharing.phtml b/app/design/frontend/base/default/template/wishlist/sharing.phtml
index cb06ff0..2190446 100644
--- a/app/design/frontend/base/default/template/wishlist/sharing.phtml
+++ b/app/design/frontend/base/default/template/wishlist/sharing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/wishlist/sidebar.phtml b/app/design/frontend/base/default/template/wishlist/sidebar.phtml
index 11982a3..916c41b 100644
--- a/app/design/frontend/base/default/template/wishlist/sidebar.phtml
+++ b/app/design/frontend/base/default/template/wishlist/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Sidebar */
diff --git a/app/design/frontend/base/default/template/wishlist/view.phtml b/app/design/frontend/base/default/template/wishlist/view.phtml
index 6f84cb1..e80c1a7 100644
--- a/app/design/frontend/base/default/template/wishlist/view.phtml
+++ b/app/design/frontend/base/default/template/wishlist/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Wishlist */
diff --git a/app/design/frontend/base/default/template/xmlconnect/centinel/authentication.phtml b/app/design/frontend/base/default/template/xmlconnect/centinel/authentication.phtml
index 122eb2b..c30a0f1 100644
--- a/app/design/frontend/base/default/template/xmlconnect/centinel/authentication.phtml
+++ b/app/design/frontend/base/default/template/xmlconnect/centinel/authentication.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/base/default/template/xmlconnect/pbridge/result.phtml b/app/design/frontend/base/default/template/xmlconnect/pbridge/result.phtml
index 2d375b7..b0f6513 100644
--- a/app/design/frontend/base/default/template/xmlconnect/pbridge/result.phtml
+++ b/app/design/frontend/base/default/template/xmlconnect/pbridge/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/blank/etc/theme.xml b/app/design/frontend/default/blank/etc/theme.xml
index 4c0d497..5f82c42 100644
--- a/app/design/frontend/default/blank/etc/theme.xml
+++ b/app/design/frontend/default/blank/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_blank
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/blank/etc/widget.xml b/app/design/frontend/default/blank/etc/widget.xml
index e904df7..51070fd 100644
--- a/app/design/frontend/default/blank/etc/widget.xml
+++ b/app/design/frontend/default/blank/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_blank
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/default/etc/theme.xml b/app/design/frontend/default/default/etc/theme.xml
index d0b262c..8e9e140 100644
--- a/app/design/frontend/default/default/etc/theme.xml
+++ b/app/design/frontend/default/default/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/default/etc/widget.xml b/app/design/frontend/default/default/etc/widget.xml
index 38be8aa..f1de09e 100644
--- a/app/design/frontend/default/default/etc/widget.xml
+++ b/app/design/frontend/default/default/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/etc/theme.xml b/app/design/frontend/default/iphone/etc/theme.xml
index eac5bee..f247842 100644
--- a/app/design/frontend/default/iphone/etc/theme.xml
+++ b/app/design/frontend/default/iphone/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/etc/widget.xml b/app/design/frontend/default/iphone/etc/widget.xml
index 6a9df7a..3fc4dcc 100644
--- a/app/design/frontend/default/iphone/etc/widget.xml
+++ b/app/design/frontend/default/iphone/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/bundle.xml b/app/design/frontend/default/iphone/layout/bundle.xml
index 19cf8b8..56ab1dc 100644
--- a/app/design/frontend/default/iphone/layout/bundle.xml
+++ b/app/design/frontend/default/iphone/layout/bundle.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/catalog.xml b/app/design/frontend/default/iphone/layout/catalog.xml
index 241050f..0bc65bd 100644
--- a/app/design/frontend/default/iphone/layout/catalog.xml
+++ b/app/design/frontend/default/iphone/layout/catalog.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/catalogsearch.xml b/app/design/frontend/default/iphone/layout/catalogsearch.xml
index 55ddb6b..89d574c 100644
--- a/app/design/frontend/default/iphone/layout/catalogsearch.xml
+++ b/app/design/frontend/default/iphone/layout/catalogsearch.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/checkout.xml b/app/design/frontend/default/iphone/layout/checkout.xml
index 3b2fff9..7ac3177 100644
--- a/app/design/frontend/default/iphone/layout/checkout.xml
+++ b/app/design/frontend/default/iphone/layout/checkout.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/cms.xml b/app/design/frontend/default/iphone/layout/cms.xml
index 2eea976..a243068 100644
--- a/app/design/frontend/default/iphone/layout/cms.xml
+++ b/app/design/frontend/default/iphone/layout/cms.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/contacts.xml b/app/design/frontend/default/iphone/layout/contacts.xml
index ad34448..cf9de77 100644
--- a/app/design/frontend/default/iphone/layout/contacts.xml
+++ b/app/design/frontend/default/iphone/layout/contacts.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/customer.xml b/app/design/frontend/default/iphone/layout/customer.xml
index 48bb5c6..67a4115 100644
--- a/app/design/frontend/default/iphone/layout/customer.xml
+++ b/app/design/frontend/default/iphone/layout/customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/newsletter.xml b/app/design/frontend/default/iphone/layout/newsletter.xml
index cc4f83d..3d83d91 100644
--- a/app/design/frontend/default/iphone/layout/newsletter.xml
+++ b/app/design/frontend/default/iphone/layout/newsletter.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/page.xml b/app/design/frontend/default/iphone/layout/page.xml
index 604b310..03b1655 100644
--- a/app/design/frontend/default/iphone/layout/page.xml
+++ b/app/design/frontend/default/iphone/layout/page.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/review.xml b/app/design/frontend/default/iphone/layout/review.xml
index 8057fa0..cfd8a0b 100644
--- a/app/design/frontend/default/iphone/layout/review.xml
+++ b/app/design/frontend/default/iphone/layout/review.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/rss.xml b/app/design/frontend/default/iphone/layout/rss.xml
index 066612d..62c853e 100644
--- a/app/design/frontend/default/iphone/layout/rss.xml
+++ b/app/design/frontend/default/iphone/layout/rss.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/sales.xml b/app/design/frontend/default/iphone/layout/sales.xml
index 9592889..0edd4d2 100644
--- a/app/design/frontend/default/iphone/layout/sales.xml
+++ b/app/design/frontend/default/iphone/layout/sales.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/sales/billing_agreement.xml b/app/design/frontend/default/iphone/layout/sales/billing_agreement.xml
index ea4e634..2945e20 100644
--- a/app/design/frontend/default/iphone/layout/sales/billing_agreement.xml
+++ b/app/design/frontend/default/iphone/layout/sales/billing_agreement.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/sales/recurring_profile.xml b/app/design/frontend/default/iphone/layout/sales/recurring_profile.xml
index cad395d..99b4383 100644
--- a/app/design/frontend/default/iphone/layout/sales/recurring_profile.xml
+++ b/app/design/frontend/default/iphone/layout/sales/recurring_profile.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/sendfriend.xml b/app/design/frontend/default/iphone/layout/sendfriend.xml
index 099db33..18f3b2c 100644
--- a/app/design/frontend/default/iphone/layout/sendfriend.xml
+++ b/app/design/frontend/default/iphone/layout/sendfriend.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/iphone/layout/tag.xml b/app/design/frontend/default/iphone/layout/tag.xml
index 745d1a5..f9df1dd 100644
--- a/app/design/frontend/default/iphone/layout/tag.xml
+++ b/app/design/frontend/default/iphone/layout/tag.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/layout/wishlist.xml b/app/design/frontend/default/iphone/layout/wishlist.xml
index ccebc4d..9a25535 100644
--- a/app/design/frontend/default/iphone/layout/wishlist.xml
+++ b/app/design/frontend/default/iphone/layout/wishlist.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/bundle/catalog/product/view/type/bundle.phtml b/app/design/frontend/default/iphone/template/bundle/catalog/product/view/type/bundle.phtml
index eb204be..22c3bca 100644
--- a/app/design/frontend/default/iphone/template/bundle/catalog/product/view/type/bundle.phtml
+++ b/app/design/frontend/default/iphone/template/bundle/catalog/product/view/type/bundle.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/bundle/sales/order/items/renderer.phtml b/app/design/frontend/default/iphone/template/bundle/sales/order/items/renderer.phtml
index 6df7d26..3b4c456 100644
--- a/app/design/frontend/default/iphone/template/bundle/sales/order/items/renderer.phtml
+++ b/app/design/frontend/default/iphone/template/bundle/sales/order/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/category/view.phtml b/app/design/frontend/default/iphone/template/catalog/category/view.phtml
index 5aa0830..e6b6077 100644
--- a/app/design/frontend/default/iphone/template/catalog/category/view.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/category/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/layer/view.phtml b/app/design/frontend/default/iphone/template/catalog/layer/view.phtml
index e3f24e6..1956034 100644
--- a/app/design/frontend/default/iphone/template/catalog/layer/view.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/layer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/navigation/top.phtml b/app/design/frontend/default/iphone/template/catalog/navigation/top.phtml
index b04a04b..b053233 100644
--- a/app/design/frontend/default/iphone/template/catalog/navigation/top.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/navigation/top.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/gallery.phtml b/app/design/frontend/default/iphone/template/catalog/product/gallery.phtml
index 1ef0aa9..d53f1e3 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/gallery.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/gallery.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/list.phtml b/app/design/frontend/default/iphone/template/catalog/product/list.phtml
index ea9997a..812a82a 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/list.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/list/toolbar.phtml b/app/design/frontend/default/iphone/template/catalog/product/list/toolbar.phtml
index 07c2fb2..3f45d59 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/list/toolbar.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/list/toolbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/list/upsell.phtml b/app/design/frontend/default/iphone/template/catalog/product/list/upsell.phtml
index 1a17bca..eecb366 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/list/upsell.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/list/upsell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/price.phtml b/app/design/frontend/default/iphone/template/catalog/product/price.phtml
index f70dcea..05fee45 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/price.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/price_msrp.phtml b/app/design/frontend/default/iphone/template/catalog/product/price_msrp.phtml
index 8ba9fc4..008ff75 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/price_msrp.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/price_msrp.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/price_msrp_noform.phtml b/app/design/frontend/default/iphone/template/catalog/product/price_msrp_noform.phtml
index 8ba9fc4..008ff75 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/price_msrp_noform.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/price_msrp_noform.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/view.phtml b/app/design/frontend/default/iphone/template/catalog/product/view.phtml
index 3505824..61ad12b 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/view.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/catalog/product/view/addto.phtml b/app/design/frontend/default/iphone/template/catalog/product/view/addto.phtml
index 472523c..18c1440 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/view/addto.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/view/addto.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalog/product/view/media.phtml b/app/design/frontend/default/iphone/template/catalog/product/view/media.phtml
index 4226260..c84b271 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/view/media.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/view/media.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/catalog/product/view/options/wrapper.phtml b/app/design/frontend/default/iphone/template/catalog/product/view/options/wrapper.phtml
index 2ad7f66..b30b73a 100644
--- a/app/design/frontend/default/iphone/template/catalog/product/view/options/wrapper.phtml
+++ b/app/design/frontend/default/iphone/template/catalog/product/view/options/wrapper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/catalogsearch/form.mini.phtml b/app/design/frontend/default/iphone/template/catalogsearch/form.mini.phtml
index f648442..2937f9b 100644
--- a/app/design/frontend/default/iphone/template/catalogsearch/form.mini.phtml
+++ b/app/design/frontend/default/iphone/template/catalogsearch/form.mini.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Core_Block_Template */
diff --git a/app/design/frontend/default/iphone/template/catalogsearch/result.phtml b/app/design/frontend/default/iphone/template/catalogsearch/result.phtml
index d81d4cb..6d68407 100644
--- a/app/design/frontend/default/iphone/template/catalogsearch/result.phtml
+++ b/app/design/frontend/default/iphone/template/catalogsearch/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/checkout/cart.phtml b/app/design/frontend/default/iphone/template/checkout/cart.phtml
index 6c8221b..8f6864a 100644
--- a/app/design/frontend/default/iphone/template/checkout/cart.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/checkout/cart/item/default.phtml b/app/design/frontend/default/iphone/template/checkout/cart/item/default.phtml
index 2b8b79a..091906e 100644
--- a/app/design/frontend/default/iphone/template/checkout/cart/item/default.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/checkout/onepage/review/info.phtml b/app/design/frontend/default/iphone/template/checkout/onepage/review/info.phtml
index d7dee11..24e2c27 100644
--- a/app/design/frontend/default/iphone/template/checkout/onepage/review/info.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/onepage/review/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/checkout/onepage/review/item.phtml b/app/design/frontend/default/iphone/template/checkout/onepage/review/item.phtml
index 6c41e56..af0298a 100644
--- a/app/design/frontend/default/iphone/template/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/checkout/onepage/review/totals.phtml b/app/design/frontend/default/iphone/template/checkout/onepage/review/totals.phtml
index 13ff83f..d159bb6 100644
--- a/app/design/frontend/default/iphone/template/checkout/onepage/review/totals.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/onepage/review/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/checkout/success.phtml b/app/design/frontend/default/iphone/template/checkout/success.phtml
index 80b22c3..1d29648 100644
--- a/app/design/frontend/default/iphone/template/checkout/success.phtml
+++ b/app/design/frontend/default/iphone/template/checkout/success.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/customer/account/dashboard/address.phtml b/app/design/frontend/default/iphone/template/customer/account/dashboard/address.phtml
index ef500bf..d0a2be6 100644
--- a/app/design/frontend/default/iphone/template/customer/account/dashboard/address.phtml
+++ b/app/design/frontend/default/iphone/template/customer/account/dashboard/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/customer/account/navigation.phtml b/app/design/frontend/default/iphone/template/customer/account/navigation.phtml
index e915868..7d304ee 100644
--- a/app/design/frontend/default/iphone/template/customer/account/navigation.phtml
+++ b/app/design/frontend/default/iphone/template/customer/account/navigation.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/customer/address/book.phtml b/app/design/frontend/default/iphone/template/customer/address/book.phtml
index a08f86b..3cdb5fc 100644
--- a/app/design/frontend/default/iphone/template/customer/address/book.phtml
+++ b/app/design/frontend/default/iphone/template/customer/address/book.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/customer/form/login.phtml b/app/design/frontend/default/iphone/template/customer/form/login.phtml
index 8d6be7e..2e98450 100644
--- a/app/design/frontend/default/iphone/template/customer/form/login.phtml
+++ b/app/design/frontend/default/iphone/template/customer/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/checkout/cart/item/default.phtml b/app/design/frontend/default/iphone/template/downloadable/checkout/cart/item/default.phtml
index 184e781..1fa07b2 100644
--- a/app/design/frontend/default/iphone/template/downloadable/checkout/cart/item/default.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/checkout/onepage/review/item.phtml b/app/design/frontend/default/iphone/template/downloadable/checkout/onepage/review/item.phtml
index 45e4fd8..f497947 100644
--- a/app/design/frontend/default/iphone/template/downloadable/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/customer/products/list.phtml b/app/design/frontend/default/iphone/template/downloadable/customer/products/list.phtml
index 5f433d3..0996b88 100644
--- a/app/design/frontend/default/iphone/template/downloadable/customer/products/list.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/customer/products/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml b/app/design/frontend/default/iphone/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
index 006ed57..65564e8 100644
--- a/app/design/frontend/default/iphone/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/sales/order/creditmemo/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml b/app/design/frontend/default/iphone/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
index a77418c..75851bb 100644
--- a/app/design/frontend/default/iphone/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/sales/order/invoice/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/downloadable/sales/order/items/renderer/downloadable.phtml b/app/design/frontend/default/iphone/template/downloadable/sales/order/items/renderer/downloadable.phtml
index 0deccdc..c64e173 100644
--- a/app/design/frontend/default/iphone/template/downloadable/sales/order/items/renderer/downloadable.phtml
+++ b/app/design/frontend/default/iphone/template/downloadable/sales/order/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/newsletter/subscribe.phtml b/app/design/frontend/default/iphone/template/newsletter/subscribe.phtml
index f3b15ee..a074dd1 100644
--- a/app/design/frontend/default/iphone/template/newsletter/subscribe.phtml
+++ b/app/design/frontend/default/iphone/template/newsletter/subscribe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/1column.phtml b/app/design/frontend/default/iphone/template/page/1column.phtml
index 3d0c2fe..2ab4f9e 100644
--- a/app/design/frontend/default/iphone/template/page/1column.phtml
+++ b/app/design/frontend/default/iphone/template/page/1column.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/html/footer.phtml b/app/design/frontend/default/iphone/template/page/html/footer.phtml
index 26e35a0..3d10749 100644
--- a/app/design/frontend/default/iphone/template/page/html/footer.phtml
+++ b/app/design/frontend/default/iphone/template/page/html/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/html/head.phtml b/app/design/frontend/default/iphone/template/page/html/head.phtml
index 9a07284..b2e107c 100644
--- a/app/design/frontend/default/iphone/template/page/html/head.phtml
+++ b/app/design/frontend/default/iphone/template/page/html/head.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/html/header.phtml b/app/design/frontend/default/iphone/template/page/html/header.phtml
index e0f499b..0bf8a2f 100644
--- a/app/design/frontend/default/iphone/template/page/html/header.phtml
+++ b/app/design/frontend/default/iphone/template/page/html/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/default/iphone/template/page/html/pager.phtml b/app/design/frontend/default/iphone/template/page/html/pager.phtml
index 5da1a50..4b6a55f 100644
--- a/app/design/frontend/default/iphone/template/page/html/pager.phtml
+++ b/app/design/frontend/default/iphone/template/page/html/pager.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/switch/languages.phtml b/app/design/frontend/default/iphone/template/page/switch/languages.phtml
index 7cb6056..0f7f019 100644
--- a/app/design/frontend/default/iphone/template/page/switch/languages.phtml
+++ b/app/design/frontend/default/iphone/template/page/switch/languages.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/switch/stores.phtml b/app/design/frontend/default/iphone/template/page/switch/stores.phtml
index 9bfc5d6..aaebb18 100644
--- a/app/design/frontend/default/iphone/template/page/switch/stores.phtml
+++ b/app/design/frontend/default/iphone/template/page/switch/stores.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/page/template/links.phtml b/app/design/frontend/default/iphone/template/page/template/links.phtml
index 9691965..4a0e27e 100644
--- a/app/design/frontend/default/iphone/template/page/template/links.phtml
+++ b/app/design/frontend/default/iphone/template/page/template/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/paypal/express/review.phtml b/app/design/frontend/default/iphone/template/paypal/express/review.phtml
index 437ee70..eee1815 100644
--- a/app/design/frontend/default/iphone/template/paypal/express/review.phtml
+++ b/app/design/frontend/default/iphone/template/paypal/express/review.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Express_Review */
diff --git a/app/design/frontend/default/iphone/template/paypal/express/review/details.phtml b/app/design/frontend/default/iphone/template/paypal/express/review/details.phtml
index f762f36..466ddf2 100644
--- a/app/design/frontend/default/iphone/template/paypal/express/review/details.phtml
+++ b/app/design/frontend/default/iphone/template/paypal/express/review/details.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/persistent/checkout/onepage/login.phtml b/app/design/frontend/default/iphone/template/persistent/checkout/onepage/login.phtml
index 38ec6bc..ab0e652 100644
--- a/app/design/frontend/default/iphone/template/persistent/checkout/onepage/login.phtml
+++ b/app/design/frontend/default/iphone/template/persistent/checkout/onepage/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/persistent/customer/form/login.phtml b/app/design/frontend/default/iphone/template/persistent/customer/form/login.phtml
index d6e1e74..8119d15 100644
--- a/app/design/frontend/default/iphone/template/persistent/customer/form/login.phtml
+++ b/app/design/frontend/default/iphone/template/persistent/customer/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/persistent/remember_me_tooltip.phtml b/app/design/frontend/default/iphone/template/persistent/remember_me_tooltip.phtml
index 9301c58..82f0685 100644
--- a/app/design/frontend/default/iphone/template/persistent/remember_me_tooltip.phtml
+++ b/app/design/frontend/default/iphone/template/persistent/remember_me_tooltip.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/review/customer/list.phtml b/app/design/frontend/default/iphone/template/review/customer/list.phtml
index d8a8471..fb7786d 100644
--- a/app/design/frontend/default/iphone/template/review/customer/list.phtml
+++ b/app/design/frontend/default/iphone/template/review/customer/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/billing/agreement/view.phtml b/app/design/frontend/default/iphone/template/sales/billing/agreement/view.phtml
index 2bc5e77..8c86d21 100644
--- a/app/design/frontend/default/iphone/template/sales/billing/agreement/view.phtml
+++ b/app/design/frontend/default/iphone/template/sales/billing/agreement/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/billing/agreements.phtml b/app/design/frontend/default/iphone/template/sales/billing/agreements.phtml
index 2ab9a2c..03f6f27 100644
--- a/app/design/frontend/default/iphone/template/sales/billing/agreements.phtml
+++ b/app/design/frontend/default/iphone/template/sales/billing/agreements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/creditmemo/items.phtml b/app/design/frontend/default/iphone/template/sales/order/creditmemo/items.phtml
index ce2c61b..5077e54 100644
--- a/app/design/frontend/default/iphone/template/sales/order/creditmemo/items.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/creditmemo/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/creditmemo/items/renderer/default.phtml b/app/design/frontend/default/iphone/template/sales/order/creditmemo/items/renderer/default.phtml
index fc908bf..9d5d7bc 100644
--- a/app/design/frontend/default/iphone/template/sales/order/creditmemo/items/renderer/default.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/creditmemo/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/history.phtml b/app/design/frontend/default/iphone/template/sales/order/history.phtml
index aefcc08..f3f8a29 100644
--- a/app/design/frontend/default/iphone/template/sales/order/history.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/history.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/invoice/items.phtml b/app/design/frontend/default/iphone/template/sales/order/invoice/items.phtml
index 4e90b55..b962198 100644
--- a/app/design/frontend/default/iphone/template/sales/order/invoice/items.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/invoice/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/invoice/items/renderer/default.phtml b/app/design/frontend/default/iphone/template/sales/order/invoice/items/renderer/default.phtml
index 3c35fe8..4a34fe2 100644
--- a/app/design/frontend/default/iphone/template/sales/order/invoice/items/renderer/default.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/invoice/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/items.phtml b/app/design/frontend/default/iphone/template/sales/order/items.phtml
index c911697..be99eb5 100644
--- a/app/design/frontend/default/iphone/template/sales/order/items.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/items/renderer/default.phtml b/app/design/frontend/default/iphone/template/sales/order/items/renderer/default.phtml
index 69b5a78..607e7e2 100644
--- a/app/design/frontend/default/iphone/template/sales/order/items/renderer/default.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/recent.phtml b/app/design/frontend/default/iphone/template/sales/order/recent.phtml
index 4d186c9..b80bb18 100644
--- a/app/design/frontend/default/iphone/template/sales/order/recent.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/recent.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/sales/order/totals.phtml b/app/design/frontend/default/iphone/template/sales/order/totals.phtml
index 6371e5b..728fb38 100644
--- a/app/design/frontend/default/iphone/template/sales/order/totals.phtml
+++ b/app/design/frontend/default/iphone/template/sales/order/totals.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/default/iphone/template/shipping/tracking/popup.phtml b/app/design/frontend/default/iphone/template/shipping/tracking/popup.phtml
index 77f7e36..fa53cf0 100644
--- a/app/design/frontend/default/iphone/template/shipping/tracking/popup.phtml
+++ b/app/design/frontend/default/iphone/template/shipping/tracking/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/tag/list.phtml b/app/design/frontend/default/iphone/template/tag/list.phtml
index 6ff7c4b..0fe2a2a 100644
--- a/app/design/frontend/default/iphone/template/tag/list.phtml
+++ b/app/design/frontend/default/iphone/template/tag/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/tax/order/tax.phtml b/app/design/frontend/default/iphone/template/tax/order/tax.phtml
index e03c32f..d2c711a 100644
--- a/app/design/frontend/default/iphone/template/tax/order/tax.phtml
+++ b/app/design/frontend/default/iphone/template/tax/order/tax.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/wishlist/item/column/cart.phtml b/app/design/frontend/default/iphone/template/wishlist/item/column/cart.phtml
index e1b9c48..a183482 100644
--- a/app/design/frontend/default/iphone/template/wishlist/item/column/cart.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/item/column/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/wishlist/item/column/image.phtml b/app/design/frontend/default/iphone/template/wishlist/item/column/image.phtml
index 5390fc1..e1aabde 100644
--- a/app/design/frontend/default/iphone/template/wishlist/item/column/image.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/item/column/image.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/wishlist/item/column/info.phtml b/app/design/frontend/default/iphone/template/wishlist/item/column/info.phtml
index e61ffc4..ebcab22 100644
--- a/app/design/frontend/default/iphone/template/wishlist/item/column/info.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/item/column/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/iphone/template/wishlist/item/configure/addto.phtml b/app/design/frontend/default/iphone/template/wishlist/item/configure/addto.phtml
index d26b280..bcec1b6 100644
--- a/app/design/frontend/default/iphone/template/wishlist/item/configure/addto.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/item/configure/addto.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/wishlist/item/list.phtml b/app/design/frontend/default/iphone/template/wishlist/item/list.phtml
index 4411abb..9b0e070 100644
--- a/app/design/frontend/default/iphone/template/wishlist/item/list.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/item/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/iphone/template/wishlist/shared.phtml b/app/design/frontend/default/iphone/template/wishlist/shared.phtml
index 39ee2c9..a6c725e 100644
--- a/app/design/frontend/default/iphone/template/wishlist/shared.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/shared.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Share_Wishlist */
diff --git a/app/design/frontend/default/iphone/template/wishlist/view.phtml b/app/design/frontend/default/iphone/template/wishlist/view.phtml
index a2fc15a..2ad8a3d 100644
--- a/app/design/frontend/default/iphone/template/wishlist/view.phtml
+++ b/app/design/frontend/default/iphone/template/wishlist/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Wishlist */
diff --git a/app/design/frontend/default/modern/etc/theme.xml b/app/design/frontend/default/modern/etc/theme.xml
index 6f6493c..c6404c2 100644
--- a/app/design/frontend/default/modern/etc/theme.xml
+++ b/app/design/frontend/default/modern/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/etc/widget.xml b/app/design/frontend/default/modern/etc/widget.xml
index 77d11fa..940ad3f 100644
--- a/app/design/frontend/default/modern/etc/widget.xml
+++ b/app/design/frontend/default/modern/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/catalog.xml b/app/design/frontend/default/modern/layout/catalog.xml
index 6c09bfb..1a97e8e 100644
--- a/app/design/frontend/default/modern/layout/catalog.xml
+++ b/app/design/frontend/default/modern/layout/catalog.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/catalogsearch.xml b/app/design/frontend/default/modern/layout/catalogsearch.xml
index b556fd3..dc03dd2 100644
--- a/app/design/frontend/default/modern/layout/catalogsearch.xml
+++ b/app/design/frontend/default/modern/layout/catalogsearch.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/checkout.xml b/app/design/frontend/default/modern/layout/checkout.xml
index 8c6f371..b6d5fbf 100644
--- a/app/design/frontend/default/modern/layout/checkout.xml
+++ b/app/design/frontend/default/modern/layout/checkout.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/contacts.xml b/app/design/frontend/default/modern/layout/contacts.xml
index 03baf57..560c3d6 100644
--- a/app/design/frontend/default/modern/layout/contacts.xml
+++ b/app/design/frontend/default/modern/layout/contacts.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/customer.xml b/app/design/frontend/default/modern/layout/customer.xml
index b339c07..dfbb431 100644
--- a/app/design/frontend/default/modern/layout/customer.xml
+++ b/app/design/frontend/default/modern/layout/customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/newsletter.xml b/app/design/frontend/default/modern/layout/newsletter.xml
index 619a51b..72fd48d 100644
--- a/app/design/frontend/default/modern/layout/newsletter.xml
+++ b/app/design/frontend/default/modern/layout/newsletter.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/page.xml b/app/design/frontend/default/modern/layout/page.xml
index 0ff7cc9..50d2a37 100644
--- a/app/design/frontend/default/modern/layout/page.xml
+++ b/app/design/frontend/default/modern/layout/page.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/payment.xml b/app/design/frontend/default/modern/layout/payment.xml
index 921cb1b..6ed5993 100644
--- a/app/design/frontend/default/modern/layout/payment.xml
+++ b/app/design/frontend/default/modern/layout/payment.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/persistent.xml b/app/design/frontend/default/modern/layout/persistent.xml
index d2a3dc4..0ddefb1 100644
--- a/app/design/frontend/default/modern/layout/persistent.xml
+++ b/app/design/frontend/default/modern/layout/persistent.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/review.xml b/app/design/frontend/default/modern/layout/review.xml
index 0ccad7a..db9d111 100644
--- a/app/design/frontend/default/modern/layout/review.xml
+++ b/app/design/frontend/default/modern/layout/review.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/rss.xml b/app/design/frontend/default/modern/layout/rss.xml
index cf41b61..7ce851b 100644
--- a/app/design/frontend/default/modern/layout/rss.xml
+++ b/app/design/frontend/default/modern/layout/rss.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/sales.xml b/app/design/frontend/default/modern/layout/sales.xml
index 099f41c..bd0db94 100644
--- a/app/design/frontend/default/modern/layout/sales.xml
+++ b/app/design/frontend/default/modern/layout/sales.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/sendfriend.xml b/app/design/frontend/default/modern/layout/sendfriend.xml
index 64555bd..891119f 100644
--- a/app/design/frontend/default/modern/layout/sendfriend.xml
+++ b/app/design/frontend/default/modern/layout/sendfriend.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/default/modern/layout/tag.xml b/app/design/frontend/default/modern/layout/tag.xml
index d522373..cf80694 100644
--- a/app/design/frontend/default/modern/layout/tag.xml
+++ b/app/design/frontend/default/modern/layout/tag.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/layout/wishlist.xml b/app/design/frontend/default/modern/layout/wishlist.xml
index 9f7678e..b7fcacd 100644
--- a/app/design/frontend/default/modern/layout/wishlist.xml
+++ b/app/design/frontend/default/modern/layout/wishlist.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/template/catalog/product/list.phtml b/app/design/frontend/default/modern/template/catalog/product/list.phtml
index e70f980..ccc3d20 100644
--- a/app/design/frontend/default/modern/template/catalog/product/list.phtml
+++ b/app/design/frontend/default/modern/template/catalog/product/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/catalog/product/list/upsell.phtml b/app/design/frontend/default/modern/template/catalog/product/list/upsell.phtml
index f09701a..897ad1f 100644
--- a/app/design/frontend/default/modern/template/catalog/product/list/upsell.phtml
+++ b/app/design/frontend/default/modern/template/catalog/product/list/upsell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/catalog/product/view.phtml b/app/design/frontend/default/modern/template/catalog/product/view.phtml
index 27ee70e..ae6441d 100644
--- a/app/design/frontend/default/modern/template/catalog/product/view.phtml
+++ b/app/design/frontend/default/modern/template/catalog/product/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/template/catalog/product/view/media.phtml b/app/design/frontend/default/modern/template/catalog/product/view/media.phtml
index 04464ca..8c25e55 100644
--- a/app/design/frontend/default/modern/template/catalog/product/view/media.phtml
+++ b/app/design/frontend/default/modern/template/catalog/product/view/media.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/template/catalog/product/view/tabs.phtml b/app/design/frontend/default/modern/template/catalog/product/view/tabs.phtml
index 4fc5187..ead56b4 100644
--- a/app/design/frontend/default/modern/template/catalog/product/view/tabs.phtml
+++ b/app/design/frontend/default/modern/template/catalog/product/view/tabs.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/default/modern/template/catalogsearch/form.mini.phtml b/app/design/frontend/default/modern/template/catalogsearch/form.mini.phtml
index 5e76041..bb37e80 100644
--- a/app/design/frontend/default/modern/template/catalogsearch/form.mini.phtml
+++ b/app/design/frontend/default/modern/template/catalogsearch/form.mini.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Core_Block_Template */
diff --git a/app/design/frontend/default/modern/template/checkout/cart.phtml b/app/design/frontend/default/modern/template/checkout/cart.phtml
index 551eb97..826ff67 100644
--- a/app/design/frontend/default/modern/template/checkout/cart.phtml
+++ b/app/design/frontend/default/modern/template/checkout/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/newsletter/subscribe.phtml b/app/design/frontend/default/modern/template/newsletter/subscribe.phtml
index f543918..93094a7 100644
--- a/app/design/frontend/default/modern/template/newsletter/subscribe.phtml
+++ b/app/design/frontend/default/modern/template/newsletter/subscribe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/page/3columns.phtml b/app/design/frontend/default/modern/template/page/3columns.phtml
index a912b10..dbb6927 100644
--- a/app/design/frontend/default/modern/template/page/3columns.phtml
+++ b/app/design/frontend/default/modern/template/page/3columns.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/page/html/footer.phtml b/app/design/frontend/default/modern/template/page/html/footer.phtml
index 1e39e6e..280a2a3 100644
--- a/app/design/frontend/default/modern/template/page/html/footer.phtml
+++ b/app/design/frontend/default/modern/template/page/html/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/default/modern/template/page/html/header.phtml b/app/design/frontend/default/modern/template/page/html/header.phtml
index a1060f8..d40de92 100644
--- a/app/design/frontend/default/modern/template/page/html/header.phtml
+++ b/app/design/frontend/default/modern/template/page/html/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/default/modern/template/sample/home.phtml b/app/design/frontend/default/modern/template/sample/home.phtml
index 211d39e..f43da47 100644
--- a/app/design/frontend/default/modern/template/sample/home.phtml
+++ b/app/design/frontend/default/modern/template/sample/home.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/etc/theme.xml b/app/design/frontend/rwd/default/etc/theme.xml
index c4075f8..eb0fa01 100644
--- a/app/design/frontend/rwd/default/etc/theme.xml
+++ b/app/design/frontend/rwd/default/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/etc/widget.xml b/app/design/frontend/rwd/default/etc/widget.xml
index e3b08c4..3673ad7 100644
--- a/app/design/frontend/rwd/default/etc/widget.xml
+++ b/app/design/frontend/rwd/default/etc/widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/bundle.xml b/app/design/frontend/rwd/default/layout/bundle.xml
index 8dd6429..1cf09d4 100644
--- a/app/design/frontend/rwd/default/layout/bundle.xml
+++ b/app/design/frontend/rwd/default/layout/bundle.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/catalog.xml b/app/design/frontend/rwd/default/layout/catalog.xml
index c580cc9..2ff2fdf 100644
--- a/app/design/frontend/rwd/default/layout/catalog.xml
+++ b/app/design/frontend/rwd/default/layout/catalog.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/catalog_msrp.xml b/app/design/frontend/rwd/default/layout/catalog_msrp.xml
index 88971b4..9eb8a4d 100644
--- a/app/design/frontend/rwd/default/layout/catalog_msrp.xml
+++ b/app/design/frontend/rwd/default/layout/catalog_msrp.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/catalogsearch.xml b/app/design/frontend/rwd/default/layout/catalogsearch.xml
index 8f39034..f550797 100644
--- a/app/design/frontend/rwd/default/layout/catalogsearch.xml
+++ b/app/design/frontend/rwd/default/layout/catalogsearch.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/checkout.xml b/app/design/frontend/rwd/default/layout/checkout.xml
index 8c9dcaa..9dceccb 100644
--- a/app/design/frontend/rwd/default/layout/checkout.xml
+++ b/app/design/frontend/rwd/default/layout/checkout.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/cms.xml b/app/design/frontend/rwd/default/layout/cms.xml
index e3ef6ab..349ae62 100644
--- a/app/design/frontend/rwd/default/layout/cms.xml
+++ b/app/design/frontend/rwd/default/layout/cms.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/configurableswatches.xml b/app/design/frontend/rwd/default/layout/configurableswatches.xml
index a5cb83a..076ab79 100644
--- a/app/design/frontend/rwd/default/layout/configurableswatches.xml
+++ b/app/design/frontend/rwd/default/layout/configurableswatches.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/contacts.xml b/app/design/frontend/rwd/default/layout/contacts.xml
index 3ee02c7..e691ace 100644
--- a/app/design/frontend/rwd/default/layout/contacts.xml
+++ b/app/design/frontend/rwd/default/layout/contacts.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/customer.xml b/app/design/frontend/rwd/default/layout/customer.xml
index 10c800f..60edf87 100644
--- a/app/design/frontend/rwd/default/layout/customer.xml
+++ b/app/design/frontend/rwd/default/layout/customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/directory.xml b/app/design/frontend/rwd/default/layout/directory.xml
index be92b3d..2a3aa76 100644
--- a/app/design/frontend/rwd/default/layout/directory.xml
+++ b/app/design/frontend/rwd/default/layout/directory.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/downloadable.xml b/app/design/frontend/rwd/default/layout/downloadable.xml
index 3d41dbd..8ef1433 100644
--- a/app/design/frontend/rwd/default/layout/downloadable.xml
+++ b/app/design/frontend/rwd/default/layout/downloadable.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/newsletter.xml b/app/design/frontend/rwd/default/layout/newsletter.xml
index 0d2c408..9ca6b16 100644
--- a/app/design/frontend/rwd/default/layout/newsletter.xml
+++ b/app/design/frontend/rwd/default/layout/newsletter.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/oauth.xml b/app/design/frontend/rwd/default/layout/oauth.xml
index 1184758..5615fec 100644
--- a/app/design/frontend/rwd/default/layout/oauth.xml
+++ b/app/design/frontend/rwd/default/layout/oauth.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/page.xml b/app/design/frontend/rwd/default/layout/page.xml
index de124bd..c8a5e58 100644
--- a/app/design/frontend/rwd/default/layout/page.xml
+++ b/app/design/frontend/rwd/default/layout/page.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/paypal.xml b/app/design/frontend/rwd/default/layout/paypal.xml
index 183cdae..f6eba03 100644
--- a/app/design/frontend/rwd/default/layout/paypal.xml
+++ b/app/design/frontend/rwd/default/layout/paypal.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/persistent.xml b/app/design/frontend/rwd/default/layout/persistent.xml
index 72b2a60..9bce5c1 100644
--- a/app/design/frontend/rwd/default/layout/persistent.xml
+++ b/app/design/frontend/rwd/default/layout/persistent.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/review.xml b/app/design/frontend/rwd/default/layout/review.xml
index 3746842..13a0a87 100644
--- a/app/design/frontend/rwd/default/layout/review.xml
+++ b/app/design/frontend/rwd/default/layout/review.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/rss.xml b/app/design/frontend/rwd/default/layout/rss.xml
index d40f554..77e162f 100644
--- a/app/design/frontend/rwd/default/layout/rss.xml
+++ b/app/design/frontend/rwd/default/layout/rss.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/frontend/rwd/default/layout/sales.xml b/app/design/frontend/rwd/default/layout/sales.xml
index c97128b..fd1e60f 100644
--- a/app/design/frontend/rwd/default/layout/sales.xml
+++ b/app/design/frontend/rwd/default/layout/sales.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/layout/wishlist.xml b/app/design/frontend/rwd/default/layout/wishlist.xml
index ef6c5a1..6a98645 100644
--- a/app/design/frontend/rwd/default/layout/wishlist.xml
+++ b/app/design/frontend/rwd/default/layout/wishlist.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/authorizenet/directpost/form.phtml b/app/design/frontend/rwd/default/template/authorizenet/directpost/form.phtml
index fe31195..cf4582a 100644
--- a/app/design/frontend/rwd/default/template/authorizenet/directpost/form.phtml
+++ b/app/design/frontend/rwd/default/template/authorizenet/directpost/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle.phtml b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle.phtml
index 5f37437..7581957 100644
--- a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/availability.phtml b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/availability.phtml
index 9bfff9b..bf8ec95 100644
--- a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/availability.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/availability.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 $_product = $this->getProduct() ?>
diff --git a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
index 1f22425..a02fffc 100644
--- a/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/catalog/product/view/type/bundle/option/select.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/bundle/email/order/items/creditmemo/default.phtml b/app/design/frontend/rwd/default/template/bundle/email/order/items/creditmemo/default.phtml
index 6ca00b1..61130c2 100644
--- a/app/design/frontend/rwd/default/template/bundle/email/order/items/creditmemo/default.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/email/order/items/creditmemo/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/bundle/email/order/items/invoice/default.phtml b/app/design/frontend/rwd/default/template/bundle/email/order/items/invoice/default.phtml
index 113c941..d4ca2ba3 100644
--- a/app/design/frontend/rwd/default/template/bundle/email/order/items/invoice/default.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/email/order/items/invoice/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/bundle/email/order/items/order/default.phtml b/app/design/frontend/rwd/default/template/bundle/email/order/items/order/default.phtml
index a1148d3..95b1ff5 100644
--- a/app/design/frontend/rwd/default/template/bundle/email/order/items/order/default.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/email/order/items/order/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/bundle/email/order/items/shipment/default.phtml b/app/design/frontend/rwd/default/template/bundle/email/order/items/shipment/default.phtml
index ea0b965..aea31d9 100644
--- a/app/design/frontend/rwd/default/template/bundle/email/order/items/shipment/default.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/email/order/items/shipment/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/bundle/sales/order/items/renderer.phtml b/app/design/frontend/rwd/default/template/bundle/sales/order/items/renderer.phtml
index bdfc5c5..9127630 100644
--- a/app/design/frontend/rwd/default/template/bundle/sales/order/items/renderer.phtml
+++ b/app/design/frontend/rwd/default/template/bundle/sales/order/items/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/captcha/zend.phtml b/app/design/frontend/rwd/default/template/captcha/zend.phtml
index 6162c27..d178964 100644
--- a/app/design/frontend/rwd/default/template/captcha/zend.phtml
+++ b/app/design/frontend/rwd/default/template/captcha/zend.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/layer/filter.phtml b/app/design/frontend/rwd/default/template/catalog/layer/filter.phtml
index cafd809..a79b4d1 100644
--- a/app/design/frontend/rwd/default/template/catalog/layer/filter.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/layer/filter.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/layer/state.phtml b/app/design/frontend/rwd/default/template/catalog/layer/state.phtml
index b57b76e..66b4000 100644
--- a/app/design/frontend/rwd/default/template/catalog/layer/state.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/layer/state.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/layer/view.phtml b/app/design/frontend/rwd/default/template/catalog/layer/view.phtml
index 72cf5dc..143f607 100644
--- a/app/design/frontend/rwd/default/template/catalog/layer/view.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/layer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/msrp/popup.phtml b/app/design/frontend/rwd/default/template/catalog/msrp/popup.phtml
index 537e5fa..72b2871 100644
--- a/app/design/frontend/rwd/default/template/catalog/msrp/popup.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/msrp/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/navigation/left.phtml b/app/design/frontend/rwd/default/template/catalog/navigation/left.phtml
index c2f3e02..a2a0f91 100644
--- a/app/design/frontend/rwd/default/template/catalog/navigation/left.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/navigation/left.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/catalog/product/compare/list.phtml b/app/design/frontend/rwd/default/template/catalog/product/compare/list.phtml
index b6ced97..e2bdf12 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/compare/list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/compare/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Catalog_Block_Product_Compare_List */
diff --git a/app/design/frontend/rwd/default/template/catalog/product/compare/sidebar.phtml b/app/design/frontend/rwd/default/template/catalog/product/compare/sidebar.phtml
index 19fde8b..fc8ba69 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/compare/sidebar.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/compare/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Catalog_Block_Product_Compare_Sidebar */
diff --git a/app/design/frontend/rwd/default/template/catalog/product/list.phtml b/app/design/frontend/rwd/default/template/catalog/product/list.phtml
index b614fd1..dd66f5d 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/list/related.phtml b/app/design/frontend/rwd/default/template/catalog/product/list/related.phtml
index cda34c9..1de1078 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/list/related.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/list/related.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/list/toolbar.phtml b/app/design/frontend/rwd/default/template/catalog/product/list/toolbar.phtml
index 4abff54..5bc8b93 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/list/toolbar.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/list/toolbar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/list/upsell.phtml b/app/design/frontend/rwd/default/template/catalog/product/list/upsell.phtml
index 134dec0..e9e5739 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/list/upsell.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/list/upsell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/price.phtml b/app/design/frontend/rwd/default/template/catalog/product/price.phtml
index f7d9b97..26688dc 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/price.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view.phtml b/app/design/frontend/rwd/default/template/catalog/product/view.phtml
index 3411474..8c22d55 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/addto.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/addto.phtml
index eedd054..0cc3ff1 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/addto.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/addto.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/addtocart.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/addtocart.phtml
index 0fedc1d..384294f 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/addtocart.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/addtocart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/media.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/media.phtml
index fc1b4de..6a4423c 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/media.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/media.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/sharing.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/sharing.phtml
index f944432..b3d2389 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/sharing.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/sharing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/default.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/default.phtml
index f3cc1f7..7662ffd 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/default.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 $_product = $this->getProduct(); ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/grouped.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/grouped.phtml
index c8c0a64..cb53e22 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/grouped.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/type/availability/grouped.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 $_product = $this->getProduct(); ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/type/default.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/type/default.phtml
index b8f4ffe..086baad 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/type/default.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/type/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/type/grouped.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/type/grouped.phtml
index f0e9462..3883648 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/type/grouped.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/type/grouped.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/catalog/product/view/type/options/configurable.phtml b/app/design/frontend/rwd/default/template/catalog/product/view/type/options/configurable.phtml
index 65bc75c..55da961 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/view/type/options/configurable.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/view/type/options/configurable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_default_list.phtml b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_default_list.phtml
index 3260732..b37ae99 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_default_list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_images_list.phtml b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_images_list.phtml
index ca63dc3..da61aa9 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_images_list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_names_list.phtml b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_names_list.phtml
index 6a30010..430f2b6 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_names_list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/widget/new/column/new_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_grid.phtml b/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_grid.phtml
index 95a4fbf..6d445f7 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_grid.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_list.phtml b/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_list.phtml
index 1823eb5..2925ba6 100644
--- a/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_list.phtml
+++ b/app/design/frontend/rwd/default/template/catalog/product/widget/new/content/new_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/cataloginventory/stockqty/composite.phtml b/app/design/frontend/rwd/default/template/cataloginventory/stockqty/composite.phtml
index 7e861d4..156e22e 100644
--- a/app/design/frontend/rwd/default/template/cataloginventory/stockqty/composite.phtml
+++ b/app/design/frontend/rwd/default/template/cataloginventory/stockqty/composite.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/catalogsearch/advanced/form.phtml b/app/design/frontend/rwd/default/template/catalogsearch/advanced/form.phtml
index 6e699e6..f896472 100644
--- a/app/design/frontend/rwd/default/template/catalogsearch/advanced/form.phtml
+++ b/app/design/frontend/rwd/default/template/catalogsearch/advanced/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/catalogsearch/form.mini.phtml b/app/design/frontend/rwd/default/template/catalogsearch/form.mini.phtml
index 1044bb4..537ffa4 100644
--- a/app/design/frontend/rwd/default/template/catalogsearch/form.mini.phtml
+++ b/app/design/frontend/rwd/default/template/catalogsearch/form.mini.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Core_Block_Template */
diff --git a/app/design/frontend/rwd/default/template/catalogsearch/result.phtml b/app/design/frontend/rwd/default/template/catalogsearch/result.phtml
index dd215de..e5a69da 100644
--- a/app/design/frontend/rwd/default/template/catalogsearch/result.phtml
+++ b/app/design/frontend/rwd/default/template/catalogsearch/result.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/centinel/authentication/start.phtml b/app/design/frontend/rwd/default/template/centinel/authentication/start.phtml
index ad952b9..606352b 100644
--- a/app/design/frontend/rwd/default/template/centinel/authentication/start.phtml
+++ b/app/design/frontend/rwd/default/template/centinel/authentication/start.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart.phtml b/app/design/frontend/rwd/default/template/checkout/cart.phtml
index 3fb60d0..48783ea 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/coupon.phtml b/app/design/frontend/rwd/default/template/checkout/cart/coupon.phtml
index fbbcde2..a90c652 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/coupon.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/coupon.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/crosssell.phtml b/app/design/frontend/rwd/default/template/checkout/cart/crosssell.phtml
index 4acf426..d405845 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/crosssell.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/crosssell.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/item/configure/updatecart.phtml b/app/design/frontend/rwd/default/template/checkout/cart/item/configure/updatecart.phtml
index 36d4a44..876d384 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/item/configure/updatecart.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/item/configure/updatecart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/item/default.phtml b/app/design/frontend/rwd/default/template/checkout/cart/item/default.phtml
index 164f0a0..42b07d2 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/item/default.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/minicart.phtml b/app/design/frontend/rwd/default/template/checkout/cart/minicart.phtml
index bb134b3..21c958a 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/minicart.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/minicart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/minicart/default.phtml b/app/design/frontend/rwd/default/template/checkout/cart/minicart/default.phtml
index 022bd14..d737648 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/minicart/default.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/minicart/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/minicart/items.phtml b/app/design/frontend/rwd/default/template/checkout/cart/minicart/items.phtml
index 6b15c10..373eb1f 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/minicart/items.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/minicart/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/render/default.phtml b/app/design/frontend/rwd/default/template/checkout/cart/render/default.phtml
index 748909a..69ada7c 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/render/default.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/render/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/render/simple.phtml b/app/design/frontend/rwd/default/template/checkout/cart/render/simple.phtml
index c2a4287..037a342 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/render/simple.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/render/simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/shipping.phtml b/app/design/frontend/rwd/default/template/checkout/cart/shipping.phtml
index d48c2da..39004be 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/shipping.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/sidebar.phtml b/app/design/frontend/rwd/default/template/checkout/cart/sidebar.phtml
index 08dcdce..4774fb6 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/sidebar.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/checkout/cart/sidebar/default.phtml b/app/design/frontend/rwd/default/template/checkout/cart/sidebar/default.phtml
index 4d649b2..341c953 100644
--- a/app/design/frontend/rwd/default/template/checkout/cart/sidebar/default.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/cart/sidebar/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/multishipping/addresses.phtml b/app/design/frontend/rwd/default/template/checkout/multishipping/addresses.phtml
index dfa6d9b..756f99f 100644
--- a/app/design/frontend/rwd/default/template/checkout/multishipping/addresses.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/multishipping/addresses.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/multishipping/billing.phtml b/app/design/frontend/rwd/default/template/checkout/multishipping/billing.phtml
index 4fdd3b8..81ea4d8 100644
--- a/app/design/frontend/rwd/default/template/checkout/multishipping/billing.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/multishipping/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/multishipping/item/default.phtml b/app/design/frontend/rwd/default/template/checkout/multishipping/item/default.phtml
index b40ead3..43140af 100644
--- a/app/design/frontend/rwd/default/template/checkout/multishipping/item/default.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/multishipping/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/multishipping/overview.phtml b/app/design/frontend/rwd/default/template/checkout/multishipping/overview.phtml
index 111a2eb..f2834d3 100644
--- a/app/design/frontend/rwd/default/template/checkout/multishipping/overview.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/multishipping/overview.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/multishipping/overview/item.phtml b/app/design/frontend/rwd/default/template/checkout/multishipping/overview/item.phtml
index 7f62f56..edc9c0d 100644
--- a/app/design/frontend/rwd/default/template/checkout/multishipping/overview/item.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/multishipping/overview/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage.phtml b/app/design/frontend/rwd/default/template/checkout/onepage.phtml
index 7d77200..df24ebb 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage/payment.phtml b/app/design/frontend/rwd/default/template/checkout/onepage/payment.phtml
index c5750a3..037b02d 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage/payment.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage/payment.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage/progress.phtml b/app/design/frontend/rwd/default/template/checkout/onepage/progress.phtml
index 0465a8f..3c6b3b1 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage/progress.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage/progress.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage/review/info.phtml b/app/design/frontend/rwd/default/template/checkout/onepage/review/info.phtml
index 0dc0d64..29426a5 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage/review/info.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage/review/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage/review/item.phtml b/app/design/frontend/rwd/default/template/checkout/onepage/review/item.phtml
index 442b28e..8f734e8 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/checkout/onepage/shipping.phtml b/app/design/frontend/rwd/default/template/checkout/onepage/shipping.phtml
index e7d8c01..1fc5d13 100644
--- a/app/design/frontend/rwd/default/template/checkout/onepage/shipping.phtml
+++ b/app/design/frontend/rwd/default/template/checkout/onepage/shipping.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/filter/swatches.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/filter/swatches.phtml
index cd8b3e6..5b6f49c 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/filter/swatches.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/filter/swatches.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/state/swatch.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/state/swatch.phtml
index 7ab4fec..14804bc 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/state/swatch.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/layer/state/swatch.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/media/js.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/media/js.phtml
index 14322ca..3288641 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/media/js.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/media/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/price/js.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/price/js.phtml
index 69fdd3e..11f4488 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/price/js.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/price/js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/swatches.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/swatches.phtml
index 2fd9c50..776eb32 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/swatches.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/list/swatches.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/configurable/swatch-js.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/configurable/swatch-js.phtml
index 456a843..4280c51 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/configurable/swatch-js.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/configurable/swatch-js.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/options/configurable/swatches.phtml b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/options/configurable/swatches.phtml
index 26a8fcc..e2e6370 100644
--- a/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/options/configurable/swatches.phtml
+++ b/app/design/frontend/rwd/default/template/configurableswatches/catalog/product/view/type/options/configurable/swatches.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/contacts/form.phtml b/app/design/frontend/rwd/default/template/contacts/form.phtml
index 06912d5..2136fe1 100644
--- a/app/design/frontend/rwd/default/template/contacts/form.phtml
+++ b/app/design/frontend/rwd/default/template/contacts/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/account/dashboard.phtml b/app/design/frontend/rwd/default/template/customer/account/dashboard.phtml
index 6c9a01d..77279c7 100644
--- a/app/design/frontend/rwd/default/template/customer/account/dashboard.phtml
+++ b/app/design/frontend/rwd/default/template/customer/account/dashboard.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/account/dashboard/address.phtml b/app/design/frontend/rwd/default/template/customer/account/dashboard/address.phtml
index e333584..dbba9af 100644
--- a/app/design/frontend/rwd/default/template/customer/account/dashboard/address.phtml
+++ b/app/design/frontend/rwd/default/template/customer/account/dashboard/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/account/navigation.phtml b/app/design/frontend/rwd/default/template/customer/account/navigation.phtml
index 9010b84..049e6c9 100644
--- a/app/design/frontend/rwd/default/template/customer/account/navigation.phtml
+++ b/app/design/frontend/rwd/default/template/customer/account/navigation.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/address/edit.phtml b/app/design/frontend/rwd/default/template/customer/address/edit.phtml
index 1a0b92f..032bf52 100644
--- a/app/design/frontend/rwd/default/template/customer/address/edit.phtml
+++ b/app/design/frontend/rwd/default/template/customer/address/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/address.phtml b/app/design/frontend/rwd/default/template/customer/form/address.phtml
index a615660..8967f1a 100644
--- a/app/design/frontend/rwd/default/template/customer/form/address.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/changepassword.phtml b/app/design/frontend/rwd/default/template/customer/form/changepassword.phtml
index 10b8f91..37a3d19 100644
--- a/app/design/frontend/rwd/default/template/customer/form/changepassword.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/changepassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/confirmation.phtml b/app/design/frontend/rwd/default/template/customer/form/confirmation.phtml
index 19c62e6..74497a7 100644
--- a/app/design/frontend/rwd/default/template/customer/form/confirmation.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/confirmation.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/edit.phtml b/app/design/frontend/rwd/default/template/customer/form/edit.phtml
index 20964e8..789a8b9 100644
--- a/app/design/frontend/rwd/default/template/customer/form/edit.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/edit.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/forgotpassword.phtml b/app/design/frontend/rwd/default/template/customer/form/forgotpassword.phtml
index ddad684..50fe813 100644
--- a/app/design/frontend/rwd/default/template/customer/form/forgotpassword.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/forgotpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/mini.login.phtml b/app/design/frontend/rwd/default/template/customer/form/mini.login.phtml
index 0b507a3..43d92e4 100644
--- a/app/design/frontend/rwd/default/template/customer/form/mini.login.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/mini.login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/customer/form/resetforgottenpassword.phtml b/app/design/frontend/rwd/default/template/customer/form/resetforgottenpassword.phtml
index fd3f25f..1810ac7 100644
--- a/app/design/frontend/rwd/default/template/customer/form/resetforgottenpassword.phtml
+++ b/app/design/frontend/rwd/default/template/customer/form/resetforgottenpassword.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/directory/currency.phtml b/app/design/frontend/rwd/default/template/directory/currency.phtml
index 9853805..6d30ddf 100644
--- a/app/design/frontend/rwd/default/template/directory/currency.phtml
+++ b/app/design/frontend/rwd/default/template/directory/currency.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/catalog/product/type.phtml b/app/design/frontend/rwd/default/template/downloadable/catalog/product/type.phtml
index 0147f84..f7d6aa1 100644
--- a/app/design/frontend/rwd/default/template/downloadable/catalog/product/type.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/catalog/product/type.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/downloadable/checkout/cart/item/default.phtml b/app/design/frontend/rwd/default/template/downloadable/checkout/cart/item/default.phtml
index e5fb754..ba71394 100644
--- a/app/design/frontend/rwd/default/template/downloadable/checkout/cart/item/default.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/checkout/cart/item/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/checkout/onepage/review/item.phtml b/app/design/frontend/rwd/default/template/downloadable/checkout/onepage/review/item.phtml
index 19eef4c..94a30cd 100644
--- a/app/design/frontend/rwd/default/template/downloadable/checkout/onepage/review/item.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/checkout/onepage/review/item.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/customer/products/list.phtml b/app/design/frontend/rwd/default/template/downloadable/customer/products/list.phtml
index b5d0166..27a1b49 100644
--- a/app/design/frontend/rwd/default/template/downloadable/customer/products/list.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/customer/products/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml b/app/design/frontend/rwd/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
index 65e3a2d..d6e850e 100644
--- a/app/design/frontend/rwd/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/email/order/items/creditmemo/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/email/order/items/invoice/downloadable.phtml b/app/design/frontend/rwd/default/template/downloadable/email/order/items/invoice/downloadable.phtml
index cf09122..a2614ae 100644
--- a/app/design/frontend/rwd/default/template/downloadable/email/order/items/invoice/downloadable.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/email/order/items/invoice/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/email/order/items/order/downloadable.phtml b/app/design/frontend/rwd/default/template/downloadable/email/order/items/order/downloadable.phtml
index b2f4ecb..ec84637 100644
--- a/app/design/frontend/rwd/default/template/downloadable/email/order/items/order/downloadable.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/email/order/items/order/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/downloadable/sales/order/items/renderer/downloadable.phtml b/app/design/frontend/rwd/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
index 63b15c0..991212e 100644
--- a/app/design/frontend/rwd/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
+++ b/app/design/frontend/rwd/default/template/downloadable/sales/order/items/renderer/downloadable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/catalog/product/list.phtml b/app/design/frontend/rwd/default/template/email/catalog/product/list.phtml
index 2803c53..33c9169 100644
--- a/app/design/frontend/rwd/default/template/email/catalog/product/list.phtml
+++ b/app/design/frontend/rwd/default/template/email/catalog/product/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/catalog/product/new.phtml b/app/design/frontend/rwd/default/template/email/catalog/product/new.phtml
index 2ab0804..1166aa7 100644
--- a/app/design/frontend/rwd/default/template/email/catalog/product/new.phtml
+++ b/app/design/frontend/rwd/default/template/email/catalog/product/new.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/creditmemo/items.phtml b/app/design/frontend/rwd/default/template/email/order/creditmemo/items.phtml
index d31b359..76c18ff 100644
--- a/app/design/frontend/rwd/default/template/email/order/creditmemo/items.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/creditmemo/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/invoice/items.phtml b/app/design/frontend/rwd/default/template/email/order/invoice/items.phtml
index 09afa7a..27c5c34 100644
--- a/app/design/frontend/rwd/default/template/email/order/invoice/items.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/invoice/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/items.phtml b/app/design/frontend/rwd/default/template/email/order/items.phtml
index 222ddf4..de10b4e 100644
--- a/app/design/frontend/rwd/default/template/email/order/items.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/items/creditmemo/default.phtml b/app/design/frontend/rwd/default/template/email/order/items/creditmemo/default.phtml
index 2e85595..23e4563 100644
--- a/app/design/frontend/rwd/default/template/email/order/items/creditmemo/default.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/items/creditmemo/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/items/invoice/default.phtml b/app/design/frontend/rwd/default/template/email/order/items/invoice/default.phtml
index 2e85595..23e4563 100644
--- a/app/design/frontend/rwd/default/template/email/order/items/invoice/default.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/items/invoice/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/items/order/default.phtml b/app/design/frontend/rwd/default/template/email/order/items/order/default.phtml
index e9b6c2b..4e080ad 100644
--- a/app/design/frontend/rwd/default/template/email/order/items/order/default.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/items/order/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/items/shipment/default.phtml b/app/design/frontend/rwd/default/template/email/order/items/shipment/default.phtml
index 3c799fc..59dcd93 100644
--- a/app/design/frontend/rwd/default/template/email/order/items/shipment/default.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/items/shipment/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/shipment/items.phtml b/app/design/frontend/rwd/default/template/email/order/shipment/items.phtml
index 052d9ba..0a58ca0 100644
--- a/app/design/frontend/rwd/default/template/email/order/shipment/items.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/shipment/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/shipment/track.phtml b/app/design/frontend/rwd/default/template/email/order/shipment/track.phtml
index 7db33e6..175a46b 100644
--- a/app/design/frontend/rwd/default/template/email/order/shipment/track.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/shipment/track.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/order/totals/wrapper.phtml b/app/design/frontend/rwd/default/template/email/order/totals/wrapper.phtml
index a3edadd..eca1a29 100644
--- a/app/design/frontend/rwd/default/template/email/order/totals/wrapper.phtml
+++ b/app/design/frontend/rwd/default/template/email/order/totals/wrapper.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/email/productalert/price.phtml b/app/design/frontend/rwd/default/template/email/productalert/price.phtml
index 4f78d0d..d14024a 100644
--- a/app/design/frontend/rwd/default/template/email/productalert/price.phtml
+++ b/app/design/frontend/rwd/default/template/email/productalert/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/email/productalert/stock.phtml b/app/design/frontend/rwd/default/template/email/productalert/stock.phtml
index 095b838..d3164d5 100644
--- a/app/design/frontend/rwd/default/template/email/productalert/stock.phtml
+++ b/app/design/frontend/rwd/default/template/email/productalert/stock.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/newsletter/subscribe.phtml b/app/design/frontend/rwd/default/template/newsletter/subscribe.phtml
index f289806..973d4a3 100644
--- a/app/design/frontend/rwd/default/template/newsletter/subscribe.phtml
+++ b/app/design/frontend/rwd/default/template/newsletter/subscribe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/oauth/authorize/form/login-simple.phtml b/app/design/frontend/rwd/default/template/oauth/authorize/form/login-simple.phtml
index c963512..945858c 100644
--- a/app/design/frontend/rwd/default/template/oauth/authorize/form/login-simple.phtml
+++ b/app/design/frontend/rwd/default/template/oauth/authorize/form/login-simple.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/page/1column.phtml b/app/design/frontend/rwd/default/template/page/1column.phtml
index f619f58..26ee45a 100644
--- a/app/design/frontend/rwd/default/template/page/1column.phtml
+++ b/app/design/frontend/rwd/default/template/page/1column.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/2columns-left.phtml b/app/design/frontend/rwd/default/template/page/2columns-left.phtml
index 41ca307..55feb41 100644
--- a/app/design/frontend/rwd/default/template/page/2columns-left.phtml
+++ b/app/design/frontend/rwd/default/template/page/2columns-left.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/2columns-right.phtml b/app/design/frontend/rwd/default/template/page/2columns-right.phtml
index 408c4c5..fe99125 100644
--- a/app/design/frontend/rwd/default/template/page/2columns-right.phtml
+++ b/app/design/frontend/rwd/default/template/page/2columns-right.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/3columns.phtml b/app/design/frontend/rwd/default/template/page/3columns.phtml
index f88ff5a..670b62b 100644
--- a/app/design/frontend/rwd/default/template/page/3columns.phtml
+++ b/app/design/frontend/rwd/default/template/page/3columns.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/empty.phtml b/app/design/frontend/rwd/default/template/page/empty.phtml
index 9a6d0cd..20f2211 100644
--- a/app/design/frontend/rwd/default/template/page/empty.phtml
+++ b/app/design/frontend/rwd/default/template/page/empty.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/html/footer.phtml b/app/design/frontend/rwd/default/template/page/html/footer.phtml
index 7a33383..2e0b517 100644
--- a/app/design/frontend/rwd/default/template/page/html/footer.phtml
+++ b/app/design/frontend/rwd/default/template/page/html/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/html/header.phtml b/app/design/frontend/rwd/default/template/page/html/header.phtml
index d453207..3b75d35 100644
--- a/app/design/frontend/rwd/default/template/page/html/header.phtml
+++ b/app/design/frontend/rwd/default/template/page/html/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/app/design/frontend/rwd/default/template/page/html/pager.phtml b/app/design/frontend/rwd/default/template/page/html/pager.phtml
index 0344c5f..564b744 100644
--- a/app/design/frontend/rwd/default/template/page/html/pager.phtml
+++ b/app/design/frontend/rwd/default/template/page/html/pager.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/html/topmenu.phtml b/app/design/frontend/rwd/default/template/page/html/topmenu.phtml
index 8478baf..93ef129 100644
--- a/app/design/frontend/rwd/default/template/page/html/topmenu.phtml
+++ b/app/design/frontend/rwd/default/template/page/html/topmenu.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/html/topmenu/renderer.phtml b/app/design/frontend/rwd/default/template/page/html/topmenu/renderer.phtml
index a6b5bf3..cb280b9 100644
--- a/app/design/frontend/rwd/default/template/page/html/topmenu/renderer.phtml
+++ b/app/design/frontend/rwd/default/template/page/html/topmenu/renderer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/page/popup.phtml b/app/design/frontend/rwd/default/template/page/popup.phtml
index 361fcd3..0134db6 100644
--- a/app/design/frontend/rwd/default/template/page/popup.phtml
+++ b/app/design/frontend/rwd/default/template/page/popup.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/print.phtml b/app/design/frontend/rwd/default/template/page/print.phtml
index 7720a44..fa90903 100644
--- a/app/design/frontend/rwd/default/template/page/print.phtml
+++ b/app/design/frontend/rwd/default/template/page/print.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/page/template/links.phtml b/app/design/frontend/rwd/default/template/page/template/links.phtml
index c581a1a..9c11d65 100644
--- a/app/design/frontend/rwd/default/template/page/template/links.phtml
+++ b/app/design/frontend/rwd/default/template/page/template/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/payment/form/cc.phtml b/app/design/frontend/rwd/default/template/payment/form/cc.phtml
index 4f50f5a..de88e0f 100644
--- a/app/design/frontend/rwd/default/template/payment/form/cc.phtml
+++ b/app/design/frontend/rwd/default/template/payment/form/cc.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/payment/form/ccsave.phtml b/app/design/frontend/rwd/default/template/payment/form/ccsave.phtml
index fb9b771..d19cb22 100644
--- a/app/design/frontend/rwd/default/template/payment/form/ccsave.phtml
+++ b/app/design/frontend/rwd/default/template/payment/form/ccsave.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/payment/info/default.phtml b/app/design/frontend/rwd/default/template/payment/info/default.phtml
index 55d54d0..dfa24f5 100644
--- a/app/design/frontend/rwd/default/template/payment/info/default.phtml
+++ b/app/design/frontend/rwd/default/template/payment/info/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/paypal/bml.phtml b/app/design/frontend/rwd/default/template/paypal/bml.phtml
index 4147d8a..86e6fc8 100644
--- a/app/design/frontend/rwd/default/template/paypal/bml.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/bml.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/paypal/express/minicart/shortcut.phtml b/app/design/frontend/rwd/default/template/paypal/express/minicart/shortcut.phtml
index 6e19c07..c0776e6 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/minicart/shortcut.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/minicart/shortcut.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/paypal/express/product/shortcut.phtml b/app/design/frontend/rwd/default/template/paypal/express/product/shortcut.phtml
index 97a4cc6..e191dac 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/product/shortcut.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/product/shortcut.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/paypal/express/review.phtml b/app/design/frontend/rwd/default/template/paypal/express/review.phtml
index a855d65..4b8769b 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/review.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/review.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Express_Review */
diff --git a/app/design/frontend/rwd/default/template/paypal/express/review/address.phtml b/app/design/frontend/rwd/default/template/paypal/express/review/address.phtml
index 4e72f5d..9a67f01 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/review/address.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/review/address.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/paypal/express/review/details.phtml b/app/design/frontend/rwd/default/template/paypal/express/review/details.phtml
index 9884e31..0435bda 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/review/details.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/review/details.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/paypal/express/review/shipping/method.phtml b/app/design/frontend/rwd/default/template/paypal/express/review/shipping/method.phtml
index 732b6e6..fab1867 100644
--- a/app/design/frontend/rwd/default/template/paypal/express/review/shipping/method.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/express/review/shipping/method.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Paypal_Block_Express_Review */
diff --git a/app/design/frontend/rwd/default/template/paypal/partner/us_logo.phtml b/app/design/frontend/rwd/default/template/paypal/partner/us_logo.phtml
index 5c898e7..77848bc 100644
--- a/app/design/frontend/rwd/default/template/paypal/partner/us_logo.phtml
+++ b/app/design/frontend/rwd/default/template/paypal/partner/us_logo.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/checkout/onepage/billing.phtml b/app/design/frontend/rwd/default/template/persistent/checkout/onepage/billing.phtml
index 40fc9e7..d92b96a 100644
--- a/app/design/frontend/rwd/default/template/persistent/checkout/onepage/billing.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/checkout/onepage/billing.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var Mage_Checkout_Block_Onepage_Billing $this */
diff --git a/app/design/frontend/rwd/default/template/persistent/checkout/onepage/login.phtml b/app/design/frontend/rwd/default/template/persistent/checkout/onepage/login.phtml
index a6745f1..ff0494d 100644
--- a/app/design/frontend/rwd/default/template/persistent/checkout/onepage/login.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/checkout/onepage/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/customer/form/login.phtml b/app/design/frontend/rwd/default/template/persistent/customer/form/login.phtml
index e3d06b5..4bf18be 100644
--- a/app/design/frontend/rwd/default/template/persistent/customer/form/login.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/customer/form/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/customer/form/register.phtml b/app/design/frontend/rwd/default/template/persistent/customer/form/register.phtml
index 0989605..eb9edf7 100644
--- a/app/design/frontend/rwd/default/template/persistent/customer/form/register.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/customer/form/register.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/header/links.phtml b/app/design/frontend/rwd/default/template/persistent/header/links.phtml
index 039d43e..5ff61f8 100644
--- a/app/design/frontend/rwd/default/template/persistent/header/links.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/header/links.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/remember_me.phtml b/app/design/frontend/rwd/default/template/persistent/remember_me.phtml
index 0a9844f..9a187a4 100644
--- a/app/design/frontend/rwd/default/template/persistent/remember_me.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/remember_me.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/persistent/remember_me_tooltip.phtml b/app/design/frontend/rwd/default/template/persistent/remember_me_tooltip.phtml
index b9a0814..23d63e1 100644
--- a/app/design/frontend/rwd/default/template/persistent/remember_me_tooltip.phtml
+++ b/app/design/frontend/rwd/default/template/persistent/remember_me_tooltip.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/rating/detailed.phtml b/app/design/frontend/rwd/default/template/rating/detailed.phtml
index 3b39fa4..8a0f9eb 100644
--- a/app/design/frontend/rwd/default/template/rating/detailed.phtml
+++ b/app/design/frontend/rwd/default/template/rating/detailed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/product_viewed.phtml b/app/design/frontend/rwd/default/template/reports/product_viewed.phtml
index cad1a4b..401d671 100644
--- a/app/design/frontend/rwd/default/template/reports/product_viewed.phtml
+++ b/app/design/frontend/rwd/default/template/reports/product_viewed.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Reports_Block_Product_Viewed */
diff --git a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_default_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_default_list.phtml
index 02d7382..4d20d20 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_default_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_images_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_images_list.phtml
index 85671ea..4b8c42a 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_images_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_names_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_names_list.phtml
index 3935d0a..485d7e9 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_names_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/compared/column/compared_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_grid.phtml b/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_grid.phtml
index 87999cc..86c15d5 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_grid.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_list.phtml
index 7b09b32..ce588eb 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/compared/content/compared_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_default_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_default_list.phtml
index 0a3717b..4a9d2fd 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_default_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_default_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_images_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_images_list.phtml
index 9723cab..9359933 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_images_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_images_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_names_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_names_list.phtml
index 71702e8..0c15f34 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_names_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/viewed/column/viewed_names_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_grid.phtml b/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_grid.phtml
index 0c99292..94a1ec7 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_grid.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_list.phtml b/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_list.phtml
index 6401630..242b18e 100644
--- a/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_list.phtml
+++ b/app/design/frontend/rwd/default/template/reports/widget/viewed/content/viewed_list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/review/customer/view.phtml b/app/design/frontend/rwd/default/template/review/customer/view.phtml
index 9c00c5d..634780e 100644
--- a/app/design/frontend/rwd/default/template/review/customer/view.phtml
+++ b/app/design/frontend/rwd/default/template/review/customer/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/review/form.phtml b/app/design/frontend/rwd/default/template/review/form.phtml
index 365ac54..3b5eba6 100644
--- a/app/design/frontend/rwd/default/template/review/form.phtml
+++ b/app/design/frontend/rwd/default/template/review/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/review/product/view/list.phtml b/app/design/frontend/rwd/default/template/review/product/view/list.phtml
index 55b0442..1d07f75 100644
--- a/app/design/frontend/rwd/default/template/review/product/view/list.phtml
+++ b/app/design/frontend/rwd/default/template/review/product/view/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/review/view.phtml b/app/design/frontend/rwd/default/template/review/view.phtml
index 4d92931..867961b 100644
--- a/app/design/frontend/rwd/default/template/review/view.phtml
+++ b/app/design/frontend/rwd/default/template/review/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/billing/agreement/view.phtml b/app/design/frontend/rwd/default/template/sales/billing/agreement/view.phtml
index 9745761..51411cc 100644
--- a/app/design/frontend/rwd/default/template/sales/billing/agreement/view.phtml
+++ b/app/design/frontend/rwd/default/template/sales/billing/agreement/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/billing/agreements.phtml b/app/design/frontend/rwd/default/template/sales/billing/agreements.phtml
index cde7e6c..671f228 100644
--- a/app/design/frontend/rwd/default/template/sales/billing/agreements.phtml
+++ b/app/design/frontend/rwd/default/template/sales/billing/agreements.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/creditmemo/items.phtml b/app/design/frontend/rwd/default/template/sales/order/creditmemo/items.phtml
index de2748a..a7918b8 100644
--- a/app/design/frontend/rwd/default/template/sales/order/creditmemo/items.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/creditmemo/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/creditmemo/items/renderer/default.phtml b/app/design/frontend/rwd/default/template/sales/order/creditmemo/items/renderer/default.phtml
index 925f0ae..69e7086 100644
--- a/app/design/frontend/rwd/default/template/sales/order/creditmemo/items/renderer/default.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/creditmemo/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/history.phtml b/app/design/frontend/rwd/default/template/sales/order/history.phtml
index 92ba3a0..2b4df8d 100644
--- a/app/design/frontend/rwd/default/template/sales/order/history.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/history.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/invoice/items.phtml b/app/design/frontend/rwd/default/template/sales/order/invoice/items.phtml
index 01d7737..902bfaa 100644
--- a/app/design/frontend/rwd/default/template/sales/order/invoice/items.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/invoice/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/invoice/items/renderer/default.phtml b/app/design/frontend/rwd/default/template/sales/order/invoice/items/renderer/default.phtml
index 3c00445..9c68ddf 100644
--- a/app/design/frontend/rwd/default/template/sales/order/invoice/items/renderer/default.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/invoice/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/items.phtml b/app/design/frontend/rwd/default/template/sales/order/items.phtml
index 1230297..27ba5d3 100644
--- a/app/design/frontend/rwd/default/template/sales/order/items.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/items/renderer/default.phtml b/app/design/frontend/rwd/default/template/sales/order/items/renderer/default.phtml
index d68b25f..4cf003b 100644
--- a/app/design/frontend/rwd/default/template/sales/order/items/renderer/default.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/items/renderer/default.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/recent.phtml b/app/design/frontend/rwd/default/template/sales/order/recent.phtml
index 8f96b44..57fadcc 100644
--- a/app/design/frontend/rwd/default/template/sales/order/recent.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/recent.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/order/shipment/items.phtml b/app/design/frontend/rwd/default/template/sales/order/shipment/items.phtml
index 235ccc2..6f863db 100644
--- a/app/design/frontend/rwd/default/template/sales/order/shipment/items.phtml
+++ b/app/design/frontend/rwd/default/template/sales/order/shipment/items.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/recurring/grid.phtml b/app/design/frontend/rwd/default/template/sales/recurring/grid.phtml
index f699c2d..8de7bda 100644
--- a/app/design/frontend/rwd/default/template/sales/recurring/grid.phtml
+++ b/app/design/frontend/rwd/default/template/sales/recurring/grid.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/recurring/profile/view.phtml b/app/design/frontend/rwd/default/template/sales/recurring/profile/view.phtml
index 1ba507a..650abd1 100644
--- a/app/design/frontend/rwd/default/template/sales/recurring/profile/view.phtml
+++ b/app/design/frontend/rwd/default/template/sales/recurring/profile/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/sales/widget/guest/form.phtml b/app/design/frontend/rwd/default/template/sales/widget/guest/form.phtml
index a5678b6..47048d6 100644
--- a/app/design/frontend/rwd/default/template/sales/widget/guest/form.phtml
+++ b/app/design/frontend/rwd/default/template/sales/widget/guest/form.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /** @var $this Mage_Sales_Block_Widget_Guest_Form */
diff --git a/app/design/frontend/rwd/default/template/sendfriend/send.phtml b/app/design/frontend/rwd/default/template/sendfriend/send.phtml
index 235a58b..34a973b 100644
--- a/app/design/frontend/rwd/default/template/sendfriend/send.phtml
+++ b/app/design/frontend/rwd/default/template/sendfriend/send.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Sendfriend_Block_Send */
diff --git a/app/design/frontend/rwd/default/template/wishlist/button/update.phtml b/app/design/frontend/rwd/default/template/wishlist/button/update.phtml
index 25d29a3..d10b3ec 100644
--- a/app/design/frontend/rwd/default/template/wishlist/button/update.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/button/update.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/wishlist/item/column/cart.phtml b/app/design/frontend/rwd/default/template/wishlist/item/column/cart.phtml
index 0192a11..6549c2a 100644
--- a/app/design/frontend/rwd/default/template/wishlist/item/column/cart.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/item/column/cart.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/wishlist/item/column/info.phtml b/app/design/frontend/rwd/default/template/wishlist/item/column/info.phtml
index bc9aa66..f337da3 100644
--- a/app/design/frontend/rwd/default/template/wishlist/item/column/info.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/item/column/info.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/wishlist/item/column/price.phtml b/app/design/frontend/rwd/default/template/wishlist/item/column/price.phtml
index 5b8b6bf..6515e2e 100644
--- a/app/design/frontend/rwd/default/template/wishlist/item/column/price.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/item/column/price.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/wishlist/item/column/quantity.phtml b/app/design/frontend/rwd/default/template/wishlist/item/column/quantity.phtml
index 93c2590..2881334 100644
--- a/app/design/frontend/rwd/default/template/wishlist/item/column/quantity.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/item/column/quantity.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/frontend/rwd/default/template/wishlist/item/list.phtml b/app/design/frontend/rwd/default/template/wishlist/item/list.phtml
index a54a5e3..1202cbe 100644
--- a/app/design/frontend/rwd/default/template/wishlist/item/list.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/item/list.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/frontend/rwd/default/template/wishlist/shared.phtml b/app/design/frontend/rwd/default/template/wishlist/shared.phtml
index 9430887..1bd87dd 100644
--- a/app/design/frontend/rwd/default/template/wishlist/shared.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/shared.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Share_Wishlist */
diff --git a/app/design/frontend/rwd/default/template/wishlist/sidebar.phtml b/app/design/frontend/rwd/default/template/wishlist/sidebar.phtml
index c51c42c..f48eb40 100644
--- a/app/design/frontend/rwd/default/template/wishlist/sidebar.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/sidebar.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Sidebar */
diff --git a/app/design/frontend/rwd/default/template/wishlist/view.phtml b/app/design/frontend/rwd/default/template/wishlist/view.phtml
index 669ebe3..a389cd1 100644
--- a/app/design/frontend/rwd/default/template/wishlist/view.phtml
+++ b/app/design/frontend/rwd/default/template/wishlist/view.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* @var $this Mage_Wishlist_Block_Customer_Wishlist */
diff --git a/app/design/install/default/default/etc/theme.xml b/app/design/install/default/default/etc/theme.xml
index d0b262c..8e9e140 100644
--- a/app/design/install/default/default/etc/theme.xml
+++ b/app/design/install/default/default/etc/theme.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/design/install/default/default/layout/main.xml b/app/design/install/default/default/layout/main.xml
index a541045..7770e12 100644
--- a/app/design/install/default/default/layout/main.xml
+++ b/app/design/install/default/default/layout/main.xml
@@ -21,7 +21,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/begin.phtml b/app/design/install/default/default/template/install/begin.phtml
index 3b39ddf..7fd1794 100644
--- a/app/design/install/default/default/template/install/begin.phtml
+++ b/app/design/install/default/default/template/install/begin.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/config.phtml b/app/design/install/default/default/template/install/config.phtml
index 19977c4..fe3a8c2 100644
--- a/app/design/install/default/default/template/install/config.phtml
+++ b/app/design/install/default/default/template/install/config.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/create_admin.phtml b/app/design/install/default/default/template/install/create_admin.phtml
index a682ae5..54d12d3 100644
--- a/app/design/install/default/default/template/install/create_admin.phtml
+++ b/app/design/install/default/default/template/install/create_admin.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/db/main.phtml b/app/design/install/default/default/template/install/db/main.phtml
index c45549b..2bfb657 100644
--- a/app/design/install/default/default/template/install/db/main.phtml
+++ b/app/design/install/default/default/template/install/db/main.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/db/mysql4.phtml b/app/design/install/default/default/template/install/db/mysql4.phtml
index 869fb6a..db533aa 100644
--- a/app/design/install/default/default/template/install/db/mysql4.phtml
+++ b/app/design/install/default/default/template/install/db/mysql4.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/download.phtml b/app/design/install/default/default/template/install/download.phtml
index 1191a0c..79d9150 100644
--- a/app/design/install/default/default/template/install/download.phtml
+++ b/app/design/install/default/default/template/install/download.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/end.phtml b/app/design/install/default/default/template/install/end.phtml
index 5fed1f7..3375e25 100644
--- a/app/design/install/default/default/template/install/end.phtml
+++ b/app/design/install/default/default/template/install/end.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/locale.phtml b/app/design/install/default/default/template/install/locale.phtml
index 4f3c823..622547c 100644
--- a/app/design/install/default/default/template/install/locale.phtml
+++ b/app/design/install/default/default/template/install/locale.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/app/design/install/default/default/template/install/state.phtml b/app/design/install/default/default/template/install/state.phtml
index df2ee05..d5b52f8 100644
--- a/app/design/install/default/default/template/install/state.phtml
+++ b/app/design/install/default/default/template/install/state.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/design/install/default/default/template/page.phtml b/app/design/install/default/default/template/page.phtml
index ee61431..d566e3a 100644
--- a/app/design/install/default/default/template/page.phtml
+++ b/app/design/install/default/default/template/page.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/app/etc/config.xml b/app/etc/config.xml
index 844ef77..8fb5327 100644
--- a/app/etc/config.xml
+++ b/app/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
@@ -145,6 +145,10 @@
             <template>
                 <allow_symlink>0</allow_symlink>
             </template>
+            <log>
+                <file>system.log</file>
+                <allowedFileExtensions>log,txt,html,csv</allowedFileExtensions>
+            </log>
         </dev>
         <general>
             <locale>
diff --git a/app/etc/local.xml.additional b/app/etc/local.xml.additional
index 1b7226c..10e7323 100644
--- a/app/etc/local.xml.additional
+++ b/app/etc/local.xml.additional
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/local.xml.template b/app/etc/local.xml.template
index 9a307a4..6296fed 100644
--- a/app/etc/local.xml.template
+++ b/app/etc/local.xml.template
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_All.xml b/app/etc/modules/Mage_All.xml
index 25c3f3a..3da667c 100644
--- a/app/etc/modules/Mage_All.xml
+++ b/app/etc/modules/Mage_All.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Core
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Api.xml b/app/etc/modules/Mage_Api.xml
index 97ed173..d4be9cd 100644
--- a/app/etc/modules/Mage_Api.xml
+++ b/app/etc/modules/Mage_Api.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Api2.xml b/app/etc/modules/Mage_Api2.xml
index 1517ad8..2496459 100644
--- a/app/etc/modules/Mage_Api2.xml
+++ b/app/etc/modules/Mage_Api2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Api2
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Authorizenet.xml b/app/etc/modules/Mage_Authorizenet.xml
index 2319850..a67b454 100644
--- a/app/etc/modules/Mage_Authorizenet.xml
+++ b/app/etc/modules/Mage_Authorizenet.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Authorizenet
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Bundle.xml b/app/etc/modules/Mage_Bundle.xml
index eabced7..48ab483 100644
--- a/app/etc/modules/Mage_Bundle.xml
+++ b/app/etc/modules/Mage_Bundle.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Bundle
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Captcha.xml b/app/etc/modules/Mage_Captcha.xml
index 2fe3f70..215881e 100644
--- a/app/etc/modules/Mage_Captcha.xml
+++ b/app/etc/modules/Mage_Captcha.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Captcha
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Centinel.xml b/app/etc/modules/Mage_Centinel.xml
index 52d318c..b18d48a 100644
--- a/app/etc/modules/Mage_Centinel.xml
+++ b/app/etc/modules/Mage_Centinel.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Centinel
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Compiler.xml b/app/etc/modules/Mage_Compiler.xml
index debc2d1..c9231e4 100644
--- a/app/etc/modules/Mage_Compiler.xml
+++ b/app/etc/modules/Mage_Compiler.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Compiler
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_ConfigurableSwatches.xml b/app/etc/modules/Mage_ConfigurableSwatches.xml
index c56f90a..f38cb72 100644
--- a/app/etc/modules/Mage_ConfigurableSwatches.xml
+++ b/app/etc/modules/Mage_ConfigurableSwatches.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ConfigurableSwatches
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Connect.xml b/app/etc/modules/Mage_Connect.xml
index 6db7966..799c5c3 100644
--- a/app/etc/modules/Mage_Connect.xml
+++ b/app/etc/modules/Mage_Connect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_CurrencySymbol.xml b/app/etc/modules/Mage_CurrencySymbol.xml
index d326024..bf1c8c3 100644
--- a/app/etc/modules/Mage_CurrencySymbol.xml
+++ b/app/etc/modules/Mage_CurrencySymbol.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_CurrencySymbol
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Downloadable.xml b/app/etc/modules/Mage_Downloadable.xml
index fec386f..1350fce 100644
--- a/app/etc/modules/Mage_Downloadable.xml
+++ b/app/etc/modules/Mage_Downloadable.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloadable
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_ImportExport.xml b/app/etc/modules/Mage_ImportExport.xml
index bc1b1d2..9299329 100644
--- a/app/etc/modules/Mage_ImportExport.xml
+++ b/app/etc/modules/Mage_ImportExport.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_ImportExport
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Oauth.xml b/app/etc/modules/Mage_Oauth.xml
index 47b6de2..19a9c8b 100644
--- a/app/etc/modules/Mage_Oauth.xml
+++ b/app/etc/modules/Mage_Oauth.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Oauth
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_PageCache.xml b/app/etc/modules/Mage_PageCache.xml
index f935abf..586aa93 100644
--- a/app/etc/modules/Mage_PageCache.xml
+++ b/app/etc/modules/Mage_PageCache.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_PageCache
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Persistent.xml b/app/etc/modules/Mage_Persistent.xml
index 31349e6..9c11e9f 100644
--- a/app/etc/modules/Mage_Persistent.xml
+++ b/app/etc/modules/Mage_Persistent.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Persistent
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Weee.xml b/app/etc/modules/Mage_Weee.xml
index 8b63196..487476c 100644
--- a/app/etc/modules/Mage_Weee.xml
+++ b/app/etc/modules/Mage_Weee.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Weee
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_Widget.xml b/app/etc/modules/Mage_Widget.xml
index 9e4e51c..3a38cf2 100644
--- a/app/etc/modules/Mage_Widget.xml
+++ b/app/etc/modules/Mage_Widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Widget
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Mage_XmlConnect.xml b/app/etc/modules/Mage_XmlConnect.xml
index 1979ff5..5f9b70a 100644
--- a/app/etc/modules/Mage_XmlConnect.xml
+++ b/app/etc/modules/Mage_XmlConnect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_XmlConnect
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/app/etc/modules/Phoenix_Moneybookers.xml b/app/etc/modules/Phoenix_Moneybookers.xml
index 98776ed..8b8f65f 100644
--- a/app/etc/modules/Phoenix_Moneybookers.xml
+++ b/app/etc/modules/Phoenix_Moneybookers.xml
@@ -15,7 +15,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/app/locale/en_US/Mage_Adminhtml.csv b/app/locale/en_US/Mage_Adminhtml.csv
index 46953c8..08b087b 100644
--- a/app/locale/en_US/Mage_Adminhtml.csv
+++ b/app/locale/en_US/Mage_Adminhtml.csv
@@ -106,6 +106,7 @@
 "Always (during development)","Always (during development)"
 "Amounts","Amounts"
 "An error has occured while syncronizing media storages.","An error has occured while syncronizing media storages."
+"An error occurred while adding condition.","An error occurred while adding condition."
 "An error occurred while clearing the JavaScript/CSS cache.","An error occurred while clearing the JavaScript/CSS cache."
 "An error occurred while clearing the configurable swatches image cache.","An error occurred while clearing the configurable swatches image cache."
 "An error occurred while clearing the image cache.","An error occurred while clearing the image cache."
@@ -116,6 +117,7 @@
 "An error occurred while deleting this set.","An error occurred while deleting this set."
 "An error occurred while deleting this template.","An error occurred while deleting this template."
 "An error occurred while finishing process. Please refresh the cache","An error occurred while finishing process. Please refresh the cache"
+"An error occurred while logging in.","An error occurred while logging in."
 "An error occurred while rebuilding the CatalogInventory Stock Status.","An error occurred while rebuilding the CatalogInventory Stock Status."
 "An error occurred while rebuilding the catalog index.","An error occurred while rebuilding the catalog index."
 "An error occurred while rebuilding the flat catalog category.","An error occurred while rebuilding the flat catalog category."
diff --git a/app/locale/en_US/Mage_Core.csv b/app/locale/en_US/Mage_Core.csv
index 4f11005..607dc45 100644
--- a/app/locale/en_US/Mage_Core.csv
+++ b/app/locale/en_US/Mage_Core.csv
@@ -164,6 +164,7 @@
 "Input type ""%value%"" not found in the input types list.","Input type ""%value%"" not found in the input types list."
 "Invalid MIME type.","Invalid MIME type."
 "Invalid URL '%value%'.","Invalid URL '%value%'."
+"Invalid URL scheme.","Invalid URL scheme."
 "Invalid base url type","Invalid base url type"
 "Invalid block type: %s","Invalid block type: %s"
 "Invalid block: %s","Invalid block: %s"
@@ -173,6 +174,7 @@
 "Invalid layout update handle","Invalid layout update handle"
 "Invalid messages storage ""%s"" for layout messages initialization","Invalid messages storage ""%s"" for layout messages initialization"
 "Invalid query","Invalid query"
+"Invalid stream.","Invalid stream."
 "Invalid transactional email code: %s","Invalid transactional email code: %s"
 "Invalid website\'s configuration path: %s","Invalid website\'s configuration path: %s"
 "JavaScript Settings","JavaScript Settings"
diff --git a/app/locale/en_US/Mage_Page.csv b/app/locale/en_US/Mage_Page.csv
index c9f596c..0bdb03c 100644
--- a/app/locale/en_US/Mage_Page.csv
+++ b/app/locale/en_US/Mage_Page.csv
@@ -1,7 +1,7 @@
 "%s Item(s)","%s Item(s)"
 "%s-%s of %s","%s-%s of %s"
 "&copy; 2013 Magento Demo Store. All Rights Reserved.","&copy; 2013 Magento Demo Store. All Rights Reserved."
-"&copy; 2018 Magento Demo Store. All Rights Reserved.","&copy; 2018 Magento Demo Store. All Rights Reserved."
+"&copy; 2019 Magento Demo Store. All Rights Reserved.","&copy; 2019 Magento Demo Store. All Rights Reserved."
 "(Shift-)Click or drag to change value","(Shift-)Click or drag to change value"
 "(ver. %s)","(ver. %s)"
 "- Click on any of the time parts to increase it","- Click on any of the time parts to increase it"
diff --git a/app/locale/en_US/Mage_Rss.csv b/app/locale/en_US/Mage_Rss.csv
index f539487..da94a2f 100644
--- a/app/locale/en_US/Mage_Rss.csv
+++ b/app/locale/en_US/Mage_Rss.csv
@@ -19,6 +19,7 @@
 "Discount","Discount"
 "Discount (%s)","Discount (%s)"
 "Enable RSS","Enable RSS"
+"Enabling can increase security risk by exposing some order details.","Enabling can increase security risk by exposing some order details."
 "Error in processing xml. %s","Error in processing xml. %s"
 "From:","From:"
 "Get Feed","Get Feed"
diff --git a/app/locale/en_US/Mage_Widget.csv b/app/locale/en_US/Mage_Widget.csv
index 2667c84..c8395c5 100644
--- a/app/locale/en_US/Mage_Widget.csv
+++ b/app/locale/en_US/Mage_Widget.csv
@@ -6,6 +6,7 @@
 "All","All"
 "All Pages","All Pages"
 "All Product Types","All Product Types"
+"An error occurred during POST data validation: %s","An error occurred during POST data validation: %s"
 "An error occurred during saving a widget: %s","An error occurred during saving a widget: %s"
 "Anchor Categories","Anchor Categories"
 "Apply","Apply"
diff --git a/cron.php b/cron.php
index e116210..d43e199 100644
--- a/cron.php
+++ b/cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/cron.sh b/cron.sh
index dfa16c8..9051440 100644
--- a/cron.sh
+++ b/cron.sh
@@ -20,7 +20,7 @@
 #
 # @category    Mage
 # @package     Mage
-# @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+# @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 # @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 #
 
diff --git a/dev/tests/functional/bootstrap.php b/dev/tests/functional/bootstrap.php
index 30be743..454c7a5 100644
--- a/dev/tests/functional/bootstrap.php
+++ b/dev/tests/functional/bootstrap.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/credentials.xml.dist b/dev/tests/functional/credentials.xml.dist
index 091810f..df9001e 100644
--- a/dev/tests/functional/credentials.xml.dist
+++ b/dev/tests/functional/credentials.xml.dist
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/etc/config.xml b/dev/tests/functional/etc/config.xml
index 3b8888a..8afc16d 100644
--- a/dev/tests/functional/etc/config.xml
+++ b/dev/tests/functional/etc/config.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/etc/config.xsd b/dev/tests/functional/etc/config.xsd
index 5583a6f..5467a1e 100644
--- a/dev/tests/functional/etc/config.xsd
+++ b/dev/tests/functional/etc/config.xsd
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/etc/di.xml b/dev/tests/functional/etc/di.xml
index 78e5c0d..7d9c45b 100644
--- a/dev/tests/functional/etc/di.xml
+++ b/dev/tests/functional/etc/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/etc/events.xml b/dev/tests/functional/etc/events.xml
index 6b93e37..2c333ef 100644
--- a/dev/tests/functional/etc/events.xml
+++ b/dev/tests/functional/etc/events.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/etc/events.xsd b/dev/tests/functional/etc/events.xsd
index 5efea8d..2951a6b 100644
--- a/dev/tests/functional/etc/events.xsd
+++ b/dev/tests/functional/etc/events.xsd
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/isolation.php b/dev/tests/functional/isolation.php
index b7f2b9d..b89de78 100644
--- a/dev/tests/functional/isolation.php
+++ b/dev/tests/functional/isolation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/App/State/AbstractState.php b/dev/tests/functional/lib/Magento/Mtf/App/State/AbstractState.php
index 7fbb0b0..2f3f699 100644
--- a/dev/tests/functional/lib/Magento/Mtf/App/State/AbstractState.php
+++ b/dev/tests/functional/lib/Magento/Mtf/App/State/AbstractState.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/App/State/State1.php b/dev/tests/functional/lib/Magento/Mtf/App/State/State1.php
index aefe601..e0aeefa 100644
--- a/dev/tests/functional/lib/Magento/Mtf/App/State/State1.php
+++ b/dev/tests/functional/lib/Magento/Mtf/App/State/State1.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Driver/Selenium/Driver.php b/dev/tests/functional/lib/Magento/Mtf/Client/Driver/Selenium/Driver.php
index f83e6a7..d342395 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Driver/Selenium/Driver.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Driver/Selenium/Driver.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/ConditionsElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/ConditionsElement.php
index 61dcd97..1ec224e 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/ConditionsElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/ConditionsElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectgrouplistElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectgrouplistElement.php
index fba505c..eae8e0f 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectgrouplistElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectgrouplistElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectlistElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectlistElement.php
index 060e8b3..f888b98 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectlistElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/MultiselectlistElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/OptgroupselectElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/OptgroupselectElement.php
index a86b18d..28cbb75 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/OptgroupselectElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/OptgroupselectElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/SelectstoreElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/SelectstoreElement.php
index 98815c3..545da9a 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/SelectstoreElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/SelectstoreElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/SimpleElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/SimpleElement.php
index 5829965..d09764b 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/SimpleElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/SimpleElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Client/Element/TreeElement.php b/dev/tests/functional/lib/Magento/Mtf/Client/Element/TreeElement.php
index 824aa5a..09581de 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Client/Element/TreeElement.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Client/Element/TreeElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Constraint/AbstractAssertForm.php b/dev/tests/functional/lib/Magento/Mtf/Constraint/AbstractAssertForm.php
index 72ea180..aac5062 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Constraint/AbstractAssertForm.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Constraint/AbstractAssertForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Page/BackendPage.php b/dev/tests/functional/lib/Magento/Mtf/Page/BackendPage.php
index 5719389..e279afd 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Page/BackendPage.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Page/BackendPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Fixture/FieldsProvider.php b/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Fixture/FieldsProvider.php
index ad8f05a..15e6fb0 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Fixture/FieldsProvider.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Fixture/FieldsProvider.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Page.php b/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Page.php
index 707510e..ceb558b 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Page.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Util/Generate/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/BackendDecorator.php b/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/BackendDecorator.php
index 1bbe8e8..c0c9d5b 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/BackendDecorator.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/BackendDecorator.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/FrontendDecorator.php b/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/FrontendDecorator.php
index edc715d..385b34a 100644
--- a/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/FrontendDecorator.php
+++ b/dev/tests/functional/lib/Magento/Mtf/Util/Protocol/CurlTransport/FrontendDecorator.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/phpunit.xml.dist b/dev/tests/functional/phpunit.xml.dist
index 4f91378..2c3a804 100644
--- a/dev/tests/functional/phpunit.xml.dist
+++ b/dev/tests/functional/phpunit.xml.dist
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleInGrid.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleInGrid.php
index 5dd5bba..20a8b76 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleSuccessSaveMessage.php
index 0c04028..6a5cd16 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertRoleSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccessDeniedMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccessDeniedMessage.php
index dd05ed0..1d83dd2 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccessDeniedMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccessDeniedMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccountInactiveMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccountInactiveMessage.php
index 46d86be..40c5f2e 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccountInactiveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserAccountInactiveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserDuplicateMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserDuplicateMessage.php
index c18e79c..15eac14 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserDuplicateMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserDuplicateMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInGrid.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInGrid.php
index 9478155..0471f2c 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInvalidEmailMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInvalidEmailMessage.php
index ece5f89..51b3521 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInvalidEmailMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserInvalidEmailMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserIsLockedMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserIsLockedMessage.php
index 87753007..75c85b1 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserIsLockedMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserIsLockedMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogOut.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogOut.php
index 7729094..9a50e12 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogOut.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogOut.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogin.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogin.php
index fd3b24d..d9630bd 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogin.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessLogin.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessSaveMessage.php
index 1c2392f..fd3f02e 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithCustomRole.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithCustomRole.php
index 6fe7e33..5e3f9df 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithCustomRole.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithCustomRole.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithRestrictedResources.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithRestrictedResources.php
index a8f1312..0f92539 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithRestrictedResources.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWithRestrictedResources.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWrongCredentialsMessage.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWrongCredentialsMessage.php
index 4885967..4ef4df0 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWrongCredentialsMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Constraint/AssertUserWrongCredentialsMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role.xml
index a41fdc5..d235eb7 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/GwsStoreGroups.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/GwsStoreGroups.php
index 309d11a..b064d00 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/GwsStoreGroups.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/GwsStoreGroups.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/InRoleUsers.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/InRoleUsers.php
index ee50490..a3fbf63 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/InRoleUsers.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/InRoleUsers.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/RolesResources.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/RolesResources.php
index 15580dd..508cfc1 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/RolesResources.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/Role/RolesResources.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User.xml
index fe746c3..2c69fe5 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User/RoleId.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User/RoleId.php
index 67114ee..388f09c 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User/RoleId.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Fixture/User/RoleId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/Curl.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/Curl.php
index 295bf99..99d3355 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/RoleInterface.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/RoleInterface.php
index 921c6d1..69d2bf4 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/RoleInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/Role/RoleInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/Curl.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/Curl.php
index d86c974..bcb9dfb 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/UserInterface.php b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/UserInterface.php
index 0309c03..57cd16e 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/UserInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Handler/User/UserInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserEdit.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserEdit.xml
index e27b899..a0f9d45 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserIndex.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserIndex.xml
index 09a75b6..ec7f184 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleEditRole.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleEditRole.xml
index 0eaca36..c96ea3d 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleEditRole.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleEditRole.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleIndex.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleIndex.xml
index 5998b1b..57ffc8b 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Page/Adminhtml/UserRoleIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/Role.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/Role.xml
index ed7c8db..cb0c9d9 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/Role.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/Role.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/User.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/User.xml
index 4e50eb7..c65941b 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/User.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/Repository/User.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.php b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.php
index 402ec9b..782d0e51 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
index 887fb22..48c9b1a 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.php b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.php
index 67de25a..622a1de 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.xml
index 3067d53..77e0c3a 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserRoleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
index 9267767..6076c3a 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
index ec2484e..adc4a9a 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/etc/curl/di.xml
index 670ff4b..9eebaa7 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/etc/fixture.xml
index f81da49..f2ba9bc 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.php
index fdb4544..8008907 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.xml
index 6bcdf5b..091e17f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Admin/Login.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role.php
index 7614849..c072513 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role/Grid.php
index d28ba59..59c5bfa 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/Tab/Role/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.php
index a75ca64..b52d45f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.xml
index e89355b..49c754a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Api/User/UserForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cache/PageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cache/PageActions.php
index df46c3b..12f4138 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cache/PageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cache/PageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Content.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Content.php
index 081f7c6..d91f82f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Content.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.php
index 47e7e72..6d850f0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.xml
index 2e225fc..e4684c7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/CategoryForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product.php
index d68f1d8..2d35a46 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product/Grid.php
index 0d40749..8b0e929 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Edit/Tab/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Tree.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Tree.php
index 992ed6a..1059bb4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Tree.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Category/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/CustomAttribute.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/CustomAttribute.php
index 821660a..0b0e880 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/CustomAttribute.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/CustomAttribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.php
index 6417bee..466722f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.xml
index fb2cc77..26d033b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/AttributeForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
index 6b83da1..25a6ac6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.php
index 7ba660c..898a098 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.xml
index 29fffd1..4322220 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Edit/Tab/Options/Option.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Grid.php
index 46524b8..31e1b2f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Grid.php
index 6b90a41..bec91f0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main.php
index d497a57..9033601 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.php
index b67c644..b591c37 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.xml
index 2559576..9073d35 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/AttributeSetForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.php
index f6aec58..6312501 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.xml
index 7a72e2d..8c06ec5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Attribute/Set/Main/EditForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenant.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenant.php
index b34d6a6..79aef78 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenant.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenant.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenantProductsGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenantProductsGrid.php
index 21ff34c..189e89c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenantProductsGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractAppurtenantProductsGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractOptions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractOptions.php
index c6f11e4..b2ab20e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractSelectOptions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractSelectOptions.php
index 137e235..0bc7dd9 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractSelectOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AbstractSelectOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts.php
index c595fcd..51d0880 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Grid.php
index b16c866..41e76fd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.php
index ed0a3de..c773e21 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.xml
index 0c4fc0b..816930f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/AssociatedProducts/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Categories.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Categories.php
index 8bc4975..83ad331 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Categories.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Categories.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable.php
index 279e50a..e4bf655 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.php
index 4436e4c..1be9d31 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.xml
index d848396..af17c98 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.php
index 5079bef..527a47f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.xml
index 73aa92b..95f09bb 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Attribute/Option.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Grid.php
index ceb19b4..fab351d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.php
index 104daca..c50f979 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.xml
index 59e437c..142d83d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/NewProductPopup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.php
index ce4af6e..7cc09e4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.xml
index 91c575b..4d4b53a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation/AttributesElement.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation/AttributesElement.php
index 01dd691..fad5767 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation/AttributesElement.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/QuickCreation/AttributesElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/SimpleAssociatedProduct.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/SimpleAssociatedProduct.php
index 76df0c3..68e97ea 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/SimpleAssociatedProduct.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Configurable/SimpleAssociatedProduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell.php
index f611991..045f2bd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell/Grid.php
index 5237720..a685a51 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Crosssell/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions.php
index ed4ab4c..1f9180a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.php
index dbe8974..6530146 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.xml
index e2e4699..8d662b6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Area.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.php
index defd886..d4e0f90 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.xml
index c22f4c9..f5e599b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Checkbox.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.php
index 290d1e6..ab33699 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.xml
index d66c865..1c61a87 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Date.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.php
index 420bfe7..72852c2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.xml
index d66c865..1c61a87 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DateTime.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.php
index adc6096..23083cd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.xml
index c22f4c9..f5e599b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/DropDown.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.php
index 9808ab1..9d0f93f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.xml
index e2e4699..8d662b6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Field.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.php
index f7985f3..697a07f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.xml
index f9e6924..466206b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/File.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.php
index 2b203c7..42d7ecd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.xml
index c22f4c9..f5e599b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/MultipleSelect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.php
index 6117ac7..2abf304 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.xml
index c22f4c9..f5e599b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/RadioButtons.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.php
index 319fe9b..e546967 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.xml
index d66c865..1c61a87 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/CustomOptions/Time.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices.php
index 1f441d0..91eb39c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.php
index 0a3460f..007026b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.xml
index 967e30c..a0d8009 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.php
index 2368cca..b685830 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.xml
index 7c8a12b..26e1f1d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Prices/OptionTier.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/ProductSettings.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/ProductSettings.php
index 8a86630..2503ec5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/ProductSettings.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/ProductSettings.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related.php
index 7308fa1..23e8a1c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related/Grid.php
index 74b4fad..0a357ec 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Related/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/SuperSettings.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/SuperSettings.php
index 867e48c..9008af1 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/SuperSettings.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/SuperSettings.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell.php
index 4f941be..d8b8e7e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell/Grid.php
index dd11e6a..0ebddb0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Upsell/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Websites.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Websites.php
index 5c28a6f..2a22a19 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Websites.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Edit/Tab/Websites.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/FormPageActions.php
index 3a71603..0f4b24a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Grid.php
index ac375be..c5006c7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.php
index 10187a7..532d998 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.xml
index 6630cfb..7bc526e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Catalog/Product/ProductForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/FormPageActions.php
index dfa42f4..cf30858 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog.php
index c1fd535..d3f0924 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.php
index e584f9e..7af27d3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.xml
index cb145e6..e8cf306 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.php
index 6adbe3e..3387c1a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.xml
index cb145e6..e8cf306 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/Catalog/Edit/PromoForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/GridPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/GridPageActions.php
index 5a4bf76..a903bd3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/GridPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogRule/Promo/GridPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.php
index 4185a56..2420e2f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.xml
index a63b047..ac61f79 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Edit/SearchTermForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Grid.php
index 559b075..889eb5e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/CatalogSearch/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.php
index 58f6b00..0042564 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.xml
index df7163a..28be622 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Edit/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Grid.php
index fc91577..0df8114 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Checkout/Agreement/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/CmsGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/CmsGrid.php
index dfc6b38..b3b6a53 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/CmsGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/CmsGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.php
index d39a9c9..1d91c24 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.xml
index a475d50..6b131a5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/BlockForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/FormPageActions.php
index 154d131..092c74a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Block/Edit/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/FormPageActions.php
index b9d1448..6fcd486 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.php
index 32b8fae..7409aa2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.xml
index 20e5c21..1c28234 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/PageForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/Tab/Content.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/Tab/Content.php
index 11e8fe2..0562ecc 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/Tab/Content.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Edit/Tab/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Grid.php
index c31399b..810d876 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Widget/Chooser.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Widget/Chooser.php
index 7098829..dc102fe 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Widget/Chooser.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Page/Widget/Chooser.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Wysiwyg/Config.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Wysiwyg/Config.php
index 61f86b9..2ff20a8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Wysiwyg/Config.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Cms/Wysiwyg/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/CustomerGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/CustomerGrid.php
index 54dcdf7..8ad4c84 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/CustomerGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/CustomerGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.php
index c722945..73d9239 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.xml
index 465a3e9..ee696d9 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/CustomerForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/FormPageActions.php
index 10b46e5..aee452d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.php
index cf7cbd6..3bceac7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.xml
index 2c0d678..31d539b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Edit/Tab/Addresses.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.php
index 1c65303..a00417b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.xml
index 5615c9d..ba90f31 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Edit/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Grid.php
index a5f0a0c..b575d6c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Customer/Group/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/FormPageActions.php
index e18bcc0..acb8e5f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/GridPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/GridPageActions.php
index 49997f1..39c0c2c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/GridPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/GridPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Newsletter/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Newsletter/Grid.php
index 83d5994..af3444f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Newsletter/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Newsletter/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Footer.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Footer.php
index 36a6f59..7f952e8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Footer.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Footer.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Header.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Header.php
index bd4f20a..e5f3593 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Header.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Main.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Main.php
index 71758a3..f636629 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Main.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Page/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/PageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/PageActions.php
index 74b4768..a9fb752 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/PageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/PageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Edit/Tab/RoleResources.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Edit/Tab/RoleResources.php
index 584a3ba..c6db7c4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Edit/Tab/RoleResources.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Edit/Tab/RoleResources.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Grid/RoleGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Grid/RoleGrid.php
index de119f0..29b3cc3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Grid/RoleGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/Grid/RoleGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.php
index 6f29a24..58b4129 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.xml
index 143e02d..4059b57 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/Role/RoleForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/User/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/User/Grid.php
index 25d6703..9a50f0e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/User/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Permissions/User/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Grid.php
index c50129f..036ead9 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/FormPageActions.php
index 43c9ec8..fd02fcb 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.php
index e1b95f3..a0b9daf 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.xml
index 5e7ad79..df0d7ed 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/PromoQuoteForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/Labels.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/Labels.php
index 95c8634..f2931d5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/Labels.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/Labels.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/RuleInformation.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/RuleInformation.php
index 40e6f02..a27152e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/RuleInformation.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Promo/Quote/Edit/Tab/RuleInformation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Rating/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Rating/Grid.php
index 5ba4b99..43ea680 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Rating/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Rating/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails.php
index 2f66df3..e0c0330 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails/RatingElement.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails/RatingElement.php
index 01f4798..4c82164 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails/RatingElement.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Edit/ReviewDetails/RatingElement.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Grid.php
index 4cb83a6..5e78972 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.php
index ac576eb..9c4e31a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.xml
index fa2bffd..cb5e195 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Review/ReviewForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/AbstractGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/AbstractGrid.php
index 3b02861..1e75a90 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/AbstractGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/AbstractGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/Grid.php
index 256ea61..137eadb 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items.php
index 7b7f645..9e7b74f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items/Item.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items/Item.php
index a3f21ef..f608fd7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/CreditMemos/View/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Actions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Actions.php
index beb1675..80c52c8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Actions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Grid.php
index ff74567..cd6643e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items.php
index c83ca9c..e0ca479 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items/Item.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items/Item.php
index fd9de8b..75d51d3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Invoices/View/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm.php
index c2a8876..997930c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/Product.php
index 63a39b8..a099201 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/ProductForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/ProductForm.php
index bc9b136..b69ab28 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/ProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractForm/ProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems.php
index 355577a..9b9cd87 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems/AbstractItem.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems/AbstractItem.php
index 3628efa..fe2368b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems/AbstractItem.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItems/AbstractItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItemsNewBlock.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItemsNewBlock.php
index ffdd708..ecae543 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItemsNewBlock.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/AbstractItemsNewBlock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Actions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Actions.php
index 8d3dc24..a092ebd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Actions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Actions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Address.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Address.php
index ae87470..e8148a2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Address.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Comments.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Comments.php
index 929ccc7..6eadc52 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Comments.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Comments.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create.php
index f983303..ca41db9 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.php
index aa72aa5..12afdfe 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.xml
index c25974c..3e5fd77 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Billing/Address.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.php
index c819f9d..87be8ff 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.xml
index 181cb96..d16f691 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Coupons.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities.php
index 5ac2bba..086cbd1 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar.php
index 9be4446..9c1f9a7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar/ShoppingCartItems.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar/ShoppingCartItems.php
index 24f9ca0..8e2c0bc 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar/ShoppingCartItems.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerActivities/Sidebar/ShoppingCartItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerGrid.php
index fe8b3a9..c4b691e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/CustomerGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items.php
index 26e483d..7c144d5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.php
index 2ebd707..e080ac6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.xml
index 4e1e7bd..591535b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Items/ItemProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Payment.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Payment.php
index f452881..8c69cc6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Payment.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Payment.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search.php
index 4a3b3c4..b5f394e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search/Grid.php
index 42ebc18..2b9274c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Shipping.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Shipping.php
index 87e6614..7f5b718 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Shipping.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Store.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Store.php
index b601849..5c0f42d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Store.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Create/Store.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.php
index 0c1d243..8744b35 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.xml
index f223db2..78a6e9c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items.php
index 0479a0b..399095d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.php
index b413d32..e34cd92 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.xml
index 6fc60f3..29eb267 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Form/Items/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Totals.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Totals.php
index 512cebb..af01ba5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Creditmemo/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Grid.php
index 0e7dc41..2c13878 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.php
index c758a19..38d73bc 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.xml
index d44645b..9a674b4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items.php
index da23dfb..0ce9090 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.php
index f174889..34ce660 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.xml
index ff966dd..db04e00 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Form/Items/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Totals.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Totals.php
index 1d3fed6..4ff3fba 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Invoice/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.php
index ef8f65d..36b6adb 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.xml
index e2836c4..12949b8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items.php
index c0f0839..0e99b45 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.php
index e70c01a..d73c12d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.xml
index 7cb1c40..1e7877b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Items/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking.php
index d803fe7..19e573d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.php
index 7d40e4d..030ce2d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.xml
index cb7e544..cceb365 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Shipment/Form/Tracking/Item.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Title.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Title.php
index 5b95b8f..c4073db 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Title.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Totals.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Totals.php
index ae527b8..a59158e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/AbstractGridTab.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/AbstractGridTab.php
index dc44535..4bfa272 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/AbstractGridTab.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/AbstractGridTab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.php
index 4c90cd6..3762ac4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.xml
index 5a27146..aa4dc74 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items.php
index 9aff77a..03f781a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.php
index b4ffaf2..ba0ce62 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.xml
index 19a86d6..97b3f8f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Items/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/CreditMemos.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/CreditMemos.php
index e9b92d4..2eedda8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/CreditMemos.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/CreditMemos.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Info.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Info.php
index c34ccd6..429cad0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Info.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Invoices.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Invoices.php
index adf469c..ad68ca5 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Invoices.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Invoices.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Shipments.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Shipments.php
index ef1efb6..906e40c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Shipments.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Shipments.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Transactions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Transactions.php
index 473f2db..fbd1769 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Transactions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Order/View/Tab/Transactions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Shipment/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Shipment/Grid.php
index 35dcc05..bb63e35 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Shipment/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Shipment/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Transactions/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Transactions/Grid.php
index ab2a2db..17e5c87 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Transactions/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sales/Transactions/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/Grid.php
index 014989a..24b50b4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items.php
index 638fd76..2f899dd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items/Item.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items/Item.php
index 06492d9..8038f29 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Shipping/View/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/Form.php
index 7f57c05..d1a2152 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/FormPageActions.php
index 9ed2843..dd39bde 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Edit/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Grid.php
index 89bfc69..0563a3e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Sitemap/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Config/Switcher.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Config/Switcher.php
index 8ca3ad6..adfaa8e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Config/Switcher.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Config/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/CurrencyGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/CurrencyGrid.php
index 63ef608..95c2ae3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/CurrencyGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/CurrencyGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/GridPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/GridPageActions.php
index e5b5c96..5dccdf0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/GridPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Currency/GridPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.php
index 9d734c1..c27aa79 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.xml
index 4b3e3eb..1540654 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/CurrencySymbolForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/FormPageActions.php
index 34b1dc4..03c2def 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Process/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Process/Grid.php
index cf5372b..ff54649 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Process/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Process/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.php
new file mode 100644
index 0000000..81340f8
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.php
@@ -0,0 +1,47 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+namespace Mage\Adminhtml\Test\Block\System\Store\Delete\Form;
+
+use Magento\Mtf\Block\Form;
+
+/**
+ * Form for website deleted.
+ */
+class GroupForm extends Form
+{
+    /**
+     * Fill delete form.
+     *
+     * @return void
+     * @throws \Exception
+     */
+    public function fillForm()
+    {
+        $mapping = $this->dataMapping(['create_backup' => 'No']);
+        $this->_fill($mapping);
+    }
+}
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.xml
new file mode 100644
index 0000000..0349f48
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/GroupForm.xml
@@ -0,0 +1,34 @@
+<?xml version="1.0"?>
+<!--
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+-->
+<mapping strict="0">
+    <fields>
+        <create_backup>
+            <input>select</input>
+        </create_backup>
+    </fields>
+</mapping>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.php
new file mode 100644
index 0000000..49897ce
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.php
@@ -0,0 +1,47 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+namespace Mage\Adminhtml\Test\Block\System\Store\Delete\Form;
+
+use Magento\Mtf\Block\Form;
+
+/**
+ * Form for website deleted.
+ */
+class StoreForm extends Form
+{
+    /**
+     * Fill delete form.
+     *
+     * @return void
+     * @throws \Exception
+     */
+    public function fillForm()
+    {
+        $mapping = $this->dataMapping(['create_backup' => 'No']);
+        $this->_fill($mapping);
+    }
+}
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.xml
new file mode 100644
index 0000000..0349f48
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Form/StoreForm.xml
@@ -0,0 +1,34 @@
+<?xml version="1.0"?>
+<!--
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+-->
+<mapping strict="0">
+    <fields>
+        <create_backup>
+            <input>select</input>
+        </create_backup>
+    </fields>
+</mapping>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
index 9e48235..96e90de 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.xml
index c99dec3..0349f48 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.php
index 3079ff1..751f937 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.xml
index 2913b12..961fe3e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/GroupForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.php
index 92f0971..55c619a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.xml
index 99a2a4c..311ab0d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/StoreForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.php
index aacc9b5..d0045a6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.xml
index e93714a..2fd2bdd 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Edit/Form/WebsiteForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/GridPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/GridPageActions.php
index 4ce1a58..ffdc92c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/GridPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/GridPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/StoreGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/StoreGrid.php
index 1a0207e..9ea4778 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/StoreGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/StoreGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.php
index 5bd6837..a9ded03 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.xml
index 1c83798..613c79b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/Edit/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/RatesGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/RatesGrid.php
index b4b6608..8c3020e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/RatesGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rate/RatesGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.php
index 4389316..8d4d5a8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.xml
index d377a42..6c8341a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Edit/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/FormPageActions.php
index af78b20..ea0a558 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Grid.php
index 6b996c6..b4ae8e8 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Tax/Rule/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Template.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Template.php
index 69f2e37..287cb10 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Template.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/FormTabs.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/FormTabs.php
index d5723a0..4994047 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/FormTabs.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/FormTabs.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Grid.php
index 1edf779..8845d72 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Tab.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Tab.php
index ba75fbe..40321f2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Tab.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Widget/Tab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist.php
index 1b4c8e5..c6a8ef0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist/Grid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist/Grid.php
index cc0d930..b6fc041 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/Wishlist/Customer/Edit/Tab/Wishlist/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertProductIsPresentOnCustomWebsite.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertProductIsPresentOnCustomWebsite.php
index 527050a..42dcf71 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertProductIsPresentOnCustomWebsite.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertProductIsPresentOnCustomWebsite.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -191,7 +191,7 @@ class AssertProductIsPresentOnCustomWebsite extends AbstractConstraint
             ]
         ];
 
-        $fixture = $fixtureFactory->createByCode('configData', ['data' => $data]);
+        $fixture = $fixtureFactory->createByCode('customConfigData', ['data' => $data]);
         $fixture->persist();
     }
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreBackend.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreBackend.php
index 6b6fb27..898351c 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreBackend.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreBackend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreForm.php
index 3c8ed02..4a772ec 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreFrontend.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreFrontend.php
index a52a9cd..74782cc 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupForm.php
index 0148870..d391d98 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInGrid.php
index 6fcbc2d..5909826 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInPurchasePointDropdown.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInPurchasePointDropdown.php
index f5a7c5a..afc2de7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInPurchasePointDropdown.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupInPurchasePointDropdown.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupOnStoreViewForm.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupOnStoreViewForm.php
index 8c0aee4..e93c66d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupOnStoreViewForm.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupOnStoreViewForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupSuccessSaveMessage.php
index dc6ed73..5cd5252 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreGroupSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreInGrid.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreInGrid.php
index c756f0a..50f5ee4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreLocalized.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreLocalized.php
index d108d8d..1a737f6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreLocalized.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreLocalized.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreNotOnFrontend.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreNotOnFrontend.php
index 7d137a2..e098680 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreNotOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreNotOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreSuccessSaveMessage.php
index 8bdcd30..cdd2672 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertStoreSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertVersionCorrect.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertVersionCorrect.php
index 1dae706..52fd371 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertVersionCorrect.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Constraint/AssertVersionCorrect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/CustomConfigData.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/CustomConfigData.xml
new file mode 100644
index 0000000..756dad0
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/CustomConfigData.xml
@@ -0,0 +1,37 @@
+<?xml version="1.0"?>
+<!--
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+-->
+<config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../vendor/magento/mtf/etc/fixture.xsd">
+    <fixture name="customConfigData" module="Mage_Adminhtml" type="flat" entity_type="core_config_data" collection="Mage\Core\Model\Resource\Config\Data\Collection" repository_class="Mage\Core\Test\Repository\ConfigData" handler_interface="Mage\Adminhtml\Test\Handler\CustomConfigData\CustomConfigDataInterface" class="Mage\Adminhtml\Test\Fixture\CustomConfigData">
+        <field name="config_id" is_required="1"/>
+        <field name="scope" is_required="0"/>
+        <field name="scope_id" is_required="0"/>
+        <field name="path" is_required="0"/>
+        <field name="value" is_required="0"/>
+        <field name="section"/>
+    </fixture>
+</config>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store.xml
index 2e95685..67ef8a1 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store/GroupId.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store/GroupId.php
index 1af1f02..3823755 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store/GroupId.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Store/GroupId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup.xml
index 06ea15b..508f526 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/CategoryId.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/CategoryId.php
index 41aa2e5..ca6baf3 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/CategoryId.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/CategoryId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/WebsiteId.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/WebsiteId.php
index f643cf0..1080c8e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/WebsiteId.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/StoreGroup/WebsiteId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Website.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Website.xml
index e90aa26..2d3a539 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Website.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Fixture/Website.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Conditions.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Conditions.php
index 0e0c55e..9a5524d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Conditions.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Conditions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/Curl.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/Curl.php
new file mode 100644
index 0000000..8e9338f
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/Curl.php
@@ -0,0 +1,68 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+namespace Mage\Adminhtml\Test\Handler\CustomConfigData;
+
+use Mage\Core\Test\Handler\ConfigData\Curl as ConfigDataCurl;
+
+/**
+ * Curl for setting config.
+ */
+class Curl extends ConfigDataCurl implements CustomConfigDataInterface
+{
+    /**
+     * {@inheritdoc}
+     */
+    protected function prepareConfigPath(array $input)
+    {
+        $resultArray = '';
+        $InputValue = isset($input['value']) ? $input['value'] : null;
+        $path = explode('/', str_replace($input['scope'], '', $input['path']));
+        array_unshift($path, rtrim($input['scope'], '/'));
+        foreach ($path as $position => $subPath) {
+            if ($position === 0) {
+                $resultArray .= $subPath;
+                continue;
+            } elseif ($position === (count($path) - 1)) {
+                $resultArray .= '[fields]';
+            } else {
+                $resultArray .= '[groups]';
+            }
+            $resultArray .= '[' . $subPath . ']';
+        }
+        $resultArray .= '[value]';
+        if (is_array($InputValue)) {
+            $values = [];
+            foreach ($InputValue as $key => $value) {
+                $values[] = $resultArray . "[$key]=$value";
+            }
+            $resultArray = implode('&', $values);
+        } elseif(!empty($InputValue)) {
+            $resultArray .= '=' . $InputValue;
+        }
+        return $resultArray;
+    }
+}
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/CustomConfigDataInterface.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/CustomConfigDataInterface.php
new file mode 100644
index 0000000..85a50ef
--- /dev/null
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/CustomConfigData/CustomConfigDataInterface.php
@@ -0,0 +1,37 @@
+<?php
+/**
+ * Magento
+ *
+ * NOTICE OF LICENSE
+ *
+ * This source file is subject to the Open Software License (OSL 3.0)
+ * that is bundled with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://opensource.org/licenses/osl-3.0.php
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@magento.com so we can send you a copy immediately.
+ *
+ * DISCLAIMER
+ *
+ * Do not edit or add to this file if you wish to upgrade Magento to newer
+ * versions in the future. If you wish to customize Magento for your
+ * needs please refer to http://www.magento.com for more information.
+ *
+ * @category    Tests
+ * @package     Tests_Functional
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
+ * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
+ */
+
+namespace Mage\Adminhtml\Test\Handler\CustomConfigData;
+
+use Magento\Mtf\Handler\HandlerInterface;
+
+/**
+ * ConfigData interface.
+ */
+interface CustomConfigDataInterface extends HandlerInterface
+{
+    //
+}
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Extractor.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Extractor.php
index 62801ee..5043416 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Extractor.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Extractor.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/Curl.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/Curl.php
index a449475..31371e2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/StoreInterface.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/StoreInterface.php
index 450c480..ab49a44 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/StoreInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Store/StoreInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/Curl.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/Curl.php
index 7b58037..2fc6ad6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/StoreGroupInterface.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/StoreGroupInterface.php
index f31341d..2f4be94 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/StoreGroupInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/StoreGroup/StoreGroupInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Ui/LoginUser.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Ui/LoginUser.php
index 7303b8c..f27496d 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Ui/LoginUser.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Ui/LoginUser.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/Curl.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/Curl.php
index c13be1b..42177d0 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/WebsiteInterface.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/WebsiteInterface.php
index d51efea..b03e179 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/WebsiteInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Handler/Website/WebsiteInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminAuthLogin.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminAuthLogin.xml
index 16560af..c62f01f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminAuthLogin.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminAuthLogin.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminLogout.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminLogout.xml
index 4dc56c1..85dbbf1 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminLogout.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/AdminLogout.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Cache.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Cache.xml
index 0d3d974..8796afe 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Cache.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Cache.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Dashboard.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Dashboard.xml
index 0ef19d0..3fd7144 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Dashboard.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/Dashboard.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteGroup.xml
index f11e44c..89a4ef6 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteGroup.xml
@@ -21,12 +21,13 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
 <config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../../vendor/magento/mtf/etc/pages.xsd">
     <page name="DeleteGroup" area="Adminhtml" mca="system_store/deleteGroup" module="Mage_Adminhtml">
+        <block name="form" class="Mage\Adminhtml\Test\Block\System\Store\Delete\Form\GroupForm" locator="[id='page:main-container']" strategy="css selector"/>
         <block name="formPageActions" class="Mage\Adminhtml\Test\Block\FormPageActions" locator=".content-footer" strategy="css selector"/>
     </page>
 </config>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteStore.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteStore.xml
index 5d18115..faa7c0a 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteStore.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteStore.xml
@@ -21,12 +21,13 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
 <config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../../vendor/magento/mtf/etc/pages.xsd">
     <page name="DeleteStore" area="Adminhtml" mca="system_store/deleteStore" module="Mage_Adminhtml">
+        <block name="form" class="Mage\Adminhtml\Test\Block\System\Store\Delete\Form\StoreForm" locator="[id='page:main-container']" strategy="css selector"/>
         <block name="formPageActions" class="Mage\Adminhtml\Test\Block\FormPageActions" locator=".content-footer" strategy="css selector"/>
     </page>
 </config>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteWebsite.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteWebsite.xml
index 2f1777a..ad77c4b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteWebsite.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/DeleteWebsite.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditGroup.xml
index b216bd5..5af1ca7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditStore.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditStore.xml
index d31e732..add9d4e 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditStore.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditStore.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditWebsite.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditWebsite.xml
index c6cb069..7aaf772 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditWebsite.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/EditWebsite.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewStoreGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewStoreGroup.xml
index 45435a2..93c1640 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewStoreGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewStoreGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewWebsite.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewWebsite.xml
index a02afe3..447d435 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewWebsite.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/NewWebsite.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/ProcessList.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/ProcessList.xml
index 8a63029..23c7287 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/ProcessList.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/ProcessList.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreIndex.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreIndex.xml
index e7c666c..c8505b4 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreNew.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreNew.xml
index 89e01fd..cd12193 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/StoreNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/SystemConfig.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/SystemConfig.xml
index b427c88..0b2bb07 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/SystemConfig.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Page/Adminhtml/SystemConfig.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/ConfigData.xml
index 8f22801..6a66ac2 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Store.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Store.xml
index f76d3bd..dff3e0f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Store.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Store.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/StoreGroup.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/StoreGroup.xml
index 1a54a0d..3b1c666 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/StoreGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/StoreGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Website.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Website.xml
index 537dd2c..4ac9482 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Website.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Repository/Website.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.php
index a62e4c4..0623386 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -174,11 +174,19 @@ class CreateStoreEntityTest extends Injectable
         if ($this->store->getGroupId() === 'Main Website/Main Website Store') {
             $this->storeIndex->getStoreGrid()->openStore($this->store);
             $this->editStore->getFormPageActions()->delete();
-            $this->deleteStore->getFormPageActions()->delete();
+            $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+            if ($deleteStoreFormPageActions->isVisible()) {
+                $this->deleteStore->getForm()->fillForm();
+                $deleteStoreFormPageActions->delete();
+            }
         } else {
             $this->storeIndex->getStoreGrid()->openStoreGroup(explode('/', $this->store->getGroupId())[1]);
             $this->editGroup->getFormPageActions()->delete();
-            $this->deleteGroup->getFormPageActions()->delete();
+            $deleteGroupFormPageActions = $this->deleteGroup->getFormPageActions();
+            if ($deleteGroupFormPageActions->isVisible()) {
+                $this->deleteGroup->getForm()->fillForm();
+                $deleteGroupFormPageActions->delete();
+            }
         }
     }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.xml
index b6d5055..621ce4b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.php
index f8a7257..1cde2a7 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -153,11 +153,19 @@ class CreateStoreGroupEntityTest extends Injectable
         if ($this->storeGroup->getWebsiteId() !== 'Main Website') {
             $this->storeIndex->getStoreGrid()->openWebsite($this->storeGroup->getWebsiteId());
             $this->editStore->getFormPageActions()->delete();
-            $this->deleteStore->getFormPageActions()->delete();
+            $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+            if ($deleteStoreFormPageActions->isVisible()) {
+                $this->deleteStore->getForm()->fillForm();
+                $deleteStoreFormPageActions->delete();
+            }
         } else {
             $this->storeIndex->getStoreGrid()->openStoreGroupByName($this->storeGroup->getName());
             $this->editStore->getFormPageActions()->delete();
-            $this->deleteStore->getFormPageActions()->delete();
+            $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+            if ($deleteStoreFormPageActions->isVisible()) {
+                $this->deleteStore->getForm()->fillForm();
+                $deleteStoreFormPageActions->delete();
+            }
         }
     }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.xml
index cbfb9d4..9c93298 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateStoreGroupEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.php
index 80cbe6e..4c0aa3b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -223,7 +223,11 @@ class CreateWebsiteEntityTest extends Injectable
             $storeGrid = $this->storeIndex->getStoreGrid();
             $storeGrid->openWebsite($this->website->getName());
             $this->editStore->getFormPageActions()->delete();
-            $this->deleteStore->getFormPageActions()->delete();
+            $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+            if ($deleteStoreFormPageActions->isVisible()) {
+                $this->deleteStore->getForm()->fillForm();
+                $deleteStoreFormPageActions->delete();
+            }
         }
     }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.xml
index f3b4214..c89e333 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestCase/CreateWebsiteEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteStoreGroupsStep.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteStoreGroupsStep.php
index 2981f17..1102833 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteStoreGroupsStep.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteStoreGroupsStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -95,7 +95,11 @@ class DeleteStoreGroupsStep implements TestStepInterface
             /** @var StoreGroup $storeGroup */
             $this->storeIndex->getStoreGrid()->openStoreGroupByName($storeGroup->getName());
             $this->editStore->getFormPageActions()->delete();
-            $this->deleteStore->getFormPageActions()->delete();
+            $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+            if ($deleteStoreFormPageActions->isVisible()) {
+                $this->deleteStore->getForm()->fillForm();
+                $deleteStoreFormPageActions->delete();
+            }
         }
     }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
index 4686607..d55405b 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/curl/di.xml
index 6615830..f785837 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
@@ -29,4 +29,5 @@
     <preference for="Mage\Adminhtml\Test\Handler\StoreGroup\StoreGroupInterface" type="\Mage\Adminhtml\Test\Handler\StoreGroup\Curl" />
     <preference for="Mage\Adminhtml\Test\Handler\Store\StoreInterface" type="\Mage\Adminhtml\Test\Handler\Store\Curl" />
     <preference for="Mage\Adminhtml\Test\Handler\Website\WebsiteInterface" type="\Mage\Adminhtml\Test\Handler\Website\Curl" />
+    <preference for="Mage\Adminhtml\Test\Handler\CustomConfigData\CustomConfigDataInterface" type="\Mage\Adminhtml\Test\Handler\CustomConfigData\Curl" />
 </config>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/fixture.xml
index d2c8fe9..66038ae 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
@@ -43,4 +43,15 @@
         <collection>Magento\Store\Model\Resource\Store\Collection</collection>
         <identifier>code</identifier>
     </store>
+    <customConfigData module="Mage_Adminhtml">
+        <type>flat</type>
+        <entity_type>core_config_data</entity_type>
+        <collection>Mage\Core\Model\Resource\Config\Data\Collection</collection>
+        <fields>
+            <section>
+                <attribute_code>section</attribute_code>
+                <backend_type>virtual</backend_type>
+            </section>
+        </fields>
+    </customConfigData>
 </fixture>
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.php
index 6136bb4..3e18e05 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.xml
index af45b59..3ac7829 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Block/Directpost/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
index 81e518b..0aaa07c 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.php
index a632a83..3346064 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.xml
index b959801..55f96e3 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForAuthorizenetDirectpostMethodTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
index a09540f..e4e26f7 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.php
index 94a538b..42ece37 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.xml
index af6715b..3462c7a 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOfflineRefundForAuthorizenetDirectpostMethodTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.php
index d812274..0f802a2 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.xml
index 4012aec..398ee18 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForAuthorizenetDirectpostMethodTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
index 248fb6c..73a7c4b 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.php
index dbcb079..84761e2 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.xml
index 60ea357..bf7a14d 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithAuthorizenetDirectpostMethodTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
index c3f18fa..71c5b62 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
index 7f87928..dcdcea0 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.php
index 4eff6f1..ccd4dd3 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.xml
index f834026..7141062 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestCase/CreateShipmentForAuthorizenetDirectpostMethodTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestStep/FillCreditCardStep.php b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestStep/FillCreditCardStep.php
index e5533ea..273b800 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestStep/FillCreditCardStep.php
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/TestStep/FillCreditCardStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/etc/testcase.xml
index 0ab6e6a..6752d66 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
index 70294f8..b0f02ae 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
index 6a89933..3a397cc 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.xml
index 1675fa1..5c873b4 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
index f9f6d7c..2212691 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Search/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
index b4c980b..b92b129 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.xml
index 56aedc5..7304de3 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Bundle/Option/Selection.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
index ae21b20..5429b3a 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/Price.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/Price.php
index b06f058..cbb0be8 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/Price.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View.php
index 3a61bfc..a47a995 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Bundle.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Bundle.php
index 74ae82f..3652395 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Bundle.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Bundle.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option.php
index af7ca3d..d0c7b6e 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.php
index 0b294ac..4153d2a 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.xml
index cbcc051..9da0de9 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Checkbox.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.php
index ef06142..a2daa12 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.xml
index 0cb0e95..f762d05 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Dropdown.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.php
index 0f97b05..cb4e119 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.xml
index 7a1a63c..f6d6ef2 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Multipleselect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.php
index 9d56928..454fe61 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.xml
index eacd808..be35e9a 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Block/Catalog/Product/View/Type/Option/Radiobuttons.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleItemsOnProductPage.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleItemsOnProductPage.php
index 43471b1..fc6e158 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleItemsOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleItemsOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceType.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceType.php
index aa3a8b3..fdcc39a 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceType.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceType.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceView.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceView.php
index ce815c1..5749933 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceView.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundlePriceView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductForm.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductForm.php
index be7c8d3..4f060a8 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductPage.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductPage.php
index cd0da99..d403e3d 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertBundleProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertProductTierPriceOnBundleProductPage.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertProductTierPriceOnBundleProductPage.php
index 8c75a8e..dcf058f 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertProductTierPriceOnBundleProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Constraint/AssertProductTierPriceOnBundleProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct.xml
index e70441c..76e317c 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct/BundleSelections.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct/BundleSelections.php
index 9de7c81..94f7235 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct/BundleSelections.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/BundleProduct/BundleSelections.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/Cart/Item.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/Cart/Item.php
index 668c53f..389aab8 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/Cart/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Fixture/Cart/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/BundleProductInterface.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/BundleProductInterface.php
index 315936e..2180496 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/BundleProductInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/BundleProductInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/Curl.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/Curl.php
index d68bda7..a8334b8 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Handler/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Page/Product/CatalogProductView.xml
index b95dd21..43d7601 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct.xml
index 980d6b4..e3dcb40 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/BundleSelections.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/BundleSelections.xml
index 3010ab5..307a50e 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/BundleSelections.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/BundleSelections.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/CheckoutData.xml
index f8778fc..7bc7092 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/Price.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/Price.xml
index b21179c..e6b8b81 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/Repository/BundleProduct/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductToWishlistEntityTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductToWishlistEntityTest.xml
index 07bdcd0..182fca3 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductToWishlistEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductToWishlistEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
index 0c88bb8..3f24f85 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToShoppingCartEntityTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
index b87d70a..cab44fe 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
index dedcdfd..ea02e7c 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.php
index 2a2228d..c00362e 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.xml
index c827322..cadbacc 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/CreateBundleProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/DeleteBundleProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/DeleteBundleProductEntityTest.xml
index 68ab66a..c2b57ff 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/DeleteBundleProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/DeleteBundleProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
index 333f648..74ac93f 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/curl/di.xml
index 2e6eeee..5f6363f 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/fixture.xml
index eaed746..1661d7d 100644
--- a/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Bundle/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/AbstractConfigureBlock.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/AbstractConfigureBlock.php
index d225dbb..9ea333a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/AbstractConfigureBlock.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/AbstractConfigureBlock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Category/View.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Category/View.php
index bea4c5d..131ba5a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Category/View.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Category/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Layer/View.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Layer/View.php
index 1eb19b8..ac22471 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Layer/View.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Layer/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Msrp/Popup.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Msrp/Popup.php
index 1da56f9..629ac0d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Msrp/Popup.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Msrp/Popup.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/ListCompare.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/ListCompare.php
index 5a3243b..7b9ed34 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/ListCompare.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/ListCompare.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/Sidebar.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/Sidebar.php
index b8ce4f5..6790574 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/Sidebar.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Compare/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ConfigurableProductView.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ConfigurableProductView.php
index 0334cd1..c32e4e4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ConfigurableProductView.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ConfigurableProductView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/GroupedProductView.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/GroupedProductView.php
index e208e20..ae9eab3 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/GroupedProductView.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/GroupedProductView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ListProduct.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ListProduct.php
index 869f384..03bc11f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ListProduct.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ListProduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Price.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Price.php
index 3db5b64..ccfd488 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Price.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/BottomToolbar.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/BottomToolbar.php
index 2ee84e1..4771e18 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/BottomToolbar.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/BottomToolbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Compare.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Compare.php
index 9d53f2b..6478c37 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Compare.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Compare.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell.php
index ad0df54..5ab3b52 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell/Item.php
index 21f6a4c..14dc733 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Crosssell/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related.php
index 3a16fdd..e4236b6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related/Item.php
index d416357..6f7e3b2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Related/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/TopToolbar.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/TopToolbar.php
index 23d57f6..eafe506 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/TopToolbar.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/TopToolbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell.php
index 2c23697..472c483 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell/Item.php
index 0a0143f..3521a24 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/ProductList/Upsell/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View.php
index 6248c91..d26d148 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.php
index 2760d14..d9828a8 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.xml
index 62dc3ad..ffbe684 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/ConfigurableOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.php
index 6d9b9e1..032ceba 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.xml
index e4c52eb..c46cc7c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/CustomOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.php
index 877b2ee..3e6aae1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.xml
index 17ef288..a0869cc 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedItemForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedProduct.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedProduct.php
index 3b44c0f..d1a762d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedProduct.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Product/View/GroupedProduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Search.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Search.php
index 3b62c97..7306bc7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Search.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Block/Search.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertPriceOnGroupedProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertPriceOnGroupedProductPage.php
index 95da4e5..81704bc 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertPriceOnGroupedProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertPriceOnGroupedProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertProductsVisibleOnCategoryPageShopByFilter.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertProductsVisibleOnCategoryPageShopByFilter.php
index ef393bc..15612c1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertProductsVisibleOnCategoryPageShopByFilter.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AbstractAssertProductsVisibleOnCategoryPageShopByFilter.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddToCartButtonPresent.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddToCartButtonPresent.php
index 60a78cc..74d2cd3 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddToCartButtonPresent.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddToCartButtonPresent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddedProductAttributeOnProductForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddedProductAttributeOnProductForm.php
index 413815e..1d80619 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddedProductAttributeOnProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAddedProductAttributeOnProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeForm.php
index 34547f1..aba8fe4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeOptionsOnProductForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeOptionsOnProductForm.php
index ab2815b..f76a0ff 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeOptionsOnProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertAttributeOptionsOnProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnBackend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnBackend.php
index 1a64113..9f3dbaa 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnBackend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnBackend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnFrontend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnFrontend.php
index 4048a38..c56345e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryAbsenceOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForAssignedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForAssignedProducts.php
index 02f59db..e28bd41 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForAssignedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForAssignedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForm.php
index 876b848..d704f18 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryPage.php
index 7b7df58..6bccf7c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryRedirect.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryRedirect.php
index ddf080d..2b50de6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryRedirect.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategoryRedirect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySaveMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySaveMessage.php
index 6b508e3..b07d25e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySuccessDeleteMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySuccessDeleteMessage.php
index f485a8b..3fc83fb 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySuccessDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCategorySuccessDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductForm.php
index bc729f0..6b32aac 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductInCart.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductInCart.php
index 64bf2b0..c4a450c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductInCart.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductInCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductPage.php
index 266540b..df2e917 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertConfigurableProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProducts.php
index 7d0ab2e..9aced4c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProductsSection.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProductsSection.php
index f5ed440..6ed6f02 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProductsSection.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertCrossSellProductsSection.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedPriceOnGroupedProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedPriceOnGroupedProductPage.php
index 5500d53..adfb526 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedPriceOnGroupedProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedPriceOnGroupedProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedProductsDefaultQty.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedProductsDefaultQty.php
index 9663fee..6594da7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedProductsDefaultQty.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertGroupedProductsDefaultQty.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertPriceOnProductPageInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertPriceOnProductPageInterface.php
index b61eba9..db37f7e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertPriceOnProductPageInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertPriceOnProductPageInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentCrossSells.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentCrossSells.php
index 02465b8..881ffef 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentCrossSells.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentCrossSells.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentRelatedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentRelatedProducts.php
index bbad7ef..3da49f8 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentRelatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentRelatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentUpSells.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentUpSells.php
index 488a6f4..6e375c4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentUpSells.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAbsentUpSells.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeDisplayingOnSearchForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeDisplayingOnSearchForm.php
index ecc8925..212ba9f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeDisplayingOnSearchForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeDisplayingOnSearchForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeInGrid.php
index 37c3432..06ffe18 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsComparable.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsComparable.php
index db5437a..d0b6003 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsComparable.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsComparable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterable.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterable.php
index b0f1ced..26ca1b2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterable.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterableInSearch.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterableInSearch.php
index 87c1afe..8baadff 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterableInSearch.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsFilterableInSearch.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsGlobal.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsGlobal.php
index 7ab801b..594d007 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsGlobal.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsGlobal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsRequired.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsRequired.php
index 73c6464..f701799 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsRequired.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsRequired.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUnique.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUnique.php
index e4481a5..4ec7247 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUnique.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUnique.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUsedInSortOnFrontend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUsedInSortOnFrontend.php
index b48455f..fa9f0d6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUsedInSortOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeIsUsedInSortOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeSearchableByLabel.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeSearchableByLabel.php
index b6aced9..6943ca0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeSearchableByLabel.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductAttributeSearchableByLabel.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCanNotAddToCart.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCanNotAddToCart.php
index d511c16..049a6ef 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCanNotAddToCart.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCanNotAddToCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareBlockOnCmsPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareBlockOnCmsPage.php
index 2a9a65a..1bf2456 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareBlockOnCmsPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareBlockOnCmsPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLink.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLink.php
index 810b4f0..7f69eca 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLink.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLink.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLinkIsAbsent.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLinkIsAbsent.php
index 3220cec..2f13ef4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLinkIsAbsent.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareItemsLinkIsAbsent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductComparePage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductComparePage.php
index 7ee0352..87c9043 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductComparePage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductComparePage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessAddMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessAddMessage.php
index 0ef402f..c4cb6ec 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessAddMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessAddMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessRemoveAllProductsMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessRemoveAllProductsMessage.php
index 78a308c..faddfb2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessRemoveAllProductsMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCompareSuccessRemoveAllProductsMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCrossSells.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCrossSells.php
index c6673b2..b88eafa 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCrossSells.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCrossSells.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCustomOptionsOnProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCustomOptionsOnProductPage.php
index ef02a6f..b1b02f2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCustomOptionsOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductCustomOptionsOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateForm.php
index 28a4384..405572d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateIsNotDisplayingOnFrontend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateIsNotDisplayingOnFrontend.php
index 5245f53..e84a532 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateIsNotDisplayingOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateIsNotDisplayingOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateMessage.php
index ba0b5fe..a0c0fe0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicateMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicatedInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicatedInGrid.php
index caf3244..5a187f2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicatedInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductDuplicatedInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductForm.php
index 567e484..08afbb7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductGroupedPriceOnProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductGroupedPriceOnProductPage.php
index 12e17b3..2aee617 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductGroupedPriceOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductGroupedPriceOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCart.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCart.php
index fc14e9f..8c5ff54 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCart.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCategory.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCategory.php
index 5d71821..5f34ab6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCategory.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInGrid.php
index 2179d4d..acaa2e4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInStock.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInStock.php
index 052a62a..0e5e151 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInStock.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductInStock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductIsNotDisplayingOnFrontend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductIsNotDisplayingOnFrontend.php
index 22a129a..dc401c7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductIsNotDisplayingOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductIsNotDisplayingOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedBeforeCheckout.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedBeforeCheckout.php
index 3e2302e..549a8e0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedBeforeCheckout.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedBeforeCheckout.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedInCart.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedInCart.php
index fac9719..388918f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedInCart.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedInCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedOnGesture.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedOnGesture.php
index 317f6c2..4e70f39 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedOnGesture.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductMapAppliedOnGesture.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotInGrid.php
index 095199b..e5f3f6f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotSearchableBySku.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotSearchableBySku.php
index 36e942d..9c003c6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotSearchableBySku.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductNotSearchableBySku.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStock.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStock.php
index 6114791..ddeff25 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStock.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockOnCategory.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockOnCategory.php
index ee91485..d62f810 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockOnCategory.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockOnCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockVisibleInCategory.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockVisibleInCategory.php
index 9fae8cc..35c6c1c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockVisibleInCategory.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductOutOfStockVisibleInCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductPage.php
index 00e1371..7797bac 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductRelatedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductRelatedProducts.php
index a55b758..36e1825 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductRelatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductRelatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSaveMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSaveMessage.php
index 8fd6c27..1fca4dc 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSearchable.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSearchable.php
index ec7c5f5..d7a466c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSearchable.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSearchable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
index 8f5bb92..047e213 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 namespace Mage\Catalog\Test\Constraint;
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceOnProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceOnProductPage.php
index 7799519..21c9a44 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateForm.php
index 3256e35..dda6575 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateInGrid.php
index 18ced14..f34079c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateOnProductForm.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateOnProductForm.php
index 67b06a5..8ff3b5d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateOnProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateOnProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateSuccessSaveMessage.php
index 7dde973..314eace 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTemplateSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTierPriceOnProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTierPriceOnProductPage.php
index 96fbf15..7d7b064 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTierPriceOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductTierPriceOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductVisibleInCategory.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductVisibleInCategory.php
index 49da197..abe47fa 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductVisibleInCategory.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductVisibleInCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsIsNotDisplayingOnFrontend.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsIsNotDisplayingOnFrontend.php
index e1598a8..ef5dd88 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsIsNotDisplayingOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsIsNotDisplayingOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotInGrid.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotInGrid.php
index 89e3f31..34d6bd0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotVisibleInCategory.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotVisibleInCategory.php
index 74cfcfb..f7ec80e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotVisibleInCategory.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsNotVisibleInCategory.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsSuccessDeleteMessage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsSuccessDeleteMessage.php
index f9b1367..f0c29f0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsSuccessDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsSuccessDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByAttribute.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByAttribute.php
index 7af9eaf..0a518d7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByAttribute.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByAttribute.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByPrice.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByPrice.php
index 825894c..cd7305d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByPrice.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductsVisibleOnCategoryPageShopByPrice.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProducts.php
index 503bbc3..f9bfc7e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProductsSection.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProductsSection.php
index 5fbb566..2b959ec 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProductsSection.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertRelatedProductsSection.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertSpecialPriceOnGroupedProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertSpecialPriceOnGroupedProductPage.php
index 42066f8..86f6076 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertSpecialPriceOnGroupedProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertSpecialPriceOnGroupedProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertTierPriceOnGroupedProductPage.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertTierPriceOnGroupedProductPage.php
index 55560ac..0adf429 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertTierPriceOnGroupedProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertTierPriceOnGroupedProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProducts.php
index 3cb0e30..0e9c7aa 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProductsSection.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProductsSection.php
index 8364a7e..a902e7f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProductsSection.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertUpSellProductsSection.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductConfigurableHandler.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductConfigurableHandler.php
index 46c7d44..5db22d1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductConfigurableHandler.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductConfigurableHandler.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductHandler.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductHandler.php
index 1336cae..fb51c99 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductHandler.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/ProductHandler.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/Cart/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/Cart/Item.php
index e3dcfdc..31ce804 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/Cart/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/Cart/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet.xml
index fdddab4..bb6f3d0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/AssignedAttributes.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/AssignedAttributes.php
index ec22873..4315b3f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/AssignedAttributes.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/AssignedAttributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/SkeletonSet.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/SkeletonSet.php
index 153c4c0..8e123fe 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/SkeletonSet.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogAttributeSet/SkeletonSet.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory.xml
index 3daa62a..9abe774 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/CategoryProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/CategoryProducts.php
index 12ee80d..d0869da 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/CategoryProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/CategoryProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/ParentId.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/ParentId.php
index a7c232b..969c559 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/ParentId.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogCategory/ParentId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute.xml
index 63675e6..bf1c3f5 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute/Options.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute/Options.php
index 1854bf2..ee0d8d0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute/Options.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductAttribute/Options.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple.xml
index 14382ac..740fe60 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AbstractRelatedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AbstractRelatedProducts.php
index 678afad..30d1679 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AbstractRelatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AbstractRelatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AttributeSetId.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AttributeSetId.php
index b4f9c8c..5f6f68f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AttributeSetId.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/AttributeSetId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Attributes.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Attributes.php
index db362e7..073e6f4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Attributes.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Attributes.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CategoryIds.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CategoryIds.php
index 5469c97..595e1cd 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CategoryIds.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CategoryIds.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CrossSellProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CrossSellProducts.php
index 4b8ebc1..eb88c2c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CrossSellProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CrossSellProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CustomOptions.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CustomOptions.php
index 52c4d4a..b20e73a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CustomOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/CustomOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Fpt.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Fpt.php
index 97b1fef..9ca018f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Fpt.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Fpt.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Price.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Price.php
index 773dee0..e8ebf0f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Price.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/RelatedProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/RelatedProducts.php
index 076ebb4..141926c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/RelatedProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/RelatedProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/TaxClass.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/TaxClass.php
index adc8035..2a715d1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/TaxClass.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/TaxClass.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/UpSellProducts.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/UpSellProducts.php
index 864cef8..2c4a824 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/UpSellProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/UpSellProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/WebsiteIds.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/WebsiteIds.php
index b5bb305..a44a4c5 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/WebsiteIds.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductSimple/WebsiteIds.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductVirtual.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductVirtual.xml
index 2ea8fce..0714108 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductVirtual.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/CatalogProductVirtual.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct.xml
index b5f617a..8e1c01a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/Cart/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/Cart/Item.php
index 69275e1..66114d9 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/Cart/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/Cart/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/ConfigurableOptions.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/ConfigurableOptions.php
index 59aaeed..820ce4f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/ConfigurableOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/ConfigurableProduct/ConfigurableOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct.xml
index 1b859c5..8795d71 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Associated.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Associated.php
index 1c9c837..a9bbc3f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Associated.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Associated.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Cart/Item.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Cart/Item.php
index 15bf0f4..663b4ad 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Cart/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Fixture/GroupedProduct/Cart/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/CatalogAttributeSetInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/CatalogAttributeSetInterface.php
index 2749027..d404ccc 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/CatalogAttributeSetInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/CatalogAttributeSetInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/Curl.php
index d396433..bb16b1c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogAttributeSet/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/CatalogCategoryInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/CatalogCategoryInterface.php
index 30b09e0..6c3b524 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/CatalogCategoryInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/CatalogCategoryInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/Curl.php
index 071e3b8..137c4aa 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogCategory/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/CatalogProductAttributeInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/CatalogProductAttributeInterface.php
index 9177fcb..0532a83 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/CatalogProductAttributeInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/CatalogProductAttributeInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/Curl.php
index d8fe567..9cc198b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductAttribute/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/CatalogProductSimpleInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/CatalogProductSimpleInterface.php
index a98afb6..68627fb 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/CatalogProductSimpleInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/CatalogProductSimpleInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/Curl.php
index 09a1f81..bb1bd9f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductSimple/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/CatalogProductVirtualInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/CatalogProductVirtualInterface.php
index a2746be..26119cd 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/CatalogProductVirtualInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/CatalogProductVirtualInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/Curl.php
index 7e08cf5..6d5dafe 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/CatalogProductVirtual/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/ConfigurableProductInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/ConfigurableProductInterface.php
index 6dfcae5..0c5a970 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/ConfigurableProductInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/ConfigurableProductInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/Curl.php
index f14c408..d27f562 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/ConfigurableProduct/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/Curl.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/Curl.php
index 142f156..3214f09 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/GroupedProductInterface.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/GroupedProductInterface.php
index 0d135bf..b101b1b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/GroupedProductInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Handler/GroupedProduct/GroupedProductInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogCategoryIndex.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogCategoryIndex.xml
index 04d16eb..a7962b3 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogCategoryIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogCategoryIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProduct.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProduct.xml
index e5f7484..c9f3b2c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeEdit.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeEdit.xml
index ce3a0d4..d3c2624 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeIndex.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeIndex.xml
index 39dd747..afd84c0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeNew.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeNew.xml
index 5605b57..71eb3d9 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductAttributeNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductEdit.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductEdit.xml
index 86caa99..6d502c3 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductNew.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductNew.xml
index 7062c7a..28ac3ed 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetAdd.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetAdd.xml
index a2e8c5a..9728f44 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetAdd.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetAdd.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetEdit.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetEdit.xml
index a566f94..c111696 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetIndex.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetIndex.xml
index 499b193..d5da585 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Adminhtml/CatalogProductSetIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Category/CatalogCategoryView.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Category/CatalogCategoryView.xml
index 8fd7c7d..ad6c382 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Category/CatalogCategoryView.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Category/CatalogCategoryView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductCompare.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductCompare.xml
index 80875ba..d037a1f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductCompare.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductCompare.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductView.xml
index 705eec8..8fa3b1b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogAttributeSet.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogAttributeSet.xml
index 599c548..79c2414 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogAttributeSet.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogAttributeSet.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogCategory.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogCategory.xml
index 95e549a..034f599 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogCategory.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogCategory.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute.xml
index 8a953bb..63332e7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute/Options.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute/Options.xml
index cdc6987..99a9474 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute/Options.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductAttribute/Options.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/CheckoutData.xml
index 3ffc738..4ce88c1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/ConfigurableOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/ConfigurableOptions.xml
index 4dcf959..3ee1d58 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/ConfigurableOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/ConfigurableOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/Price.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/Price.xml
index 78c07d9..c51bfd0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductConfigurable/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple.xml
index e98ee7e..d1bd71e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Attributes.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Attributes.xml
index 24e33a9..43f8cc6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Attributes.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Attributes.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CheckoutData.xml
index d3b9917..2fa037f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CustomOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CustomOptions.xml
index b84f437..f7ea6e0 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CustomOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/CustomOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Fpt.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Fpt.xml
index 19caf0b..d49264a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Fpt.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Fpt.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/GroupPriceOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/GroupPriceOptions.xml
index 2260858..db066338 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/GroupPriceOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/GroupPriceOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Price.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Price.xml
index eb5df5a..1799be2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/TierPriceOptions.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/TierPriceOptions.xml
index d644109..98b02c5 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/TierPriceOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductSimple/TierPriceOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual.xml
index b5158c8..edd20d2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/CheckoutData.xml
index c355188..b609301 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/Price.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/Price.xml
index b15868b..c6880e4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/CatalogProductVirtual/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigData.xml
index ad4257d..04dd3f5 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigurableProduct.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigurableProduct.xml
index b915c5a..1fe463a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigurableProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/ConfigurableProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct.xml
index e67afb0..32324c7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Associated.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Associated.xml
index 2d1b6d2..cce2556 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Associated.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Associated.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/CheckoutData.xml
index 76ffa59..08f820e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Price.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Price.xml
index 6a04d67..bbb3fed 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Repository/GroupedProduct/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.php
index 4e45811..a29198b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.xml
index 04e422b..7972e94 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/CreateCategoryEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.php
index 140253e..9675fee 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.xml
index d386908..74c8bf7 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/DeleteCategoryEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.php
index 07bbe86..e44f09d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.xml
index 94082c8..3b1bc33 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Category/UpdateCategoryEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.php
index 97968b9..cd680e1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.xml
index 17faa66..e457a63 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Layer/FilterProductListTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractAddAppurtenantProductsEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractAddAppurtenantProductsEntityTest.php
index 8e556f9..6b69365 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractAddAppurtenantProductsEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractAddAppurtenantProductsEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractProductsCompareTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractProductsCompareTest.php
index 179e9d4..fb7e5e9 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractProductsCompareTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractProductsCompareTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractPromoteAppurtenantProductsEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractPromoteAppurtenantProductsEntityTest.php
index c6bee3b..be1896c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractPromoteAppurtenantProductsEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AbstractPromoteAppurtenantProductsEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.php
index 16d3387..e95dade 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.xml
index cd2930c..0ffd9fd 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddCrossSellProductsEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.php
index 2d82e52..2c7de3c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.xml
index d62a15f..02a4039 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddProductsToCompareTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.php
index 26a8a4e..93f6b6b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.xml
index 5a301cf..282b38a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddRelatedProductsEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.php
index f7d1751..1fb8fc1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.xml
index 6b8fe80..0914277 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/AddUpSellProductsEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.php
index 1e3946d..0c8ad8f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.xml
index 4dbaaf1..984ac0a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ApplyMapTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.php
index d039b67..cff98dc 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.xml
index b69f23d..506a668 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/ClearAllCompareProductsTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.php
index c70527c..1c606d5 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.xml
index 1a0c3b7..e60d63f 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateConfigurableProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.php
index b32819d..f016334 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.xml
index f8ed315..96b28ec 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateGroupedProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.php
index eae442c..a3fe45c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
index 42f4195..968d8ed 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.php
index 7f3e20d..94f943a 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.xml
index 81cb490..cf2eed4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateVirtualProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.php
index 60a3b11..f80d567 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.xml
index a8f1579..5f83147 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DeleteProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.php
index 86c96b6..e0698e2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.xml
index 7bf7701..df72586 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/DuplicateProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.php
index 79afeb0..0d70c75 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.xml
index f597cde..e1d2673 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsCrossSellsTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.php
index 953997d..aeca6e2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.xml
index c3cd687..77b233c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsRelatedTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.php
index 1ec588b..cb96db2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.xml
index 0d11947..79bdf5b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/PromoteProductsAsUpSellsTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.php
index 436b41e..2c268ee 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.xml
index 00beb0c..6bf0581 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateConfigurableProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.php
index 957bc14..2e788de 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.xml
index d2497aa..3ef5c6b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/UpdateSimpleProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.php
index 2d153ac..ce5e05d 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.xml
index c8d49d9..8ac3255 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateAttributeSetEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.php
index c5b3351..c1c31f6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.xml
index 2a4a551..473aac4 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/ProductAttribute/CreateProductAttributeEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductAttributeStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductAttributeStep.php
index 1f9b506..52c7905 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductAttributeStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductAttributeStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductStep.php
index 5fadf1f..b923ad2 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductTemplateStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductTemplateStep.php
index 785ae10..3534154 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductTemplateStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductTemplateStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductsStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductsStep.php
index a4ea46c..2359d23 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductsStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/CreateProductsStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/OpenProductOnBackendStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/OpenProductOnBackendStep.php
index c8da567..33413f9 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/OpenProductOnBackendStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/OpenProductOnBackendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/SaveProductStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/SaveProductStep.php
index f19e5f5..b8085ad 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/SaveProductStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/SaveProductStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep.php
index d42b22d..3b2f90b 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AbstractSubStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AbstractSubStep.php
index cea2277..ae27a79 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AbstractSubStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AbstractSubStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AddOptionsSubStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AddOptionsSubStep.php
index adf6167..995d5d8 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AddOptionsSubStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/AddOptionsSubStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/CreateProductSubStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/CreateProductSubStep.php
index cfcdba3..8fe7578 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/CreateProductSubStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/CreateProductSubStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/DeleteOptionsSubStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/DeleteOptionsSubStep.php
index 4867b71..e722dd1 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/DeleteOptionsSubStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/DeleteOptionsSubStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/UpdateOptionsSubStep.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/UpdateOptionsSubStep.php
index adc4b2d..a770330 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/UpdateOptionsSubStep.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestStep/UpdateConfigurableProductStep/UpdateOptionsSubStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/curl/di.xml
index cff0772..ae7aa7e 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/fixture.xml
index e73911d..358463c 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/testcase.xml
index e926be4..3739ef6 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInCatalogPage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInCatalogPage.php
index fd16183..0a1e098 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInCatalogPage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInCatalogPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInProductPage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInProductPage.php
index b47f742..68dfde6 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInShoppingCart.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInShoppingCart.php
index 03d6d9f..e4a6f12 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleAppliedInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleForm.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleForm.php
index 2cbf50a..0edb648 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleForm.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleInGrid.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleInGrid.php
index ae2e1da..f170944 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInGrid.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInGrid.php
index f1af5ae..ab1a052 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 namespace Mage\CatalogRule\Test\Constraint;
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInProductPage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInProductPage.php
index f83e58e..1ffaa3d 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNotInProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNoticeMessage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNoticeMessage.php
index fcb518e..170b4c6 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNoticeMessage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleNoticeMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessDeleteMessage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessDeleteMessage.php
index 10f372a..8298821 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessSaveMessage.php
index a556fdc..577a55e 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Constraint/AssertCatalogPriceRuleSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Fixture/CatalogRule.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Fixture/CatalogRule.xml
index cb0f9c6..238c320 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Fixture/CatalogRule.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Fixture/CatalogRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/CatalogRuleInterface.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/CatalogRuleInterface.php
index 2a96be8..d8c093f 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/CatalogRuleInterface.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/CatalogRuleInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/Curl.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/Curl.php
index b6a2b4c..bd3da15 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Handler/CatalogRule/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleEdit.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleEdit.xml
index 2bd5026..9a121d6 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleIndex.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleIndex.xml
index 6e171f6..30c3711 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Page/Adminhtml/CatalogRuleIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Repository/CatalogRule.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Repository/CatalogRule.xml
index ecbebcd..9809ca4 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Repository/CatalogRule.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/Repository/CatalogRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/AbstractCatalogRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/AbstractCatalogRuleEntityTest.php
index fc94204..ff5dc83 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/AbstractCatalogRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/AbstractCatalogRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.php
index 791c023..d752a0f 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.xml
index 12bdc16..dea2576 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/ApplySeveralCatalogPriceRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.php
index 5579cae..4d56859 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.xml
index 8d17f19..a0b7a70 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/CreateCatalogPriceRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.php
index 97c459e..9d4ab93 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.xml
index 6434f3a..ff30f6e 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestCase/DeleteCatalogPriceRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/CreateCatalogRuleStep.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/CreateCatalogRuleStep.php
index 7983111..4c405f0a 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/CreateCatalogRuleStep.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/CreateCatalogRuleStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/DeleteAllCatalogRulesStep.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/DeleteAllCatalogRulesStep.php
index 3267026..dfff18b 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/DeleteAllCatalogRulesStep.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/DeleteAllCatalogRulesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/SaveAndApplyCatalogRuleStep.php b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/SaveAndApplyCatalogRuleStep.php
index d7d7d7c..2f98c05 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/SaveAndApplyCatalogRuleStep.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/TestStep/SaveAndApplyCatalogRuleStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/curl/di.xml
index 9a8b24a..8a8cf88 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/fixture.xml
index 38131b9..50f30ea 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogRule/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Block/Advanced/Form.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Block/Advanced/Form.php
index 48cfda8..142d2c5 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Block/Advanced/Form.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Block/Advanced/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermForm.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermForm.php
index eca4a89..74dc999 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermForm.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermInGrid.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermInGrid.php
index c548206..5510d41 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermOnFrontend.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermOnFrontend.php
index 601ded0..ed935d4 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSuccessSaveMessage.php
index 6601d14..cce7282 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSynonymOnFrontend.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSynonymOnFrontend.php
index 4460027..31438b6 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSynonymOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSearchTermSynonymOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSuggestSearchingResult.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSuggestSearchingResult.php
index 89e618b..907350c 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSuggestSearchingResult.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Constraint/AssertSuggestSearchingResult.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery.xml
index 26676fc..8aca198 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery/QueryText.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery/QueryText.php
index b0a9d9e..dd552af 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery/QueryText.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Fixture/CatalogSearchQuery/QueryText.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchEdit.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchEdit.xml
index 5a11660..4acaa01 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchIndex.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchIndex.xml
index 52ea2c8..53625a7 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/Adminhtml/CatalogSearchIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchAdvanced.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchAdvanced.xml
index 477c5f0..8f02246 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchAdvanced.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchAdvanced.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchResult.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchResult.xml
index 8d2248e..390f454 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchResult.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/Page/CatalogsearchResult.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.php
index 17534d7..db0df56 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.xml
index 47b02b8..09ab43f 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/CreateSearchTermEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.php b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.php
index ea7008d..30e7424 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.xml b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.xml
index 7d5e64c..2b1aecb 100644
--- a/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CatalogSearch/Test/TestCase/SuggestSearchingResultEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/AbstractItem.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/AbstractItem.php
index 0494871..d36ffbd 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/AbstractItem.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/AbstractItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart.php
index cd55133..4298765 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/CartItem.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/CartItem.php
index ace46b2..3242002 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/CartItem.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/CartItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/DiscountCodes.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/DiscountCodes.php
index 9d640df..02046a5 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/DiscountCodes.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/DiscountCodes.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.php
index 2379a1c..08178bc 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.xml
index bbcbaca..8152dbd 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Shipping.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar.php
index 50add79..260e6e7 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar/CartItem.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar/CartItem.php
index 232b285..d4cf666 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar/CartItem.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Sidebar/CartItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Totals.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Totals.php
index 4f369ca..71adf30 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Cart/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart.php
index c9c7454..16f8743 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart/CartItem.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart/CartItem.php
index f07a69a..4e1992c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart/CartItem.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/GroupedProductCart/CartItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping.php
index 847bf68..259e65c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping/AbstractItems.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping/AbstractItems.php
index ebc4727..8a6e58e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping/AbstractItems.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/AbstractMultishipping/AbstractItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses.php
index 6cead9a..c368e54 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items.php
index 72eb1de..4924399 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items/Item.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items/Item.php
index 755b5e6..dd0b44c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Addresses/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Billing.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Billing.php
index ae85af2..fe99c39 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Billing.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Overview.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Overview.php
index 6a3fbb4..d11e82a 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Overview.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Overview.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.php
index 1bbe4cd..d25851c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.xml
index 167b7a7..932cfe2 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Register.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping.php
index b8d2883..26ff9ab 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items.php
index 366cae8..60a724d 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items/Item.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items/Item.php
index 1334966..fa03b7c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Shipping/Items/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Success.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Success.php
index 1ae649e..c2e87a2 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Success.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Multishipping/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/AbstractOnepage.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/AbstractOnepage.php
index 9e6a5df..903bdb8 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/AbstractOnepage.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/AbstractOnepage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.php
index c9424fd..d0fa6bb 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.xml
index cad8d66..4bf8fc4 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Billing.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Link.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Link.php
index 61df499..e9335aa 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Link.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.php
index 5675118..abb9413 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.xml
index 9cf8f6b..e6459c3 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Login.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Payment/Methods.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Payment/Methods.php
index 9affce1..5145577 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Payment/Methods.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Payment/Methods.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review.php
index f1f4e89..f081766 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items.php
index 05f3a26..767b447 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items/Product.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items/Product.php
index 524edc2..00b1b18 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Totals.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Totals.php
index e9dcfc3..b96c704 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Review/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Shipping/Method.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Shipping/Method.php
index afcc47b..7a61d91 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Shipping/Method.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Shipping/Method.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Success.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Success.php
index f9f414a..f1ab6ca 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Success.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Block/Onepage/Success.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AbstractAssertProductInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AbstractAssertProductInShoppingCart.php
index 2c124d9..1fa5557 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AbstractAssertProductInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AbstractAssertProductInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertAbstractOrderAddressSameAsPaypal.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertAbstractOrderAddressSameAsPaypal.php
index d4486a8..5ef37a2 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertAbstractOrderAddressSameAsPaypal.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertAbstractOrderAddressSameAsPaypal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartIsEmpty.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartIsEmpty.php
index c3ab4b5..a626710 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartIsEmpty.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartIsEmpty.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartItemsOptions.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartItemsOptions.php
index 2e38987..7c2640f 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartItemsOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertCartItemsOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertGrandTotalInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertGrandTotalInShoppingCart.php
index c60c2e0..e2302dc 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertGrandTotalInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertGrandTotalInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderBillingAddressSameAsPaypalShipping.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderBillingAddressSameAsPaypalShipping.php
index f3097ad..80226c8 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderBillingAddressSameAsPaypalShipping.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderBillingAddressSameAsPaypalShipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderShippingAddressSameAsPaypalBilling.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderShippingAddressSameAsPaypalBilling.php
index 589de53..e646f1e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderShippingAddressSameAsPaypalBilling.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderShippingAddressSameAsPaypalBilling.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderSuccessPlacedMessage.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderSuccessPlacedMessage.php
index 46c32ac..92abc1d 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderSuccessPlacedMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderSuccessPlacedMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderWithMultishippingSuccessPlacedMessage.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderWithMultishippingSuccessPlacedMessage.php
index 6b86503..20c6fa0 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderWithMultishippingSuccessPlacedMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertOrderWithMultishippingSuccessPlacedMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertPriceInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertPriceInShoppingCart.php
index ba5b4c1..d702a41 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertPriceInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertPriceInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductIsNotEditable.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductIsNotEditable.php
index 32092ae..8c7d28c 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductIsNotEditable.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductIsNotEditable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInMiniShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInMiniShoppingCart.php
index d4c8679..65c2171 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInMiniShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInMiniShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInShoppingCart.php
index 032314b..585c425 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductQtyInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductsPresentInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductsPresentInShoppingCart.php
index 804741f..b2220b2 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductsPresentInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertProductsPresentInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertSubtotalInShoppingCart.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertSubtotalInShoppingCart.php
index 0ae63da..1552428 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertSubtotalInShoppingCart.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertSubtotalInShoppingCart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermInGrid.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermInGrid.php
index 51798f0..ada5737 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermOnCheckout.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermOnCheckout.php
index 2155074..96513df 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermOnCheckout.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermOnCheckout.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermRequireMessageOnMultishippingCheckout.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermRequireMessageOnMultishippingCheckout.php
index 403f09e..8d8a253 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermRequireMessageOnMultishippingCheckout.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermRequireMessageOnMultishippingCheckout.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermSuccessSaveMessage.php
index 444e9fa..e8e34f9 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Constraint/AssertTermSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart.xml
index 203e67e..57c697f 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart/Items.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart/Items.php
index b90c424..d5f6f82 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/Cart/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement.xml
index 2261a2a..d11f708 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement/Stores.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement/Stores.php
index 925fd2c..d968439 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement/Stores.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Fixture/CheckoutAgreement/Stores.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementEdit.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementEdit.xml
index facfb65..5b1ad02 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementIndex.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementIndex.xml
index 1c0b2e9..467ff34 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementNew.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementNew.xml
index c17dda6..6148d23 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/Adminhtml/CheckoutAgreementNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutCart.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutCart.xml
index 9f7c2b9..4abff94 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutCart.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutCart.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddressNewShipping.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddressNewShipping.xml
index 214cf41..75ba3ca 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddressNewShipping.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddressNewShipping.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddresses.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddresses.xml
index bcec185..1a3ef70 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddresses.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingAddresses.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingBilling.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingBilling.xml
index a8a258d..a0c58b8 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingBilling.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingBilling.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingLogin.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingLogin.xml
index 374aac2..9d73c1e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingLogin.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingLogin.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingOverview.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingOverview.xml
index 28a8b3c..085a00b 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingOverview.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingOverview.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingRegister.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingRegister.xml
index e50c5aa..c8297fa 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingRegister.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingRegister.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingShipping.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingShipping.xml
index b5ad611..5f9a5c7 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingShipping.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingShipping.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingSuccess.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingSuccess.xml
index 79097e5..2eb51b8 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingSuccess.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutMultishippingSuccess.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepage.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepage.xml
index 328cdf7..d29e073 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepage.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepageSuccess.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepageSuccess.xml
index 0ee5f47..1b372c6 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepageSuccess.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CheckoutOnepageSuccess.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CmsIndex.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CmsIndex.xml
index a2c0307..6db1c76 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CmsIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Page/CmsIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/CheckoutAgreement.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/CheckoutAgreement.xml
index f57f9cf..4b6b5f9 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/CheckoutAgreement.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/CheckoutAgreement.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/ConfigData.xml
index 8324f97..76da76e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.php
index db6e575..1910e9a 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
index 991ac34..a6d9fe6 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/AddProductsToShoppingCartEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.php
index 209a848b..7452f02 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.xml
index a0ecf17..d56183f 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CheckoutWithMultishippingTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.php
index 1fcafb4..7c63fda 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.xml
index f629344..0f0d89a 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/CreateTermEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.php
index 322df9a..ddbdab7 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.xml
index 5a1fa8e..03f9105 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/DeleteProductsFromShoppingCartTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.php
index df2297f..dd9d51e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.xml
index 106cacc..fa9eb89 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.php
index b7e0113..84df02e 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.xml
index 9a1ff2c..4572f33 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinDhlShippingMethod.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.php
index 28f0cac..70492fa 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.xml
index 64c8cee..e1dc693 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/OnePageCheckoutWithinOnlineShippingMethods.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.php
index 500b572..fc4a6fd 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.xml
index 7a3ca3a..987e852 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestCase/UpdateShoppingCartTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddNewCheckoutAgreementStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddNewCheckoutAgreementStep.php
index f247ffc..f2ce6e9 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddNewCheckoutAgreementStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddNewCheckoutAgreementStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddProductsToTheCartStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddProductsToTheCartStep.php
index 6f8a412..1f073c5 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddProductsToTheCartStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/AddProductsToTheCartStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/CreateCartItemStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/CreateCartItemStep.php
index c0d4469..362839a 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/CreateCartItemStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/CreateCartItemStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/DeleteAllTermsEntityStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/DeleteAllTermsEntityStep.php
index 4a2b960..6fea029 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/DeleteAllTermsEntityStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/DeleteAllTermsEntityStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/EnterNewAddressesStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/EnterNewAddressesStep.php
index 02f7b8e..bc9b9d9 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/EnterNewAddressesStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/EnterNewAddressesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillAndSaveCheckoutAgreementStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillAndSaveCheckoutAgreementStep.php
index 13eefb4..6ca16cd 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillAndSaveCheckoutAgreementStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillAndSaveCheckoutAgreementStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillBillingInformationStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillBillingInformationStep.php
index decd3f7..4bbb44f 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillBillingInformationStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillBillingInformationStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodStep.php
index 2bce6c7..e2cc1db 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodWithMultishippingStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodWithMultishippingStep.php
index f9439b1..b321ea3 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodWithMultishippingStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/FillShippingMethodWithMultishippingStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderStep.php
index 0954699..1ebf662 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderWithMultishippingStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderWithMultishippingStep.php
index f700e5f..a682468 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderWithMultishippingStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/PlaceOrderWithMultishippingStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutStep.php
index 83d4eb0..17db901 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutWithMultishippingStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutWithMultishippingStep.php
index cbcb6db..3dd6d7f 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutWithMultishippingStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/ProceedToCheckoutWithMultishippingStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectAddressesStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectAddressesStep.php
index 45b11c4..1fec2743 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectAddressesStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectAddressesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodStep.php
index 8b60567..b091a34 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodWithMultishippingStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodWithMultishippingStep.php
index 298965d..38de62d 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodWithMultishippingStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectCheckoutMethodWithMultishippingStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodStep.php
index f3932e0..601b571 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodWithMultishippingStep.php b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodWithMultishippingStep.php
index 2aba99d..3afee50 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodWithMultishippingStep.php
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/TestStep/SelectPaymentMethodWithMultishippingStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/fixture.xml
index d981c05..72f80cd 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/testcase.xml
index ba8a87e..4c9ab81 100644
--- a/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Checkout/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Block/Page.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Block/Page.php
index f2477dd..b1a7355 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Block/Page.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Block/Page.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockInGrid.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockInGrid.php
index f346bd3..4c5ae12 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockNotOnCategoryPage.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockNotOnCategoryPage.php
index ce70581..a4b7c74 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockNotOnCategoryPage.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockNotOnCategoryPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockOnCategoryPage.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockOnCategoryPage.php
index c163b0f..2b58b8f 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockOnCategoryPage.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockOnCategoryPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockSuccessSaveMessage.php
index b37307a..36dc68d 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsBlockSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDeleteMessage.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDeleteMessage.php
index 517bd03..63ffa25 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnFrontend.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnFrontend.php
index 7194220..b447605 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnUnassignedStoreView.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnUnassignedStoreView.php
index fe3e504..1df4d60 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnUnassignedStoreView.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageDisabledOnUnassignedStoreView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageForm.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageForm.php
index 48e6299..d7c1d29 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageForm.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageInGrid.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageInGrid.php
index 6d559a2..78459cf 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageNotInGrid.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageNotInGrid.php
index 2c240e4..87140cc 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageNotInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageNotInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPagePreview.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPagePreview.php
index e000356..c79018b 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPagePreview.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPagePreview.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageSuccessSaveMessage.php
index 9ea5825..84df0f3 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Constraint/AssertCmsPageSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock.xml
index 6a8c02c..6036166 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock/Stores.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock/Stores.php
index cf8d1c7..1e91747e 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock/Stores.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlock/Stores.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlockMultiStore.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlockMultiStore.xml
index 490e676..7eddcb5 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlockMultiStore.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsBlockMultiStore.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage.xml
index c50b796..f6f9224 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/Content.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/Content.php
index 77239ea..232d2f9 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/Content.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/StoreId.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/StoreId.php
index 87be023..bd8c7b6 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/StoreId.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPage/StoreId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPageMultiStore.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPageMultiStore.xml
index cb8e104..bc93e56 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPageMultiStore.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Fixture/CmsPageMultiStore.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/CmsPageInterface.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/CmsPageInterface.php
index f4eabf7..ecc08fe 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/CmsPageInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/CmsPageInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/Curl.php b/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/Curl.php
index b00c839..7db1f7d 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Handler/CmsPage/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockEdit.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockEdit.xml
index 58ec670..b242901 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockIndex.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockIndex.xml
index 00ec323..1876a2c 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockNew.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockNew.xml
index 9853880..f458252 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsBlockNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageEdit.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageEdit.xml
index 81b9b9b..f876ad6 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageIndex.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageIndex.xml
index 3c9a756..0dce5bd 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageNew.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageNew.xml
index 51f3383..ef5c0ba 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/Adminhtml/CmsPageNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsIndex.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsIndex.xml
index 63dc0d9..1305989 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsPage.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsPage.xml
index 0b63ed0..1187406 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsPage.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Page/CmsPage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsBlock.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsBlock.xml
index cfc268d..476cd3f 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsBlock.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsBlock.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsPage.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsPage.xml
index cd90659..17af407 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsPage.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/Repository/CmsPage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.php b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.php
index 192839d..4696577 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.xml
index 6f0ba17..9d53541 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsBlockEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
index 3cfd61d..6e1e25c 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.xml
index 1067672..6bc80b3 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.php b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.php
index 57b0c20..f381567 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.xml
index b492152..12140fd 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/DeleteCmsPageEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.php b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.php
index f154db5..7bb69a1 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.xml
index 87b7d44..ca3743f 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/UpdateCmsPageEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/etc/curl/di.xml
index ee27f0b..9cfce95 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Cms/Test/etc/fixture.xml
index 14eea30..ebf5331 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.php b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.php
index d5a0f1d..f83d08e 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.xml b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.xml
index 53a307d..c82b34a 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.xml
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Content.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.php b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.php
index 6f88832..c8d8486 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.xml b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.xml
index 2286ef0..d5601d2 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.xml
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Login.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Navigation.php b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Navigation.php
index 4e4544a..09faf94 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Navigation.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Block/Connect/Navigation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertChannelTextPresent.php b/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertChannelTextPresent.php
index 790489d..86b4d7d 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertChannelTextPresent.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertChannelTextPresent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertSuccessUpgrade.php b/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertSuccessUpgrade.php
index 57d038f..e2d4d0b 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertSuccessUpgrade.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Constraint/AssertSuccessUpgrade.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Fixture/Connect.xml b/dev/tests/functional/tests/app/Mage/Connect/Test/Fixture/Connect.xml
index a58e300..249b2ea 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Fixture/Connect.xml
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Fixture/Connect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/Page/ConnectManager.xml b/dev/tests/functional/tests/app/Mage/Connect/Test/Page/ConnectManager.xml
index cd9ea84..3862a34 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/Page/ConnectManager.xml
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/Page/ConnectManager.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.php b/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.php
index 59cf1fa..f2ef365 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.php
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.xml b/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.xml
index b53c542..6581518 100644
--- a/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Connect/Test/TestCase/UpgradeTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Block/Messages.php b/dev/tests/functional/tests/app/Mage/Core/Test/Block/Messages.php
index 7b636f9..827c61d 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Block/Messages.php
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Block/Messages.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/ConfigData.xml
index 985fd51..023e2ce 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/Date.php b/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/Date.php
index 9cc4496..04e97d2 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/Date.php
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Fixture/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/ConfigDataInterface.php b/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/ConfigDataInterface.php
index 1b77466..dadd51a 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/ConfigDataInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/ConfigDataInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/Curl.php b/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/Curl.php
index aa1c45e..bbde2b6 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Handler/ConfigData/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Core/Test/Repository/ConfigData.xml
index 6ebf4a8..a38c5fd 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/TestStep/SetupConfigurationStep.php b/dev/tests/functional/tests/app/Mage/Core/Test/TestStep/SetupConfigurationStep.php
index 3ee18b8..20d3003 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/TestStep/SetupConfigurationStep.php
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/TestStep/SetupConfigurationStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Core/Test/etc/curl/di.xml
index d1bde11..bb870fb 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Core/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Core/Test/etc/fixture.xml
index 48bb198..b43e359 100644
--- a/dev/tests/functional/tests/app/Mage/Core/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Core/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnCatalogPage.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnCatalogPage.php
index 70e4dda..6f7a04a 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnCatalogPage.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnCatalogPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnProductPage.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnProductPage.php
index 1e5928b..5a2ffb1 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolSuccessSaveMessage.php
index b53e56a..805272f 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Constraint/AssertCurrencySymbolSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Fixture/CurrencySymbolEntity.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Fixture/CurrencySymbolEntity.xml
index a793d12..0076f66 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Fixture/CurrencySymbolEntity.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Fixture/CurrencySymbolEntity.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencyIndex.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencyIndex.xml
index a6fb562..33cbb54 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencyIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencyIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencySymbolIndex.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencySymbolIndex.xml
index b776a65..779b664 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencySymbolIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Page/Adminhtml/SystemCurrencySymbolIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Repository/ConfigData.xml
index dabb795..95696f4 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.php
index 15705c8..24064c8 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.xml
index 2914dd0..364bc8d 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestCase/EditCurrencySymbolEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ApplyCurrencyInConfigStep.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ApplyCurrencyInConfigStep.php
index 67a49ba..522d589 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ApplyCurrencyInConfigStep.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ApplyCurrencyInConfigStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ImportCurrencyRatesStep.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ImportCurrencyRatesStep.php
index 8188fbc..eadd02f 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ImportCurrencyRatesStep.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/ImportCurrencyRatesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/SetupCurrencyRatesStep.php b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/SetupCurrencyRatesStep.php
index 8b91c28..492c2f4 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/SetupCurrencyRatesStep.php
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/TestStep/SetupCurrencyRatesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/etc/fixture.xml
index ba6e7ee..91bbddc 100644
--- a/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/CurrencySymbol/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/AdditionalAddress.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/AdditionalAddress.php
index 59544d2..7df10a4 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/AdditionalAddress.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/AdditionalAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/Book.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/Book.php
index 468800f..f191d95 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/Book.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Address/Book.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Dashboard/Info.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Dashboard/Info.php
index a5789d5..c5ea492 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Dashboard/Info.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Dashboard/Info.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Navigation.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Navigation.php
index 87ad948..3f83887 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Navigation.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Account/Navigation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.php
index d970b84..3dd4f01 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.xml
index 57bcf69..6e0b02c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Edit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Renderer.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Renderer.php
index 5e1a5e2..c47f46c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Renderer.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Address/Renderer.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.php
index ae1bc9a..833701f 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.xml
index ef65cb11..a055092 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/CustomerForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.php
index 633837a..3510221 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.xml
index 9cf8f6b..e6459c3 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Login.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.php
index 62da9e3..c77f62e 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.xml
index 6d8bb6f..1fa3e3c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Block/Form/Register.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedBackend.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedBackend.php
index bf6c75b..680d516 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedBackend.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedBackend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedFrontend.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedFrontend.php
index d534dfa..22e24ff 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertAddressDeletedFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertChangePasswordFailMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertChangePasswordFailMessage.php
index 0f67cee..24ec5a6 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertChangePasswordFailMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertChangePasswordFailMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerFailRegisterMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerFailRegisterMessage.php
index b69faf5..9286f10 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerFailRegisterMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerFailRegisterMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerForm.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerForm.php
index 1868bd8..ce28839 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerForm.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupAlreadyExists.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupAlreadyExists.php
index a171eb3..fbc1a1f 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupAlreadyExists.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupAlreadyExists.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupInGrid.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupInGrid.php
index d6d7348..df975e0 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupOnCustomerForm.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupOnCustomerForm.php
index 84e7bed..aa7af0f 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupOnCustomerForm.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupOnCustomerForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupSuccessSaveMessage.php
index 4618e7b..4f96be8 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerGroupSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInGrid.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInGrid.php
index e93879e..3306a98 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInfoSuccessSavedMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInfoSuccessSavedMessage.php
index ee92ad3..e14d2ba 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInfoSuccessSavedMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInfoSuccessSavedMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInvalidEmail.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInvalidEmail.php
index ec95570..9f68b4d 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInvalidEmail.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerInvalidEmail.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerPasswordChanged.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerPasswordChanged.php
index 97e3ef2..5cc5483 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerPasswordChanged.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerPasswordChanged.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessRegisterMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessRegisterMessage.php
index 93477a8..54fb6b6 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessRegisterMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessRegisterMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessSaveMessage.php
index 73acc43..dbeba70 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertCustomerSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertWrongPassConfirmationMessage.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertWrongPassConfirmationMessage.php
index 346bf76..e18f8e9 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertWrongPassConfirmationMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/AssertWrongPassConfirmationMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/FrontendActionsForCustomer.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/FrontendActionsForCustomer.php
index 99857d0..0b1302f 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/FrontendActionsForCustomer.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Constraint/FrontendActionsForCustomer.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Address.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Address.xml
index e80c47b..73e3489 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Address.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Address.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer.xml
index a79c241..b963799 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/Address.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/Address.php
index 3b806af..8fdc647 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/Address.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/GroupId.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/GroupId.php
index c374f8f..f87b123 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/GroupId.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/Customer/GroupId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup.xml
index 3be007f..b36c473 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup/TaxClassIds.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup/TaxClassIds.php
index 0ec56b4..6802a32 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup/TaxClassIds.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Fixture/CustomerGroup/TaxClassIds.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/Curl.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/Curl.php
index 3e06c8a..7b932af 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/CustomerInterface.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/CustomerInterface.php
index 93a6ae2..2bbd34a 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/CustomerInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/Customer/CustomerInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/Curl.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/Curl.php
index 1699471..d0d2c06 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/CustomerGroupInterface.php b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/CustomerGroupInterface.php
index f89cb5a..841fc5a 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/CustomerGroupInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Handler/CustomerGroup/CustomerGroupInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerEdit.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerEdit.xml
index 260028f..6a88b8c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupIndex.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupIndex.xml
index a3fa23e..94c3e7d 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupNew.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupNew.xml
index 07df506..71a3c75 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerGroupNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerIndex.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerIndex.xml
index 1b2ef1e..687fcdb 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerNew.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerNew.xml
index ae98c19..710ab0b 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/Adminhtml/CustomerNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountCreate.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountCreate.xml
index 8579755..ba456c8 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountCreate.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountCreate.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountEdit.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountEdit.xml
index 2597c11..7834bdc 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountIndex.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountIndex.xml
index efbe3f2..68b8c34 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogin.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogin.xml
index dfb1bf6..098ea23 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogin.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogin.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogout.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogout.xml
index 01d9008..cbda991 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogout.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAccountLogout.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAddress.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAddress.xml
index dc6e82b..e6f4f1b 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAddress.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Page/CustomerAddress.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Address.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Address.xml
index 372fec8..baecb6b 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Address.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Address.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/ConfigData.xml
index 5b1654b..36b0b16 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Customer.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Customer.xml
index be1d7ec..9db4cf7 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Customer.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/Customer.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/CustomerGroup.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/CustomerGroup.xml
index f80d849..9f97d8a 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/CustomerGroup.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/Repository/CustomerGroup.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.php
index abde00f..e9c0c61 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.xml
index e72d4dd..84428ee 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/ChangeCustomerPasswordTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.php
index 3bf6d1f..858d9f9 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.xml
index ba5229d..0ce9461 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerFromBackendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.php
index a519851..1f5e8df 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.xml
index 5f5b35e..9510bec 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateCustomerGroupEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.php
index eb54994..9509e07 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.xml
index b0bda14..ec995da 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/CreateExistingCustomerFrontendEntity.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.php
index 518088c..6d8327c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.xml
index a131474..c74ec68 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/DeleteCustomerAddressEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.php
index 3cdf945..a2bd735 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.xml
index b03f0c2..9001cf0 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestCase/RegisterCustomerFrontendEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateCustomerStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateCustomerStep.php
index cebb643..a236572 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateCustomerStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateCustomerStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateNewAddressesFixturesStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateNewAddressesFixturesStep.php
index 410f316..980c35e 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateNewAddressesFixturesStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateNewAddressesFixturesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateOrderFromCustomerAccountStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateOrderFromCustomerAccountStep.php
index 39ec7bf..3703f56 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateOrderFromCustomerAccountStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/CreateOrderFromCustomerAccountStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LoginCustomerOnFrontendStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LoginCustomerOnFrontendStep.php
index 8d4bc70..c5a13ce 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LoginCustomerOnFrontendStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LoginCustomerOnFrontendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LogoutCustomerStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LogoutCustomerStep.php
index 29f243a..e3a315f 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LogoutCustomerStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/LogoutCustomerStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/OpenCustomerOnBackendStep.php b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/OpenCustomerOnBackendStep.php
index 64f9179..763a13c 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/OpenCustomerOnBackendStep.php
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/TestStep/OpenCustomerOnBackendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/etc/curl/di.xml
index dc70271..4008348 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Customer/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Customer/Test/etc/fixture.xml
index 7ae965e..8c44cf1 100644
--- a/dev/tests/functional/tests/app/Mage/Customer/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Customer/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Directory/Test/Block/Currency/Switcher.php b/dev/tests/functional/tests/app/Mage/Directory/Test/Block/Currency/Switcher.php
index b55c109..5d79163 100644
--- a/dev/tests/functional/tests/app/Mage/Directory/Test/Block/Currency/Switcher.php
+++ b/dev/tests/functional/tests/app/Mage/Directory/Test/Block/Currency/Switcher.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
index 841db84..489a3fc 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.php
index ba89e10..b612130 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.xml
index 86d3da7..7e07cbb 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/LinkRow.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
index 8fd7108..d058eb5 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.xml
index b4485d3..28bfc78 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Links.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.php
index 478425c..314fe18 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.xml
index 56ae986..e622d6d 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/SampleRow.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
index 5d181c1..bbf837a 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.xml
index 5c63b2e..2cf8bd1 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/Edit/Tab/Downloadable/Samples.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
index 13c6c03..4d1a57f 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Adminhtml/Catalog/Product/ProductForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View.php
index 25f37e6..f2b988d 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Links.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Links.php
index 6f4e359..00bdc24 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Links.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Samples.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Samples.php
index c3f43f2..d84183c 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Samples.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Catalog/Product/View/Samples.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review.php
index 21327e3..205aec2 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items.php
index 0def8db..09737fa 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items/Product.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items/Product.php
index 8410631..0f18904 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Block/Checkout/Onepage/Review/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableLinksData.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableLinksData.php
index 0853315..55c48df 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableLinksData.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableLinksData.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductDetailsInWishlist.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductDetailsInWishlist.php
index 0bc6a30..bb427ee 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductDetailsInWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductDetailsInWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductForm.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductForm.php
index 7abbe35..f02e237 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductForm.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableProductForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableSamplesData.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableSamplesData.php
index 0b8eb9f..29a2c3e 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableSamplesData.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertDownloadableSamplesData.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingIncludingTax.php
index 7a809ca..36f3e05 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingTax.php
index a095028..94afe44 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableIncludingTax.php
index 07d305c..60ac0fa 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertOrderTaxOnBackendDownloadableIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingIncludingTax.php
index 5f48c7d..ea1aa96 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingTax.php
index 97921a7..6692ab6 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableIncludingTax.php
index 12bbd8b..bee4ebc 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxCalculationAfterCheckoutDownloadableIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingIncludingTax.php
index 3e16a83..d57fc38 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingTax.php
index 73ca781..1cddc9e 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableIncludingTax.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableIncludingTax.php
index 7be820e..d2a90dd 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesDownloadableIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/Cart/Item.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/Cart/Item.php
index 2c803c5..f65cd6f 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/Cart/Item.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/Cart/Item.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/DownloadableProduct.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/DownloadableProduct.xml
index ec541da..6574a79 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/DownloadableProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Fixture/DownloadableProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/Curl.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/Curl.php
index 2ffd44b..a4bcde5 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/DownloadableProductInterface.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/DownloadableProductInterface.php
index 3a6cd15..0e1c628 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/DownloadableProductInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Handler/DownloadableProductInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/CheckoutOnepage.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/CheckoutOnepage.xml
index 4d7be1a..33d50a9 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/CheckoutOnepage.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/CheckoutOnepage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/Product/CatalogProductView.xml
index 9ea990c..4caf098 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct.xml
index b72d876..5e5ad83 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/CheckoutData.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/CheckoutData.xml
index 32c428a..52534e1 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/CheckoutData.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/CheckoutData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/GroupPriceOptions.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/GroupPriceOptions.xml
index 04aef6c..358fc01 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/GroupPriceOptions.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/GroupPriceOptions.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Links.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Links.xml
index 8db1591..61e6574 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Links.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Links.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Price.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Price.xml
index 623b7ef..22420b1 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Price.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Price.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Samples.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Samples.xml
index fb737ac..314da18 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Samples.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/Repository/DownloadableProduct/Samples.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductToWishlistEntityTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductToWishlistEntityTest.xml
index 2e5a845..170b795 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductToWishlistEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductToWishlistEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
index c6fe168..1f7a272 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
index 7a4310c..c71bf40 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.php
index 7e24214..3f75f27 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.xml
index 551c061..6025386 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/CreateDownloadableProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/DeleteDownloadableProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/DeleteDownloadableProductEntityTest.xml
index 4ff0eb7..75a2ed5 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/DeleteDownloadableProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/DeleteDownloadableProductEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
index fbb01a5..5912b21 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.php b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.php
index d827818..7bc96da 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.php
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.xml
index 768ca67..a93767c 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/TestCase/TaxCalculationForDownloadableProductTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/curl/di.xml
index 0805ea6..0f6a4e8 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/fixture.xml
index 17a01ae..abb4c28 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/testcase.xml
index 0a39a2c..0499c92 100644
--- a/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Downloadable/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.php
index 832a75a..620f0fa 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.xml
index 163ff3c..ef03451 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.php
index 6c73c54..d013751 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.xml
index 4fd2254..d81047d 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Inline/GiftMessageForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/Items/View.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/Items/View.php
index 90c66b1..8516d09 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/Items/View.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/Items/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/View.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/View.php
index a111349..2725a13 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/View.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Block/Message/Order/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AbstractAssertGiftMessageOnFrontend.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AbstractAssertGiftMessageOnFrontend.php
index 708896a..07300a0 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AbstractAssertGiftMessageOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AbstractAssertGiftMessageOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrder.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrder.php
index 49fb01c..dd8c195 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrder.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrder.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrderItems.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrderItems.php
index 15b6246..13e2832 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrderItems.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Constraint/AssertGiftMessageInFrontendOrderItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage.xml
index f3f4fae..dbb2a5d 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage/Items.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage/Items.php
index d08b6aa..a3a7a2a 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage/Items.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Fixture/GiftMessage/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/CheckoutOnepage.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/CheckoutOnepage.xml
index a0b009d..297fe28 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/CheckoutOnepage.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/CheckoutOnepage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/OrderView.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/OrderView.xml
index 9b8cc99..d60862f 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/OrderView.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Page/OrderView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Repository/GiftMessage.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Repository/GiftMessage.xml
index d2eca8b..c199a36 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Repository/GiftMessage.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/Repository/GiftMessage.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.php
index f2f16c1..7fa0a04 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.xml
index d058567..55fedfc 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestCase/CheckoutWithGiftMessagesTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestStep/AddGiftMessageStep.php b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestStep/AddGiftMessageStep.php
index 18ba713..fe0ca13 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestStep/AddGiftMessageStep.php
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/TestStep/AddGiftMessageStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/fixture.xml
index 8726ddb..965efee 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/testcase.xml
index fc5926e..bece518 100644
--- a/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/GiftMessage/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.php
index 3b8c99d..2b0c6ec 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.xml
index 4d86172..0f2988a 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Configuration.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueBlock.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueBlock.php
index 84b2188..c3422da 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueBlock.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueBlock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueDownloadBlock.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueDownloadBlock.php
index 6a65b24..c318a36 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueDownloadBlock.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/ContinueDownloadBlock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/License.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/License.php
index 0f1d656..4864118 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/License.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/License.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.php
index a188424..d878d50 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.xml
index dd0266a..d4f989c 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Localization.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Main.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Main.php
index 148435c..ac7537d 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Main.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Main.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.php
index 7a8595f..eb9470e 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.xml
index 885ea74..a443c4e 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/PersonalInformation.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Welcome.php b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Welcome.php
index fe84bed..4997e55 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Block/Welcome.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Block/Welcome.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertAgreementTextPresent.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertAgreementTextPresent.php
index 93ba126..cde90cb 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertAgreementTextPresent.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertAgreementTextPresent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertCurrencySelected.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertCurrencySelected.php
index 6d63a21..008a4fc 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertCurrencySelected.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertCurrencySelected.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertDownloadCompleted.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertDownloadCompleted.php
index 85c323b..4584e0b 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertDownloadCompleted.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertDownloadCompleted.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertLanguageSelected.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertLanguageSelected.php
index bb5151e..ca99ccf 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertLanguageSelected.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertLanguageSelected.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertRewritesEnabled.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertRewritesEnabled.php
index 519302f..c34f057 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertRewritesEnabled.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertRewritesEnabled.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSecureUrlEnabled.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSecureUrlEnabled.php
index 027fcdc..3801330 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSecureUrlEnabled.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSecureUrlEnabled.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessDeploy.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessDeploy.php
index 1cb2d3e..7deaee0 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessDeploy.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessDeploy.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessInstall.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessInstall.php
index 383b9f5..dfadd97 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessInstall.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertSuccessInstall.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertWelcomeWizardTextPresent.php b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertWelcomeWizardTextPresent.php
index 7a6ddc6..360caff 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertWelcomeWizardTextPresent.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Constraint/AssertWelcomeWizardTextPresent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/Install.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/Install.xml
index a3cf405..f684af4 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/Install.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/Install.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/InstallLocale.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/InstallLocale.xml
index c30ba5e..7680063 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/InstallLocale.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Fixture/InstallLocale.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/Downloader.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/Downloader.xml
index 57656ab..6627457 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/Downloader.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/Downloader.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeploy.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeploy.xml
index b52e5ec..1960330 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeploy.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeploy.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeployEnd.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeployEnd.xml
index b3ec565..b11b5af 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeployEnd.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderDeployEnd.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderValidation.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderValidation.xml
index 535894c..9a6d898 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderValidation.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderValidation.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderWelcome.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderWelcome.xml
index 69a2e49..d8da7cf 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderWelcome.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/DownloaderWelcome.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/Install.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/Install.xml
index fb7b6d7..bda955b 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/Install.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/Install.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardAdministrator.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardAdministrator.xml
index 88b1719..20a3c48 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardAdministrator.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardAdministrator.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardConfig.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardConfig.xml
index 79dd6be..aaf65b1 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardConfig.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardConfig.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardEnd.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardEnd.xml
index efc9cfb..1f73093 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardEnd.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardEnd.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardLocale.xml b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardLocale.xml
index 8a70ddc..83bd724 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardLocale.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/Page/InstallWizardLocale.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.php
index 657a632..585d76b 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.xml
index 54c0a9c..3a70cd2 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderPart2Test.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.php
index f906750..791926a 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.xml
index 29138b7..d02c17c 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/DownloaderTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.php
index e06b931..22bfb00 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.xml
index 273625b..936b05d 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.php
index 078e0ec..4a5714e 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.xml
index fa2c839..421c823 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.php
index 4e5c259..9f74842 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.xml
index b3d2921..13257ef 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest3.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.php
index afcd3d2..8b61072 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.xml
index 2226af0..f9e42a4 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest4.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.php
index 2c07014..c43fef1 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.xml
index a880532..b249c44 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest5.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.php b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.php
index f3f50b9..32a3e5d 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.php
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.xml b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.xml
index 3e51c32..2ce9121 100644
--- a/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.xml
+++ b/dev/tests/functional/tests/app/Mage/Install/Test/TestCase/InstallTest6.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Newsletter/Test/Constraint/AssertCustomerIsSubscribedToNewsletter.php b/dev/tests/functional/tests/app/Mage/Newsletter/Test/Constraint/AssertCustomerIsSubscribedToNewsletter.php
index 7d1b1dd..a092db6 100644
--- a/dev/tests/functional/tests/app/Mage/Newsletter/Test/Constraint/AssertCustomerIsSubscribedToNewsletter.php
+++ b/dev/tests/functional/tests/app/Mage/Newsletter/Test/Constraint/AssertCustomerIsSubscribedToNewsletter.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Newsletter/Test/Page/Adminhtml/SubscriberIndex.xml b/dev/tests/functional/tests/app/Mage/Newsletter/Test/Page/Adminhtml/SubscriberIndex.xml
index d9c137b..ebb580c 100644
--- a/dev/tests/functional/tests/app/Mage/Newsletter/Test/Page/Adminhtml/SubscriberIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Newsletter/Test/Page/Adminhtml/SubscriberIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Footer.php b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Footer.php
index d42f7a4..7eb6239 100644
--- a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Footer.php
+++ b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Footer.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Header.php b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Header.php
index 63705f5..2612246 100644
--- a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Header.php
+++ b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Title.php b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Title.php
index 1623f07..c8d4f22 100644
--- a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Title.php
+++ b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Topmenu.php b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Topmenu.php
index 9606ab3..cf6a600 100644
--- a/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Topmenu.php
+++ b/dev/tests/functional/tests/app/Mage/Page/Test/Block/Html/Topmenu.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.php b/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.php
index 88b152d..d845157 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.php
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.xml
index af45b59..3ac7829 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Block/Form/Cc.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Constraint/Assert3DSecureVerificationFailed.php b/dev/tests/functional/tests/app/Mage/Payment/Test/Constraint/Assert3DSecureVerificationFailed.php
index 366bea7..84eee6f 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Constraint/Assert3DSecureVerificationFailed.php
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Constraint/Assert3DSecureVerificationFailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
index 712c019..2b605da 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
index a7769f5..40f968c 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/Cc.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/Cc.xml
index 131bcb5..6952b52 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/Cc.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/Cc.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
@@ -59,7 +59,7 @@
             <field name="cc_type" xsi:type="string">Visa</field>
             <field name="cc_number" xsi:type="string">%CC_VISA_4%</field>
             <field name="cc_exp_month" xsi:type="string">01 - January</field>
-            <field name="cc_exp_year" xsi:type="string">2017</field>
+            <field name="cc_exp_year" xsi:type="string">2020</field>
             <field name="cc_cid" xsi:type="string">123</field>
         </dataset>
         <dataset name="visa_3d_secure_negative">
@@ -79,21 +79,21 @@
             <field name="cc_type" xsi:type="string">Visa</field>
             <field name="cc_number" xsi:type="string">%CC_VISA_1%</field>
             <field name="cc_exp_month" xsi:type="string">01</field>
-            <field name="cc_exp_year" xsi:type="string">19</field>
+            <field name="cc_exp_year" xsi:type="string">2020</field>
             <field name="cc_cid" xsi:type="string">123</field>
         </dataset>
         <dataset name="hosted_pro_action_sale">
             <field name="cc_type" xsi:type="string">Visa</field>
             <field name="cc_number" xsi:type="string">%CC_VISA_2%</field>
             <field name="cc_exp_month" xsi:type="string">01</field>
-            <field name="cc_exp_year" xsi:type="string">19</field>
+            <field name="cc_exp_year" xsi:type="string">2020</field>
             <field name="cc_cid" xsi:type="string">123</field>
         </dataset>
         <dataset name="hosted_pro">
             <field name="cc_type" xsi:type="string">Visa</field>
             <field name="cc_number" xsi:type="string">%CC_VISA_2%</field>
             <field name="cc_exp_month" xsi:type="string">01</field>
-            <field name="cc_exp_year" xsi:type="string">19</field>
+            <field name="cc_exp_year" xsi:type="string">2020</field>
             <field name="cc_cid" xsi:type="string">123</field>
         </dataset>
     </repository>
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ConfigData.xml
index 5c39217..c4fb764 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ValidationPassword.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ValidationPassword.xml
index 8becf3c..7a1edbd 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ValidationPassword.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Repository/ValidationPassword.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/TestStep/Fill3DSecureCreditCardValidationStep.php b/dev/tests/functional/tests/app/Mage/Payment/Test/TestStep/Fill3DSecureCreditCardValidationStep.php
index a9464fc..d2a756c 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/TestStep/Fill3DSecureCreditCardValidationStep.php
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/TestStep/Fill3DSecureCreditCardValidationStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/AbstractReview.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/AbstractReview.php
index b9a86cf..785b649 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/AbstractReview.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/AbstractReview.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Addresses.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Addresses.php
index b09e0dc..4ebe4c8 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Addresses.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Addresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Review.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Review.php
index 9ae4419..1558a16 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Review.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Shortcut.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Shortcut.php
index 2083e29..a520a61 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Shortcut.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Express/Shortcut.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.php
index b20432a..c61a1fb 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.xml
index b2d32a4..1485742 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Form/Centinel.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.php
index 5502a8a..b64bb73 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.xml
index ccf6d33..a83c6f7 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Hosted/Pro/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.php
index d7b80ec..c651d79 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -123,4 +123,18 @@ class Login extends Form
         $this->waitForElementNotVisible($this->loader);
         return parent::fill($customer, $this->switchOnPayPalFrame($element));
     }
+
+    /**
+     * Check is block active
+     *
+     * @return bool
+     */
+    public function isBlockActive()
+    {
+        if ($this->browser->find($this->mapping['password']['selector'])->isVisible()) {
+            return true;
+        }
+
+        return false;
+    }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.xml
index 1ecf16e..3ab100a 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Login.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.php
index 608bcfc..593a52f 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 namespace Mage\Paypal\Test\Block;
@@ -63,16 +63,18 @@ class NewLogin extends Login
      */
     public function fill(FixtureInterface $customer, Element $element = null)
     {
+        $fullMapping = $this->mapping;
+
         $this->waitForElementNotVisible($this->loader);
-        $this->clickToElement($this->startLoginButton);
         $this->_rootElement = $this->browser->find('.main');
+
+        $this->overrideMapping($this->getFormSplitMapping('email'));
         parent::fill($customer, $this->switchOnPayPalFrame($element));
 
-        $path = glob(MTF_TESTS_PATH . preg_replace('/^\w+\/\w+/', '*/*', str_replace('\\', '/', get_class($this))) . 'Password.xml');
-        $this->mapping = $this->mapper->read(reset($path))['fields'];
-        if (!$this->browser->find($this->mapping['password']['selector'])->isVisible()) {
+        if (!$this->browser->find($fullMapping['password']['selector'])->isVisible()) {
             $this->clickToElement($this->nextButton);
         }
+        $this->overrideMapping($this->getFormSplitMapping('password'));
         parent::fill($customer, $this->switchOnPayPalFrame($element));
 
         return $this;
@@ -83,4 +85,44 @@ class NewLogin extends Login
         $rootElement = $this->findRootElement();
         $rootElement->find($selector)->click();
     }
+
+    /**
+     * Check is block active
+     *
+     * @return bool
+     */
+    public function isBlockActive()
+    {
+        if (!$this->browser->find($this->mapping['password']['selector'])->isVisible()) {
+            return true;
+        }
+
+        return false;
+    }
+
+    /**
+     * Override mapping to the form
+     *
+     * @param array $mapping
+     * @return void
+     */
+    protected function overrideMapping(array $mapping)
+    {
+        $this->mapping = $mapping;
+    }
+
+    /**
+     * Get mapping to the form by key
+     *
+     * @return array
+     */
+    protected function getFormSplitMapping($key)
+    {
+        $mapping = $this->getFormMapping();
+        if (empty($mapping)) {
+            return [];
+        }
+
+        return isset($mapping['fields'][$key]) ? [$key => $mapping['fields'][$key]] : [];
+    }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.xml
index d882053..5b2d2a6 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLogin.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
@@ -30,5 +30,8 @@
         <email>
             <selector>[name='login_email']</selector>
         </email>
+        <password>
+            <selector>[name='login_password']</selector>
+        </password>
     </fields>
 </mapping>
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLoginPassword.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLoginPassword.xml
index da4fe6a..9e5745e 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLoginPassword.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/NewLoginPassword.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldAddresses.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldAddresses.php
index b4cb7da..34f9de8 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldAddresses.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldAddresses.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.php
index bfeda4f..dfa3d0d 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.xml
index dbfb068..5b2d2a6 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldLogin.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldReview.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldReview.php
index 59a6c91..d9d65b0 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldReview.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/OldReview.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.php
index 6aa63a4..e4bf572 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.xml
index 09a012b..5e1d9cd 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Advanced/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.php
index cbd166b..231b168 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.xml
index 09a012b..5e1d9cd 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Payflow/Link/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Product/View.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Product/View.php
index 9f7f50a..7f5194b 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Review.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Review.php
index d5de897..4fce319 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Review.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Block/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Constraint/AssertTransaction.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Constraint/AssertTransaction.php
index 1353785..44db85d 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Constraint/AssertTransaction.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Constraint/AssertTransaction.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalAddress.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalAddress.xml
index 2e484be..7581c5b 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalAddress.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalAddress.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer.xml
index cdc39b3..c6671a4 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer/Address.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer/Address.php
index c987597..0b18dc3 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer/Address.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Fixture/PaypalCustomer/Address.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Paypal.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Paypal.php
index eced359..2c4a421 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Paypal.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Paypal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -71,7 +71,7 @@ class Paypal extends Page
         ],
         'newLoginBlock' => [
             'class' => 'Mage\Paypal\Test\Block\NewLogin',
-            'locator' => '#fullSignup',
+            'locator' => '#login',
             'strategy' => 'css selector',
         ],
     ];
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/PaypalExpressReview.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/PaypalExpressReview.xml
index 6629cbf..32e4055 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/PaypalExpressReview.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/PaypalExpressReview.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Product/CatalogProductView.xml
index 4e43134..912b044 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/ConfigData.xml
index bde6dbd..9bcf2dd 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalAddress.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalAddress.xml
index d6ee0c9..b2d315a 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalAddress.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalAddress.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalCustomer.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalCustomer.xml
index ba664b3..6e3b387 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalCustomer.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/Repository/PaypalCustomer.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForOnlinePaymentMethodsTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForOnlinePaymentMethodsTest.php
index bc72d4b..65d65a7 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForOnlinePaymentMethodsTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForOnlinePaymentMethodsTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForPaypalExpressCheckoutTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForPaypalExpressCheckoutTest.php
index 01a45d2..ad45e38 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForPaypalExpressCheckoutTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/AbstractCreateSalesEntityForPaypalExpressCheckoutTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.php
index 445edca..7d17645 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.xml
index e768dc9..fc28c3c 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateInvoiceForPaypalExpressCheckoutTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
index 538c0dc..3a8b04b 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
index 211d9f0..f18d89a 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
index 45dc57e..e7ff925 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
index ec6437d..7ed8733 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOfflineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
index 63c2eb7..9a26626 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
index c26b346..0f8fa18 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
index 763a781..06a3e90 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
index a2805a0..a986211 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineInvoiceForOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.php
index 24f5449..a16a79a 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.xml
index faf8eee..a09189d 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.php
index 8c411fc..6752fa1 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.xml
index 00a3f3e..afc9620 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.php
index 7087849..d410e2f 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.xml
index 2d249c5..09bf0e6 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOnlineRefundForPaypalExpressCheckoutTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.php
index 02df99a..0376e80 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
index 08b6608..46b15ed 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWith3DSecureTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.php
index 09a797e..9256f79 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.xml
index 98fbc26..15d9266 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.php
index ff27619..079a2d9 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
index c9979e0..e038bff 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithOnlinePaymentsMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.php
index db09cb4..d92d104 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.xml
index bf78e34..e238ac8 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateOrderWithPayPalStandardTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.php
index c76e711..4fcca19 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.xml
index 5dac878..a04a897 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.php
index c98fe3a..acbc9ac 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.xml
index 4b3c57d..53584b2 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForOnlinePaymentMethodsWithoutIFrameTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.php
index 72b1ce9..3f8b8c6 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.xml
index 5a36088..1b048dd 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/CreateShipmentForPaypalExpressCheckoutTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.php
index 1621c9b..da976e5 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.xml
index 83ec65d..5eaaa08 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonFromProductPageTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.php
index 5ad7dc5..9159159 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.xml
index 5fa1e9b..6f40944 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestCase/TestCreationForExpressCheckoutWithinPayPalButtonTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalFromProductPageStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalFromProductPageStep.php
index 94fac25..0a8f186 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalFromProductPageStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalFromProductPageStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalStep.php
index 3f9368f..983b049 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/CheckoutWithPayPalStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/ContinuePayPalCheckoutStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/ContinuePayPalCheckoutStep.php
index b34a80c..c52268d 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/ContinuePayPalCheckoutStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/ContinuePayPalCheckoutStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/FillCreditCardInIFrameStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/FillCreditCardInIFrameStep.php
index 1e91155..c95554e 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/FillCreditCardInIFrameStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/FillCreditCardInIFrameStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/LoginToPayPalStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/LoginToPayPalStep.php
index 57479fc..106a60b 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/LoginToPayPalStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/LoginToPayPalStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -110,13 +110,13 @@ class LoginToPayPalStep implements TestStepInterface
     /**
      * Returns actual login block by selector
      *
-     * @return \Mage\Paypal\Test\Block\Login|\Mage\Paypal\Test\Block\OldLogin|\Mage\Paypal\Test\Page\NewLogin
+     * @return \Mage\Paypal\Test\Block\NewLogin|\Mage\Paypal\Test\Block\Login|\Mage\Paypal\Test\Block\OldLogin
      */
     protected function getActualBlock()
     {
-        if ($this->paypalPage->getNewLoginBlock()->isVisible()) {
+        if ($this->paypalPage->getNewLoginBlock()->isBlockActive()) {
             $returnBlock = $this->paypalPage->getNewLoginBlock();
-        } elseif ($this->paypalPage->getLoginBlock()->isVisible()) {
+        } elseif ($this->paypalPage->getLoginBlock()->isBlockActive()) {
             $returnBlock = $this->paypalPage->getLoginBlock();
         } else {
             $returnBlock = $this->paypalPage->getOldLoginBlock();
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/PlaceOrderStep.php b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/PlaceOrderStep.php
index 7aa3011..58bb8a3 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/PlaceOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/TestStep/PlaceOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Paypal/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Paypal/Test/etc/testcase.xml
index 20443cd..4d1af6f 100644
--- a/dev/tests/functional/tests/app/Mage/Paypal/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Paypal/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingInProductPage.php b/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingInProductPage.php
index 3bf713b..dc371ff 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingInProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingInProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingOnReviewPage.php b/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingOnReviewPage.php
index 3a38a82..6a78f1b 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingOnReviewPage.php
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Constraint/AssertProductRatingOnReviewPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating.xml b/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating.xml
index 17d75d8..c25925d 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating.xml
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating/Stores.php b/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating/Stores.php
index 4ae631a..f2cce6b 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating/Stores.php
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Fixture/Rating/Stores.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/Curl.php b/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/Curl.php
index 8de9b32..bf28aeb 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/RatingInterface.php b/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/RatingInterface.php
index c1bc3c9..b828f94 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/RatingInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Handler/RatingInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingEdit.xml b/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingEdit.xml
index df37c9b..b55b5eb 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingIndex.xml b/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingIndex.xml
index e22296f..1267bf5 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Page/Adminhtml/RatingIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/Repository/Rating.xml b/dev/tests/functional/tests/app/Mage/Rating/Test/Repository/Rating.xml
index 9d09566..df0ee93 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/Repository/Rating.xml
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/Repository/Rating.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Rating/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Rating/Test/etc/curl/di.xml
index 1789518..673cdd3 100644
--- a/dev/tests/functional/tests/app/Mage/Rating/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Rating/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View.php b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View.php
index a92e09b..f38f014 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.php b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.php
index 63b5eb0..66fa288 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.xml
index 9f8c1a9..072ee1d 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Review.php b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Review.php
index 48d2e59..7f56a77 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Review.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Block/Product/View/Review.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewForm.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewForm.php
index bc64989..4030754 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewForm.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewInGrid.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewInGrid.php
index 533695a..5b70e3a 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewIsAbsentOnProductPage.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewIsAbsentOnProductPage.php
index 77e210b..2a51f54 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewIsAbsentOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewIsAbsentOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewOnProductPage.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewOnProductPage.php
index 906480e..c333933 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertProductReviewOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewCreationSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewCreationSuccessMessage.php
index 564377e..13158fd 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewCreationSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewCreationSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewLinksIsPresentOnProductPage.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewLinksIsPresentOnProductPage.php
index ee2f823..c206149 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewLinksIsPresentOnProductPage.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewLinksIsPresentOnProductPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewSuccessSaveMessage.php
index 050550e..b7acf1f 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertReviewSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertSetApprovedProductReview.php b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertSetApprovedProductReview.php
index c2ddca6..ff90613 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertSetApprovedProductReview.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Constraint/AssertSetApprovedProductReview.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review.xml
index 85fbf41..58ba8e0 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/EntityId.php b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/EntityId.php
index a1ea6f0..239eb1d 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/EntityId.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/EntityId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/Ratings.php b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/Ratings.php
index 41660ef..83d0ff1 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/Ratings.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Fixture/Review/Ratings.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReview.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReview.xml
index d2c2435..65d36d3 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReview.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReview.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReviewEdit.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReviewEdit.xml
index 3f1179a..3e79aa8 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReviewEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Adminhtml/CatalogProductReviewEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/CatalogProductView.xml
index 3f94cb6..76a7c37 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/ReviewProductList.xml b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/ReviewProductList.xml
index 55b393a..8764779 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/ReviewProductList.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/Page/Product/ReviewProductList.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.php b/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.php
index 5c4f023..f6707ad 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.xml b/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.xml
index 32e8e84..9a3c677 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/TestCase/CreateProductReviewFrontendEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/AddFrontendReviewStep.php b/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/AddFrontendReviewStep.php
index 19c77ec..6a255bd 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/AddFrontendReviewStep.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/AddFrontendReviewStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/DeleteAllRatingsStep.php b/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/DeleteAllRatingsStep.php
index 4c09713..db8489b 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/DeleteAllRatingsStep.php
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/TestStep/DeleteAllRatingsStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Review/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Review/Test/etc/testcase.xml
index 6923ce3..590cd8c 100644
--- a/dev/tests/functional/tests/app/Mage/Review/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Review/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractProductView.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractProductView.php
index a933dfd..a1ce3fb 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractProductView.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractProductView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities.php
index cb9aea1..008c8d1 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity.php
index 1a49236..2f9f884 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity/Items/Product.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity/Items/Product.php
index e7bf238..425112f 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/AbstractSalesEntities/SalesEntity/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos.php
index e6ed968..6aed8ba 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo.php
index bbe480d..1d7c6cc 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items.php
index c94ba71..6883723 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items/Product.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items/Product.php
index 8899144..850b6ff 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/CreditMemos/CreditMemo/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/History.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/History.php
index 37897d1..f77bfc1 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/History.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/History.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices.php
index 51b2a08..d147160 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice.php
index 02fc375..3a65c18 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items.php
index 81e5997..bca3541 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items/Product.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items/Product.php
index be60264..88fc66e 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/Invoices/Invoice/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/OrderPrint/View.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/OrderPrint/View.php
index 2f94708..efa89e9 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/OrderPrint/View.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/OrderPrint/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View.php
index dfff4d0..09588de 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/ActionsToolbar.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/ActionsToolbar.php
index 67b7b6b..36255f0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/ActionsToolbar.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/ActionsToolbar.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items.php
index a5c8bb3..82e8c27 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items/Product.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items/Product.php
index 91a6b24..c042862 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Totals.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Totals.php
index de5a876..bc813a2 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Totals.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Order/View/Totals.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.php
index 0d76bec..078c1de 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.xml
index d5cbe4b..31ac283 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Block/Widget/Guest/Form.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertItems.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertItems.php
index d646ad1..ea78aae 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertItems.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertNoButtonOnOrderPage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertNoButtonOnOrderPage.php
index cf5ebde..65226cd 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertNoButtonOnOrderPage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertNoButtonOnOrderPage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertOrdersAddress.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertOrdersAddress.php
index 7e25001..d51f7ec 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertOrdersAddress.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertOrdersAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSales.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSales.php
index 1076ba4..d88df37 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSales.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSales.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInGrid.php
index 369d446..7036a89 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityGrid.php
index c7250b0..a6cad4c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityTab.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityTab.php
index 9bfc698..30c59a5 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityTab.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityInSalesEntityTab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityItemsOnFrontend.php
index 960abd2..ea15a8b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AbstractAssertSalesEntityItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertConfigurableProductInItemsOrderedGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertConfigurableProductInItemsOrderedGrid.php
index 266b047..71e4da9 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertConfigurableProductInItemsOrderedGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertConfigurableProductInItemsOrderedGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItems.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItems.php
index 09e0a28..8157dc9 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItems.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItemsOnFrontend.php
index f547eeb..4d4a9d8 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoConfigurableItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosGrid.php
index ca7c0a8..8c85147 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosTab.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosTab.php
index e733d14..c4b444b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosTab.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoInCreditMemosTab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItems.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItems.php
index 4c458e1..538c836 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItems.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItemsOnFrontend.php
index 416b5b6..f953e9f 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoSuccessCreateMessage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoSuccessCreateMessage.php
index b203c21..2dd2192 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoSuccessCreateMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertCreditMemoSuccessCreateMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItems.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItems.php
index 5eb9c2c..90f3723 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItems.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItemsOnFrontend.php
index 69ada7a..6a73920 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceConfigurableItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesGrid.php
index 4e56606..045a90c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesTab.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesTab.php
index c3118cf..dfd6262 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesTab.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceInInvoicesTab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItems.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItems.php
index dd6e748..5abc1c7 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItems.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItemsOnFrontend.php
index b8fd299..cfa769a 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceSuccessCreateMessage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceSuccessCreateMessage.php
index 5268fc4..1552619 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceSuccessCreateMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceSuccessCreateMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceWithShipmentSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceWithShipmentSuccessMessage.php
index b4a5937..6931420 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceWithShipmentSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertInvoiceWithShipmentSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertItemsOrderedBlockIsEmpty.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertItemsOrderedBlockIsEmpty.php
index 801a79c..82ef40f 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertItemsOrderedBlockIsEmpty.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertItemsOrderedBlockIsEmpty.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoCreditMemoButton.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoCreditMemoButton.php
index 3342f0f..7034e21 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoCreditMemoButton.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoCreditMemoButton.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoInvoiceButton.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoInvoiceButton.php
index 57abdbc..5e81e67 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoInvoiceButton.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertNoInvoiceButton.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderButtonsAvailable.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderButtonsAvailable.php
index da4106d..7d1420d 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderButtonsAvailable.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderButtonsAvailable.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCancelSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCancelSuccessMessage.php
index 2202404..b2a8ad6 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCancelSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCancelSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCreateSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCreateSuccessMessage.php
index f26459f..779dc95 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCreateSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderCreateSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderGrandTotal.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderGrandTotal.php
index 2c8f765..c1a4bdb 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderGrandTotal.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderGrandTotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGrid.php
index 3a92eb7..1cd9c1a 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGridOnFrontend.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGridOnFrontend.php
index 23f8895..f1e89a0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGridOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderInOrdersGridOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderStatusIsCorrect.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderStatusIsCorrect.php
index ab4b3cd..d0be283 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderStatusIsCorrect.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrderStatusIsCorrect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersBillingAddress.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersBillingAddress.php
index ac46852..fe9b630 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersBillingAddress.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersBillingAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersCount.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersCount.php
index 371eb64..b429ce4 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersCount.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersCount.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersGrandTotal.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersGrandTotal.php
index 9c19d6d..6128e85 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersGrandTotal.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersGrandTotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersShippingAddress.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersShippingAddress.php
index c3acd44..ccfac14 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersShippingAddress.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertOrdersShippingAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductInItemsOrderedGrid.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductInItemsOrderedGrid.php
index 5c63310..98752f6 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductInItemsOrderedGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductInItemsOrderedGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductsVisibilityInItemsOrderedBlock.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductsVisibilityInItemsOrderedBlock.php
index 02f00ba..d783081 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductsVisibilityInItemsOrderedBlock.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertProductsVisibilityInItemsOrderedBlock.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertReorderedOrderStatusIsCorrect.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertReorderedOrderStatusIsCorrect.php
index 43e18ad..468022f 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertReorderedOrderStatusIsCorrect.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertReorderedOrderStatusIsCorrect.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderBillingAddress.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderBillingAddress.php
index a881f21..7a243a1 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderBillingAddress.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderBillingAddress.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderGrandTotal.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderGrandTotal.php
index d2d9610..295e065 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderGrandTotal.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderGrandTotal.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderPaymentMethod.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderPaymentMethod.php
index be6fc88..759e763 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderPaymentMethod.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderPaymentMethod.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderProducts.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderProducts.php
index fe74b19..1062d12 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderProducts.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/AssertSalesPrintOrderProducts.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/FrontendActionsForSalesAssert.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/FrontendActionsForSalesAssert.php
index 4c382c7..c9de6ea 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/FrontendActionsForSalesAssert.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Constraint/FrontendActionsForSalesAssert.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order.xml
index 8619130..3bf0f7b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/BillingAddressId.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/BillingAddressId.php
index 09c36fb..d889373 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/BillingAddressId.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/BillingAddressId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/CustomerId.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/CustomerId.php
index 7ea6d95..298294c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/CustomerId.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/CustomerId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/EntityId.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/EntityId.php
index ed7204a..80ec259 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/EntityId.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/EntityId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/StoreId.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/StoreId.php
index e163d59..203f1b7 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/StoreId.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Fixture/Order/StoreId.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/Curl.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/Curl.php
index 53a9b3a..02cd0a0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/OrderInterface.php b/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/OrderInterface.php
index ff3d8a0..2a4b9ff 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/OrderInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Handler/Order/OrderInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemo.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemo.xml
index c72596d..d88a3ea 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemo.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemo.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemoView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemoView.xml
index d778eb8..109a9e3 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemoView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesCreditMemoView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoice.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoice.xml
index ac3aa95..33ea392 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoice.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoice.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoiceView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoiceView.xml
index b97946b..27548a8 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoiceView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesInvoiceView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreateIndex.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreateIndex.xml
index f038ebf..ac460bc 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreateIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreateIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreditMemoNew.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreditMemoNew.xml
index 17bcf58..3258bcb 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreditMemoNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderCreditMemoNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderIndex.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderIndex.xml
index 6b1eb24..e77b10e 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderInvoiceNew.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderInvoiceNew.xml
index 0472892..418a1ed 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderInvoiceNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderInvoiceNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderView.xml
index 525f391..9f643bc 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/Adminhtml/SalesOrderView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/CreditMemoView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/CreditMemoView.xml
index 4f3e351..f5fd484 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/CreditMemoView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/CreditMemoView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/InvoiceView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/InvoiceView.xml
index 1063d19..bc0b1e8 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/InvoiceView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/InvoiceView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderHistory.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderHistory.xml
index db2692b..3e171ac 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderHistory.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderHistory.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderView.xml
index d9c2fab..f877020 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/OrderView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestForm.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestForm.xml
index 3f35dff..fb709f7 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestPrint.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestPrint.xml
index 3f27d83..a793c81 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestPrint.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestPrint.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestView.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestView.xml
index 677d2bf..981c8ed 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestView.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Page/SalesGuestView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/ConfigData.xml
index 174eb23..49f381b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/Order.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/Order.xml
index 1eaa87e..ca34a98 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/Order.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/Repository/Order.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.php
index c1024c1..8d5e88e 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.xml
index 6a7e3c2..3177f6f 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CancelCreatedOrderTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.php
index 0fe3efa..7f1b9a8 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.xml
index 1cd2074..25c5ede 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendCustomerPageTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.php
index d8c9799..4bb697b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.xml
index dcfa4fd..5dce14a 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/CreateOrderFromBackendWithinOfflinePaymentMethodsTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.php
index e5c97fd..f495fe4 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.xml
index eee24f8..1abbc52 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/MoveShoppingCartProductsOnOrderPageTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.php
index ee49e39..4a0fa41 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.xml
index f72f92b..68da6ae 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/PrintOrderFrontendGuestTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.php
index d1e010d..e01ea2b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.xml
index efa1518..cfc8a64 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestCase/ReorderOrderEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateRefundStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateRefundStep.php
index b741852..1ba6f82 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateRefundStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateRefundStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateSalesEntityStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateSalesEntityStep.php
index b547f51..9a5fba9 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateSalesEntityStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AbstractCreateSalesEntityStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AddProductsStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AddProductsStep.php
index 43b2ebb..2dba6c6 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AddProductsStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/AddProductsStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateInvoiceStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateInvoiceStep.php
index fe86344..f2139e5 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateInvoiceStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateInvoiceStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderStep.php
index db6d20e..3c7880b 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderViaCurlStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderViaCurlStep.php
index 8ae3ad2..137f86c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderViaCurlStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateNewOrderViaCurlStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOfflineRefundStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOfflineRefundStep.php
index 2a026d8..8643767 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOfflineRefundStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOfflineRefundStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOnlineRefundStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOnlineRefundStep.php
index c63a09b..9e65738 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOnlineRefundStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/CreateOnlineRefundStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/FillBillingAddressStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/FillBillingAddressStep.php
index e319bd1..9dd887c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/FillBillingAddressStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/FillBillingAddressStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/MoveProductsFromShoppingCartSidebarStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/MoveProductsFromShoppingCartSidebarStep.php
index b963e7a..75faac0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/MoveProductsFromShoppingCartSidebarStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/MoveProductsFromShoppingCartSidebarStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenOrderStep.php
index aabe7c7..4eb27ab 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrderOnFrontendForGuestStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrderOnFrontendForGuestStep.php
index 4664968..f8fbe3c 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrderOnFrontendForGuestStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrderOnFrontendForGuestStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrdersStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrdersStep.php
index 3af5aa0..21df892 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrdersStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/OpenSalesOrdersStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/PrintOrderOnFrontendStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/PrintOrderOnFrontendStep.php
index 98021c7..a1fd405 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/PrintOrderOnFrontendStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/PrintOrderOnFrontendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/ReorderOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/ReorderOrderStep.php
index 113db4e..492baf0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/ReorderOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/ReorderOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectCustomerOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectCustomerOrderStep.php
index 4c4bc66..31237c4 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectCustomerOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectCustomerOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectPaymentMethodForOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectPaymentMethodForOrderStep.php
index c9ecc67..7269aff 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectPaymentMethodForOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectPaymentMethodForOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectShippingMethodForOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectShippingMethodForOrderStep.php
index f0980c3..e207fc2 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectShippingMethodForOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectShippingMethodForOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectStoreOnCreateOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectStoreOnCreateOrderStep.php
index 3a21fa2..8637b04 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectStoreOnCreateOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SelectStoreOnCreateOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SubmitOrderStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SubmitOrderStep.php
index 5b2b961..5383bc0 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SubmitOrderStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/SubmitOrderStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/UpdateProductsDataStep.php b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/UpdateProductsDataStep.php
index 329db1d..de9dbac 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/UpdateProductsDataStep.php
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/TestStep/UpdateProductsDataStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/curl/di.xml
index 22881cc..4e99f8e 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/fixture.xml
index ee96c12..2d71724 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/testcase.xml
index 5d948c5..f5f2991 100644
--- a/dev/tests/functional/tests/app/Mage/Sales/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Sales/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AbstractCartPriceRuleApplying.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AbstractCartPriceRuleApplying.php
index f6ad085..45c09f1 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AbstractCartPriceRuleApplying.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AbstractCartPriceRuleApplying.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsApplied.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsApplied.php
index ef75bef..1e1e3b9 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsApplied.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsNotApplied.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsNotApplied.php
index 98e7580..38d0f07 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsNotApplied.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleConditionIsNotApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleForm.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleForm.php
index 1517674..7a83dbb 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleForm.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleFreeShippingIsApplied.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleFreeShippingIsApplied.php
index fcaa954..48b598a 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleFreeShippingIsApplied.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleFreeShippingIsApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsAppliedToShipping.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsAppliedToShipping.php
index de24443..a7b3479 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsAppliedToShipping.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsAppliedToShipping.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsNotPresentedInGrid.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsNotPresentedInGrid.php
index 7300f3c..bf3cfda 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsNotPresentedInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleIsNotPresentedInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessDeleteMessage.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessDeleteMessage.php
index f64970b..027b253 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessSaveMessage.php
index fa3b79e..aa77b82 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Constraint/AssertCartPriceRuleSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule.xml
index dc182e3..503e78c 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule/WebsiteIds.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule/WebsiteIds.php
index c4a838b..14c1e93 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule/WebsiteIds.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Fixture/SalesRule/WebsiteIds.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/Curl.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/Curl.php
index 8266638..f1542bf 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/SalesRuleInterface.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/SalesRuleInterface.php
index aa98335..fbc401d 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/SalesRuleInterface.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Handler/SalesRule/SalesRuleInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteEdit.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteEdit.xml
index e7ffefc..4bbd216 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteIndex.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteIndex.xml
index 6d0cb04..ea6e03c 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteNew.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteNew.xml
index 60037c2..8ee4cfa 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteNew.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Page/Adminhtml/PromoQuoteNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Repository/SalesRule.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Repository/SalesRule.xml
index b6b4cb2..8160c96 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/Repository/SalesRule.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/Repository/SalesRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.php
index 2df044d..3b67852 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.xml
index cc5fb19..8f46888 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/CreateSalesRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.php
index 30fac2e..7736d49 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.xml
index 32a0e33..3ea38f8 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/DeleteSalesRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/ReorderOrderEntityTest.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/ReorderOrderEntityTest.xml
index c7c88c8..27efad6 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/ReorderOrderEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestCase/ReorderOrderEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnBackendStep.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnBackendStep.php
index e9f511c..fc52af0 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnBackendStep.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnBackendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnFrontendStep.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnFrontendStep.php
index 70f568d..bf90473 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnFrontendStep.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/ApplySalesRuleOnFrontendStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/CreateSalesRuleStep.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/CreateSalesRuleStep.php
index 66f2a46..4ebbf23 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/CreateSalesRuleStep.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/CreateSalesRuleStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/DeleteAllSalesRuleStep.php b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/DeleteAllSalesRuleStep.php
index 3f13f5c..7c4a323 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/DeleteAllSalesRuleStep.php
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/TestStep/DeleteAllSalesRuleStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/curl/di.xml
index b1645a2..e3eee0a 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/fixture.xml
index 72881c5..bc7b5e3 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/testcase.xml
index 1a520c4..cd22bdc 100644
--- a/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/SalesRule/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments.php
index 302eae6..15a7d07 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment.php
index 499482b..056ae47 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items.php
index 214404f..ef39ffc 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items/Product.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items/Product.php
index 5c6a9cc..da55d26 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Block/Sales/Order/Shipments/Shipment/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertNoShipButton.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertNoShipButton.php
index 87beea6..8a9645d 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertNoShipButton.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertNoShipButton.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItems.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItems.php
index d8ee358..49e15ce 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItems.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItemsOnFrontend.php
index ca3ead9..58b1d83 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentConfigurableItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsGrid.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsGrid.php
index 482b536..a06e51b 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsTab.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsTab.php
index 91e3161..cacd437 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsTab.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentInShipmentsTab.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItems.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItems.php
index bbe8834..1fa5ef8 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItems.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItems.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItemsOnFrontend.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItemsOnFrontend.php
index 6bc0783..8effa2d 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItemsOnFrontend.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentItemsOnFrontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentSuccessCreateMessage.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentSuccessCreateMessage.php
index ac5ca9e..4f967ca 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentSuccessCreateMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShipmentSuccessCreateMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShippingMethodOnPrintOrder.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShippingMethodOnPrintOrder.php
index 640012e..0a8adb4 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShippingMethodOnPrintOrder.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Constraint/AssertShippingMethodOnPrintOrder.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesOrderShipmentNew.xml b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesOrderShipmentNew.xml
index 2d052aa..0f5522a 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesOrderShipmentNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesOrderShipmentNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipment.xml b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipment.xml
index 99c35a6..e543335 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipment.xml
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipment.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipmentView.xml b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipmentView.xml
index 1b70a74..12d5370 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipmentView.xml
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/Adminhtml/SalesShipmentView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/ShipmentView.xml b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/ShipmentView.xml
index fa31889..0eded29 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/ShipmentView.xml
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Page/ShipmentView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Shipping/Test/Repository/ConfigData.xml
index ce8e078..962fbdf 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Shipping/Test/TestStep/CreateShipmentStep.php b/dev/tests/functional/tests/app/Mage/Shipping/Test/TestStep/CreateShipmentStep.php
index af1bd76..b7538c0 100644
--- a/dev/tests/functional/tests/app/Mage/Shipping/Test/TestStep/CreateShipmentStep.php
+++ b/dev/tests/functional/tests/app/Mage/Shipping/Test/TestStep/CreateShipmentStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapContent.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapContent.php
index e815de7..faa6538 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapContent.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapContent.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailFolderSaveMessage.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailFolderSaveMessage.php
index f2968c2..35cba8b 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailFolderSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailFolderSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailPathSaveMessage.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailPathSaveMessage.php
index 0e2a455..654e5b3 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailPathSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapFailPathSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapInGrid.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapInGrid.php
index 4c9a97e7..8e292b8 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveAndGenerateMessages.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveAndGenerateMessages.php
index 65ada18..691fe75 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveAndGenerateMessages.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveAndGenerateMessages.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveMessage.php
index 9d8586e..56876da 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Constraint/AssertSitemapSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Fixture/Sitemap.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Fixture/Sitemap.xml
index 07d79a0..a56cf7c 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Fixture/Sitemap.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Fixture/Sitemap.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapIndex.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapIndex.xml
index aab29a5..49cea29 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapNew.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapNew.xml
index ab72c2a..fef3227 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Page/Adminhtml/SitemapNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Repository/Sitemap.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Repository/Sitemap.xml
index 2c92982..95ba90c 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/Repository/Sitemap.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/Repository/Sitemap.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.php
index c323032..744caf8 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.xml
index faf4cd5..d26832b 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/CreateSitemapEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.php b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.php
index 28583c7..6b91cbe 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.xml
index 0158170..591e290 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/TestCase/GenerateSitemapEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Sitemap/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Sitemap/Test/etc/fixture.xml
index 53ac9c9..34f4e22 100644
--- a/dev/tests/functional/tests/app/Mage/Sitemap/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Sitemap/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertOrderTaxOnBackend.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertOrderTaxOnBackend.php
index f1a5da9..fe7b71c 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertOrderTaxOnBackend.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertOrderTaxOnBackend.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTax.php
index 859b0e7..91fd20e 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxCalculationAfterCheckout.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxCalculationAfterCheckout.php
index 3a6ba70..56f27b2e 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxCalculationAfterCheckout.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxCalculationAfterCheckout.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxRuleIsAppliedToAllPrices.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxRuleIsAppliedToAllPrices.php
index 5738a50..2b31e78 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxRuleIsAppliedToAllPrices.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxRuleIsAppliedToAllPrices.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxWithCrossBorderApplying.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxWithCrossBorderApplying.php
index 801f54f..e4c976e 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxWithCrossBorderApplying.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AbstractAssertTaxWithCrossBorderApplying.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingIncludingTax.php
index 3bee9df..b68a3d7 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingTax.php
index ef9aa02..7c71f49 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendIncludingTax.php
index be8f836..6e6f938 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertOrderTaxOnBackendIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingIncludingTax.php
index ac2485e..811d4dc 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingTax.php
index 2137555..1eac679 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutIncludingTax.php
index 8c85515..6704202 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxCalculationAfterCheckoutIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateForm.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateForm.php
index 0eae45c..e797b47 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateForm.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInGrid.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInGrid.php
index dd71a49..4c1a725 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInTaxRule.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInTaxRule.php
index 9a0f32b..7ddb26e 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInTaxRule.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateInTaxRule.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateIsInCorrectRange.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateIsInCorrectRange.php
index 21099ac..e2baeb8 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateIsInCorrectRange.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateIsInCorrectRange.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInGrid.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInGrid.php
index 0703aa5..97ff90f 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInTaxRule.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInTaxRule.php
index ed9440f..9e8deb8 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInTaxRule.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateNotInTaxRule.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessDeleteMessage.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessDeleteMessage.php
index f92dcb0..7c1653c 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessDeleteMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessDeleteMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessSaveMessage.php
index 051cbd6..73a3118 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRateSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleForm.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleForm.php
index 2ec9384..0309f1d 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleForm.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleInGrid.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleInGrid.php
index e07a07c..6108b78 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingIncludingTax.php
index af28db2..ac1dde1 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingTax.php
index 526b929..3968dd7 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesExcludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesIncludingTax.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesIncludingTax.php
index 70ae53c..81baab1 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesIncludingTax.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleIsAppliedToAllPricesIncludingTax.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleSuccessSaveMessage.php
index 6355fd8..97d83d9 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxRuleSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderApplied.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderApplied.php
index 4c90eab..333f472 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderApplied.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderNotApplied.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderNotApplied.php
index 7541aaf..81fd8f8 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderNotApplied.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Constraint/AssertTaxWithCrossBorderNotApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxClass.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxClass.xml
index e72162b..db2ae40 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxClass.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxClass.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRate.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRate.xml
index 6b7cd32..914888f 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRate.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRate.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule.xml
index 95d0903..a04ba03 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxClass.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxClass.php
index 4a9b79e..a2fb37e 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxClass.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxClass.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxRate.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxRate.php
index a1a953a..1cc1532 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxRate.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Fixture/TaxRule/TaxRate.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/Curl.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/Curl.php
index 066852b..6387d2f 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/TaxClassInterface.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/TaxClassInterface.php
index 2b8a282..7bbd25a 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/TaxClassInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxClass/TaxClassInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/Curl.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/Curl.php
index 07e3e92..51396b1 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/TaxRateInterface.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/TaxRateInterface.php
index 69d6423..01b147d 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/TaxRateInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRate/TaxRateInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/Curl.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/Curl.php
index 6a10437..dd4f6ac 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/TaxRuleInterface.php b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/TaxRuleInterface.php
index 85d07b1..0ce2500 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/TaxRuleInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Handler/TaxRule/TaxRuleInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateEdit.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateEdit.xml
index cc76a64..8984f39 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateIndex.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateIndex.xml
index a40bf83..23470fe 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateNew.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateNew.xml
index 3d4c581..2b21c43 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRateNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleIndex.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleIndex.xml
index e6ebbfc..685a1d4 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleNew.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleNew.xml
index af7f846..1a88fc8 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Page/Adminhtml/TaxRuleNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/ConfigData.xml
index d2acf2e..b387ecf 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxClass.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxClass.xml
index a36cd67..63e6684 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxClass.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxClass.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRate.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRate.xml
index 8592c04..5531a39 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRate.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRate.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRule.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRule.xml
index 6b13cd6..c1fc65a 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRule.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/Repository/TaxRule.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.php
index 1fdd184..08a0512 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.xml
index 6a4af4e..590b786 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/AutomaticTaxApplyingBasedOnVatIdTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.php
index cc0ddd7..5bc519b 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.xml
index 315cdbe..34f76c5 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRateEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.php
index 45a1287..c6984cc 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.xml
index e24e49b..630639a 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/CreateTaxRuleEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.php
index 6ccdd2c..26b4fcf 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.xml
index 835a6b8..d0557f2 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/DeleteTaxRateEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.php
index 33e9ba4..18c281d 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.xml
index 8a8e224..931a2d6 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxCalculationTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.php
index 43a949e..5c3edcb 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.xml
index c5518d1..7f6684d 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestCase/TaxWithCrossBorderTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/CreateTaxRuleStep.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/CreateTaxRuleStep.php
index 402aec6..7c8b882 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/CreateTaxRuleStep.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/CreateTaxRuleStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/DeleteAllTaxRulesStep.php b/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/DeleteAllTaxRulesStep.php
index 52e7b5d..3463386 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/DeleteAllTaxRulesStep.php
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/TestStep/DeleteAllTaxRulesStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/curl/di.xml
index 52fbf35..bfee362 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/fixture.xml
index 344ea28..afd5479 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/testcase.xml
index 10c1236..4df4947 100644
--- a/dev/tests/functional/tests/app/Mage/Tax/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Tax/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Links.php b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Links.php
index 1a91367b..79495d9 100644
--- a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Links.php
+++ b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Links.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Title.php b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Title.php
index ffc7c46..ab78d5e 100644
--- a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Title.php
+++ b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/Title.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/TopLinks.php b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/TopLinks.php
index 523ba64..9a58bef 100644
--- a/dev/tests/functional/tests/app/Mage/Theme/Test/Block/TopLinks.php
+++ b/dev/tests/functional/tests/app/Mage/Theme/Test/Block/TopLinks.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart.php
index 87d06fc..0e56324 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart/CartItem.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart/CartItem.php
index 74af28e..fca55a7 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart/CartItem.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Cart/CartItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ListProduct.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ListProduct.php
index d04d479..1da9ebd 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ListProduct.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ListProduct.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/Price.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/Price.php
index 24ca18e..c260287 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/Price.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/Price.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ProductList/ProductItem.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ProductList/ProductItem.php
index 02b9d3d..3247678 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ProductList/ProductItem.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/ProductList/ProductItem.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/View.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/View.php
index f21f73b..9d09e64 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/View.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Block/Product/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Constraint/AssertFptApplied.php b/dev/tests/functional/tests/app/Mage/Weee/Test/Constraint/AssertFptApplied.php
index c34de07..12d2809 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Constraint/AssertFptApplied.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Constraint/AssertFptApplied.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Category/CatalogCategoryView.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Category/CatalogCategoryView.xml
index 541a0d8..c039b5e 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Category/CatalogCategoryView.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Category/CatalogCategoryView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/CheckoutCart.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/CheckoutCart.xml
index bd82b44..cf8d76b 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/CheckoutCart.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/CheckoutCart.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Product/CatalogProductView.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Product/CatalogProductView.xml
index c3b9bcb..5057dcb 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Product/CatalogProductView.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Page/Product/CatalogProductView.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/Repository/ConfigData.xml
index d961b18..0c40aad 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/Repository/ConfigData.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.php b/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.php
index e60b69a..b74eb59 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.php
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.xml
index f0deec9..1e91b85 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/TestCase/CreateTaxWithFptTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Weee/Test/etc/testcase.xml b/dev/tests/functional/tests/app/Mage/Weee/Test/etc/testcase.xml
index 00dc90b..3357a0b 100644
--- a/dev/tests/functional/tests/app/Mage/Weee/Test/etc/testcase.xml
+++ b/dev/tests/functional/tests/app/Mage/Weee/Test/etc/testcase.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/FormPageActions.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/FormPageActions.php
index 6991036..1e5eebe 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/FormPageActions.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/FormPageActions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/ChosenOption.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/ChosenOption.php
index 1cf5b0a..911814d 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/ChosenOption.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/ChosenOption.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdates.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdates.php
index cfd067e..500b8e2 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdates.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdates.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.php
index b552f1b..0b6ea0e 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.xml
index 99634c3..5d2805a 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/GenericPages.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/LayoutForm.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/LayoutForm.php
index d0f9d68..064a3ae 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/LayoutForm.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/LayoutForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Product/Grid.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Product/Grid.php
index ac16424..0d733a1 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Product/Grid.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Product/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.php
index 8218d7b..65bc0e7 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.xml
index 75ad196..be57ffe 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/LayoutUpdatesType/Products.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
index d28b4e8..37920d1 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/Settings.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptions.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptions.php
index 9e224d2..fdb37e9 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptionsType/WidgetOptionsForm.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptionsType/WidgetOptionsForm.php
index 88cc053..b63ab4f 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptionsType/WidgetOptionsForm.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/Tab/WidgetOptionsType/WidgetOptionsForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.php
index 6ab272b..86fe324 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.xml
index 342592e..6fa2281 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/Instance/Edit/WidgetForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/WidgetGrid.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/WidgetGrid.php
index 88d583b..423a55d 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/WidgetGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/Widget/WidgetGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.php
index 554250d..784ead0 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.xml
index 0022b25..278de2f 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/Adminhtml/WidgetForm.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/WidgetView.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/WidgetView.php
index 8f76e35..fa057b9 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Block/WidgetView.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Block/WidgetView.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetInGrid.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetInGrid.php
index d506852..5e38de2 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetInGrid.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetInGrid.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetSuccessSaveMessage.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetSuccessSaveMessage.php
index 7d169d4..a033705 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetSuccessSaveMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Constraint/AssertWidgetSuccessSaveMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget.xml
index edf9156..ff32b68 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/LayoutUpdates.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/LayoutUpdates.php
index 9131056..0d7b748 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/LayoutUpdates.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/LayoutUpdates.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/StoreIds.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/StoreIds.php
index ad12178..c06c83d 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/StoreIds.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/StoreIds.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/WidgetOptions.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/WidgetOptions.php
index 3916243..2e01716 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/WidgetOptions.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Fixture/Widget/WidgetOptions.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/Curl.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/Curl.php
index 5e680d2..804fb1f 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/Curl.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/WidgetInterface.php b/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/WidgetInterface.php
index 6844495..76f4f66 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/WidgetInterface.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Handler/Widget/WidgetInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceEdit.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceEdit.xml
index 4d9733b..00fcf7a 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceEdit.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceEdit.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceIndex.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceIndex.xml
index 30dd651..e63eef0 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceNew.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceNew.xml
index 07f6159..fd52e1b 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceNew.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/Adminhtml/WidgetInstanceNew.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/CmsIndex.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/CmsIndex.xml
index 120ddc8..19b2a18 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Page/CmsIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Page/CmsIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget.xml
index f8d1717..f0220bd 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget/LayoutUpdates.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget/LayoutUpdates.xml
index 5f909bc..d9fd5ae 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget/LayoutUpdates.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/Repository/Widget/LayoutUpdates.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/TestCase/AbstractCreateWidgetEntityTest.php b/dev/tests/functional/tests/app/Mage/Widget/Test/TestCase/AbstractCreateWidgetEntityTest.php
index ecfefd3..d480e9c 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/TestCase/AbstractCreateWidgetEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/TestCase/AbstractCreateWidgetEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/TestStep/DeleteAllWidgetsStep.php b/dev/tests/functional/tests/app/Mage/Widget/Test/TestStep/DeleteAllWidgetsStep.php
index fb4f04e..7c6e42f 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/TestStep/DeleteAllWidgetsStep.php
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/TestStep/DeleteAllWidgetsStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/etc/curl/di.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/etc/curl/di.xml
index 88e790a..1c585db 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/etc/curl/di.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/etc/curl/di.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Widget/Test/etc/fixture.xml b/dev/tests/functional/tests/app/Mage/Widget/Test/etc/fixture.xml
index c3578a5..323738f 100644
--- a/dev/tests/functional/tests/app/Mage/Widget/Test/etc/fixture.xml
+++ b/dev/tests/functional/tests/app/Mage/Widget/Test/etc/fixture.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist.php
index 260378d..ac1fc8f 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items.php
index 8639b36..66547be 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.php
index f9307c3..fd05c8b 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.xml
index 657dade..a05feeb 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Block/Customer/Wishlist/Items/Product.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductToWishlistSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductToWishlistSuccessMessage.php
index 5e4e7fc..776be3d 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductToWishlistSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductToWishlistSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductsToWishlistSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductsToWishlistSuccessMessage.php
index 8c0fe60..f03520a 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductsToWishlistSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertAddProductsToWishlistSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertMoveProductToWishlistSuccessMessage.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertMoveProductToWishlistSuccessMessage.php
index 3576b09..5b614e7 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertMoveProductToWishlistSuccessMessage.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertMoveProductToWishlistSuccessMessage.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductDetailsInWishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductDetailsInWishlist.php
index beb9d66..29664f0 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductDetailsInWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductDetailsInWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInCustomerBackendWishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInCustomerBackendWishlist.php
index 9ce7a8a..fac14d8 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInCustomerBackendWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInCustomerBackendWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInWishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInWishlist.php
index 2d2e9a6..b7705b5 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductIsPresentInWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsArePresentInCustomerBackendWishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsArePresentInCustomerBackendWishlist.php
index e4c47d5..b692866 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsArePresentInCustomerBackendWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsArePresentInCustomerBackendWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsIsAbsentInWishlist.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsIsAbsentInWishlist.php
index 431a9cd..be3024e 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsIsAbsentInWishlist.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertProductsIsAbsentInWishlist.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertWishlistIsEmpty.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertWishlistIsEmpty.php
index af50e21..c94d9dc 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertWishlistIsEmpty.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Constraint/AssertWishlistIsEmpty.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Page/WishlistIndex.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Page/WishlistIndex.xml
index 13a05c5..e099044 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/Page/WishlistIndex.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/Page/WishlistIndex.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AbstractWishlistTest.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AbstractWishlistTest.php
index 929cbce..1e918ac 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AbstractWishlistTest.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AbstractWishlistTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.php
index ae503ca..3d3bfed 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.xml
index 1204b7a..ca9c72f 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductToWishlistEntityTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.php
index 54abcf7..54d0ca3 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
index 1c19e9a..a653b35 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/AddProductsToCartFromCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.php
index d0c2884..9127ad4 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
index dc2bd27..5b12fa4 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/ConfigureProductInCustomerWishlistOnFrontendTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.php
index e20b85a..3cd1546 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
index 50977fe..c5d5d2f 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestCase/MoveProductFromShoppingCartToWishlistTest.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
  -->
diff --git a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestStep/AddProductsToWishlistStep.php b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestStep/AddProductsToWishlistStep.php
index 137c236..2155b74 100644
--- a/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestStep/AddProductsToWishlistStep.php
+++ b/dev/tests/functional/tests/app/Mage/Wishlist/Test/TestStep/AddProductsToWishlistStep.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests.php b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests.php
index cf8c820..2227276 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests.php
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/3rdParty.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/3rdParty.xml
index f755f63..b174fd4 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/3rdParty.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/3rdParty.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenet.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenet.xml
index e4956de..4486321 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenet.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenet.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenetdp.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenetdp.xml
index 86699d7..5dbeb80 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenetdp.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/authorizenetdp.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/basic.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/basic.xml
index 17ac8f4..c1c814a 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/basic.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/basic.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download.xml
index 3c5c34e..694450a 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download2.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download2.xml
index d48bf7e..0db96b3 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download2.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_download2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_main.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_main.xml
index 0a36c12..cbc388e 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_main.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/ce_main.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce.xml
index 36636e3..3ffd540 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce2.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce2.xml
index f411ce2..7c657fe 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce2.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce3.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce3.xml
index a9a2e43..071674e 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce3.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce3.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce4.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce4.xml
index d6ef590..d30eda9 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce4.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce4.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce5.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce5.xml
index c2f3d5a..9b9fe28 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce5.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce5.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce6.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce6.xml
index a656805..71dff0f 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce6.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/installationce6.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal.xml
index f8a2d06..7885f33 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal1.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal1.xml
index 0f150ef..d3e3225 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal1.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypal1.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaladvanced.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaladvanced.xml
index 207fedd..5b25f51 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaladvanced.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaladvanced.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaldirect.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaldirect.xml
index 53f73fe..ad6f268 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaldirect.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypaldirect.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbutton.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbutton.xml
index cf6612c..36ca86e 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbutton.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbutton.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbuttonproduct.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbuttonproduct.xml
index 51c64d3..5b8ea64 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbuttonproduct.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecbuttonproduct.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecinvoice.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecinvoice.xml
index 0f150ef..d3e3225 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecinvoice.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecinvoice.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecrefund.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecrefund.xml
index 5bfdf9b..dca7123 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecrefund.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecrefund.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecshipment.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecshipment.xml
index 4bc252d..b1bb222 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecshipment.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalecshipment.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalhostedsolution.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalhostedsolution.xml
index a2b8264..f443c96 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalhostedsolution.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalhostedsolution.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowlink.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowlink.xml
index f7177cd..7258a4c 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowlink.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowlink.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowpro.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowpro.xml
index 16d039e..17cc325 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowpro.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpayflowpro.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpaymentspro.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpaymentspro.xml
index 2f2069f..9e0cdab 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpaymentspro.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalpaymentspro.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalstandard.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalstandard.xml
index 461e5b7..1eb4aa1 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalstandard.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/paypalstandard.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite1.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite1.xml
index 8aae48c..64e7d91 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite1.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite1.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite2.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite2.xml
index 3833002..d36180a 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite2.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite2.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite3.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite3.xml
index a36bcdb..45996f3 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite3.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/suite3.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/upgradeconnectce.xml b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/upgradeconnectce.xml
index 27c8fc9..85e6987 100644
--- a/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/upgradeconnectce.xml
+++ b/dev/tests/functional/testsuites/Magento/Mtf/TestSuite/InjectableTests/upgradeconnectce.xml
@@ -21,7 +21,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/dev/tests/functional/utils/bootstrap.php b/dev/tests/functional/utils/bootstrap.php
index dd005a3..35a1b98 100644
--- a/dev/tests/functional/utils/bootstrap.php
+++ b/dev/tests/functional/utils/bootstrap.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 umask(0);
diff --git a/dev/tests/functional/utils/generate.php b/dev/tests/functional/utils/generate.php
index ca801e5..576f5c8 100644
--- a/dev/tests/functional/utils/generate.php
+++ b/dev/tests/functional/utils/generate.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 require_once dirname(__FILE__) . '/' . 'bootstrap.php';
diff --git a/dev/tests/functional/utils/generate/fixture.php b/dev/tests/functional/utils/generate/fixture.php
index bc8d8d0..95f73d2 100644
--- a/dev/tests/functional/utils/generate/fixture.php
+++ b/dev/tests/functional/utils/generate/fixture.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 require_once dirname(__DIR__) . '/' . 'bootstrap.php';
diff --git a/dev/tests/functional/utils/generate/handler.php b/dev/tests/functional/utils/generate/handler.php
index baaf031..78f341b 100644
--- a/dev/tests/functional/utils/generate/handler.php
+++ b/dev/tests/functional/utils/generate/handler.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 require_once dirname(__DIR__) . '/' . 'bootstrap.php';
diff --git a/dev/tests/functional/utils/generate/page.php b/dev/tests/functional/utils/generate/page.php
index 21e8ad5..55a5c84 100644
--- a/dev/tests/functional/utils/generate/page.php
+++ b/dev/tests/functional/utils/generate/page.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 require_once dirname(__DIR__) . '/' . 'bootstrap.php';
diff --git a/dev/tests/functional/utils/generate/repository.php b/dev/tests/functional/utils/generate/repository.php
index f1692f3..5a7c918 100644
--- a/dev/tests/functional/utils/generate/repository.php
+++ b/dev/tests/functional/utils/generate/repository.php
@@ -20,7 +20,7 @@
  *
  * @category    Tests
  * @package     Tests_Functional
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 require_once dirname(__DIR__) . '/' . 'bootstrap.php';
diff --git a/downloader/Maged/BruteForce/Validator.php b/downloader/Maged/BruteForce/Validator.php
index 5d2d57c..2602015 100644
--- a/downloader/Maged/BruteForce/Validator.php
+++ b/downloader/Maged/BruteForce/Validator.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Maged_BruteForce_Validator
diff --git a/downloader/Maged/Connect.php b/downloader/Maged/Connect.php
index 4bd17f9..819ef5b 100644
--- a/downloader/Maged/Connect.php
+++ b/downloader/Maged/Connect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Connect/Frontend.php b/downloader/Maged/Connect/Frontend.php
index 0b13cbd..1264b9a 100644
--- a/downloader/Maged/Connect/Frontend.php
+++ b/downloader/Maged/Connect/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Controller.php b/downloader/Maged/Controller.php
index bcfb008..6707ccd 100644
--- a/downloader/Maged/Controller.php
+++ b/downloader/Maged/Controller.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -1074,7 +1074,7 @@ final class Maged_Controller
             'major'     => '1',
             'minor'     => '9',
             'revision'  => '4',
-            'patch'     => '0',
+            'patch'     => '1',
             'stability' => '',
             'number'    => '',
         );
diff --git a/downloader/Maged/Exception.php b/downloader/Maged/Exception.php
index 592e292..691e3ea 100644
--- a/downloader/Maged/Exception.php
+++ b/downloader/Maged/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model.php b/downloader/Maged/Model.php
index 87b7263..b7de1aa 100644
--- a/downloader/Maged/Model.php
+++ b/downloader/Maged/Model.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/BruteForce/ConfigIni.php b/downloader/Maged/Model/BruteForce/ConfigIni.php
index cd17331..92883fe 100644
--- a/downloader/Maged/Model/BruteForce/ConfigIni.php
+++ b/downloader/Maged/Model/BruteForce/ConfigIni.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Maged_Model_BruteForce_ConfigIni implements Maged_Model_BruteForce_ModelConfigInterface
diff --git a/downloader/Maged/Model/BruteForce/ModelConfigInterface.php b/downloader/Maged/Model/BruteForce/ModelConfigInterface.php
index bf212ea..23030b2 100644
--- a/downloader/Maged/Model/BruteForce/ModelConfigInterface.php
+++ b/downloader/Maged/Model/BruteForce/ModelConfigInterface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/BruteForce/Resource/FTP.php b/downloader/Maged/Model/BruteForce/Resource/FTP.php
index c752293..a34bc35 100644
--- a/downloader/Maged/Model/BruteForce/Resource/FTP.php
+++ b/downloader/Maged/Model/BruteForce/Resource/FTP.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Maged_Model_BruteForce_Resource_FTP implements Maged_Model_BruteForce_Resource_ResourceInterface
diff --git a/downloader/Maged/Model/BruteForce/Resource/File.php b/downloader/Maged/Model/BruteForce/Resource/File.php
index 55b3d7d..5a1af95 100644
--- a/downloader/Maged/Model/BruteForce/Resource/File.php
+++ b/downloader/Maged/Model/BruteForce/Resource/File.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Maged_Model_BruteForce_Resource_File implements Maged_Model_BruteForce_Resource_ResourceInterface
diff --git a/downloader/Maged/Model/BruteForce/Resource/ResourceInterface.php b/downloader/Maged/Model/BruteForce/Resource/ResourceInterface.php
index 5cd11f0..2e2107b 100644
--- a/downloader/Maged/Model/BruteForce/Resource/ResourceInterface.php
+++ b/downloader/Maged/Model/BruteForce/Resource/ResourceInterface.php
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 interface Maged_Model_BruteForce_Resource_ResourceInterface
diff --git a/downloader/Maged/Model/Config.php b/downloader/Maged/Model/Config.php
index 5fccea1..b035ba2 100644
--- a/downloader/Maged/Model/Config.php
+++ b/downloader/Maged/Model/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Config/Abstract.php b/downloader/Maged/Model/Config/Abstract.php
index c0c9d4f..6eca1d3 100644
--- a/downloader/Maged/Model/Config/Abstract.php
+++ b/downloader/Maged/Model/Config/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Config/Community.php b/downloader/Maged/Model/Config/Community.php
index dd45a89..5ceb935 100644
--- a/downloader/Maged/Model/Config/Community.php
+++ b/downloader/Maged/Model/Config/Community.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Config/Interface.php b/downloader/Maged/Model/Config/Interface.php
index 984c940..1be1850 100644
--- a/downloader/Maged/Model/Config/Interface.php
+++ b/downloader/Maged/Model/Config/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Connect.php b/downloader/Maged/Model/Connect.php
index bc16a42..a2849ae 100644
--- a/downloader/Maged/Model/Connect.php
+++ b/downloader/Maged/Model/Connect.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Connect/Request.php b/downloader/Maged/Model/Connect/Request.php
index 623b42c..d031d62 100644
--- a/downloader/Maged/Model/Connect/Request.php
+++ b/downloader/Maged/Model/Connect/Request.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Dowloader.php b/downloader/Maged/Model/Dowloader.php
index c023a89..da421f9 100644
--- a/downloader/Maged/Model/Dowloader.php
+++ b/downloader/Maged/Model/Dowloader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/Model/Session.php b/downloader/Maged/Model/Session.php
index 27fa01b..3701491 100644
--- a/downloader/Maged/Model/Session.php
+++ b/downloader/Maged/Model/Session.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/Maged/View.php b/downloader/Maged/View.php
index a396189..8420794 100644
--- a/downloader/Maged/View.php
+++ b/downloader/Maged/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/index.php b/downloader/index.php
index 468d264..e977ce1 100644
--- a/downloader/index.php
+++ b/downloader/index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive.php b/downloader/lib/Mage/Archive.php
index fe4d28e..eb767ce 100644
--- a/downloader/lib/Mage/Archive.php
+++ b/downloader/lib/Mage/Archive.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Abstract.php b/downloader/lib/Mage/Archive/Abstract.php
index 4baaf25..3ff62a9 100644
--- a/downloader/lib/Mage/Archive/Abstract.php
+++ b/downloader/lib/Mage/Archive/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Bz.php b/downloader/lib/Mage/Archive/Bz.php
index 7dd9a24..22fea0b 100644
--- a/downloader/lib/Mage/Archive/Bz.php
+++ b/downloader/lib/Mage/Archive/Bz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Gz.php b/downloader/lib/Mage/Archive/Gz.php
index 6a09c0a..0d298f2 100644
--- a/downloader/lib/Mage/Archive/Gz.php
+++ b/downloader/lib/Mage/Archive/Gz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Helper/File.php b/downloader/lib/Mage/Archive/Helper/File.php
index 5b524b6..974016b 100644
--- a/downloader/lib/Mage/Archive/Helper/File.php
+++ b/downloader/lib/Mage/Archive/Helper/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Helper/File/Bz.php b/downloader/lib/Mage/Archive/Helper/File/Bz.php
index 9879e73..f75aac1 100644
--- a/downloader/lib/Mage/Archive/Helper/File/Bz.php
+++ b/downloader/lib/Mage/Archive/Helper/File/Bz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Helper/File/Gz.php b/downloader/lib/Mage/Archive/Helper/File/Gz.php
index eb10943..866188a 100644
--- a/downloader/lib/Mage/Archive/Helper/File/Gz.php
+++ b/downloader/lib/Mage/Archive/Helper/File/Gz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Interface.php b/downloader/lib/Mage/Archive/Interface.php
index d3428d3..379d0a5 100644
--- a/downloader/lib/Mage/Archive/Interface.php
+++ b/downloader/lib/Mage/Archive/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Archive/Tar.php b/downloader/lib/Mage/Archive/Tar.php
index 8b344ce..4b9421a 100644
--- a/downloader/lib/Mage/Archive/Tar.php
+++ b/downloader/lib/Mage/Archive/Tar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Autoload/Simple.php b/downloader/lib/Mage/Autoload/Simple.php
index e757afb..9a9485d 100644
--- a/downloader/lib/Mage/Autoload/Simple.php
+++ b/downloader/lib/Mage/Autoload/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup.php b/downloader/lib/Mage/Backup.php
index 2d7d45a..4f3bd57 100644
--- a/downloader/lib/Mage/Backup.php
+++ b/downloader/lib/Mage/Backup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Abstract.php b/downloader/lib/Mage/Backup/Abstract.php
index 184deda..cd2fc18 100644
--- a/downloader/lib/Mage/Backup/Abstract.php
+++ b/downloader/lib/Mage/Backup/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Archive/Tar.php b/downloader/lib/Mage/Backup/Archive/Tar.php
index becc8bc..ba973aa 100644
--- a/downloader/lib/Mage/Backup/Archive/Tar.php
+++ b/downloader/lib/Mage/Backup/Archive/Tar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Db.php b/downloader/lib/Mage/Backup/Db.php
index 75554c8..0587c65 100644
--- a/downloader/lib/Mage/Backup/Db.php
+++ b/downloader/lib/Mage/Backup/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception.php b/downloader/lib/Mage/Backup/Exception.php
index 86e75cc..ffced85 100644
--- a/downloader/lib/Mage/Backup/Exception.php
+++ b/downloader/lib/Mage/Backup/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception/CantLoadSnapshot.php b/downloader/lib/Mage/Backup/Exception/CantLoadSnapshot.php
index ef73223..2e7c723 100644
--- a/downloader/lib/Mage/Backup/Exception/CantLoadSnapshot.php
+++ b/downloader/lib/Mage/Backup/Exception/CantLoadSnapshot.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception/FtpConnectionFailed.php b/downloader/lib/Mage/Backup/Exception/FtpConnectionFailed.php
index d986a4b..fbfdf2c 100644
--- a/downloader/lib/Mage/Backup/Exception/FtpConnectionFailed.php
+++ b/downloader/lib/Mage/Backup/Exception/FtpConnectionFailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception/FtpValidationFailed.php b/downloader/lib/Mage/Backup/Exception/FtpValidationFailed.php
index 7cf0198..90e86f2 100644
--- a/downloader/lib/Mage/Backup/Exception/FtpValidationFailed.php
+++ b/downloader/lib/Mage/Backup/Exception/FtpValidationFailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php b/downloader/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
index 3d3858a..2cf5aa9 100644
--- a/downloader/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
+++ b/downloader/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Exception/NotEnoughPermissions.php b/downloader/lib/Mage/Backup/Exception/NotEnoughPermissions.php
index 6f4a9ed..a642caf 100644
--- a/downloader/lib/Mage/Backup/Exception/NotEnoughPermissions.php
+++ b/downloader/lib/Mage/Backup/Exception/NotEnoughPermissions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem.php b/downloader/lib/Mage/Backup/Filesystem.php
index 464e267..d88ce3d 100644
--- a/downloader/lib/Mage/Backup/Filesystem.php
+++ b/downloader/lib/Mage/Backup/Filesystem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Helper.php b/downloader/lib/Mage/Backup/Filesystem/Helper.php
index 644107f..9bc55fd 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Helper.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Helper.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Iterator/File.php b/downloader/lib/Mage/Backup/Filesystem/Iterator/File.php
index 3763ea2..1066bf9 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Iterator/File.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Iterator/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Iterator/Filter.php b/downloader/lib/Mage/Backup/Filesystem/Iterator/Filter.php
index 3f91b89..e4658cd 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Iterator/Filter.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Iterator/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Rollback/Abstract.php b/downloader/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
index ee420bb..bfaf3ef 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Rollback/Fs.php b/downloader/lib/Mage/Backup/Filesystem/Rollback/Fs.php
index db301b0..28d4e7b 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Rollback/Fs.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Rollback/Fs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Filesystem/Rollback/Ftp.php b/downloader/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
index 999fdb1..310d482 100644
--- a/downloader/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
+++ b/downloader/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Interface.php b/downloader/lib/Mage/Backup/Interface.php
index 9cc46e8..233160f 100644
--- a/downloader/lib/Mage/Backup/Interface.php
+++ b/downloader/lib/Mage/Backup/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Media.php b/downloader/lib/Mage/Backup/Media.php
index fb2deeb..cb2b474 100644
--- a/downloader/lib/Mage/Backup/Media.php
+++ b/downloader/lib/Mage/Backup/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Nomedia.php b/downloader/lib/Mage/Backup/Nomedia.php
index 4ddb658..5cf108e 100644
--- a/downloader/lib/Mage/Backup/Nomedia.php
+++ b/downloader/lib/Mage/Backup/Nomedia.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Backup/Snapshot.php b/downloader/lib/Mage/Backup/Snapshot.php
index dc393bd..d6adbfb 100644
--- a/downloader/lib/Mage/Backup/Snapshot.php
+++ b/downloader/lib/Mage/Backup/Snapshot.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Backup.php b/downloader/lib/Mage/Connect/Backup.php
index a8fbadb..f892a01 100644
--- a/downloader/lib/Mage/Connect/Backup.php
+++ b/downloader/lib/Mage/Connect/Backup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Channel/Generator.php b/downloader/lib/Mage/Connect/Channel/Generator.php
index e3a1b3e..3b9aaf4 100644
--- a/downloader/lib/Mage/Connect/Channel/Generator.php
+++ b/downloader/lib/Mage/Connect/Channel/Generator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Channel/Parser.php b/downloader/lib/Mage/Connect/Channel/Parser.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Channel/Parser.php
+++ b/downloader/lib/Mage/Connect/Channel/Parser.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Channel/VO.php b/downloader/lib/Mage/Connect/Channel/VO.php
index 08d227a..2a21040 100644
--- a/downloader/lib/Mage/Connect/Channel/VO.php
+++ b/downloader/lib/Mage/Connect/Channel/VO.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command.php b/downloader/lib/Mage/Connect/Command.php
index 1361587..bfa576e 100644
--- a/downloader/lib/Mage/Connect/Command.php
+++ b/downloader/lib/Mage/Connect/Command.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Channels.php b/downloader/lib/Mage/Connect/Command/Channels.php
index 0c1698b..df57206 100644
--- a/downloader/lib/Mage/Connect/Command/Channels.php
+++ b/downloader/lib/Mage/Connect/Command/Channels.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Channels_Header.php b/downloader/lib/Mage/Connect/Command/Channels_Header.php
index b2e0a1a..79cc40c 100644
--- a/downloader/lib/Mage/Connect/Command/Channels_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Channels_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Config.php b/downloader/lib/Mage/Connect/Command/Config.php
index a625f1d..08d6314 100644
--- a/downloader/lib/Mage/Connect/Command/Config.php
+++ b/downloader/lib/Mage/Connect/Command/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Config_Header.php b/downloader/lib/Mage/Connect/Command/Config_Header.php
index e660642..278260d 100644
--- a/downloader/lib/Mage/Connect/Command/Config_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Config_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Install.php b/downloader/lib/Mage/Connect/Command/Install.php
index 7c6a361..0dbd267 100644
--- a/downloader/lib/Mage/Connect/Command/Install.php
+++ b/downloader/lib/Mage/Connect/Command/Install.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 final class Mage_Connect_Command_Install extends Mage_Connect_Command
diff --git a/downloader/lib/Mage/Connect/Command/Install_Header.php b/downloader/lib/Mage/Connect/Command/Install_Header.php
index c9db98e..2fd59b9 100644
--- a/downloader/lib/Mage/Connect/Command/Install_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Install_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Package.php b/downloader/lib/Mage/Connect/Command/Package.php
index 294c217..26827f9 100644
--- a/downloader/lib/Mage/Connect/Command/Package.php
+++ b/downloader/lib/Mage/Connect/Command/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Package_Header.php b/downloader/lib/Mage/Connect/Command/Package_Header.php
index c592ed2..b3be30a 100644
--- a/downloader/lib/Mage/Connect/Command/Package_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Package_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Registry.php b/downloader/lib/Mage/Connect/Command/Registry.php
index 24ec8c9..7fcadd2 100644
--- a/downloader/lib/Mage/Connect/Command/Registry.php
+++ b/downloader/lib/Mage/Connect/Command/Registry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Registry_Header.php b/downloader/lib/Mage/Connect/Command/Registry_Header.php
index 17425a2..5084228 100644
--- a/downloader/lib/Mage/Connect/Command/Registry_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Registry_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Remote.php b/downloader/lib/Mage/Connect/Command/Remote.php
index c5d6e90..359c684 100644
--- a/downloader/lib/Mage/Connect/Command/Remote.php
+++ b/downloader/lib/Mage/Connect/Command/Remote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Command/Remote_Header.php b/downloader/lib/Mage/Connect/Command/Remote_Header.php
index aa46e9f..4d15a23 100644
--- a/downloader/lib/Mage/Connect/Command/Remote_Header.php
+++ b/downloader/lib/Mage/Connect/Command/Remote_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Config.php b/downloader/lib/Mage/Connect/Config.php
index d36699e..8e0c132 100644
--- a/downloader/lib/Mage/Connect/Config.php
+++ b/downloader/lib/Mage/Connect/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Converter.php b/downloader/lib/Mage/Connect/Converter.php
index 81c33bf..cde7d8e 100644
--- a/downloader/lib/Mage/Connect/Converter.php
+++ b/downloader/lib/Mage/Connect/Converter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Frontend.php b/downloader/lib/Mage/Connect/Frontend.php
index e692c13..9462e9e 100644
--- a/downloader/lib/Mage/Connect/Frontend.php
+++ b/downloader/lib/Mage/Connect/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Connect_Frontend
diff --git a/downloader/lib/Mage/Connect/Frontend/CLI.php b/downloader/lib/Mage/Connect/Frontend/CLI.php
index 49ce093..4b46bb7 100644
--- a/downloader/lib/Mage/Connect/Frontend/CLI.php
+++ b/downloader/lib/Mage/Connect/Frontend/CLI.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Ftp.php b/downloader/lib/Mage/Connect/Ftp.php
index 4b9b7c6..ee8a514 100644
--- a/downloader/lib/Mage/Connect/Ftp.php
+++ b/downloader/lib/Mage/Connect/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Loader.php b/downloader/lib/Mage/Connect/Loader.php
index e78ffc8..b3104b9 100644
--- a/downloader/lib/Mage/Connect/Loader.php
+++ b/downloader/lib/Mage/Connect/Loader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Loader/Ftp.php b/downloader/lib/Mage/Connect/Loader/Ftp.php
index 024237e..067d801 100644
--- a/downloader/lib/Mage/Connect/Loader/Ftp.php
+++ b/downloader/lib/Mage/Connect/Loader/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package.php b/downloader/lib/Mage/Connect/Package.php
index 64d1baa..eea9aa4 100644
--- a/downloader/lib/Mage/Connect/Package.php
+++ b/downloader/lib/Mage/Connect/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package/Extension.php b/downloader/lib/Mage/Connect/Package/Extension.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Package/Extension.php
+++ b/downloader/lib/Mage/Connect/Package/Extension.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Package/Hotfix.php b/downloader/lib/Mage/Connect/Package/Hotfix.php
index ba985b9..2084506 100644
--- a/downloader/lib/Mage/Connect/Package/Hotfix.php
+++ b/downloader/lib/Mage/Connect/Package/Hotfix.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package/Maintainer.php b/downloader/lib/Mage/Connect/Package/Maintainer.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Package/Maintainer.php
+++ b/downloader/lib/Mage/Connect/Package/Maintainer.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Package/Reader.php b/downloader/lib/Mage/Connect/Package/Reader.php
index 168fbe7..8cc97f0 100644
--- a/downloader/lib/Mage/Connect/Package/Reader.php
+++ b/downloader/lib/Mage/Connect/Package/Reader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package/Target.php b/downloader/lib/Mage/Connect/Package/Target.php
index 78cecfb..088e334 100644
--- a/downloader/lib/Mage/Connect/Package/Target.php
+++ b/downloader/lib/Mage/Connect/Package/Target.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package/VO.php b/downloader/lib/Mage/Connect/Package/VO.php
index 432a31c..750287c 100644
--- a/downloader/lib/Mage/Connect/Package/VO.php
+++ b/downloader/lib/Mage/Connect/Package/VO.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Package/Writer.php b/downloader/lib/Mage/Connect/Package/Writer.php
index e6f3f4a..cded4c2 100644
--- a/downloader/lib/Mage/Connect/Package/Writer.php
+++ b/downloader/lib/Mage/Connect/Package/Writer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Packager.php b/downloader/lib/Mage/Connect/Packager.php
index 9e299ae..ac00078 100644
--- a/downloader/lib/Mage/Connect/Packager.php
+++ b/downloader/lib/Mage/Connect/Packager.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Repository.php b/downloader/lib/Mage/Connect/Repository.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository.php
+++ b/downloader/lib/Mage/Connect/Repository.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Abstract.php b/downloader/lib/Mage/Connect/Repository/Abstract.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Abstract.php
+++ b/downloader/lib/Mage/Connect/Repository/Abstract.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Channel.php b/downloader/lib/Mage/Connect/Repository/Channel.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Channel.php
+++ b/downloader/lib/Mage/Connect/Repository/Channel.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Channel/Abstract.php b/downloader/lib/Mage/Connect/Repository/Channel/Abstract.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Channel/Abstract.php
+++ b/downloader/lib/Mage/Connect/Repository/Channel/Abstract.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Channel/Commercial.php b/downloader/lib/Mage/Connect/Repository/Channel/Commercial.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Channel/Commercial.php
+++ b/downloader/lib/Mage/Connect/Repository/Channel/Commercial.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Channel/Community.php b/downloader/lib/Mage/Connect/Repository/Channel/Community.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Channel/Community.php
+++ b/downloader/lib/Mage/Connect/Repository/Channel/Community.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Channel/Core.php b/downloader/lib/Mage/Connect/Repository/Channel/Core.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Channel/Core.php
+++ b/downloader/lib/Mage/Connect/Repository/Channel/Core.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Repository/Local.php b/downloader/lib/Mage/Connect/Repository/Local.php
index b0a9a41..c01f8fb 100644
--- a/downloader/lib/Mage/Connect/Repository/Local.php
+++ b/downloader/lib/Mage/Connect/Repository/Local.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/downloader/lib/Mage/Connect/Rest.php b/downloader/lib/Mage/Connect/Rest.php
index ef2d490..d9ee475 100644
--- a/downloader/lib/Mage/Connect/Rest.php
+++ b/downloader/lib/Mage/Connect/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Rest/Builder.php b/downloader/lib/Mage/Connect/Rest/Builder.php
index a469c3e..7e30733 100644
--- a/downloader/lib/Mage/Connect/Rest/Builder.php
+++ b/downloader/lib/Mage/Connect/Rest/Builder.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Rest/Factory.php b/downloader/lib/Mage/Connect/Rest/Factory.php
index dcaae02..e1db2e2 100644
--- a/downloader/lib/Mage/Connect/Rest/Factory.php
+++ b/downloader/lib/Mage/Connect/Rest/Factory.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 /**
diff --git a/downloader/lib/Mage/Connect/Singleconfig.php b/downloader/lib/Mage/Connect/Singleconfig.php
index 1a672f8..7c4fb1c 100644
--- a/downloader/lib/Mage/Connect/Singleconfig.php
+++ b/downloader/lib/Mage/Connect/Singleconfig.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Structures/Graph.php b/downloader/lib/Mage/Connect/Structures/Graph.php
index 6ccfdb0..9b36ab3 100644
--- a/downloader/lib/Mage/Connect/Structures/Graph.php
+++ b/downloader/lib/Mage/Connect/Structures/Graph.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Structures/Node.php b/downloader/lib/Mage/Connect/Structures/Node.php
index 835f6bd..08960a1 100644
--- a/downloader/lib/Mage/Connect/Structures/Node.php
+++ b/downloader/lib/Mage/Connect/Structures/Node.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Connect/Validator.php b/downloader/lib/Mage/Connect/Validator.php
index aa46b4c..8c03c20 100644
--- a/downloader/lib/Mage/Connect/Validator.php
+++ b/downloader/lib/Mage/Connect/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/DB/Exception.php b/downloader/lib/Mage/DB/Exception.php
index b8201f2..d4f7ced 100644
--- a/downloader/lib/Mage/DB/Exception.php
+++ b/downloader/lib/Mage/DB/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_DB
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/DB/Mysqli.php b/downloader/lib/Mage/DB/Mysqli.php
index 4fa36e0..0751593 100644
--- a/downloader/lib/Mage/DB/Mysqli.php
+++ b/downloader/lib/Mage/DB/Mysqli.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_DB
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Exception.php b/downloader/lib/Mage/Exception.php
index 87065f7..85b8800 100644
--- a/downloader/lib/Mage/Exception.php
+++ b/downloader/lib/Mage/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Exception
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/HTTP/Client.php b/downloader/lib/Mage/HTTP/Client.php
index 63e0ac3..793fecd 100644
--- a/downloader/lib/Mage/HTTP/Client.php
+++ b/downloader/lib/Mage/HTTP/Client.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/HTTP/Client/Curl.php b/downloader/lib/Mage/HTTP/Client/Curl.php
index b81dccf..db91381 100644
--- a/downloader/lib/Mage/HTTP/Client/Curl.php
+++ b/downloader/lib/Mage/HTTP/Client/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/HTTP/Client/Socket.php b/downloader/lib/Mage/HTTP/Client/Socket.php
index 9a44c49..a96171c 100644
--- a/downloader/lib/Mage/HTTP/Client/Socket.php
+++ b/downloader/lib/Mage/HTTP/Client/Socket.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/HTTP/IClient.php b/downloader/lib/Mage/HTTP/IClient.php
index bd3b24e..9641fd4 100644
--- a/downloader/lib/Mage/HTTP/IClient.php
+++ b/downloader/lib/Mage/HTTP/IClient.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/System/Args.php b/downloader/lib/Mage/System/Args.php
index 6c24aba..84a7bc4 100644
--- a/downloader/lib/Mage/System/Args.php
+++ b/downloader/lib/Mage/System/Args.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/System/Dirs.php b/downloader/lib/Mage/System/Dirs.php
index 4902f29..ebb99a5 100644
--- a/downloader/lib/Mage/System/Dirs.php
+++ b/downloader/lib/Mage/System/Dirs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_System_Dirs
diff --git a/downloader/lib/Mage/System/Ftp.php b/downloader/lib/Mage/System/Ftp.php
index 5ac998d..cc7ce1e 100644
--- a/downloader/lib/Mage/System/Ftp.php
+++ b/downloader/lib/Mage/System/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/lib/Mage/Xml/Generator.php b/downloader/lib/Mage/Xml/Generator.php
index f32d7af..92728ad 100644
--- a/downloader/lib/Mage/Xml/Generator.php
+++ b/downloader/lib/Mage/Xml/Generator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Xml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Xml_Generator
diff --git a/downloader/lib/Mage/Xml/Parser.php b/downloader/lib/Mage/Xml/Parser.php
index a70bd94..407b0cc 100644
--- a/downloader/lib/Mage/Xml/Parser.php
+++ b/downloader/lib/Mage/Xml/Parser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Xml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Xml_Parser
diff --git a/downloader/mage.php b/downloader/mage.php
index de5df63..a51a132 100644
--- a/downloader/mage.php
+++ b/downloader/mage.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/downloader/skin/boxes.css b/downloader/skin/boxes.css
index fbe94b6..57ed1d1 100644
--- a/downloader/skin/boxes.css
+++ b/downloader/skin/boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*
diff --git a/downloader/skin/ie7boxes.css b/downloader/skin/ie7boxes.css
index 21a6fa8..539fa0a 100644
--- a/downloader/skin/ie7boxes.css
+++ b/downloader/skin/ie7boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .main { height:auto !important; }
diff --git a/downloader/skin/ieboxes.css b/downloader/skin/ieboxes.css
index 702e8e2..6031f35 100644
--- a/downloader/skin/ieboxes.css
+++ b/downloader/skin/ieboxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 button, .form-button    { filter:chroma(color=#000000); overflow:visible; width:auto; }
diff --git a/downloader/skin/install/boxes.css b/downloader/skin/install/boxes.css
index 7db0673..4fd5ddc 100644
--- a/downloader/skin/install/boxes.css
+++ b/downloader/skin/install/boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/downloader/skin/install/clears.css b/downloader/skin/install/clears.css
index d199442..3565e37 100644
--- a/downloader/skin/install/clears.css
+++ b/downloader/skin/install/clears.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/downloader/skin/install/ie7minus.css b/downloader/skin/install/ie7minus.css
index ed17dcd..58d7fea 100644
--- a/downloader/skin/install/ie7minus.css
+++ b/downloader/skin/install/ie7minus.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/downloader/skin/install/iestyles.css b/downloader/skin/install/iestyles.css
index 8e073c4..bb80f04 100644
--- a/downloader/skin/install/iestyles.css
+++ b/downloader/skin/install/iestyles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .col2-set,
diff --git a/downloader/skin/install/reset.css b/downloader/skin/install/reset.css
index 16d469b..eb37124 100644
--- a/downloader/skin/install/reset.css
+++ b/downloader/skin/install/reset.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /******************************************/
diff --git a/downloader/target.xml b/downloader/target.xml
index 8ad980e..495b11d 100644
--- a/downloader/target.xml
+++ b/downloader/target.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Downloader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/downloader/template/connect/iframe.phtml b/downloader/template/connect/iframe.phtml
index 5c24ea9..0a34ddc 100644
--- a/downloader/template/connect/iframe.phtml
+++ b/downloader/template/connect/iframe.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/connect/packages.phtml b/downloader/template/connect/packages.phtml
index c22d2d0..4000cb8 100644
--- a/downloader/template/connect/packages.phtml
+++ b/downloader/template/connect/packages.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/connect/packages_prepare.phtml b/downloader/template/connect/packages_prepare.phtml
index 23ffdfb..05b8332 100644
--- a/downloader/template/connect/packages_prepare.phtml
+++ b/downloader/template/connect/packages_prepare.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/exception.phtml b/downloader/template/exception.phtml
index 8b4c26b..e4e9061 100644
--- a/downloader/template/exception.phtml
+++ b/downloader/template/exception.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/footer.phtml b/downloader/template/footer.phtml
index 881f0ec..07082b6 100644
--- a/downloader/template/footer.phtml
+++ b/downloader/template/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
@@ -33,7 +33,7 @@
                 <script type="text/javascript">
                     $('bug_tracking_link').target = "varien_external";
                 </script>
-                Magento is a trademark of Magento, Inc. Copyright &copy; 2018 Magento Inc.
+                Magento is a trademark of Magento, Inc. Copyright &copy; 2019 Magento Inc.
             </p>
         </div>
     </body>
diff --git a/downloader/template/header.phtml b/downloader/template/header.phtml
index 376f41d..e452f7a 100644
--- a/downloader/template/header.phtml
+++ b/downloader/template/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/index.phtml b/downloader/template/index.phtml
index 048897e..2179262 100644
--- a/downloader/template/index.phtml
+++ b/downloader/template/index.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/install/download.phtml b/downloader/template/install/download.phtml
index 18410d3..0a883e7 100644
--- a/downloader/template/install/download.phtml
+++ b/downloader/template/install/download.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/install/footer.phtml b/downloader/template/install/footer.phtml
index d650c71..9e129e2 100644
--- a/downloader/template/install/footer.phtml
+++ b/downloader/template/install/footer.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
@@ -41,7 +41,7 @@
 <script type="text/javascript">
     $('bug_tracking_link').target = "varien_external";
 </script>
-            Magento is a trademark of Magento, Inc. Copyright &copy; 2018 Magento Inc.</p>
+            Magento is a trademark of Magento, Inc. Copyright &copy; 2019 Magento Inc.</p>
         </div>
     </div>
         <!-- [end] footer -->
diff --git a/downloader/template/install/header.phtml b/downloader/template/install/header.phtml
index ece7b3c..f9cf3e7 100644
--- a/downloader/template/install/header.phtml
+++ b/downloader/template/install/header.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/install/writable.phtml b/downloader/template/install/writable.phtml
index 56ab37b..2a71d9f 100644
--- a/downloader/template/install/writable.phtml
+++ b/downloader/template/install/writable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/login.phtml b/downloader/template/login.phtml
index 8a9ec73..8cfe2d1 100644
--- a/downloader/template/login.phtml
+++ b/downloader/template/login.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/messages.phtml b/downloader/template/messages.phtml
index c1f6a7a..65acaef 100644
--- a/downloader/template/messages.phtml
+++ b/downloader/template/messages.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/noroute.phtml b/downloader/template/noroute.phtml
index 9654385..3bea40f 100644
--- a/downloader/template/noroute.phtml
+++ b/downloader/template/noroute.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/settings.phtml b/downloader/template/settings.phtml
index 7636e12..0a5dfbb 100644
--- a/downloader/template/settings.phtml
+++ b/downloader/template/settings.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/downloader/template/writable.phtml b/downloader/template/writable.phtml
index e3028ff..028eb18 100644
--- a/downloader/template/writable.phtml
+++ b/downloader/template/writable.phtml
@@ -20,7 +20,7 @@
  *
  * @category    design
  * @package     default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/errors/404.php b/errors/404.php
index 86faaa9..d04de47 100644
--- a/errors/404.php
+++ b/errors/404.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/errors/503.php b/errors/503.php
index e8e97b7..2d241c0 100644
--- a/errors/503.php
+++ b/errors/503.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/errors/default/404.phtml b/errors/default/404.phtml
index d7c34c7..982eae2 100644
--- a/errors/default/404.phtml
+++ b/errors/default/404.phtml
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/errors/default/503.phtml b/errors/default/503.phtml
index 84f48d5..9a74db2 100644
--- a/errors/default/503.phtml
+++ b/errors/default/503.phtml
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/errors/default/css/styles.css b/errors/default/css/styles.css
index 94959bb..3ef1709 100644
--- a/errors/default/css/styles.css
+++ b/errors/default/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* Reset ================================================================================= */
diff --git a/errors/default/page.phtml b/errors/default/page.phtml
index 15a64e2..09a2e7b 100644
--- a/errors/default/page.phtml
+++ b/errors/default/page.phtml
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
@@ -52,7 +52,7 @@
             </div>
             <div class="footer-container">
                 <div class="footer">
-                    <address class="copyright">Magento is a trademark of Magento Inc. Copyright &copy; 2018 Magento Inc.</address>
+                    <address class="copyright">Magento is a trademark of Magento Inc. Copyright &copy; 2019 Magento Inc.</address>
                 </div>
             </div>
         </div>
diff --git a/errors/default/report.phtml b/errors/default/report.phtml
index 7c1ed13..0b7daa7 100644
--- a/errors/default/report.phtml
+++ b/errors/default/report.phtml
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 ?>
diff --git a/errors/design.xml b/errors/design.xml
index 1793359..cd57031 100644
--- a/errors/design.xml
+++ b/errors/design.xml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/errors/local.xml.sample b/errors/local.xml.sample
index cdbe759..3af9151 100644
--- a/errors/local.xml.sample
+++ b/errors/local.xml.sample
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 -->
diff --git a/errors/processor.php b/errors/processor.php
index 0afcc3c..3f2d75e 100644
--- a/errors/processor.php
+++ b/errors/processor.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/errors/report.php b/errors/report.php
index 52199c3..d39ce3c 100644
--- a/errors/report.php
+++ b/errors/report.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Errors
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/get.php b/get.php
index 055c203..2748598 100644
--- a/get.php
+++ b/get.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 if (version_compare(phpversion(), '5.2.0', '<')===true) {
diff --git a/includes/config.php b/includes/config.php
index cf833b2..811a1be 100644
--- a/includes/config.php
+++ b/includes/config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/index.php b/index.php
index 0d9776c..dce8174 100644
--- a/index.php
+++ b/index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/index.php.sample b/index.php.sample
index 73a93d1..da2b101 100644
--- a/index.php.sample
+++ b/index.php.sample
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/install.php b/install.php
index 932a73e..44a3dbf 100644
--- a/install.php
+++ b/install.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/js/extjs/fix-defer-before.js b/js/extjs/fix-defer-before.js
index 7d7643c..daf58f9 100644
--- a/js/extjs/fix-defer-before.js
+++ b/js/extjs/fix-defer-before.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*@cc_on
diff --git a/js/extjs/fix-defer.js b/js/extjs/fix-defer.js
index 417a4ea..bd9764c 100644
--- a/js/extjs/fix-defer.js
+++ b/js/extjs/fix-defer.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/index.php b/js/index.php
index c31eab4..36d9902 100644
--- a/js/index.php
+++ b/js/index.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/js/lib/dropdown.js b/js/lib/dropdown.js
index 3fa7c0c..4b6883e 100644
--- a/js/lib/dropdown.js
+++ b/js/lib/dropdown.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 dropdown = function() {
diff --git a/js/lib/flex.js b/js/lib/flex.js
index bd80e207..db7de30 100644
--- a/js/lib/flex.js
+++ b/js/lib/flex.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/lib/jquery/noconflict.js b/js/lib/jquery/noconflict.js
index 6c5a41f..8076888 100644
--- a/js/lib/jquery/noconflict.js
+++ b/js/lib/jquery/noconflict.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/accordion.js b/js/mage/adminhtml/accordion.js
index 58b74d1..564dce5 100644
--- a/js/mage/adminhtml/accordion.js
+++ b/js/mage/adminhtml/accordion.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var varienAccordion = new Class.create();
diff --git a/js/mage/adminhtml/backup.js b/js/mage/adminhtml/backup.js
index f1b8e5c..83ea896 100644
--- a/js/mage/adminhtml/backup.js
+++ b/js/mage/adminhtml/backup.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var AdminBackup = new Class.create();
diff --git a/js/mage/adminhtml/browser.js b/js/mage/adminhtml/browser.js
index 585ff5c..c88765a 100644
--- a/js/mage/adminhtml/browser.js
+++ b/js/mage/adminhtml/browser.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 MediabrowserUtility = {
diff --git a/js/mage/adminhtml/events.js b/js/mage/adminhtml/events.js
index 567daeb..dea4b9b 100644
--- a/js/mage/adminhtml/events.js
+++ b/js/mage/adminhtml/events.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 // from http://www.someelement.com/2007/03/eventpublisher-custom-events-la-pubsub.html
diff --git a/js/mage/adminhtml/flexuploader.js b/js/mage/adminhtml/flexuploader.js
index 6f59d36..56ab7c2 100644
--- a/js/mage/adminhtml/flexuploader.js
+++ b/js/mage/adminhtml/flexuploader.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/form.js b/js/mage/adminhtml/form.js
index da35ff2..8ee754c 100644
--- a/js/mage/adminhtml/form.js
+++ b/js/mage/adminhtml/form.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var varienForm = new Class.create();
diff --git a/js/mage/adminhtml/giftmessage.js b/js/mage/adminhtml/giftmessage.js
index 83239ad..26b4afe 100644
--- a/js/mage/adminhtml/giftmessage.js
+++ b/js/mage/adminhtml/giftmessage.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/giftoptions/tooltip.js b/js/mage/adminhtml/giftoptions/tooltip.js
index aa6b403..523bc71 100644
--- a/js/mage/adminhtml/giftoptions/tooltip.js
+++ b/js/mage/adminhtml/giftoptions/tooltip.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/grid.js b/js/mage/adminhtml/grid.js
index 60584d7..e0359ad 100644
--- a/js/mage/adminhtml/grid.js
+++ b/js/mage/adminhtml/grid.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var varienGrid = new Class.create();
diff --git a/js/mage/adminhtml/hash.js b/js/mage/adminhtml/hash.js
index 05269a0..0713a86 100644
--- a/js/mage/adminhtml/hash.js
+++ b/js/mage/adminhtml/hash.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*
diff --git a/js/mage/adminhtml/image.js b/js/mage/adminhtml/image.js
index d301d64..98b6de4 100644
--- a/js/mage/adminhtml/image.js
+++ b/js/mage/adminhtml/image.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/loader.js b/js/mage/adminhtml/loader.js
index 308fd66..584888073 100644
--- a/js/mage/adminhtml/loader.js
+++ b/js/mage/adminhtml/loader.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/magento-all.js b/js/mage/adminhtml/magento-all.js
index ea5d675..7c9cd5e 100644
--- a/js/mage/adminhtml/magento-all.js
+++ b/js/mage/adminhtml/magento-all.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/moneybookers.js b/js/mage/adminhtml/moneybookers.js
index 1e5103f..4e34abe 100644
--- a/js/mage/adminhtml/moneybookers.js
+++ b/js/mage/adminhtml/moneybookers.js
@@ -13,7 +13,7 @@
  *
  * @category    Phoenix
  * @package     Phoenix_Moneybookers
- * @copyright   Copyright (c) 2018 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
+ * @copyright   Copyright (c) 2019 Phoenix Medien GmbH & Co. KG (http://www.phoenix-medien.de)
  * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/js/mage/adminhtml/product.js b/js/mage/adminhtml/product.js
index cfb4df1..fe66f57 100644
--- a/js/mage/adminhtml/product.js
+++ b/js/mage/adminhtml/product.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/product/composite/configure.js b/js/mage/adminhtml/product/composite/configure.js
index 9880dc9..a48a3ee 100644
--- a/js/mage/adminhtml/product/composite/configure.js
+++ b/js/mage/adminhtml/product/composite/configure.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/rules.js b/js/mage/adminhtml/rules.js
index 3498d5e..32e1806 100644
--- a/js/mage/adminhtml/rules.js
+++ b/js/mage/adminhtml/rules.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/sales.js b/js/mage/adminhtml/sales.js
index b08e0c8..1f06be9 100644
--- a/js/mage/adminhtml/sales.js
+++ b/js/mage/adminhtml/sales.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var AdminOrder = new Class.create();
diff --git a/js/mage/adminhtml/sales/centinel.js b/js/mage/adminhtml/sales/centinel.js
index fbb8350..9bcde9e 100644
--- a/js/mage/adminhtml/sales/centinel.js
+++ b/js/mage/adminhtml/sales/centinel.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var centinelValidator = new Class.create();
diff --git a/js/mage/adminhtml/sales/packaging.js b/js/mage/adminhtml/sales/packaging.js
index e58001b..1b9ac6e 100644
--- a/js/mage/adminhtml/sales/packaging.js
+++ b/js/mage/adminhtml/sales/packaging.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var Packaging = Class.create();
diff --git a/js/mage/adminhtml/scrollbar.js b/js/mage/adminhtml/scrollbar.js
index 04c0ea8..2bc44f4 100644
--- a/js/mage/adminhtml/scrollbar.js
+++ b/js/mage/adminhtml/scrollbar.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**************************************************
diff --git a/js/mage/adminhtml/tabs.js b/js/mage/adminhtml/tabs.js
index 6944704..5906c7b 100644
--- a/js/mage/adminhtml/tabs.js
+++ b/js/mage/adminhtml/tabs.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var varienTabs = new Class.create();
diff --git a/js/mage/adminhtml/tools.js b/js/mage/adminhtml/tools.js
index e756dd3..f08dc28 100644
--- a/js/mage/adminhtml/tools.js
+++ b/js/mage/adminhtml/tools.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 function setLocation(url){
diff --git a/js/mage/adminhtml/uploader.js b/js/mage/adminhtml/uploader.js
index fac6057..cf0cceb 100644
--- a/js/mage/adminhtml/uploader.js
+++ b/js/mage/adminhtml/uploader.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /**
diff --git a/js/mage/adminhtml/uploader/instance.js b/js/mage/adminhtml/uploader/instance.js
index c175f83..26b06b8 100644
--- a/js/mage/adminhtml/uploader/instance.js
+++ b/js/mage/adminhtml/uploader/instance.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/variables.js b/js/mage/adminhtml/variables.js
index 957f97e..cc3dc1b 100644
--- a/js/mage/adminhtml/variables.js
+++ b/js/mage/adminhtml/variables.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentovariable/editor_plugin.js b/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentovariable/editor_plugin.js
index a53798c..6399f00 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentovariable/editor_plugin.js
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentovariable/editor_plugin.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentowidget/editor_plugin.js b/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentowidget/editor_plugin.js
index 376f4da..627abcb 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentowidget/editor_plugin.js
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/plugins/magentowidget/editor_plugin.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 tinyMCE.addI18n({en:{
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js b/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
index deaee5e..88c6f7d 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/content.css b/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/content.css
index fac5fde..17b424e 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/content.css
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/content.css
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/dialog.css b/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/dialog.css
index a5f8518..2e31751 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/dialog.css
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/dialog.css
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/adminhtml/wysiwyg/widget.js b/js/mage/adminhtml/wysiwyg/widget.js
index da21fe5..5e70184 100644
--- a/js/mage/adminhtml/wysiwyg/widget.js
+++ b/js/mage/adminhtml/wysiwyg/widget.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Adminhtml
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/captcha.js b/js/mage/captcha.js
index b23ee8b..00349af 100644
--- a/js/mage/captcha.js
+++ b/js/mage/captcha.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var Captcha = Class.create();
diff --git a/js/mage/centinel.js b/js/mage/centinel.js
index 18be032..326dcf4 100644
--- a/js/mage/centinel.js
+++ b/js/mage/centinel.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var CentinelAuthenticate = Class.create();
diff --git a/js/mage/cookies.js b/js/mage/cookies.js
index 38f9b03..d0678bb 100644
--- a/js/mage/cookies.js
+++ b/js/mage/cookies.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 // old school cookie functions grabbed off the web
diff --git a/js/mage/directpost.js b/js/mage/directpost.js
index b7cb6c7..9cffe93 100644
--- a/js/mage/directpost.js
+++ b/js/mage/directpost.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var directPost = Class.create();
diff --git a/js/mage/translate.js b/js/mage/translate.js
index ec485a6..c1e2e03 100644
--- a/js/mage/translate.js
+++ b/js/mage/translate.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/translate_inline.css b/js/mage/translate_inline.css
index f3a1c21..4e70410 100644
--- a/js/mage/translate_inline.css
+++ b/js/mage/translate_inline.css
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/mage/translate_inline.js b/js/mage/translate_inline.js
index f3a26bb..6aaa35c 100644
--- a/js/mage/translate_inline.js
+++ b/js/mage/translate_inline.js
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/varien/accordion.js b/js/varien/accordion.js
index 2c7bdb8..e00e69e 100644
--- a/js/varien/accordion.js
+++ b/js/varien/accordion.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 Accordion = Class.create();
diff --git a/js/varien/configurable.js b/js/varien/configurable.js
index 153bc54..dce7c82 100644
--- a/js/varien/configurable.js
+++ b/js/varien/configurable.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 if (typeof Product == 'undefined') {
diff --git a/js/varien/form.js b/js/varien/form.js
index 94ef780..c060eb0 100644
--- a/js/varien/form.js
+++ b/js/varien/form.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 VarienForm = Class.create();
diff --git a/js/varien/iehover-fix.js b/js/varien/iehover-fix.js
index 3a7347d..80d531b 100644
--- a/js/varien/iehover-fix.js
+++ b/js/varien/iehover-fix.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 function toggleMenu(el, over)
diff --git a/js/varien/js.js b/js/varien/js.js
index c0207ad..2e0b253 100644
--- a/js/varien/js.js
+++ b/js/varien/js.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 function popWin(url,win,para) {
diff --git a/js/varien/menu.js b/js/varien/menu.js
index beedb3b..024294e 100644
--- a/js/varien/menu.js
+++ b/js/varien/menu.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/varien/payment.js b/js/varien/payment.js
index 03f0978..d62233f 100644
--- a/js/varien/payment.js
+++ b/js/varien/payment.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var paymentForm = Class.create();
diff --git a/js/varien/product.js b/js/varien/product.js
index f3558a9..c02853b 100644
--- a/js/varien/product.js
+++ b/js/varien/product.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 if(typeof Product=='undefined') {
diff --git a/js/varien/product_options.js b/js/varien/product_options.js
index a8b2556..bac6156 100644
--- a/js/varien/product_options.js
+++ b/js/varien/product_options.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/js/varien/telephone.js b/js/varien/telephone.js
index f7ff8bc..bea7c7a 100644
--- a/js/varien/telephone.js
+++ b/js/varien/telephone.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var telephoneElem = Class.create();
diff --git a/js/varien/weee.js b/js/varien/weee.js
index 38453c4..4c9db1b 100644
--- a/js/varien/weee.js
+++ b/js/varien/weee.js
@@ -19,7 +19,7 @@
  *
  * @category    Varien
  * @package     js
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/lib/Mage/Archive.php b/lib/Mage/Archive.php
index 076fd79..deb5c6a 100644
--- a/lib/Mage/Archive.php
+++ b/lib/Mage/Archive.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Abstract.php b/lib/Mage/Archive/Abstract.php
index 4baaf25..3ff62a9 100644
--- a/lib/Mage/Archive/Abstract.php
+++ b/lib/Mage/Archive/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Bz.php b/lib/Mage/Archive/Bz.php
index 7dd9a24..22fea0b 100644
--- a/lib/Mage/Archive/Bz.php
+++ b/lib/Mage/Archive/Bz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Gz.php b/lib/Mage/Archive/Gz.php
index 6a09c0a..0d298f2 100644
--- a/lib/Mage/Archive/Gz.php
+++ b/lib/Mage/Archive/Gz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Helper/File.php b/lib/Mage/Archive/Helper/File.php
index 5b524b6..974016b 100644
--- a/lib/Mage/Archive/Helper/File.php
+++ b/lib/Mage/Archive/Helper/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Helper/File/Bz.php b/lib/Mage/Archive/Helper/File/Bz.php
index 00f546a..04ffee5 100644
--- a/lib/Mage/Archive/Helper/File/Bz.php
+++ b/lib/Mage/Archive/Helper/File/Bz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Helper/File/Gz.php b/lib/Mage/Archive/Helper/File/Gz.php
index eb10943..866188a 100644
--- a/lib/Mage/Archive/Helper/File/Gz.php
+++ b/lib/Mage/Archive/Helper/File/Gz.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Interface.php b/lib/Mage/Archive/Interface.php
index d3428d3..379d0a5 100644
--- a/lib/Mage/Archive/Interface.php
+++ b/lib/Mage/Archive/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Archive/Tar.php b/lib/Mage/Archive/Tar.php
index 9dc9088..9bad33b 100644
--- a/lib/Mage/Archive/Tar.php
+++ b/lib/Mage/Archive/Tar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Archive
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Autoload/Simple.php b/lib/Mage/Autoload/Simple.php
index 7947803..5021200 100644
--- a/lib/Mage/Autoload/Simple.php
+++ b/lib/Mage/Autoload/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup.php b/lib/Mage/Backup.php
index 2d7d45a..4f3bd57 100644
--- a/lib/Mage/Backup.php
+++ b/lib/Mage/Backup.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Abstract.php b/lib/Mage/Backup/Abstract.php
index 184deda..cd2fc18 100644
--- a/lib/Mage/Backup/Abstract.php
+++ b/lib/Mage/Backup/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Archive/Tar.php b/lib/Mage/Backup/Archive/Tar.php
index becc8bc..ba973aa 100644
--- a/lib/Mage/Backup/Archive/Tar.php
+++ b/lib/Mage/Backup/Archive/Tar.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Db.php b/lib/Mage/Backup/Db.php
index 75554c8..0587c65 100644
--- a/lib/Mage/Backup/Db.php
+++ b/lib/Mage/Backup/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception.php b/lib/Mage/Backup/Exception.php
index 86e75cc..ffced85 100644
--- a/lib/Mage/Backup/Exception.php
+++ b/lib/Mage/Backup/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception/CantLoadSnapshot.php b/lib/Mage/Backup/Exception/CantLoadSnapshot.php
index ef73223..2e7c723 100644
--- a/lib/Mage/Backup/Exception/CantLoadSnapshot.php
+++ b/lib/Mage/Backup/Exception/CantLoadSnapshot.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception/FtpConnectionFailed.php b/lib/Mage/Backup/Exception/FtpConnectionFailed.php
index d986a4b..fbfdf2c 100644
--- a/lib/Mage/Backup/Exception/FtpConnectionFailed.php
+++ b/lib/Mage/Backup/Exception/FtpConnectionFailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception/FtpValidationFailed.php b/lib/Mage/Backup/Exception/FtpValidationFailed.php
index 7cf0198..90e86f2 100644
--- a/lib/Mage/Backup/Exception/FtpValidationFailed.php
+++ b/lib/Mage/Backup/Exception/FtpValidationFailed.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php b/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
index 3d3858a..2cf5aa9 100644
--- a/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
+++ b/lib/Mage/Backup/Exception/NotEnoughFreeSpace.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Exception/NotEnoughPermissions.php b/lib/Mage/Backup/Exception/NotEnoughPermissions.php
index 6f4a9ed..a642caf 100644
--- a/lib/Mage/Backup/Exception/NotEnoughPermissions.php
+++ b/lib/Mage/Backup/Exception/NotEnoughPermissions.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem.php b/lib/Mage/Backup/Filesystem.php
index 464e267..d88ce3d 100644
--- a/lib/Mage/Backup/Filesystem.php
+++ b/lib/Mage/Backup/Filesystem.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Helper.php b/lib/Mage/Backup/Filesystem/Helper.php
index 9a94d1e..263b422 100644
--- a/lib/Mage/Backup/Filesystem/Helper.php
+++ b/lib/Mage/Backup/Filesystem/Helper.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Iterator/File.php b/lib/Mage/Backup/Filesystem/Iterator/File.php
index 3763ea2..1066bf9 100644
--- a/lib/Mage/Backup/Filesystem/Iterator/File.php
+++ b/lib/Mage/Backup/Filesystem/Iterator/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Iterator/Filter.php b/lib/Mage/Backup/Filesystem/Iterator/Filter.php
index 3f91b89..e4658cd 100644
--- a/lib/Mage/Backup/Filesystem/Iterator/Filter.php
+++ b/lib/Mage/Backup/Filesystem/Iterator/Filter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Rollback/Abstract.php b/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
index ee420bb..bfaf3ef 100644
--- a/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
+++ b/lib/Mage/Backup/Filesystem/Rollback/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Rollback/Fs.php b/lib/Mage/Backup/Filesystem/Rollback/Fs.php
index db301b0..28d4e7b 100644
--- a/lib/Mage/Backup/Filesystem/Rollback/Fs.php
+++ b/lib/Mage/Backup/Filesystem/Rollback/Fs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Filesystem/Rollback/Ftp.php b/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
index b6a192c..60fe0a9 100644
--- a/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
+++ b/lib/Mage/Backup/Filesystem/Rollback/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Interface.php b/lib/Mage/Backup/Interface.php
index 9cc46e8..233160f 100644
--- a/lib/Mage/Backup/Interface.php
+++ b/lib/Mage/Backup/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Media.php b/lib/Mage/Backup/Media.php
index fb2deeb..cb2b474 100644
--- a/lib/Mage/Backup/Media.php
+++ b/lib/Mage/Backup/Media.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Nomedia.php b/lib/Mage/Backup/Nomedia.php
index 4ddb658..5cf108e 100644
--- a/lib/Mage/Backup/Nomedia.php
+++ b/lib/Mage/Backup/Nomedia.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Backup/Snapshot.php b/lib/Mage/Backup/Snapshot.php
index dc393bd..d6adbfb 100644
--- a/lib/Mage/Backup/Snapshot.php
+++ b/lib/Mage/Backup/Snapshot.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Backup
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Cache/Backend/File.php b/lib/Mage/Cache/Backend/File.php
index 523f3f5..4a8b06b 100644
--- a/lib/Mage/Cache/Backend/File.php
+++ b/lib/Mage/Cache/Backend/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Cache/Backend/Redis.php b/lib/Mage/Cache/Backend/Redis.php
index 88ead5f..a562568 100644
--- a/lib/Mage/Cache/Backend/Redis.php
+++ b/lib/Mage/Cache/Backend/Redis.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Channel/Generator.php b/lib/Mage/Connect/Channel/Generator.php
index e3a1b3e..3b9aaf4 100644
--- a/lib/Mage/Connect/Channel/Generator.php
+++ b/lib/Mage/Connect/Channel/Generator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Channel/Parser.php b/lib/Mage/Connect/Channel/Parser.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Channel/Parser.php
+++ b/lib/Mage/Connect/Channel/Parser.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Channel/VO.php b/lib/Mage/Connect/Channel/VO.php
index 08d227a..2a21040 100644
--- a/lib/Mage/Connect/Channel/VO.php
+++ b/lib/Mage/Connect/Channel/VO.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command.php b/lib/Mage/Connect/Command.php
index bb60600..ef6548d 100644
--- a/lib/Mage/Connect/Command.php
+++ b/lib/Mage/Connect/Command.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Channels.php b/lib/Mage/Connect/Command/Channels.php
index 0c1698b..df57206 100644
--- a/lib/Mage/Connect/Command/Channels.php
+++ b/lib/Mage/Connect/Command/Channels.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Channels_Header.php b/lib/Mage/Connect/Command/Channels_Header.php
index b2e0a1a..79cc40c 100644
--- a/lib/Mage/Connect/Command/Channels_Header.php
+++ b/lib/Mage/Connect/Command/Channels_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Config.php b/lib/Mage/Connect/Command/Config.php
index 91d54ca..d60a0b3 100644
--- a/lib/Mage/Connect/Command/Config.php
+++ b/lib/Mage/Connect/Command/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Config_Header.php b/lib/Mage/Connect/Command/Config_Header.php
index e660642..278260d 100644
--- a/lib/Mage/Connect/Command/Config_Header.php
+++ b/lib/Mage/Connect/Command/Config_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Install.php b/lib/Mage/Connect/Command/Install.php
index 8cc1827..8d38d67 100644
--- a/lib/Mage/Connect/Command/Install.php
+++ b/lib/Mage/Connect/Command/Install.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Install_Header.php b/lib/Mage/Connect/Command/Install_Header.php
index c9db98e..2fd59b9 100644
--- a/lib/Mage/Connect/Command/Install_Header.php
+++ b/lib/Mage/Connect/Command/Install_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Package.php b/lib/Mage/Connect/Command/Package.php
index 1a82ef7..77cb33c 100644
--- a/lib/Mage/Connect/Command/Package.php
+++ b/lib/Mage/Connect/Command/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Package_Header.php b/lib/Mage/Connect/Command/Package_Header.php
index 90ae76c..f259f32 100644
--- a/lib/Mage/Connect/Command/Package_Header.php
+++ b/lib/Mage/Connect/Command/Package_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Registry.php b/lib/Mage/Connect/Command/Registry.php
index 328677c..34469fa 100644
--- a/lib/Mage/Connect/Command/Registry.php
+++ b/lib/Mage/Connect/Command/Registry.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Registry_Header.php b/lib/Mage/Connect/Command/Registry_Header.php
index f8f3baf..fe58cfe 100644
--- a/lib/Mage/Connect/Command/Registry_Header.php
+++ b/lib/Mage/Connect/Command/Registry_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Remote.php b/lib/Mage/Connect/Command/Remote.php
index 00a8c31..a07d9bb 100644
--- a/lib/Mage/Connect/Command/Remote.php
+++ b/lib/Mage/Connect/Command/Remote.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Command/Remote_Header.php b/lib/Mage/Connect/Command/Remote_Header.php
index aa46e9f..4d15a23 100644
--- a/lib/Mage/Connect/Command/Remote_Header.php
+++ b/lib/Mage/Connect/Command/Remote_Header.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Config.php b/lib/Mage/Connect/Config.php
index e4f9613..eb3aafe 100644
--- a/lib/Mage/Connect/Config.php
+++ b/lib/Mage/Connect/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Connect_Config
diff --git a/lib/Mage/Connect/Converter.php b/lib/Mage/Connect/Converter.php
index 81c33bf..cde7d8e 100644
--- a/lib/Mage/Connect/Converter.php
+++ b/lib/Mage/Connect/Converter.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Frontend.php b/lib/Mage/Connect/Frontend.php
index 9283a07..315a860 100644
--- a/lib/Mage/Connect/Frontend.php
+++ b/lib/Mage/Connect/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Frontend/CLI.php b/lib/Mage/Connect/Frontend/CLI.php
index fdb64b0..2c97438 100644
--- a/lib/Mage/Connect/Frontend/CLI.php
+++ b/lib/Mage/Connect/Frontend/CLI.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Ftp.php b/lib/Mage/Connect/Ftp.php
index dac506d..79bba56 100644
--- a/lib/Mage/Connect/Ftp.php
+++ b/lib/Mage/Connect/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Loader.php b/lib/Mage/Connect/Loader.php
index 02b318e..b63263b 100644
--- a/lib/Mage/Connect/Loader.php
+++ b/lib/Mage/Connect/Loader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Loader/Ftp.php b/lib/Mage/Connect/Loader/Ftp.php
index 011dc7d..b43cfdb 100644
--- a/lib/Mage/Connect/Loader/Ftp.php
+++ b/lib/Mage/Connect/Loader/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package.php b/lib/Mage/Connect/Package.php
index 9daa937..73afa1b 100644
--- a/lib/Mage/Connect/Package.php
+++ b/lib/Mage/Connect/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package/Extension.php b/lib/Mage/Connect/Package/Extension.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Package/Extension.php
+++ b/lib/Mage/Connect/Package/Extension.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Package/Hotfix.php b/lib/Mage/Connect/Package/Hotfix.php
index ba985b9..2084506 100644
--- a/lib/Mage/Connect/Package/Hotfix.php
+++ b/lib/Mage/Connect/Package/Hotfix.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package/Maintainer.php b/lib/Mage/Connect/Package/Maintainer.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Package/Maintainer.php
+++ b/lib/Mage/Connect/Package/Maintainer.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Package/Reader.php b/lib/Mage/Connect/Package/Reader.php
index 168fbe7..8cc97f0 100644
--- a/lib/Mage/Connect/Package/Reader.php
+++ b/lib/Mage/Connect/Package/Reader.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package/Target.php b/lib/Mage/Connect/Package/Target.php
index 78cecfb..088e334 100644
--- a/lib/Mage/Connect/Package/Target.php
+++ b/lib/Mage/Connect/Package/Target.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package/VO.php b/lib/Mage/Connect/Package/VO.php
index 432a31c..750287c 100644
--- a/lib/Mage/Connect/Package/VO.php
+++ b/lib/Mage/Connect/Package/VO.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Package/Writer.php b/lib/Mage/Connect/Package/Writer.php
index 79ac285..33b9d10 100644
--- a/lib/Mage/Connect/Package/Writer.php
+++ b/lib/Mage/Connect/Package/Writer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Packager.php b/lib/Mage/Connect/Packager.php
index a1fc175..8f65494 100644
--- a/lib/Mage/Connect/Packager.php
+++ b/lib/Mage/Connect/Packager.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Repository.php b/lib/Mage/Connect/Repository.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository.php
+++ b/lib/Mage/Connect/Repository.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Abstract.php b/lib/Mage/Connect/Repository/Abstract.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Abstract.php
+++ b/lib/Mage/Connect/Repository/Abstract.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Channel.php b/lib/Mage/Connect/Repository/Channel.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Channel.php
+++ b/lib/Mage/Connect/Repository/Channel.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Channel/Abstract.php b/lib/Mage/Connect/Repository/Channel/Abstract.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Channel/Abstract.php
+++ b/lib/Mage/Connect/Repository/Channel/Abstract.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Channel/Commercial.php b/lib/Mage/Connect/Repository/Channel/Commercial.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Channel/Commercial.php
+++ b/lib/Mage/Connect/Repository/Channel/Commercial.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Channel/Community.php b/lib/Mage/Connect/Repository/Channel/Community.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Channel/Community.php
+++ b/lib/Mage/Connect/Repository/Channel/Community.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Channel/Core.php b/lib/Mage/Connect/Repository/Channel/Core.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Channel/Core.php
+++ b/lib/Mage/Connect/Repository/Channel/Core.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Repository/Local.php b/lib/Mage/Connect/Repository/Local.php
index b0a9a41..c01f8fb 100644
--- a/lib/Mage/Connect/Repository/Local.php
+++ b/lib/Mage/Connect/Repository/Local.php
@@ -20,6 +20,6 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
diff --git a/lib/Mage/Connect/Rest.php b/lib/Mage/Connect/Rest.php
index 83326a3..6897e42 100644
--- a/lib/Mage/Connect/Rest.php
+++ b/lib/Mage/Connect/Rest.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Singleconfig.php b/lib/Mage/Connect/Singleconfig.php
index f76f4eb..600b679 100644
--- a/lib/Mage/Connect/Singleconfig.php
+++ b/lib/Mage/Connect/Singleconfig.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Structures/Graph.php b/lib/Mage/Connect/Structures/Graph.php
index 6ccfdb0..9b36ab3 100644
--- a/lib/Mage/Connect/Structures/Graph.php
+++ b/lib/Mage/Connect/Structures/Graph.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Structures/Node.php b/lib/Mage/Connect/Structures/Node.php
index 835f6bd..08960a1 100644
--- a/lib/Mage/Connect/Structures/Node.php
+++ b/lib/Mage/Connect/Structures/Node.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Connect/Validator.php b/lib/Mage/Connect/Validator.php
index 0dc6942..e09447e 100644
--- a/lib/Mage/Connect/Validator.php
+++ b/lib/Mage/Connect/Validator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Connect
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/DB/Exception.php b/lib/Mage/DB/Exception.php
index b8201f2..d4f7ced 100644
--- a/lib/Mage/DB/Exception.php
+++ b/lib/Mage/DB/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_DB
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/DB/Mysqli.php b/lib/Mage/DB/Mysqli.php
index 4fa36e0..0751593 100644
--- a/lib/Mage/DB/Mysqli.php
+++ b/lib/Mage/DB/Mysqli.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_DB
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Exception.php b/lib/Mage/Exception.php
index 33d3afa..73144dd 100644
--- a/lib/Mage/Exception.php
+++ b/lib/Mage/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Exception
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/HTTP/Client.php b/lib/Mage/HTTP/Client.php
index 39af513..a550735 100644
--- a/lib/Mage/HTTP/Client.php
+++ b/lib/Mage/HTTP/Client.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/HTTP/Client/Curl.php b/lib/Mage/HTTP/Client/Curl.php
index 8932a2d..133075b 100644
--- a/lib/Mage/HTTP/Client/Curl.php
+++ b/lib/Mage/HTTP/Client/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/HTTP/Client/Socket.php b/lib/Mage/HTTP/Client/Socket.php
index 9a44c49..a96171c 100644
--- a/lib/Mage/HTTP/Client/Socket.php
+++ b/lib/Mage/HTTP/Client/Socket.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/HTTP/IClient.php b/lib/Mage/HTTP/IClient.php
index bd3b24e..9641fd4 100644
--- a/lib/Mage/HTTP/IClient.php
+++ b/lib/Mage/HTTP/IClient.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_HTTP
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/System/Args.php b/lib/Mage/System/Args.php
index 6c24aba..84a7bc4 100644
--- a/lib/Mage/System/Args.php
+++ b/lib/Mage/System/Args.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/System/Dirs.php b/lib/Mage/System/Dirs.php
index 97b31ec..1418383 100644
--- a/lib/Mage/System/Dirs.php
+++ b/lib/Mage/System/Dirs.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_System_Dirs
diff --git a/lib/Mage/System/Ftp.php b/lib/Mage/System/Ftp.php
index ff920a7..77fc71e 100644
--- a/lib/Mage/System/Ftp.php
+++ b/lib/Mage/System/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_System
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Mage/Xml/Generator.php b/lib/Mage/Xml/Generator.php
index f32d7af..92728ad 100644
--- a/lib/Mage/Xml/Generator.php
+++ b/lib/Mage/Xml/Generator.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Xml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Xml_Generator
diff --git a/lib/Mage/Xml/Parser.php b/lib/Mage/Xml/Parser.php
index a70bd94..407b0cc 100644
--- a/lib/Mage/Xml/Parser.php
+++ b/lib/Mage/Xml/Parser.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Xml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 class Mage_Xml_Parser
diff --git a/lib/Magento/Autoload/ClassMap.php b/lib/Magento/Autoload/ClassMap.php
index e60ed72..a9bde05 100644
--- a/lib/Magento/Autoload/ClassMap.php
+++ b/lib/Magento/Autoload/ClassMap.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 namespace Magento\Autoload;
diff --git a/lib/Magento/Autoload/IncludePath.php b/lib/Magento/Autoload/IncludePath.php
index 6c1a91f..5397b00 100644
--- a/lib/Magento/Autoload/IncludePath.php
+++ b/lib/Magento/Autoload/IncludePath.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 namespace Magento\Autoload;
diff --git a/lib/Magento/Autoload/Simple.php b/lib/Magento/Autoload/Simple.php
index 72172f0..8e916d5 100644
--- a/lib/Magento/Autoload/Simple.php
+++ b/lib/Magento/Autoload/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Crypt.php b/lib/Magento/Crypt.php
index b180356..24bb633 100644
--- a/lib/Magento/Crypt.php
+++ b/lib/Magento/Crypt.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Crypt
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Adapter/Pdo/Mysql.php b/lib/Magento/Db/Adapter/Pdo/Mysql.php
index 6ae7e22..c16e2e7 100644
--- a/lib/Magento/Db/Adapter/Pdo/Mysql.php
+++ b/lib/Magento/Db/Adapter/Pdo/Mysql.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Object.php b/lib/Magento/Db/Object.php
index 637970b..4b8707f 100644
--- a/lib/Magento/Db/Object.php
+++ b/lib/Magento/Db/Object.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Object/Interface.php b/lib/Magento/Db/Object/Interface.php
index 7c00eb3..822508f 100644
--- a/lib/Magento/Db/Object/Interface.php
+++ b/lib/Magento/Db/Object/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Object/Table.php b/lib/Magento/Db/Object/Table.php
index 2301ef6..14f13e4 100644
--- a/lib/Magento/Db/Object/Table.php
+++ b/lib/Magento/Db/Object/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Object/Trigger.php b/lib/Magento/Db/Object/Trigger.php
index 8e05ccb..bed4590 100644
--- a/lib/Magento/Db/Object/Trigger.php
+++ b/lib/Magento/Db/Object/Trigger.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Object/View.php b/lib/Magento/Db/Object/View.php
index 1023d31..cb1b278 100644
--- a/lib/Magento/Db/Object/View.php
+++ b/lib/Magento/Db/Object/View.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Sql/Select.php b/lib/Magento/Db/Sql/Select.php
index 55dfde8..888a8a8 100644
--- a/lib/Magento/Db/Sql/Select.php
+++ b/lib/Magento/Db/Sql/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Db/Sql/Trigger.php b/lib/Magento/Db/Sql/Trigger.php
index 118a602..15d73d4 100644
--- a/lib/Magento/Db/Sql/Trigger.php
+++ b/lib/Magento/Db/Sql/Trigger.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Exception.php b/lib/Magento/Exception.php
index 5c51c45..60b301a 100644
--- a/lib/Magento/Exception.php
+++ b/lib/Magento/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Exception
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Profiler.php b/lib/Magento/Profiler.php
index 1ac2108..6b777a5 100644
--- a/lib/Magento/Profiler.php
+++ b/lib/Magento/Profiler.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Profiler/Output/Csvfile.php b/lib/Magento/Profiler/Output/Csvfile.php
index d1a6367..9940499 100644
--- a/lib/Magento/Profiler/Output/Csvfile.php
+++ b/lib/Magento/Profiler/Output/Csvfile.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Profiler/Output/Firebug.php b/lib/Magento/Profiler/Output/Firebug.php
index 4ec9b60..7f5a4c4 100644
--- a/lib/Magento/Profiler/Output/Firebug.php
+++ b/lib/Magento/Profiler/Output/Firebug.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Profiler/Output/Html.php b/lib/Magento/Profiler/Output/Html.php
index 9be6b97..c839d33 100644
--- a/lib/Magento/Profiler/Output/Html.php
+++ b/lib/Magento/Profiler/Output/Html.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Magento/Profiler/OutputAbstract.php b/lib/Magento/Profiler/OutputAbstract.php
index 651283f..72e8001 100644
--- a/lib/Magento/Profiler/OutputAbstract.php
+++ b/lib/Magento/Profiler/OutputAbstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Magento
  * @package     Magento_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Parser.php b/lib/Unserialize/Parser.php
index af524cb..ad88b81 100644
--- a/lib/Unserialize/Parser.php
+++ b/lib/Unserialize/Parser.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Parser
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Arr.php b/lib/Unserialize/Reader/Arr.php
index 5628510..428d4ea 100644
--- a/lib/Unserialize/Reader/Arr.php
+++ b/lib/Unserialize/Reader/Arr.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/ArrKey.php b/lib/Unserialize/Reader/ArrKey.php
index 292e0d8..5694aa3 100644
--- a/lib/Unserialize/Reader/ArrKey.php
+++ b/lib/Unserialize/Reader/ArrKey.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/ArrValue.php b/lib/Unserialize/Reader/ArrValue.php
index 70c8ce1..5aa8bdd 100644
--- a/lib/Unserialize/Reader/ArrValue.php
+++ b/lib/Unserialize/Reader/ArrValue.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Bool.php b/lib/Unserialize/Reader/Bool.php
index 76b9a7b..ac26c77 100644
--- a/lib/Unserialize/Reader/Bool.php
+++ b/lib/Unserialize/Reader/Bool.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Dbl.php b/lib/Unserialize/Reader/Dbl.php
index c6e642d..a26cd67 100644
--- a/lib/Unserialize/Reader/Dbl.php
+++ b/lib/Unserialize/Reader/Dbl.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Int.php b/lib/Unserialize/Reader/Int.php
index e9b1026..1d96a1f 100644
--- a/lib/Unserialize/Reader/Int.php
+++ b/lib/Unserialize/Reader/Int.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Null.php b/lib/Unserialize/Reader/Null.php
index 2b5ae0d..4e44027 100644
--- a/lib/Unserialize/Reader/Null.php
+++ b/lib/Unserialize/Reader/Null.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Unserialize/Reader/Str.php b/lib/Unserialize/Reader/Str.php
index b1383cb..cda81ef 100644
--- a/lib/Unserialize/Reader/Str.php
+++ b/lib/Unserialize/Reader/Str.php
@@ -20,7 +20,7 @@
  *
  * @category    Unserialize
  * @package     Unserialize_Reader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Autoload.php b/lib/Varien/Autoload.php
index f91fec5..786e39d 100644
--- a/lib/Varien/Autoload.php
+++ b/lib/Varien/Autoload.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Autoload
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Cache/Backend/Database.php b/lib/Varien/Cache/Backend/Database.php
index 86f34fb..c5332eb 100644
--- a/lib/Varien/Cache/Backend/Database.php
+++ b/lib/Varien/Cache/Backend/Database.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Cache/Backend/Eaccelerator.php b/lib/Varien/Cache/Backend/Eaccelerator.php
index 81e6435..4a8d111 100644
--- a/lib/Varien/Cache/Backend/Eaccelerator.php
+++ b/lib/Varien/Cache/Backend/Eaccelerator.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Cache/Backend/Memcached.php b/lib/Varien/Cache/Backend/Memcached.php
index bad89df..379af19 100644
--- a/lib/Varien/Cache/Backend/Memcached.php
+++ b/lib/Varien/Cache/Backend/Memcached.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Cache/Core.php b/lib/Varien/Cache/Core.php
index f980c09..0d2468a 100644
--- a/lib/Varien/Cache/Core.php
+++ b/lib/Varien/Cache/Core.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Cache
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert.php b/lib/Varien/Convert.php
index 7f6061a..1e9beff 100644
--- a/lib/Varien/Convert.php
+++ b/lib/Varien/Convert.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Action.php b/lib/Varien/Convert/Action.php
index 2513780..91edef3 100644
--- a/lib/Varien/Convert/Action.php
+++ b/lib/Varien/Convert/Action.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Action/Abstract.php b/lib/Varien/Convert/Action/Abstract.php
index d38610a..d04e4b8 100644
--- a/lib/Varien/Convert/Action/Abstract.php
+++ b/lib/Varien/Convert/Action/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Action/Interface.php b/lib/Varien/Convert/Action/Interface.php
index 16be74f..889a206 100644
--- a/lib/Varien/Convert/Action/Interface.php
+++ b/lib/Varien/Convert/Action/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Abstract.php b/lib/Varien/Convert/Adapter/Abstract.php
index bd67a06..a43a2bf 100644
--- a/lib/Varien/Convert/Adapter/Abstract.php
+++ b/lib/Varien/Convert/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Db/Table.php b/lib/Varien/Convert/Adapter/Db/Table.php
index 90984a3..d41d708 100644
--- a/lib/Varien/Convert/Adapter/Db/Table.php
+++ b/lib/Varien/Convert/Adapter/Db/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Http.php b/lib/Varien/Convert/Adapter/Http.php
index b574826..cab58f6 100644
--- a/lib/Varien/Convert/Adapter/Http.php
+++ b/lib/Varien/Convert/Adapter/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Http/Curl.php b/lib/Varien/Convert/Adapter/Http/Curl.php
index adaf596..85bed97 100644
--- a/lib/Varien/Convert/Adapter/Http/Curl.php
+++ b/lib/Varien/Convert/Adapter/Http/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Interface.php b/lib/Varien/Convert/Adapter/Interface.php
index 03620a8..1ad3391 100644
--- a/lib/Varien/Convert/Adapter/Interface.php
+++ b/lib/Varien/Convert/Adapter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Io.php b/lib/Varien/Convert/Adapter/Io.php
index d571975..e8f1c80 100644
--- a/lib/Varien/Convert/Adapter/Io.php
+++ b/lib/Varien/Convert/Adapter/Io.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Soap.php b/lib/Varien/Convert/Adapter/Soap.php
index eff96cc..c6f1d92 100644
--- a/lib/Varien/Convert/Adapter/Soap.php
+++ b/lib/Varien/Convert/Adapter/Soap.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Std.php b/lib/Varien/Convert/Adapter/Std.php
index 4d3809f..fec5fbd 100644
--- a/lib/Varien/Convert/Adapter/Std.php
+++ b/lib/Varien/Convert/Adapter/Std.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Zend/Cache.php b/lib/Varien/Convert/Adapter/Zend/Cache.php
index 4eb64fc..e1d8f1c 100644
--- a/lib/Varien/Convert/Adapter/Zend/Cache.php
+++ b/lib/Varien/Convert/Adapter/Zend/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Adapter/Zend/Db.php b/lib/Varien/Convert/Adapter/Zend/Db.php
index 95b0d18..5a11883 100644
--- a/lib/Varien/Convert/Adapter/Zend/Db.php
+++ b/lib/Varien/Convert/Adapter/Zend/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Container/Abstract.php b/lib/Varien/Convert/Container/Abstract.php
index abf36d7..9ddef7b 100644
--- a/lib/Varien/Convert/Container/Abstract.php
+++ b/lib/Varien/Convert/Container/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Container/Collection.php b/lib/Varien/Convert/Container/Collection.php
index 8d2ecbb..05a9350 100644
--- a/lib/Varien/Convert/Container/Collection.php
+++ b/lib/Varien/Convert/Container/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Container/Generic.php b/lib/Varien/Convert/Container/Generic.php
index a02a60b..e163023 100644
--- a/lib/Varien/Convert/Container/Generic.php
+++ b/lib/Varien/Convert/Container/Generic.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Container/Interface.php b/lib/Varien/Convert/Container/Interface.php
index 23d2828..611e7ea 100644
--- a/lib/Varien/Convert/Container/Interface.php
+++ b/lib/Varien/Convert/Container/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Exception.php b/lib/Varien/Convert/Exception.php
index 5a32b9e..f478d37 100644
--- a/lib/Varien/Convert/Exception.php
+++ b/lib/Varien/Convert/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Mapper/Abstract.php b/lib/Varien/Convert/Mapper/Abstract.php
index 625ad97..03b6e4d 100644
--- a/lib/Varien/Convert/Mapper/Abstract.php
+++ b/lib/Varien/Convert/Mapper/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Mapper/Column.php b/lib/Varien/Convert/Mapper/Column.php
index 8955c21..731c353 100644
--- a/lib/Varien/Convert/Mapper/Column.php
+++ b/lib/Varien/Convert/Mapper/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Mapper/Interface.php b/lib/Varien/Convert/Mapper/Interface.php
index 748c872..9f47963 100644
--- a/lib/Varien/Convert/Mapper/Interface.php
+++ b/lib/Varien/Convert/Mapper/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Parser/Abstract.php b/lib/Varien/Convert/Parser/Abstract.php
index 5eddb21..5fdc72f 100644
--- a/lib/Varien/Convert/Parser/Abstract.php
+++ b/lib/Varien/Convert/Parser/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Parser/Csv.php b/lib/Varien/Convert/Parser/Csv.php
index b8ff592..445b3c8 100644
--- a/lib/Varien/Convert/Parser/Csv.php
+++ b/lib/Varien/Convert/Parser/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Parser/Interface.php b/lib/Varien/Convert/Parser/Interface.php
index 1d9de67..920df50 100644
--- a/lib/Varien/Convert/Parser/Interface.php
+++ b/lib/Varien/Convert/Parser/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Parser/Serialize.php b/lib/Varien/Convert/Parser/Serialize.php
index 5fd94c2..8b04d14 100644
--- a/lib/Varien/Convert/Parser/Serialize.php
+++ b/lib/Varien/Convert/Parser/Serialize.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Parser/Xml/Excel.php b/lib/Varien/Convert/Parser/Xml/Excel.php
index 063b73b..1824eb0 100644
--- a/lib/Varien/Convert/Parser/Xml/Excel.php
+++ b/lib/Varien/Convert/Parser/Xml/Excel.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Profile.php b/lib/Varien/Convert/Profile.php
index ab37a74..f55005f 100644
--- a/lib/Varien/Convert/Profile.php
+++ b/lib/Varien/Convert/Profile.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Profile/Abstract.php b/lib/Varien/Convert/Profile/Abstract.php
index 236bcb2..1ca42d3 100644
--- a/lib/Varien/Convert/Profile/Abstract.php
+++ b/lib/Varien/Convert/Profile/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Profile/Collection.php b/lib/Varien/Convert/Profile/Collection.php
index ca09d0e..f12ca4b 100644
--- a/lib/Varien/Convert/Profile/Collection.php
+++ b/lib/Varien/Convert/Profile/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Validator/Abstract.php b/lib/Varien/Convert/Validator/Abstract.php
index 6bf055e..f20cfdd 100644
--- a/lib/Varien/Convert/Validator/Abstract.php
+++ b/lib/Varien/Convert/Validator/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Validator/Column.php b/lib/Varien/Convert/Validator/Column.php
index af960a1..c84b83a 100644
--- a/lib/Varien/Convert/Validator/Column.php
+++ b/lib/Varien/Convert/Validator/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Validator/Dryrun.php b/lib/Varien/Convert/Validator/Dryrun.php
index 98f63ec..d528b48 100644
--- a/lib/Varien/Convert/Validator/Dryrun.php
+++ b/lib/Varien/Convert/Validator/Dryrun.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Convert/Validator/Interface.php b/lib/Varien/Convert/Validator/Interface.php
index b683d25..6975437 100644
--- a/lib/Varien/Convert/Validator/Interface.php
+++ b/lib/Varien/Convert/Validator/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Convert
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Crypt.php b/lib/Varien/Crypt.php
index 5159e81..f9fcd47 100644
--- a/lib/Varien/Crypt.php
+++ b/lib/Varien/Crypt.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Crypt
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Crypt/Abstract.php b/lib/Varien/Crypt/Abstract.php
index 5b41bad..973c953 100644
--- a/lib/Varien/Crypt/Abstract.php
+++ b/lib/Varien/Crypt/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Crypt
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Crypt/Mcrypt.php b/lib/Varien/Crypt/Mcrypt.php
index a1ec6c8..6e2a900 100644
--- a/lib/Varien/Crypt/Mcrypt.php
+++ b/lib/Varien/Crypt/Mcrypt.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Crypt
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Collection.php b/lib/Varien/Data/Collection.php
index 4b972f5..b145d4c 100644
--- a/lib/Varien/Data/Collection.php
+++ b/lib/Varien/Data/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Collection/Db.php b/lib/Varien/Data/Collection/Db.php
index ba99ad9..72d5412 100644
--- a/lib/Varien/Data/Collection/Db.php
+++ b/lib/Varien/Data/Collection/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Collection/Filesystem.php b/lib/Varien/Data/Collection/Filesystem.php
index 46e3d6d..690baed 100644
--- a/lib/Varien/Data/Collection/Filesystem.php
+++ b/lib/Varien/Data/Collection/Filesystem.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form.php b/lib/Varien/Data/Form.php
index 679d1e8..9347f40 100644
--- a/lib/Varien/Data/Form.php
+++ b/lib/Varien/Data/Form.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Abstract.php b/lib/Varien/Data/Form/Abstract.php
index 1bc3e0e..48a1f59 100644
--- a/lib/Varien/Data/Form/Abstract.php
+++ b/lib/Varien/Data/Form/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Abstract.php b/lib/Varien/Data/Form/Element/Abstract.php
index 66e27d7..75139ae 100644
--- a/lib/Varien/Data/Form/Element/Abstract.php
+++ b/lib/Varien/Data/Form/Element/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Button.php b/lib/Varien/Data/Form/Element/Button.php
index 938184f..c61d740 100644
--- a/lib/Varien/Data/Form/Element/Button.php
+++ b/lib/Varien/Data/Form/Element/Button.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Checkbox.php b/lib/Varien/Data/Form/Element/Checkbox.php
index 69fbb6f..c15a316 100644
--- a/lib/Varien/Data/Form/Element/Checkbox.php
+++ b/lib/Varien/Data/Form/Element/Checkbox.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Checkboxes.php b/lib/Varien/Data/Form/Element/Checkboxes.php
index 926f79d..6673a93 100644
--- a/lib/Varien/Data/Form/Element/Checkboxes.php
+++ b/lib/Varien/Data/Form/Element/Checkboxes.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Collection.php b/lib/Varien/Data/Form/Element/Collection.php
index 334a3d3..1c94a27 100644
--- a/lib/Varien/Data/Form/Element/Collection.php
+++ b/lib/Varien/Data/Form/Element/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Column.php b/lib/Varien/Data/Form/Element/Column.php
index cd54649..2fda1e5 100644
--- a/lib/Varien/Data/Form/Element/Column.php
+++ b/lib/Varien/Data/Form/Element/Column.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Date.php b/lib/Varien/Data/Form/Element/Date.php
index 61cfa97..c213dd7 100644
--- a/lib/Varien/Data/Form/Element/Date.php
+++ b/lib/Varien/Data/Form/Element/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Datetime.php b/lib/Varien/Data/Form/Element/Datetime.php
index 6f607da..d967b3e 100644
--- a/lib/Varien/Data/Form/Element/Datetime.php
+++ b/lib/Varien/Data/Form/Element/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Editor.php b/lib/Varien/Data/Form/Element/Editor.php
index 07c28c1..5921a40 100644
--- a/lib/Varien/Data/Form/Element/Editor.php
+++ b/lib/Varien/Data/Form/Element/Editor.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Fieldset.php b/lib/Varien/Data/Form/Element/Fieldset.php
index 0d902f8..23cb182 100644
--- a/lib/Varien/Data/Form/Element/Fieldset.php
+++ b/lib/Varien/Data/Form/Element/Fieldset.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/File.php b/lib/Varien/Data/Form/Element/File.php
index 8e88605..6345541 100644
--- a/lib/Varien/Data/Form/Element/File.php
+++ b/lib/Varien/Data/Form/Element/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Gallery.php b/lib/Varien/Data/Form/Element/Gallery.php
index 36595dc..975cd2b 100644
--- a/lib/Varien/Data/Form/Element/Gallery.php
+++ b/lib/Varien/Data/Form/Element/Gallery.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Hidden.php b/lib/Varien/Data/Form/Element/Hidden.php
index fffd15e..ad0e422 100644
--- a/lib/Varien/Data/Form/Element/Hidden.php
+++ b/lib/Varien/Data/Form/Element/Hidden.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Image.php b/lib/Varien/Data/Form/Element/Image.php
index 3c52a6b..47ace17 100644
--- a/lib/Varien/Data/Form/Element/Image.php
+++ b/lib/Varien/Data/Form/Element/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Imagefile.php b/lib/Varien/Data/Form/Element/Imagefile.php
index 8a0800b..841a0ae 100644
--- a/lib/Varien/Data/Form/Element/Imagefile.php
+++ b/lib/Varien/Data/Form/Element/Imagefile.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Label.php b/lib/Varien/Data/Form/Element/Label.php
index e7faf54..645e392 100644
--- a/lib/Varien/Data/Form/Element/Label.php
+++ b/lib/Varien/Data/Form/Element/Label.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Link.php b/lib/Varien/Data/Form/Element/Link.php
index 388e05a..18b5f85 100644
--- a/lib/Varien/Data/Form/Element/Link.php
+++ b/lib/Varien/Data/Form/Element/Link.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Multiline.php b/lib/Varien/Data/Form/Element/Multiline.php
index 582ae15..c61c395 100644
--- a/lib/Varien/Data/Form/Element/Multiline.php
+++ b/lib/Varien/Data/Form/Element/Multiline.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Multiselect.php b/lib/Varien/Data/Form/Element/Multiselect.php
index 679a783..e3fc7e9 100644
--- a/lib/Varien/Data/Form/Element/Multiselect.php
+++ b/lib/Varien/Data/Form/Element/Multiselect.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Note.php b/lib/Varien/Data/Form/Element/Note.php
index 5283aa2..a0e162a 100644
--- a/lib/Varien/Data/Form/Element/Note.php
+++ b/lib/Varien/Data/Form/Element/Note.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Obscure.php b/lib/Varien/Data/Form/Element/Obscure.php
index d83dfa8..d56295d 100644
--- a/lib/Varien/Data/Form/Element/Obscure.php
+++ b/lib/Varien/Data/Form/Element/Obscure.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Password.php b/lib/Varien/Data/Form/Element/Password.php
index c726f1a..6dc4030 100644
--- a/lib/Varien/Data/Form/Element/Password.php
+++ b/lib/Varien/Data/Form/Element/Password.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Radio.php b/lib/Varien/Data/Form/Element/Radio.php
index 1004fc7..e5ee39b 100644
--- a/lib/Varien/Data/Form/Element/Radio.php
+++ b/lib/Varien/Data/Form/Element/Radio.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Radios.php b/lib/Varien/Data/Form/Element/Radios.php
index 9f9bc63..b52fc5f 100644
--- a/lib/Varien/Data/Form/Element/Radios.php
+++ b/lib/Varien/Data/Form/Element/Radios.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Renderer/Interface.php b/lib/Varien/Data/Form/Element/Renderer/Interface.php
index a5259b2..2c1cfd4 100644
--- a/lib/Varien/Data/Form/Element/Renderer/Interface.php
+++ b/lib/Varien/Data/Form/Element/Renderer/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Reset.php b/lib/Varien/Data/Form/Element/Reset.php
index 6a6bdae..40e99a3 100644
--- a/lib/Varien/Data/Form/Element/Reset.php
+++ b/lib/Varien/Data/Form/Element/Reset.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Select.php b/lib/Varien/Data/Form/Element/Select.php
index 146d930..3dc5e3b 100644
--- a/lib/Varien/Data/Form/Element/Select.php
+++ b/lib/Varien/Data/Form/Element/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Submit.php b/lib/Varien/Data/Form/Element/Submit.php
index 798b82b..23b6d81 100644
--- a/lib/Varien/Data/Form/Element/Submit.php
+++ b/lib/Varien/Data/Form/Element/Submit.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Text.php b/lib/Varien/Data/Form/Element/Text.php
index e35b754..a9f26e7 100644
--- a/lib/Varien/Data/Form/Element/Text.php
+++ b/lib/Varien/Data/Form/Element/Text.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Textarea.php b/lib/Varien/Data/Form/Element/Textarea.php
index bf9e179..d83d8b8 100644
--- a/lib/Varien/Data/Form/Element/Textarea.php
+++ b/lib/Varien/Data/Form/Element/Textarea.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Element/Time.php b/lib/Varien/Data/Form/Element/Time.php
index 51d4dc9..113dcdd 100644
--- a/lib/Varien/Data/Form/Element/Time.php
+++ b/lib/Varien/Data/Form/Element/Time.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Filter/Date.php b/lib/Varien/Data/Form/Filter/Date.php
index b6ce861..f6dbb12 100644
--- a/lib/Varien/Data/Form/Filter/Date.php
+++ b/lib/Varien/Data/Form/Filter/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Filter/Datetime.php b/lib/Varien/Data/Form/Filter/Datetime.php
index 9a9da9e..d9bf177 100644
--- a/lib/Varien/Data/Form/Filter/Datetime.php
+++ b/lib/Varien/Data/Form/Filter/Datetime.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Filter/Escapehtml.php b/lib/Varien/Data/Form/Filter/Escapehtml.php
index f5bc370..c6180b5 100644
--- a/lib/Varien/Data/Form/Filter/Escapehtml.php
+++ b/lib/Varien/Data/Form/Filter/Escapehtml.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Filter/Interface.php b/lib/Varien/Data/Form/Filter/Interface.php
index ed59fce..a0a4b47 100644
--- a/lib/Varien/Data/Form/Filter/Interface.php
+++ b/lib/Varien/Data/Form/Filter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Form/Filter/Striptags.php b/lib/Varien/Data/Form/Filter/Striptags.php
index 8a4e0d9..e82c6fa 100644
--- a/lib/Varien/Data/Form/Filter/Striptags.php
+++ b/lib/Varien/Data/Form/Filter/Striptags.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Tree.php b/lib/Varien/Data/Tree.php
index 5e8b7a2..2ba200f 100644
--- a/lib/Varien/Data/Tree.php
+++ b/lib/Varien/Data/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Tree/Db.php b/lib/Varien/Data/Tree/Db.php
index e9f4916..b5a3db7 100644
--- a/lib/Varien/Data/Tree/Db.php
+++ b/lib/Varien/Data/Tree/Db.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Tree/Dbp.php b/lib/Varien/Data/Tree/Dbp.php
index b61fcbb..b7ac250 100644
--- a/lib/Varien/Data/Tree/Dbp.php
+++ b/lib/Varien/Data/Tree/Dbp.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Tree/Node.php b/lib/Varien/Data/Tree/Node.php
index a5d1356..1e4998b 100644
--- a/lib/Varien/Data/Tree/Node.php
+++ b/lib/Varien/Data/Tree/Node.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Data/Tree/Node/Collection.php b/lib/Varien/Data/Tree/Node/Collection.php
index 743dbe5..3521737 100644
--- a/lib/Varien/Data/Tree/Node/Collection.php
+++ b/lib/Varien/Data/Tree/Node/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Data
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Date.php b/lib/Varien/Date.php
index e291349..55bf5d0 100644
--- a/lib/Varien/Date.php
+++ b/lib/Varien/Date.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Date
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Adapter/Interface.php b/lib/Varien/Db/Adapter/Interface.php
index 8762b69..f6698b0 100644
--- a/lib/Varien/Db/Adapter/Interface.php
+++ b/lib/Varien/Db/Adapter/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Adapter/Mysqli.php b/lib/Varien/Db/Adapter/Mysqli.php
index 7861f0b..1c99514 100644
--- a/lib/Varien/Db/Adapter/Mysqli.php
+++ b/lib/Varien/Db/Adapter/Mysqli.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Adapter/Pdo/Mysql.php b/lib/Varien/Db/Adapter/Pdo/Mysql.php
index e6f48cf..511b9e2 100644
--- a/lib/Varien/Db/Adapter/Pdo/Mysql.php
+++ b/lib/Varien/Db/Adapter/Pdo/Mysql.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -2947,7 +2947,7 @@ class Varien_Db_Adapter_Pdo_Mysql extends Zend_Db_Adapter_Pdo_Mysql implements V
                 if (isset($condition['to'])) {
                     $query .= empty($query) ? '' : ' AND ';
                     $to     = $this->_prepareSqlDateCondition($condition, 'to');
-                    $query = $this->_prepareQuotedSqlCondition($query . $conditionKeyMap['to'], $to, $fieldName);
+                    $query = $query . $this->_prepareQuotedSqlCondition($conditionKeyMap['to'], $to, $fieldName);
                 }
             } elseif (array_key_exists($key, $conditionKeyMap)) {
                 $value = $condition[$key];
diff --git a/lib/Varien/Db/Ddl/Table.php b/lib/Varien/Db/Ddl/Table.php
index 8c2f3cc..79ff889 100644
--- a/lib/Varien/Db/Ddl/Table.php
+++ b/lib/Varien/Db/Ddl/Table.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Exception.php b/lib/Varien/Db/Exception.php
index b0c4d83..4c48dce 100644
--- a/lib/Varien/Db/Exception.php
+++ b/lib/Varien/Db/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Helper.php b/lib/Varien/Db/Helper.php
index 042484f..4c8156c 100644
--- a/lib/Varien/Db/Helper.php
+++ b/lib/Varien/Db/Helper.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Select.php b/lib/Varien/Db/Select.php
index 2f9ed4b..ad2c580 100644
--- a/lib/Varien/Db/Select.php
+++ b/lib/Varien/Db/Select.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Statement/Parameter.php b/lib/Varien/Db/Statement/Parameter.php
index 85b9875..2a2f2e9 100644
--- a/lib/Varien/Db/Statement/Parameter.php
+++ b/lib/Varien/Db/Statement/Parameter.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Statement/Pdo/Mysql.php b/lib/Varien/Db/Statement/Pdo/Mysql.php
index a4b85da..5fe8796 100644
--- a/lib/Varien/Db/Statement/Pdo/Mysql.php
+++ b/lib/Varien/Db/Statement/Pdo/Mysql.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree.php b/lib/Varien/Db/Tree.php
index 4b9a4a0..051a894 100644
--- a/lib/Varien/Db/Tree.php
+++ b/lib/Varien/Db/Tree.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree/Exception.php b/lib/Varien/Db/Tree/Exception.php
index ecf5d51..47eb885 100644
--- a/lib/Varien/Db/Tree/Exception.php
+++ b/lib/Varien/Db/Tree/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree/Node.php b/lib/Varien/Db/Tree/Node.php
index b5aba46..c8f27c0 100644
--- a/lib/Varien/Db/Tree/Node.php
+++ b/lib/Varien/Db/Tree/Node.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree/Node/Exception.php b/lib/Varien/Db/Tree/Node/Exception.php
index e591fdf..f5f5ddd 100644
--- a/lib/Varien/Db/Tree/Node/Exception.php
+++ b/lib/Varien/Db/Tree/Node/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree/NodeSet.php b/lib/Varien/Db/Tree/NodeSet.php
index 310221d..c27508f 100644
--- a/lib/Varien/Db/Tree/NodeSet.php
+++ b/lib/Varien/Db/Tree/NodeSet.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Db/Tree/NodeSet/Exception.php b/lib/Varien/Db/Tree/NodeSet/Exception.php
index c3f7302..72392fa 100644
--- a/lib/Varien/Db/Tree/NodeSet/Exception.php
+++ b/lib/Varien/Db/Tree/NodeSet/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Db
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Debug.php b/lib/Varien/Debug.php
index 35666c6..7500915 100644
--- a/lib/Varien/Debug.php
+++ b/lib/Varien/Debug.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Debug
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Directory/Collection.php b/lib/Varien/Directory/Collection.php
index 42ba931..235139f 100644
--- a/lib/Varien/Directory/Collection.php
+++ b/lib/Varien/Directory/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Directory/Factory.php b/lib/Varien/Directory/Factory.php
index c4b68c6..cd972c0 100644
--- a/lib/Varien/Directory/Factory.php
+++ b/lib/Varien/Directory/Factory.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Directory/IFactory.php b/lib/Varien/Directory/IFactory.php
index 421d46e..0a3348a 100644
--- a/lib/Varien/Directory/IFactory.php
+++ b/lib/Varien/Directory/IFactory.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Directory
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event.php b/lib/Varien/Event.php
index 9143bc0..e24be4e 100644
--- a/lib/Varien/Event.php
+++ b/lib/Varien/Event.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event/Collection.php b/lib/Varien/Event/Collection.php
index a80ef6e..5018654 100644
--- a/lib/Varien/Event/Collection.php
+++ b/lib/Varien/Event/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event/Observer.php b/lib/Varien/Event/Observer.php
index 1ca7c41..7a8a8c0 100644
--- a/lib/Varien/Event/Observer.php
+++ b/lib/Varien/Event/Observer.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event/Observer/Collection.php b/lib/Varien/Event/Observer/Collection.php
index 022ea6e..9ba8265 100644
--- a/lib/Varien/Event/Observer/Collection.php
+++ b/lib/Varien/Event/Observer/Collection.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event/Observer/Cron.php b/lib/Varien/Event/Observer/Cron.php
index 9a08061..2bf2239 100644
--- a/lib/Varien/Event/Observer/Cron.php
+++ b/lib/Varien/Event/Observer/Cron.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Event/Observer/Regex.php b/lib/Varien/Event/Observer/Regex.php
index 1488b81..ea1f889 100644
--- a/lib/Varien/Event/Observer/Regex.php
+++ b/lib/Varien/Event/Observer/Regex.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Event
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Exception.php b/lib/Varien/Exception.php
index ca0c5b1..36c069a 100644
--- a/lib/Varien/Exception.php
+++ b/lib/Varien/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Exception
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/Csv.php b/lib/Varien/File/Csv.php
index 11f282c..2671d00 100644
--- a/lib/Varien/File/Csv.php
+++ b/lib/Varien/File/Csv.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/CsvMulty.php b/lib/Varien/File/CsvMulty.php
index 69cb160..e0dffb3 100644
--- a/lib/Varien/File/CsvMulty.php
+++ b/lib/Varien/File/CsvMulty.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/Object.php b/lib/Varien/File/Object.php
index ecb492a..33b5b6a 100644
--- a/lib/Varien/File/Object.php
+++ b/lib/Varien/File/Object.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/Transfer/Adapter/Http.php b/lib/Varien/File/Transfer/Adapter/Http.php
index 5547835..34861ba 100644
--- a/lib/Varien/File/Transfer/Adapter/Http.php
+++ b/lib/Varien/File/Transfer/Adapter/Http.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/Uploader.php b/lib/Varien/File/Uploader.php
index 6b797ba..ce6e088 100644
--- a/lib/Varien/File/Uploader.php
+++ b/lib/Varien/File/Uploader.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/File/Uploader/Image.php b/lib/Varien/File/Uploader/Image.php
index 06cac84..8dc2005 100644
--- a/lib/Varien/File/Uploader/Image.php
+++ b/lib/Varien/File/Uploader/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_File
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Array.php b/lib/Varien/Filter/Array.php
index 47f6af8..d326e91 100644
--- a/lib/Varien/Filter/Array.php
+++ b/lib/Varien/Filter/Array.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Array/Grid.php b/lib/Varien/Filter/Array/Grid.php
index abdd72d..e4ed407 100644
--- a/lib/Varien/Filter/Array/Grid.php
+++ b/lib/Varien/Filter/Array/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Email.php b/lib/Varien/Filter/Email.php
index 1cec3d2..e85b98f 100644
--- a/lib/Varien/Filter/Email.php
+++ b/lib/Varien/Filter/Email.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/FormElementName.php b/lib/Varien/Filter/FormElementName.php
index 6be7a08..642178e 100644
--- a/lib/Varien/Filter/FormElementName.php
+++ b/lib/Varien/Filter/FormElementName.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Money.php b/lib/Varien/Filter/Money.php
index 9d3f7f0..0222cc1 100644
--- a/lib/Varien/Filter/Money.php
+++ b/lib/Varien/Filter/Money.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Object.php b/lib/Varien/Filter/Object.php
index 8019d8f..31f5bfe 100644
--- a/lib/Varien/Filter/Object.php
+++ b/lib/Varien/Filter/Object.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Object/Grid.php b/lib/Varien/Filter/Object/Grid.php
index f99a6de..1491adc 100644
--- a/lib/Varien/Filter/Object/Grid.php
+++ b/lib/Varien/Filter/Object/Grid.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Sprintf.php b/lib/Varien/Filter/Sprintf.php
index 41f065d..7176bde 100644
--- a/lib/Varien/Filter/Sprintf.php
+++ b/lib/Varien/Filter/Sprintf.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Template.php b/lib/Varien/Filter/Template.php
index f6c5689..ff41946 100644
--- a/lib/Varien/Filter/Template.php
+++ b/lib/Varien/Filter/Template.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
@@ -289,6 +289,8 @@ class Varien_Filter_Template implements Zend_Filter_Interface
         $stackVars = $tokenizer->tokenize();
         $result = $default;
         $last = 0;
+        /** @var $emailPathValidator Mage_Adminhtml_Model_Email_PathValidator */
+        $emailPathValidator = $this->getEmailPathValidator();
         for($i = 0; $i < count($stackVars); $i ++) {
             if ($i == 0 && isset($this->_templateVars[$stackVars[$i]['name']])) {
                 // Getting of template value
@@ -305,9 +307,13 @@ class Varien_Filter_Template implements Zend_Filter_Interface
                     if (method_exists($stackVars[$i-1]['variable'], $stackVars[$i]['name'])
                         || substr($stackVars[$i]['name'], 0, 3) == 'get'
                     ) {
+                        $isEncrypted = false;
+                        if ($stackVars[$i]['name'] == 'getConfig') {
+                            $isEncrypted = $emailPathValidator->isValid($stackVars[$i]['args']);
+                        }
                         $stackVars[$i]['variable'] = call_user_func_array(
                             array($stackVars[$i-1]['variable'], $stackVars[$i]['name']),
-                            $stackVars[$i]['args']
+                            !$isEncrypted ? $stackVars[$i]['args'] : array(null)
                         );
                     }
                 }
@@ -322,4 +328,14 @@ class Varien_Filter_Template implements Zend_Filter_Interface
         Varien_Profiler::stop("email_template_proccessing_variables");
         return $result;
     }
+
+    /**
+     * Retrieve model object
+     *
+     * @return Mage_Core_Model_Abstract
+     */
+    protected function getEmailPathValidator()
+    {
+        return Mage::getModel('adminhtml/email_pathValidator');
+    }
 }
diff --git a/lib/Varien/Filter/Template/Simple.php b/lib/Varien/Filter/Template/Simple.php
index 575cf32..32ead87 100644
--- a/lib/Varien/Filter/Template/Simple.php
+++ b/lib/Varien/Filter/Template/Simple.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Template/Tokenizer/Abstract.php b/lib/Varien/Filter/Template/Tokenizer/Abstract.php
index 62035db..05c1835 100644
--- a/lib/Varien/Filter/Template/Tokenizer/Abstract.php
+++ b/lib/Varien/Filter/Template/Tokenizer/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Template/Tokenizer/Parameter.php b/lib/Varien/Filter/Template/Tokenizer/Parameter.php
index f1e5e5d..2650caf 100644
--- a/lib/Varien/Filter/Template/Tokenizer/Parameter.php
+++ b/lib/Varien/Filter/Template/Tokenizer/Parameter.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Filter/Template/Tokenizer/Variable.php b/lib/Varien/Filter/Template/Tokenizer/Variable.php
index 430a7de..f55b03a 100644
--- a/lib/Varien/Filter/Template/Tokenizer/Variable.php
+++ b/lib/Varien/Filter/Template/Tokenizer/Variable.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Filter
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Http/Adapter/Curl.php b/lib/Varien/Http/Adapter/Curl.php
index 0114e2e..a3539a2 100644
--- a/lib/Varien/Http/Adapter/Curl.php
+++ b/lib/Varien/Http/Adapter/Curl.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Http
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Http/Client.php b/lib/Varien/Http/Client.php
index 0f0fd1c..d3298e1 100644
--- a/lib/Varien/Http/Client.php
+++ b/lib/Varien/Http/Client.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Http
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Image.php b/lib/Varien/Image.php
index 8335a1c..a5d9c6f 100644
--- a/lib/Varien/Image.php
+++ b/lib/Varien/Image.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Image
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Image/Adapter.php b/lib/Varien/Image/Adapter.php
index 2fc44b4..852b229 100644
--- a/lib/Varien/Image/Adapter.php
+++ b/lib/Varien/Image/Adapter.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Image
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Image/Adapter/Abstract.php b/lib/Varien/Image/Adapter/Abstract.php
index cdd095f..ccba925 100644
--- a/lib/Varien/Image/Adapter/Abstract.php
+++ b/lib/Varien/Image/Adapter/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Image
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Image/Adapter/Gd2.php b/lib/Varien/Image/Adapter/Gd2.php
index 8fde3e0..84d0f35 100644
--- a/lib/Varien/Image/Adapter/Gd2.php
+++ b/lib/Varien/Image/Adapter/Gd2.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Image
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/Abstract.php b/lib/Varien/Io/Abstract.php
index dea584f..12f8050 100644
--- a/lib/Varien/Io/Abstract.php
+++ b/lib/Varien/Io/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/Exception.php b/lib/Varien/Io/Exception.php
index 8451003..7a25486 100644
--- a/lib/Varien/Io/Exception.php
+++ b/lib/Varien/Io/Exception.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/File.php b/lib/Varien/Io/File.php
index 7204198..0ed20e0 100644
--- a/lib/Varien/Io/File.php
+++ b/lib/Varien/Io/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/Ftp.php b/lib/Varien/Io/Ftp.php
index 1047f36..6c4bdf7 100644
--- a/lib/Varien/Io/Ftp.php
+++ b/lib/Varien/Io/Ftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/Interface.php b/lib/Varien/Io/Interface.php
index 8302f00..6056b5d 100644
--- a/lib/Varien/Io/Interface.php
+++ b/lib/Varien/Io/Interface.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Io/Sftp.php b/lib/Varien/Io/Sftp.php
index 2e22c60..054d353 100644
--- a/lib/Varien/Io/Sftp.php
+++ b/lib/Varien/Io/Sftp.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Io
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Object.php b/lib/Varien/Object.php
index 17c76b9..be0b58c 100644
--- a/lib/Varien/Object.php
+++ b/lib/Varien/Object.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Object
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Object/Cache.php b/lib/Varien/Object/Cache.php
index 44056b6..a8a2b29 100644
--- a/lib/Varien/Object/Cache.php
+++ b/lib/Varien/Object/Cache.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Object
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Object/Mapper.php b/lib/Varien/Object/Mapper.php
index f446eb3..0e29dce 100644
--- a/lib/Varien/Object/Mapper.php
+++ b/lib/Varien/Object/Mapper.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Object
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Pear.php b/lib/Varien/Pear.php
index 4056501..cc0e2f5 100644
--- a/lib/Varien/Pear.php
+++ b/lib/Varien/Pear.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Pear
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Pear/Frontend.php b/lib/Varien/Pear/Frontend.php
index 23e866d..9182857 100644
--- a/lib/Varien/Pear/Frontend.php
+++ b/lib/Varien/Pear/Frontend.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Pear
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Pear/Package.php b/lib/Varien/Pear/Package.php
index 7375908..db8b06e 100644
--- a/lib/Varien/Pear/Package.php
+++ b/lib/Varien/Pear/Package.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Pear
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Pear/Registry.php b/lib/Varien/Pear/Registry.php
index de7c36f..5f0d064 100644
--- a/lib/Varien/Pear/Registry.php
+++ b/lib/Varien/Pear/Registry.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Pear
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Profiler.php b/lib/Varien/Profiler.php
index 431f631..89b724a 100644
--- a/lib/Varien/Profiler.php
+++ b/lib/Varien/Profiler.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Profiler
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Simplexml/Config.php b/lib/Varien/Simplexml/Config.php
index a988c1f..5f552a5 100644
--- a/lib/Varien/Simplexml/Config.php
+++ b/lib/Varien/Simplexml/Config.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Simplexml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Simplexml/Config/Cache/Abstract.php b/lib/Varien/Simplexml/Config/Cache/Abstract.php
index 852dfbd..7fca05e 100644
--- a/lib/Varien/Simplexml/Config/Cache/Abstract.php
+++ b/lib/Varien/Simplexml/Config/Cache/Abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Simplexml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Simplexml/Config/Cache/File.php b/lib/Varien/Simplexml/Config/Cache/File.php
index d58275d..ee1a17f 100644
--- a/lib/Varien/Simplexml/Config/Cache/File.php
+++ b/lib/Varien/Simplexml/Config/Cache/File.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Simplexml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/Varien/Simplexml/Element.php b/lib/Varien/Simplexml/Element.php
index 1258776..455198d 100644
--- a/lib/Varien/Simplexml/Element.php
+++ b/lib/Varien/Simplexml/Element.php
@@ -20,7 +20,7 @@
  *
  * @category    Varien
  * @package     Varien_Simplexml
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/lib/flex/uploader/uploader.mxml b/lib/flex/uploader/uploader.mxml
index 9d73f1f..1d04af5 100644
--- a/lib/flex/uploader/uploader.mxml
+++ b/lib/flex/uploader/uploader.mxml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/lib/flex/uploader/uploaderSingle.mxml b/lib/flex/uploader/uploaderSingle.mxml
index 293f2d5..d9ec305 100644
--- a/lib/flex/uploader/uploaderSingle.mxml
+++ b/lib/flex/uploader/uploaderSingle.mxml
@@ -21,7 +21,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 -->
diff --git a/lib/flex/varien/varien/upload/Uploader.as b/lib/flex/varien/varien/upload/Uploader.as
index 786c102..65c452f 100644
--- a/lib/flex/varien/varien/upload/Uploader.as
+++ b/lib/flex/varien/varien/upload/Uploader.as
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 package varien.upload
diff --git a/lib/flex/varien/varien/upload/UploaderEvent.as b/lib/flex/varien/varien/upload/UploaderEvent.as
index 1f66dd0..f8f3407 100644
--- a/lib/flex/varien/varien/upload/UploaderEvent.as
+++ b/lib/flex/varien/varien/upload/UploaderEvent.as
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 package varien.upload
diff --git a/lib/flex/varien/varien/upload/UploaderSingle.as b/lib/flex/varien/varien/upload/UploaderSingle.as
index a581123..971f2bd 100644
--- a/lib/flex/varien/varien/upload/UploaderSingle.as
+++ b/lib/flex/varien/varien/upload/UploaderSingle.as
@@ -19,7 +19,7 @@
  *
  * @category    Mage
  * @package     Mage_Uploader
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 package varien.upload
diff --git a/mage b/mage
index 4d558e9..9db918b 100644
--- a/mage
+++ b/mage
@@ -20,7 +20,7 @@
 #
 # @category    Mage
 # @package     Mage
-# @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+# @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 # @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 #
 
diff --git a/shell/abstract.php b/shell/abstract.php
index ca03ed1..2038481 100644
--- a/shell/abstract.php
+++ b/shell/abstract.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shell
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/shell/compiler.php b/shell/compiler.php
index d8c82bb..566e9db 100644
--- a/shell/compiler.php
+++ b/shell/compiler.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shell
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/shell/indexer.php b/shell/indexer.php
index dda77b4..68f4ea0 100644
--- a/shell/indexer.php
+++ b/shell/indexer.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shell
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/shell/log.php b/shell/log.php
index 4dd053f..aa2bd54 100644
--- a/shell/log.php
+++ b/shell/log.php
@@ -20,7 +20,7 @@
  *
  * @category    Mage
  * @package     Mage_Shell
- * @copyright  Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright  Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/below_ie7.css b/skin/adminhtml/default/default/below_ie7.css
index f8bbd61..65b618f 100644
--- a/skin/adminhtml/default/default/below_ie7.css
+++ b/skin/adminhtml/default/default/below_ie7.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* Set min-width */
diff --git a/skin/adminhtml/default/default/boxes.css b/skin/adminhtml/default/default/boxes.css
index 5456346..9ec6783 100644
--- a/skin/adminhtml/default/default/boxes.css
+++ b/skin/adminhtml/default/default/boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/custom.css b/skin/adminhtml/default/default/custom.css
index 5a9a1bb..f3c7ef3 100644
--- a/skin/adminhtml/default/default/custom.css
+++ b/skin/adminhtml/default/default/custom.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/ie7.css b/skin/adminhtml/default/default/ie7.css
index 659e72f..d43122c 100644
--- a/skin/adminhtml/default/default/ie7.css
+++ b/skin/adminhtml/default/default/ie7.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/iestyles.css b/skin/adminhtml/default/default/iestyles.css
index 20daad9..e447ce9 100644
--- a/skin/adminhtml/default/default/iestyles.css
+++ b/skin/adminhtml/default/default/iestyles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* Clearing */
diff --git a/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-catalog.css b/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-catalog.css
index 495d6db..fe89a36 100644
--- a/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-catalog.css
+++ b/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-catalog.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 body { margin: 0; padding: 0 }
diff --git a/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-home.css b/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-home.css
index 934cece..536347b 100644
--- a/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-home.css
+++ b/skin/adminhtml/default/default/images/xmlconnect/mobile_preview/mobile-home.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 body { margin: 0; padding: 0 }
diff --git a/skin/adminhtml/default/default/lib/prototype/windows/themes/magento.css b/skin/adminhtml/default/default/lib/prototype/windows/themes/magento.css
index d283c70..59fb95a 100644
--- a/skin/adminhtml/default/default/lib/prototype/windows/themes/magento.css
+++ b/skin/adminhtml/default/default/lib/prototype/windows/themes/magento.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .dialog { border:1px solid #555; }
diff --git a/skin/adminhtml/default/default/menu.css b/skin/adminhtml/default/default/menu.css
index 0f6152d..52fe3f9 100644
--- a/skin/adminhtml/default/default/menu.css
+++ b/skin/adminhtml/default/default/menu.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/oauth-simple.css b/skin/adminhtml/default/default/oauth-simple.css
index c4c48f1..2a626ef 100644
--- a/skin/adminhtml/default/default/oauth-simple.css
+++ b/skin/adminhtml/default/default/oauth-simple.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/print.css b/skin/adminhtml/default/default/print.css
index 74c9c1b..323b614 100644
--- a/skin/adminhtml/default/default/print.css
+++ b/skin/adminhtml/default/default/print.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/reset.css b/skin/adminhtml/default/default/reset.css
index f466808..92f4a3f 100644
--- a/skin/adminhtml/default/default/reset.css
+++ b/skin/adminhtml/default/default/reset.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /******************************************/
diff --git a/skin/adminhtml/default/default/xmlconnect/boxes.css b/skin/adminhtml/default/default/xmlconnect/boxes.css
index 6ec9aac..bd7b1e6 100644
--- a/skin/adminhtml/default/default/xmlconnect/boxes.css
+++ b/skin/adminhtml/default/default/xmlconnect/boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/xmlconnect/dropdown.css b/skin/adminhtml/default/default/xmlconnect/dropdown.css
index 61c1a98..2f2a66c 100644
--- a/skin/adminhtml/default/default/xmlconnect/dropdown.css
+++ b/skin/adminhtml/default/default/xmlconnect/dropdown.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .dropdown { float:left; width:200px; border:1px solid #ccc; position:relative; }
diff --git a/skin/adminhtml/default/default/xmlconnect/iestyles.css b/skin/adminhtml/default/default/xmlconnect/iestyles.css
index e19dcf9..4668f16 100644
--- a/skin/adminhtml/default/default/xmlconnect/iestyles.css
+++ b/skin/adminhtml/default/default/xmlconnect/iestyles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/xmlconnect/mobile-android.css b/skin/adminhtml/default/default/xmlconnect/mobile-android.css
index f8ee1ab..e669745 100644
--- a/skin/adminhtml/default/default/xmlconnect/mobile-android.css
+++ b/skin/adminhtml/default/default/xmlconnect/mobile-android.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  
diff --git a/skin/adminhtml/default/default/xmlconnect/mobile-catalog.css b/skin/adminhtml/default/default/xmlconnect/mobile-catalog.css
index 6c12f6a..f3a227d 100644
--- a/skin/adminhtml/default/default/xmlconnect/mobile-catalog.css
+++ b/skin/adminhtml/default/default/xmlconnect/mobile-catalog.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/xmlconnect/mobile-home.css b/skin/adminhtml/default/default/xmlconnect/mobile-home.css
index c128c8e..9d86612 100644
--- a/skin/adminhtml/default/default/xmlconnect/mobile-home.css
+++ b/skin/adminhtml/default/default/xmlconnect/mobile-home.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/xmlconnect/mobile-ipad-catalog.css b/skin/adminhtml/default/default/xmlconnect/mobile-ipad-catalog.css
index 67851f9..b7f8c01 100644
--- a/skin/adminhtml/default/default/xmlconnect/mobile-ipad-catalog.css
+++ b/skin/adminhtml/default/default/xmlconnect/mobile-ipad-catalog.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
  
diff --git a/skin/adminhtml/default/default/xmlconnect/mobile-ipad-home.css b/skin/adminhtml/default/default/xmlconnect/mobile-ipad-home.css
index 6765b5a..9ab5df6 100644
--- a/skin/adminhtml/default/default/xmlconnect/mobile-ipad-home.css
+++ b/skin/adminhtml/default/default/xmlconnect/mobile-ipad-home.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/adminhtml/default/default/xmlconnect/styles.css b/skin/adminhtml/default/default/xmlconnect/styles.css
index 5152786..6408367 100644
--- a/skin/adminhtml/default/default/xmlconnect/styles.css
+++ b/skin/adminhtml/default/default/xmlconnect/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .wrapper { min-width:1150px !important; }
diff --git a/skin/frontend/base/default/css/email-inline.css b/skin/frontend/base/default/css/email-inline.css
index 0f7097e..7d66eae 100644
--- a/skin/frontend/base/default/css/email-inline.css
+++ b/skin/frontend/base/default/css/email-inline.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* ============================================ *
diff --git a/skin/frontend/base/default/css/email-non-inline.css b/skin/frontend/base/default/css/email-non-inline.css
index e3f28cc..e0ded0c 100644
--- a/skin/frontend/base/default/css/email-non-inline.css
+++ b/skin/frontend/base/default/css/email-non-inline.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 @import url(http://fonts.googleapis.com/css?family=Raleway:400,500,700);
diff --git a/skin/frontend/base/default/css/widgets.css b/skin/frontend/base/default/css/widgets.css
index 9e0b868..7aac628 100644
--- a/skin/frontend/base/default/css/widgets.css
+++ b/skin/frontend/base/default/css/widgets.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/base/default/js/bundle.js b/skin/frontend/base/default/js/bundle.js
index a4380b4..9264f47 100644
--- a/skin/frontend/base/default/js/bundle.js
+++ b/skin/frontend/base/default/js/bundle.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 if(typeof Product=='undefined') {
diff --git a/skin/frontend/base/default/js/checkout/review.js b/skin/frontend/base/default/js/checkout/review.js
index 18823ec..c22ff95 100644
--- a/skin/frontend/base/default/js/checkout/review.js
+++ b/skin/frontend/base/default/js/checkout/review.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/base/default/js/giftmessage.js b/skin/frontend/base/default/js/giftmessage.js
index 51d2e43..97391fc 100644
--- a/skin/frontend/base/default/js/giftmessage.js
+++ b/skin/frontend/base/default/js/giftmessage.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var GiftMessage = Class.create();
diff --git a/skin/frontend/base/default/js/ie6.js b/skin/frontend/base/default/js/ie6.js
index 920e2fc..b4bcbf1 100644
--- a/skin/frontend/base/default/js/ie6.js
+++ b/skin/frontend/base/default/js/ie6.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/base/default/js/msrp.js b/skin/frontend/base/default/js/msrp.js
index fd32722..c063254 100644
--- a/skin/frontend/base/default/js/msrp.js
+++ b/skin/frontend/base/default/js/msrp.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 if (!window.Catalog) {
diff --git a/skin/frontend/base/default/js/opcheckout.js b/skin/frontend/base/default/js/opcheckout.js
index 91fc061..3bf78cd 100644
--- a/skin/frontend/base/default/js/opcheckout.js
+++ b/skin/frontend/base/default/js/opcheckout.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 var Checkout = Class.create();
diff --git a/skin/frontend/base/default/lib/prototype/windows/themes/magento.css b/skin/frontend/base/default/lib/prototype/windows/themes/magento.css
index ff43281..5592f37 100644
--- a/skin/frontend/base/default/lib/prototype/windows/themes/magento.css
+++ b/skin/frontend/base/default/lib/prototype/windows/themes/magento.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     base_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .dialog { border:1px solid #555; }
diff --git a/skin/frontend/default/blank/css/print.css b/skin/frontend/default/blank/css/print.css
index ac30b24..f32b11b 100644
--- a/skin/frontend/default/blank/css/print.css
+++ b/skin/frontend/default/blank/css/print.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_blank
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 *     { background:none !important; text-align:left !important; }
diff --git a/skin/frontend/default/blank/css/styles-ie.css b/skin/frontend/default/blank/css/styles-ie.css
index a721ba1..7bfaa06 100644
--- a/skin/frontend/default/blank/css/styles-ie.css
+++ b/skin/frontend/default/blank/css/styles-ie.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_blank
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/blank/css/styles.css b/skin/frontend/default/blank/css/styles.css
index ec18456..d70df04 100644
--- a/skin/frontend/default/blank/css/styles.css
+++ b/skin/frontend/default/blank/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_blank
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/blue/css/styles-ie.css b/skin/frontend/default/blue/css/styles-ie.css
index 1cb39e8..a2d3568 100644
--- a/skin/frontend/default/blue/css/styles-ie.css
+++ b/skin/frontend/default/blue/css/styles-ie.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_blue
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/blue/css/styles.css b/skin/frontend/default/blue/css/styles.css
index 6ec33aa..0da15ec 100644
--- a/skin/frontend/default/blue/css/styles.css
+++ b/skin/frontend/default/blue/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_blue
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/default/css/oauth-simple.css b/skin/frontend/default/default/css/oauth-simple.css
index 8267f21..f41c79e 100644
--- a/skin/frontend/default/default/css/oauth-simple.css
+++ b/skin/frontend/default/default/css/oauth-simple.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/default/css/print.css b/skin/frontend/default/default/css/print.css
index b92388a..0c03d93 100644
--- a/skin/frontend/default/default/css/print.css
+++ b/skin/frontend/default/default/css/print.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 *     { background:none !important; text-align:left !important; }
diff --git a/skin/frontend/default/default/css/styles-ie.css b/skin/frontend/default/default/css/styles-ie.css
index 353fd1f..4b4221c 100644
--- a/skin/frontend/default/default/css/styles-ie.css
+++ b/skin/frontend/default/default/css/styles-ie.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/default/css/styles.css b/skin/frontend/default/default/css/styles.css
index 2ed51e9..4e3a0f6 100644
--- a/skin/frontend/default/default/css/styles.css
+++ b/skin/frontend/default/default/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/iphone/css/custom.css b/skin/frontend/default/iphone/css/custom.css
index 2bc369f..f14e811 100644
--- a/skin/frontend/default/iphone/css/custom.css
+++ b/skin/frontend/default/iphone/css/custom.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* Theme options */
diff --git a/skin/frontend/default/iphone/css/iphone.css b/skin/frontend/default/iphone/css/iphone.css
index be3f01d..1f8d2f3 100644
--- a/skin/frontend/default/iphone/css/iphone.css
+++ b/skin/frontend/default/iphone/css/iphone.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/iphone/js/iphone.js b/skin/frontend/default/iphone/js/iphone.js
index dfbb3a2..ee6d725 100644
--- a/skin/frontend/default/iphone/js/iphone.js
+++ b/skin/frontend/default/iphone/js/iphone.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_iphone
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/modern/css/print.css b/skin/frontend/default/modern/css/print.css
index 3f694cf..3569cc8 100644
--- a/skin/frontend/default/modern/css/print.css
+++ b/skin/frontend/default/modern/css/print.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 *     { background:none !important; text-align:left !important; }
diff --git a/skin/frontend/default/modern/css/styles-ie.css b/skin/frontend/default/modern/css/styles-ie.css
index 2a35dc1..96bfef4 100644
--- a/skin/frontend/default/modern/css/styles-ie.css
+++ b/skin/frontend/default/modern/css/styles-ie.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/modern/css/styles.css b/skin/frontend/default/modern/css/styles.css
index b0e5c2a..9a9713a 100644
--- a/skin/frontend/default/modern/css/styles.css
+++ b/skin/frontend/default/modern/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/default/modern/css/widgets.css b/skin/frontend/default/modern/css/widgets.css
index 6ef94a8..54f031d 100644
--- a/skin/frontend/default/modern/css/widgets.css
+++ b/skin/frontend/default/modern/css/widgets.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_modern
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/css/madisonisland-ie8.css b/skin/frontend/rwd/default/css/madisonisland-ie8.css
index fe7a2bd..fc15f6a 100644
--- a/skin/frontend/rwd/default/css/madisonisland-ie8.css
+++ b/skin/frontend/rwd/default/css/madisonisland-ie8.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* ============================================ *
diff --git a/skin/frontend/rwd/default/css/madisonisland.css b/skin/frontend/rwd/default/css/madisonisland.css
index bea0b9a..244d25f 100644
--- a/skin/frontend/rwd/default/css/madisonisland.css
+++ b/skin/frontend/rwd/default/css/madisonisland.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* ============================================ *
diff --git a/skin/frontend/rwd/default/css/scaffold-forms.css b/skin/frontend/rwd/default/css/scaffold-forms.css
index 3634403..d8cb96d 100644
--- a/skin/frontend/rwd/default/css/scaffold-forms.css
+++ b/skin/frontend/rwd/default/css/scaffold-forms.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /* ============================================ *
diff --git a/skin/frontend/rwd/default/css/styles-ie8.css b/skin/frontend/rwd/default/css/styles-ie8.css
index 8ba4f57..64e1cb9 100644
--- a/skin/frontend/rwd/default/css/styles-ie8.css
+++ b/skin/frontend/rwd/default/css/styles-ie8.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*! normalize.css v2.0.1 | MIT License | git.io/normalize */
diff --git a/skin/frontend/rwd/default/css/styles.css b/skin/frontend/rwd/default/css/styles.css
index 91c8e9a..144217a 100644
--- a/skin/frontend/rwd/default/css/styles.css
+++ b/skin/frontend/rwd/default/css/styles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /*! normalize.css v2.0.1 | MIT License | git.io/normalize */
diff --git a/skin/frontend/rwd/default/js/app.js b/skin/frontend/rwd/default/js/app.js
index 0f2a5ec..5077cc1 100644
--- a/skin/frontend/rwd/default/js/app.js
+++ b/skin/frontend/rwd/default/js/app.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/configurableswatches/configurable-swatch-prices.js b/skin/frontend/rwd/default/js/configurableswatches/configurable-swatch-prices.js
index e9e0087..57f1b1b 100644
--- a/skin/frontend/rwd/default/js/configurableswatches/configurable-swatch-prices.js
+++ b/skin/frontend/rwd/default/js/configurableswatches/configurable-swatch-prices.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/configurableswatches/product-media.js b/skin/frontend/rwd/default/js/configurableswatches/product-media.js
index a0a43d3..5a7646c 100644
--- a/skin/frontend/rwd/default/js/configurableswatches/product-media.js
+++ b/skin/frontend/rwd/default/js/configurableswatches/product-media.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/configurableswatches/swatches-list.js b/skin/frontend/rwd/default/js/configurableswatches/swatches-list.js
index 0c4ebc1..9799b9f 100644
--- a/skin/frontend/rwd/default/js/configurableswatches/swatches-list.js
+++ b/skin/frontend/rwd/default/js/configurableswatches/swatches-list.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/configurableswatches/swatches-product.js b/skin/frontend/rwd/default/js/configurableswatches/swatches-product.js
index 96e6308..0742b69 100644
--- a/skin/frontend/rwd/default/js/configurableswatches/swatches-product.js
+++ b/skin/frontend/rwd/default/js/configurableswatches/swatches-product.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/minicart.js b/skin/frontend/rwd/default/js/minicart.js
index bdde047..8e34aa9 100644
--- a/skin/frontend/rwd/default/js/minicart.js
+++ b/skin/frontend/rwd/default/js/minicart.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 function Minicart(options) {
diff --git a/skin/frontend/rwd/default/js/msrp_rwd.js b/skin/frontend/rwd/default/js/msrp_rwd.js
index 4b1ea6c..2afb983 100644
--- a/skin/frontend/rwd/default/js/msrp_rwd.js
+++ b/skin/frontend/rwd/default/js/msrp_rwd.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/opcheckout_rwd.js b/skin/frontend/rwd/default/js/opcheckout_rwd.js
index fdc2c66..b15fd1c 100644
--- a/skin/frontend/rwd/default/js/opcheckout_rwd.js
+++ b/skin/frontend/rwd/default/js/opcheckout_rwd.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/js/slideshow.js b/skin/frontend/rwd/default/js/slideshow.js
index 1131555..afbc5bd 100644
--- a/skin/frontend/rwd/default/js/slideshow.js
+++ b/skin/frontend/rwd/default/js/slideshow.js
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     rwd_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/frontend/rwd/default/scss/_core.scss b/skin/frontend/rwd/default/scss/_core.scss
index 77928b9..15fcffe 100644
--- a/skin/frontend/rwd/default/scss/_core.scss
+++ b/skin/frontend/rwd/default/scss/_core.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/_framework.scss b/skin/frontend/rwd/default/scss/_framework.scss
index c3849d7..cf3419b 100644
--- a/skin/frontend/rwd/default/scss/_framework.scss
+++ b/skin/frontend/rwd/default/scss/_framework.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/_var.scss b/skin/frontend/rwd/default/scss/_var.scss
index 7a49c41..1a0940b 100644
--- a/skin/frontend/rwd/default/scss/_var.scss
+++ b/skin/frontend/rwd/default/scss/_var.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/content/_category.scss b/skin/frontend/rwd/default/scss/content/_category.scss
index e28c569..26d0f45 100644
--- a/skin/frontend/rwd/default/scss/content/_category.scss
+++ b/skin/frontend/rwd/default/scss/content/_category.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/content/_home.scss b/skin/frontend/rwd/default/scss/content/_home.scss
index ba259a6..87575fb 100644
--- a/skin/frontend/rwd/default/scss/content/_home.scss
+++ b/skin/frontend/rwd/default/scss/content/_home.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/core/_common.scss b/skin/frontend/rwd/default/scss/core/_common.scss
index da6225a..17bd1e1 100644
--- a/skin/frontend/rwd/default/scss/core/_common.scss
+++ b/skin/frontend/rwd/default/scss/core/_common.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/core/_form.scss b/skin/frontend/rwd/default/scss/core/_form.scss
index 8b98d73..589a54c 100644
--- a/skin/frontend/rwd/default/scss/core/_form.scss
+++ b/skin/frontend/rwd/default/scss/core/_form.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/core/_reset.scss b/skin/frontend/rwd/default/scss/core/_reset.scss
index bf474af..2e066ed 100644
--- a/skin/frontend/rwd/default/scss/core/_reset.scss
+++ b/skin/frontend/rwd/default/scss/core/_reset.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/core/_table.scss b/skin/frontend/rwd/default/scss/core/_table.scss
index 00e1196..e5abedd 100644
--- a/skin/frontend/rwd/default/scss/core/_table.scss
+++ b/skin/frontend/rwd/default/scss/core/_table.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/email-inline.scss b/skin/frontend/rwd/default/scss/email-inline.scss
index ce39888..4d036b7 100644
--- a/skin/frontend/rwd/default/scss/email-inline.scss
+++ b/skin/frontend/rwd/default/scss/email-inline.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/email-non-inline.scss b/skin/frontend/rwd/default/scss/email-non-inline.scss
index f7a778b..263de44 100644
--- a/skin/frontend/rwd/default/scss/email-non-inline.scss
+++ b/skin/frontend/rwd/default/scss/email-non-inline.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/function/_black.scss b/skin/frontend/rwd/default/scss/function/_black.scss
index 5554ebb..17e4812 100644
--- a/skin/frontend/rwd/default/scss/function/_black.scss
+++ b/skin/frontend/rwd/default/scss/function/_black.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/function/_white.scss b/skin/frontend/rwd/default/scss/function/_white.scss
index 1208a22..3f5b16b 100644
--- a/skin/frontend/rwd/default/scss/function/_white.scss
+++ b/skin/frontend/rwd/default/scss/function/_white.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_footer.scss b/skin/frontend/rwd/default/scss/layout/_footer.scss
index d2f6c84..70f5d5b 100644
--- a/skin/frontend/rwd/default/scss/layout/_footer.scss
+++ b/skin/frontend/rwd/default/scss/layout/_footer.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_global.scss b/skin/frontend/rwd/default/scss/layout/_global.scss
index b7dd5cd..b4f6ca8 100644
--- a/skin/frontend/rwd/default/scss/layout/_global.scss
+++ b/skin/frontend/rwd/default/scss/layout/_global.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_header-account.scss b/skin/frontend/rwd/default/scss/layout/_header-account.scss
index 2bb9e89..7612773 100644
--- a/skin/frontend/rwd/default/scss/layout/_header-account.scss
+++ b/skin/frontend/rwd/default/scss/layout/_header-account.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_header-cart.scss b/skin/frontend/rwd/default/scss/layout/_header-cart.scss
index f05876a..a473c94 100644
--- a/skin/frontend/rwd/default/scss/layout/_header-cart.scss
+++ b/skin/frontend/rwd/default/scss/layout/_header-cart.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_header-nav.scss b/skin/frontend/rwd/default/scss/layout/_header-nav.scss
index 9d1e303..bbc5c81 100644
--- a/skin/frontend/rwd/default/scss/layout/_header-nav.scss
+++ b/skin/frontend/rwd/default/scss/layout/_header-nav.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_header-search.scss b/skin/frontend/rwd/default/scss/layout/_header-search.scss
index 86af70f..2931073 100644
--- a/skin/frontend/rwd/default/scss/layout/_header-search.scss
+++ b/skin/frontend/rwd/default/scss/layout/_header-search.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/layout/_header.scss b/skin/frontend/rwd/default/scss/layout/_header.scss
index 01a8e06..cdd478a 100644
--- a/skin/frontend/rwd/default/scss/layout/_header.scss
+++ b/skin/frontend/rwd/default/scss/layout/_header.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/madisonisland-ie8.scss b/skin/frontend/rwd/default/scss/madisonisland-ie8.scss
index f9643f8..236a848 100644
--- a/skin/frontend/rwd/default/scss/madisonisland-ie8.scss
+++ b/skin/frontend/rwd/default/scss/madisonisland-ie8.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/madisonisland.scss b/skin/frontend/rwd/default/scss/madisonisland.scss
index c8a475d..876268d 100644
--- a/skin/frontend/rwd/default/scss/madisonisland.scss
+++ b/skin/frontend/rwd/default/scss/madisonisland.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_breakpoint.scss b/skin/frontend/rwd/default/scss/mixin/_breakpoint.scss
index 95ce69b..044e405 100644
--- a/skin/frontend/rwd/default/scss/mixin/_breakpoint.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_breakpoint.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_clearfix.scss b/skin/frontend/rwd/default/scss/mixin/_clearfix.scss
index db7a920..5ab5c82 100644
--- a/skin/frontend/rwd/default/scss/mixin/_clearfix.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_clearfix.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_if-resolution.scss b/skin/frontend/rwd/default/scss/mixin/_if-resolution.scss
index 14e0df2..931cac4 100644
--- a/skin/frontend/rwd/default/scss/mixin/_if-resolution.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_if-resolution.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_image-replacement.scss b/skin/frontend/rwd/default/scss/mixin/_image-replacement.scss
index 6bf1910..31e4d59 100644
--- a/skin/frontend/rwd/default/scss/mixin/_image-replacement.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_image-replacement.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_loading-overlay.scss b/skin/frontend/rwd/default/scss/mixin/_loading-overlay.scss
index 0baa36f..677fce0 100644
--- a/skin/frontend/rwd/default/scss/mixin/_loading-overlay.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_loading-overlay.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_menu.scss b/skin/frontend/rwd/default/scss/mixin/_menu.scss
index 06abd46..3f9dd00 100644
--- a/skin/frontend/rwd/default/scss/mixin/_menu.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_menu.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_not-selectable.scss b/skin/frontend/rwd/default/scss/mixin/_not-selectable.scss
index 0b10e66..6f08ee8 100644
--- a/skin/frontend/rwd/default/scss/mixin/_not-selectable.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_not-selectable.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_toggle-content.scss b/skin/frontend/rwd/default/scss/mixin/_toggle-content.scss
index a5282f7..bd4e9d6 100644
--- a/skin/frontend/rwd/default/scss/mixin/_toggle-content.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_toggle-content.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_triangle.scss b/skin/frontend/rwd/default/scss/mixin/_triangle.scss
index dfee853..6425c50 100644
--- a/skin/frontend/rwd/default/scss/mixin/_triangle.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_triangle.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/mixin/_typography.scss b/skin/frontend/rwd/default/scss/mixin/_typography.scss
index ebe0432..0d9f248 100644
--- a/skin/frontend/rwd/default/scss/mixin/_typography.scss
+++ b/skin/frontend/rwd/default/scss/mixin/_typography.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_account-orders.scss b/skin/frontend/rwd/default/scss/module/_account-orders.scss
index 4957885..d8138d3 100644
--- a/skin/frontend/rwd/default/scss/module/_account-orders.scss
+++ b/skin/frontend/rwd/default/scss/module/_account-orders.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_account-reviews.scss b/skin/frontend/rwd/default/scss/module/_account-reviews.scss
index 868c5a0..780b957 100644
--- a/skin/frontend/rwd/default/scss/module/_account-reviews.scss
+++ b/skin/frontend/rwd/default/scss/module/_account-reviews.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_billing-agreements.scss b/skin/frontend/rwd/default/scss/module/_billing-agreements.scss
index 75e8f9f..ed199a5 100644
--- a/skin/frontend/rwd/default/scss/module/_billing-agreements.scss
+++ b/skin/frontend/rwd/default/scss/module/_billing-agreements.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_captcha.scss b/skin/frontend/rwd/default/scss/module/_captcha.scss
index d817b17..c325573 100644
--- a/skin/frontend/rwd/default/scss/module/_captcha.scss
+++ b/skin/frontend/rwd/default/scss/module/_captcha.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_catalog-compare.scss b/skin/frontend/rwd/default/scss/module/_catalog-compare.scss
index 425e9a5..96752ff 100644
--- a/skin/frontend/rwd/default/scss/module/_catalog-compare.scss
+++ b/skin/frontend/rwd/default/scss/module/_catalog-compare.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_catalog-msrp.scss b/skin/frontend/rwd/default/scss/module/_catalog-msrp.scss
index d15fe6a..7eb8b6a 100644
--- a/skin/frontend/rwd/default/scss/module/_catalog-msrp.scss
+++ b/skin/frontend/rwd/default/scss/module/_catalog-msrp.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_catalog-product.scss b/skin/frontend/rwd/default/scss/module/_catalog-product.scss
index 53a59c1..0d82952 100644
--- a/skin/frontend/rwd/default/scss/module/_catalog-product.scss
+++ b/skin/frontend/rwd/default/scss/module/_catalog-product.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_checkout-cart-minicart.scss b/skin/frontend/rwd/default/scss/module/_checkout-cart-minicart.scss
index c68ac12..2649314 100644
--- a/skin/frontend/rwd/default/scss/module/_checkout-cart-minicart.scss
+++ b/skin/frontend/rwd/default/scss/module/_checkout-cart-minicart.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_checkout-cart.scss b/skin/frontend/rwd/default/scss/module/_checkout-cart.scss
index 7c43adb..1f90df5 100644
--- a/skin/frontend/rwd/default/scss/module/_checkout-cart.scss
+++ b/skin/frontend/rwd/default/scss/module/_checkout-cart.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_checkout-multi-address.scss b/skin/frontend/rwd/default/scss/module/_checkout-multi-address.scss
index da1cda6..6db0e6b 100644
--- a/skin/frontend/rwd/default/scss/module/_checkout-multi-address.scss
+++ b/skin/frontend/rwd/default/scss/module/_checkout-multi-address.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_checkout-onepage.scss b/skin/frontend/rwd/default/scss/module/_checkout-onepage.scss
index 2cdd887..50e21c9 100644
--- a/skin/frontend/rwd/default/scss/module/_checkout-onepage.scss
+++ b/skin/frontend/rwd/default/scss/module/_checkout-onepage.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_checkout-success.scss b/skin/frontend/rwd/default/scss/module/_checkout-success.scss
index 915e1c5..78934a1 100644
--- a/skin/frontend/rwd/default/scss/module/_checkout-success.scss
+++ b/skin/frontend/rwd/default/scss/module/_checkout-success.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_cms.scss b/skin/frontend/rwd/default/scss/module/_cms.scss
index 6edc1b4..bd524e3 100644
--- a/skin/frontend/rwd/default/scss/module/_cms.scss
+++ b/skin/frontend/rwd/default/scss/module/_cms.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_configurableswatches.scss b/skin/frontend/rwd/default/scss/module/_configurableswatches.scss
index f2cc0cc..5e810c0 100644
--- a/skin/frontend/rwd/default/scss/module/_configurableswatches.scss
+++ b/skin/frontend/rwd/default/scss/module/_configurableswatches.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_contacts.scss b/skin/frontend/rwd/default/scss/module/_contacts.scss
index d4cc83c..eb11a23 100644
--- a/skin/frontend/rwd/default/scss/module/_contacts.scss
+++ b/skin/frontend/rwd/default/scss/module/_contacts.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_cookies.scss b/skin/frontend/rwd/default/scss/module/_cookies.scss
index f6b1ff0..c8bb4a0 100644
--- a/skin/frontend/rwd/default/scss/module/_cookies.scss
+++ b/skin/frontend/rwd/default/scss/module/_cookies.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_customer.scss b/skin/frontend/rwd/default/scss/module/_customer.scss
index f9914a7..8c1e3e7 100644
--- a/skin/frontend/rwd/default/scss/module/_customer.scss
+++ b/skin/frontend/rwd/default/scss/module/_customer.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_paypal.scss b/skin/frontend/rwd/default/scss/module/_paypal.scss
index 40f554b..952ee49 100644
--- a/skin/frontend/rwd/default/scss/module/_paypal.scss
+++ b/skin/frontend/rwd/default/scss/module/_paypal.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_popular-terms.scss b/skin/frontend/rwd/default/scss/module/_popular-terms.scss
index c426922..c568309 100644
--- a/skin/frontend/rwd/default/scss/module/_popular-terms.scss
+++ b/skin/frontend/rwd/default/scss/module/_popular-terms.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_pricing_conditions.scss b/skin/frontend/rwd/default/scss/module/_pricing_conditions.scss
index 969f936..338c831 100644
--- a/skin/frontend/rwd/default/scss/module/_pricing_conditions.scss
+++ b/skin/frontend/rwd/default/scss/module/_pricing_conditions.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_product-list.scss b/skin/frontend/rwd/default/scss/module/_product-list.scss
index 2dae3df..bce9e4d 100644
--- a/skin/frontend/rwd/default/scss/module/_product-list.scss
+++ b/skin/frontend/rwd/default/scss/module/_product-list.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_recurring-profiles.scss b/skin/frontend/rwd/default/scss/module/_recurring-profiles.scss
index 80b41ca..87fd32d 100644
--- a/skin/frontend/rwd/default/scss/module/_recurring-profiles.scss
+++ b/skin/frontend/rwd/default/scss/module/_recurring-profiles.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_review.scss b/skin/frontend/rwd/default/scss/module/_review.scss
index 08266fb..1c90090 100644
--- a/skin/frontend/rwd/default/scss/module/_review.scss
+++ b/skin/frontend/rwd/default/scss/module/_review.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_search.scss b/skin/frontend/rwd/default/scss/module/_search.scss
index 425a280..664515b 100644
--- a/skin/frontend/rwd/default/scss/module/_search.scss
+++ b/skin/frontend/rwd/default/scss/module/_search.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_slideshow.scss b/skin/frontend/rwd/default/scss/module/_slideshow.scss
index abfeb8f..55b8ef0 100644
--- a/skin/frontend/rwd/default/scss/module/_slideshow.scss
+++ b/skin/frontend/rwd/default/scss/module/_slideshow.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_tags.scss b/skin/frontend/rwd/default/scss/module/_tags.scss
index 44472c9..263c222 100644
--- a/skin/frontend/rwd/default/scss/module/_tags.scss
+++ b/skin/frontend/rwd/default/scss/module/_tags.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_widget.scss b/skin/frontend/rwd/default/scss/module/_widget.scss
index dd66bc3..76e4b3e 100644
--- a/skin/frontend/rwd/default/scss/module/_widget.scss
+++ b/skin/frontend/rwd/default/scss/module/_widget.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/module/_wishlist.scss b/skin/frontend/rwd/default/scss/module/_wishlist.scss
index 65f44b1..81d75c6 100644
--- a/skin/frontend/rwd/default/scss/module/_wishlist.scss
+++ b/skin/frontend/rwd/default/scss/module/_wishlist.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/override/_plugin.scss b/skin/frontend/rwd/default/scss/override/_plugin.scss
index 71342bf..f3b3950 100644
--- a/skin/frontend/rwd/default/scss/override/_plugin.scss
+++ b/skin/frontend/rwd/default/scss/override/_plugin.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/scaffold-forms.scss b/skin/frontend/rwd/default/scss/scaffold-forms.scss
index 93d000b..cde545d 100644
--- a/skin/frontend/rwd/default/scss/scaffold-forms.scss
+++ b/skin/frontend/rwd/default/scss/scaffold-forms.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/styles-ie8.scss b/skin/frontend/rwd/default/scss/styles-ie8.scss
index 5d63c48..dbe03e1 100644
--- a/skin/frontend/rwd/default/scss/styles-ie8.scss
+++ b/skin/frontend/rwd/default/scss/styles-ie8.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/frontend/rwd/default/scss/styles.scss b/skin/frontend/rwd/default/scss/styles.scss
index 9e8c88d..d3696b5 100644
--- a/skin/frontend/rwd/default/scss/styles.scss
+++ b/skin/frontend/rwd/default/scss/styles.scss
@@ -19,7 +19,7 @@
 //
 // @category    design
 // @package     rwd_default
-// @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+// @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
 // @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 //
 
diff --git a/skin/install/default/default/css/boxes.css b/skin/install/default/default/css/boxes.css
index ba1c60d..dfb32e7 100644
--- a/skin/install/default/default/css/boxes.css
+++ b/skin/install/default/default/css/boxes.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/install/default/default/css/clears.css b/skin/install/default/default/css/clears.css
index 24a480e..e0b6a34 100644
--- a/skin/install/default/default/css/clears.css
+++ b/skin/install/default/default/css/clears.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/install/default/default/css/ie7minus.css b/skin/install/default/default/css/ie7minus.css
index a968313..c690577 100644
--- a/skin/install/default/default/css/ie7minus.css
+++ b/skin/install/default/default/css/ie7minus.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 
diff --git a/skin/install/default/default/css/iestyles.css b/skin/install/default/default/css/iestyles.css
index 0132cdd..52c998c 100644
--- a/skin/install/default/default/css/iestyles.css
+++ b/skin/install/default/default/css/iestyles.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 .col2-set,
diff --git a/skin/install/default/default/css/reset.css b/skin/install/default/default/css/reset.css
index 469822b..8ba56f3 100644
--- a/skin/install/default/default/css/reset.css
+++ b/skin/install/default/default/css/reset.css
@@ -19,7 +19,7 @@
  *
  * @category    design
  * @package     default_default
- * @copyright   Copyright (c) 2006-2018 Magento, Inc. (http://www.magento.com)
+ * @copyright   Copyright (c) 2006-2019 Magento, Inc. (http://www.magento.com)
  * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
  */
 /******************************************/
diff --git a/var/package/Cm_RedisSession-1.9.4.0.xml b/var/package/Cm_RedisSession-1.9.4.0.xml
deleted file mode 100644
index a13845c..0000000
--- a/var/package/Cm_RedisSession-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Cm_RedisSession</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Redis session</summary>
-    <description>Redis seesion</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:58</time>
-    <contents><target name="magecommunity"><dir name="Cm"><dir name="RedisSession"><dir name="Model"><file name="Session.php" hash="8a751a32ac85da38237012f6c4ac9077"/></dir><dir name="etc"><file name="config.xml" hash="6b32aa3b331c4504c44a7c01a24a0d3d"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Cm_RedisSession.xml" hash="f36278d589fa562d20d5182c8864a3dd"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Cm_RedisSession-1.9.4.1.xml b/var/package/Cm_RedisSession-1.9.4.1.xml
new file mode 100644
index 0000000..77f4ff1
--- /dev/null
+++ b/var/package/Cm_RedisSession-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Cm_RedisSession</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Redis session</summary>
+    <description>Redis seesion</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:40</time>
+    <contents><target name="magecommunity"><dir name="Cm"><dir name="RedisSession"><dir name="Model"><file name="Session.php" hash="8a751a32ac85da38237012f6c4ac9077"/></dir><dir name="etc"><file name="config.xml" hash="6b32aa3b331c4504c44a7c01a24a0d3d"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Cm_RedisSession.xml" hash="f36278d589fa562d20d5182c8864a3dd"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Adminhtml_Default-1.9.4.0.xml b/var/package/Interface_Adminhtml_Default-1.9.4.0.xml
deleted file mode 100644
index 3f96d27..0000000
--- a/var/package/Interface_Adminhtml_Default-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Adminhtml_Default</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Adminhtml</summary>
-    <description>Default interface for Adminhtml</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:58</time>
-    <contents><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="2b8a8e5c60e4784255103ef960654b5c"/></dir><dir name="layout"><file name="admin.xml" hash="fa2970aab5aa83b7ebc98adb626cc47e"/><file name="adminnotification.xml" hash="6c02b570b62216ddd83ef13e02c6698b"/><file name="api2.xml" hash="db2a27d7ccc02947bc5b30c59769e08b"/><file name="authorizenet.xml" hash="e46d7d9d4804cd77883bd035c207d393"/><file name="bundle.xml" hash="36df0c985b13180ceea82109d6544381"/><file name="captcha.xml" hash="aba7100ae7edc86767e264e5fcfeed0d"/><file name="catalog.xml" hash="ab017f81ffc3316d6f1aed1011705789"/><file name="cms.xml" hash="0d847542950f96c30d7e493d6581f382"/><file name="connect.xml" hash="4b115e8eea0c7a5366bb650f9ecd678e"/><file name="currencysymbol.xml" hash="f834ed67581bb8c6a0f1e9077a0e916a"/><file name="customer.xml" hash="8dea541c83192d8d11c4fb49ea78045b"/><file name="dataflow.xml" hash="6f3baacc217afac27c7046d216afbaa6"/><file name="downloadable.xml" hash="b86d8dd5b096210d7ead7578b724bcad"/><file name="giftmessage.xml" hash="8a9454ccace970bfc7113bbfcc694d72"/><file name="importexport.xml" hash="4ee599ba56fabb14579b4c4f62f12b05"/><file name="index.xml" hash="7d5d63387702ae4f89790ddf333a85f0"/><file name="main.xml" hash="579885879b15e799e92cc2a9db33c277"/><file name="newsletter.xml" hash="cd6f875069103180ba3c6e175afb36c8"/><file name="oauth.xml" hash="9e68b6469faedb70bd5e19c076f07a66"/><file name="pagecache.xml" hash="649b2dc7b23ffa346745e2f439ada44f"/><file name="promo.xml" hash="ecce633b40d46540091a5f4674a6b5d7"/><file name="report.xml" hash="aebf6e9b94610bf1de7523781dc9df6b"/><file name="rss.xml" hash="381d71a524ace3375faa236867473cb3"/><file name="sales.xml" hash="8e29ebd2adff0f926c5dbcdca8eb8b38"/><file name="search.xml" hash="08e65788b1c39852084489a2110f9ff7"/><file name="tag.xml" hash="be945871f64a7df6d5b9dc163f2a7906"/><file name="tax.xml" hash="575eaccb30e80c89569192a9793bbe31"/><file name="widget.xml" hash="660afe2914732b367367da4ff252fc0a"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="735c9ec66d1309f1206294f075fdcdd1"/></dir></dir><dir name="template"><file name="access_denied.phtml" hash="0b93425b87b9d7ac08f545fe9b8e1362"/><dir name="api"><file name="role_users_grid_js.phtml" hash="19b2a78abc5572a2d6f00d2bae61b06b"/><file name="roleinfo.phtml" hash="26c30a9376cb26e6e695a5e30c0d3ba4"/><file name="roles.phtml" hash="c7e568ce60aa3f2d5ef99b07ff188f62"/><file name="rolesedit.phtml" hash="2fc361094d6175350a69fe4e7adb22de"/><file name="rolesusers.phtml" hash="c7b229b2a85ad3a22ec7b3658cb81992"/><file name="user_roles_grid_js.phtml" hash="cc0ca1bd4762b3213b39e0ea6387f2a9"/><file name="userinfo.phtml" hash="71d5c55d0baebbb17a7253d54dcf261f"/><file name="usernroles.phtml" hash="bef71e724dbb7b176ade07ddd895d249"/><file name="userroles.phtml" hash="c65d101f41a14ea2f6f9c5336c339ec2"/><file name="users.phtml" hash="79609ef733b95a347cc4d7551407da35"/></dir><dir name="api2"><dir name="attribute"><file name="buttons.phtml" hash="a0f72346b1d2f7d0ecc00c663152594d"/><file name="resource.phtml" hash="ac52c34f754dbd0d18033c77d77f310e"/></dir><dir name="permissions"><dir name="user"><dir name="edit"><dir name="tab"><dir name="roles"><file name="js.phtml" hash="8f86b7111ea63f3f92082bd7e354998e"/></dir></dir></dir></dir></dir><dir name="role"><file name="buttons.phtml" hash="c82b5abc2905bb1e366de48e271b8396"/><file name="users_grid_js.phtml" hash="f04c43f09d5a3881bb30bd23a7627419"/></dir></dir><dir name="authorizenet"><dir name="directpost"><file name="iframe.phtml" hash="45b445708ecef65d83c5ecc15d330edd"/><file name="info.phtml" hash="1d71da92ea0ddb22633bbcf1e2838102"/></dir></dir><dir name="backup"><file name="dialogs.phtml" hash="7b48547221f06a4a6d22d15e1e83672f"/><file name="left.phtml" hash="dfc47c2fc8db80a7d689d6c4b9c839f0"/><file name="list.phtml" hash="db411fc64166d19591964830e13c66a8"/></dir><dir name="bundle"><dir name="product"><dir name="composite"><dir name="fieldset"><dir name="options"><file name="bundle.phtml" hash="3c5955a856a6dd3f00422ce849ab121d"/><dir name="type"><file name="checkbox.phtml" hash="7c0db4ab7ca921ce57a9396e28bce585"/><file name="multi.phtml" hash="1514e211126df7763d75df47d72b0d95"/><file name="radio.phtml" hash="ae244ff90f64532aad44df7fd763a97a"/><file name="select.phtml" hash="708a91a59658cebbc4b5f141c1b8e27c"/></dir></dir></dir></dir><dir name="edit"><dir name="bundle"><dir name="option"><file name="search.phtml" hash="96f1988c6a61107ea033f24acfb331ed"/><file name="selection.phtml" hash="56ee8f504e7b17ca87ffa037ba224d8f"/></dir><file name="option.phtml" hash="8e84e2dffcc3560656c4094d0e11c83d"/></dir><file name="bundle.phtml" hash="d1c03f6494a5d1b63b1cf0f87d381d4e"/></dir></dir><dir name="sales"><dir name="creditmemo"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="0eff64f467a00ba9871dcf235ea6116c"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="2dde16cdd49acb1f94f298168c5e2c9a"/></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="72daa1a5ca1f2ff17fd9d32956fcbe1f"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="87f9bcc14b13f4c2253cc16adee2d71c"/></dir></dir></dir><dir name="order"><dir name="view"><dir name="items"><file name="renderer.phtml" hash="88a49b9c825845b9e931abd4fce2d2d7"/></dir></dir></dir><dir name="shipment"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="87cb061dcbad3235343331c73af75c29"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="1a447952fa64ab75222642852945f525"/></dir></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="4bb4d10d1969e62ea626c2f3ad17059b"/></dir><dir name="catalog"><dir name="category"><dir name="checkboxes"><file name="tree.phtml" hash="316072d4357faf2dda4607ba7f02e5e1"/></dir><dir name="edit"><file name="form.phtml" hash="1f2ec2f818af0dae1a3d898489a1bca7"/></dir><file name="edit.phtml" hash="8c6a5c83242ebd0f262a8b884066d071"/><file name="tree.phtml" hash="166e16cb27184b953cc9e7f60f0eba40"/><dir name="widget"><file name="tree.phtml" hash="f6611d0ceb9f6068e5c3988930b0a00c"/></dir></dir><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="58c77338ef7ee88a33cb8d0703d752de"/></dir></dir></dir><dir name="product"><dir name="attribute"><file name="js.phtml" hash="7e01ac475d716fe1a0ff364683805fef"/><dir name="new"><file name="created.phtml" hash="b6466ae0b3778ef2f08583a84aa7099d"/></dir><file name="options.phtml" hash="4d43f18ee71fa9f5a4d518b279888aed"/><dir name="set"><dir name="main"><dir name="tree"><file name="attribute.phtml" hash="e31959cb6e8a00cf1c85bcf3e528f73f"/><file name="group.phtml" hash="ad056aa1c05478509d9252cd9cbbf9e7"/></dir></dir><file name="main.phtml" hash="0a9fc542d48b62a9e218f9fb5fa33133"/><dir name="toolbar"><file name="add.phtml" hash="2271a6d595c86af8bf84b987eb0efc17"/><file name="main.phtml" hash="bf70b4d5a5a62a0abc98eb8003e1b8d6"/></dir></dir></dir><dir name="composite"><file name="configure.phtml" hash="7f6774cf9023b4daa9a250454149d373"/><dir name="fieldset"><file name="configurable.phtml" hash="4861932bdb04e14eb32c8fa072c9ab4c"/><file name="grouped.phtml" hash="020b1cb486b20b39a1fb4d4b5711c68b"/><dir name="options"><file name="js.phtml" hash="59ac4bb852525ff1f6b7bd31eb4f55ea"/><dir name="type"><file name="date.phtml" hash="e68657a02a40e818cdf43552d64914d4"/><file name="default.phtml" hash="cd59ccac8a9d4212e161ea5dbb55f348"/><file name="file.phtml" hash="ab87b63a754052d01a64e31ebd3b33a6"/><file name="select.phtml" hash="49130463308c229d1d9041499e9d3ccc"/><file name="text.phtml" hash="ca826937903254f82d322f8f91e7d46a"/></dir></dir><file name="options.phtml" hash="1e5706149c20d21fd1d4deae1e4814f7"/><file name="qty.phtml" hash="911d3700ea16934737ef4838cf5905a5"/></dir></dir><file name="created.phtml" hash="eeda128f5468e66a37eb6048ff20046f"/><dir name="edit"><dir name="action"><file name="attribute.phtml" hash="c8e6a25bfd9b467557e76f6c8c6d5ff8"/><file name="inventory.phtml" hash="4aa5d8046544aad2fa7ecb4d62cb7b4f"/><file name="websites.phtml" hash="bef55654e3461543c6f2ae9d3d8826f2"/></dir><file name="categories.phtml" hash="61ea947c5375f24d183964abf564bd06"/><dir name="options"><file name="option.phtml" hash="5b2c7428c87ae6c888e57de4228b49d3"/><dir name="type"><file name="date.phtml" hash="56d17e997bff9a38c85abad8674d2b1c"/><file name="file.phtml" hash="0ed1da6973f5665b926533c9e1d6883f"/><file name="select.phtml" hash="68df7d25b614c17fd6465e93c458ceb8"/><file name="text.phtml" hash="fad130667515a76412509dea18c55e86"/></dir></dir><file name="options.phtml" hash="f0f0a18efa190eb3b20cc345f2e946fd"/><dir name="price"><file name="group.phtml" hash="3956ebb0b1d06f602caa4f7a3ec8016d"/><file name="tier.phtml" hash="fe083276dc080bb0c300d29f0e42e663"/></dir><file name="serializer.phtml" hash="598b4c51e63a0633a139f17bba395c51"/><dir name="super"><file name="config.phtml" hash="7c36eec763f1c2c7627026c6723d7d75"/></dir><file name="websites.phtml" hash="a59008e748041ce32ffa01c52bfada66"/></dir><file name="edit.phtml" hash="e33e2c7513399a924c3224a9791b252a"/><dir name="helper"><file name="gallery.phtml" hash="2ea402574e8813e211f6ad6e45690082"/></dir><file name="js.phtml" hash="47cf9938cc0ebc74b583370cceb93498"/><file name="price.phtml" hash="0d6960c138926e5832ef39dc2d6f0923"/><dir name="tab"><file name="alert.phtml" hash="c7f72e8114ab15177be2c83598e8705e"/><file name="inventory.phtml" hash="e6e15282ceea9e10ddc47771c8c73503"/></dir><dir name="widget"><dir name="chooser"><file name="container.phtml" hash="2af850a1f664772599a1a42b12cbd037"/></dir></dir></dir><file name="product.phtml" hash="0db5b8a63cf7bdfcbe0278569e048e9b"/><dir name="wysiwyg"><file name="js.phtml" hash="868d61a1c261c64255367f1d18c06146"/></dir></dir><dir name="cms"><dir name="browser"><dir name="content"><file name="files.phtml" hash="b40e36c2a9c7884d6ebe6d52d7ebbc70"/><file name="newfolder.phtml" hash="4631d1a3602fff8fac3528d2d620edd3"/><file name="uploader.phtml" hash="0ca35f576a3407276f08579da3d767fa"/></dir><file name="content.phtml" hash="5060e5bf45f748de04e476754ac1dfd0"/><file name="js.phtml" hash="d7f24abe14eaaa076de3ecfcb9cd37ac"/><file name="tree.phtml" hash="31337b44e306b1c72b6248f782a2f987"/></dir><dir name="page"><dir name="edit"><dir name="form"><dir name="renderer"><file name="content.phtml" hash="3ff9151632c1207f57108393c3a2d1b1"/></dir></dir></dir></dir></dir><file name="coming.phtml" hash="584b6eb5bd5c02169d95bf218fd78f32"/><dir name="connect"><dir name="extension"><dir name="custom"><file name="authors.phtml" hash="abcf5c33760f7f41e849aa0ccdc3094c"/><file name="contents.phtml" hash="b0750fce6e052964e936194175cc2de5"/><file name="depends.phtml" hash="9750b3aa40cf7b948dd76e1975e81c00"/><file name="load.phtml" hash="c14d4bfcae6c2da8b66ddb12f98e1bcd"/><file name="package.phtml" hash="acd9f10cd82a311eb546cd63bd648bdc"/><file name="release.phtml" hash="e25b1c7c5e8007610044e0be15926066"/></dir></dir></dir><dir name="currencysymbol"><file name="grid.phtml" hash="4909494d83f5a434e9549d4c9b208b7b"/></dir><dir name="customer"><dir name="edit"><file name="js.phtml" hash="dbdef333341b26c8e5a4d6487452bba0"/><dir name="tab"><dir name="account"><dir name="form"><dir name="renderer"><file name="group.phtml" hash="07ca40d8a48dccbf882c2bd9d97c8fdd"/></dir></dir></dir><dir name="view"><dir name="grid"><file name="item.phtml" hash="cffe779f8286f8ddbd5d9e36455c1f91"/></dir></dir></dir></dir><file name="online.phtml" hash="26c038872c35622dce5192b66157d8f2"/><dir name="sales"><dir name="order"><dir name="create"><dir name="address"><dir name="form"><dir name="renderer"><file name="vat.phtml" hash="bcb6dcd5283f6ca54a31f794ae05ff42"/></dir></dir></dir></dir></dir></dir><dir name="system"><dir name="config"><file name="validatevat.phtml" hash="83e4b57c6dff8ec1ffb5480133126767"/></dir></dir><dir name="tab"><file name="addresses.phtml" hash="4e08e870ac344b06a61ba5df94acdce9"/><file name="cart.phtml" hash="7bd07def03346874d530832138a82e83"/><file name="newsletter.phtml" hash="a875958e512c96b7b3841282edcfb36e"/><dir name="view"><file name="sales.phtml" hash="0dbba8c504374b5dd09304727261ce6a"/></dir><file name="view.phtml" hash="4153cc71e7a6db1e6f8cd6b5e949b052"/><file name="wishlist.phtml" hash="bbfef68c40383558d550e93bcaf788de"/></dir></dir><dir name="dashboard"><dir name="graph"><file name="disabled.phtml" hash="9fd9442cb7012d11528a5008d7edfc8b"/></dir><file name="graph.phtml" hash="b64fea82a4e48856749a118aa394b3e4"/><file name="grid.phtml" hash="92391c6885262018eace82dc98041815"/><file name="index.phtml" hash="1485125ad7b75ea87312cc9aae2c64c7"/><file name="salebar.phtml" hash="35051aca2c8af240a93905ace6a95aef"/><file name="searches.phtml" hash="85a0eab13b10481bec450c27146ece41"/><dir name="store"><file name="switcher.phtml" hash="e16a68b53244d1e0becf36a1b2e1235b"/></dir><file name="totalbar.phtml" hash="49a2ccc2dbb571f33aa773cb896b04b7"/></dir><dir name="directory"><dir name="js"><file name="optional_zip_countries.phtml" hash="f2c21b03d0109c7505be950febe20d1c"/></dir></dir><dir name="downloadable"><dir name="product"><dir name="composite"><dir name="fieldset"><file name="downloadable.phtml" hash="ec539bc7a37dde2d1369a38872e04ae0"/></dir></dir><dir name="edit"><dir name="downloadable"><file name="links.phtml" hash="50f196fbc173c7b6db47b73897bbba53"/><file name="samples.phtml" hash="0a4e10d341d2e373e89a9b990cee5658"/></dir><file name="downloadable.phtml" hash="0e3685802262cd0ff745f7b5a3c4a399"/></dir></dir><dir name="sales"><dir name="items"><dir name="column"><dir name="downloadable"><dir name="creditmemo"><file name="name.phtml" hash="0b929b22a5b6bfe4faefd36c8fe3e7cb"/></dir><dir name="invoice"><file name="name.phtml" hash="69aa15a70fe3e10ff66d301f83774d8e"/></dir><file name="name.phtml" hash="90e67c7d2963a36239d1cfedf02eb2d6"/></dir></dir></dir><dir name="order"><dir name="creditmemo"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="564951f90faa742f3a7485cd325f3928"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="c0060b9a5190d959423435c2fec44fd7"/></dir></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="4e1430f0773f61cc998500dcbf3df9f1"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="5a47d33cef0453245cf6751611b614f9"/></dir></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="142c07b8ecd8dc21d5f3873e61e8a95d"/></dir></dir></dir></dir></dir></dir><dir name="eav"><dir name="attribute"><dir name="edit"><file name="js.phtml" hash="e31959cb6e8a00cf1c85bcf3e528f73f"/></dir><file name="options.phtml" hash="b264987df981b6954197362620ce5dc3"/></dir></dir><dir name="email"><dir name="order"><file name="items.phtml" hash="eb03db94a2470c2355776460c6c91c20"/></dir></dir><file name="empty.phtml" hash="3dc7e87bf6701ff9fcdcccc53e169727"/><file name="example.phtml" hash="f032afae414344e63cf7fa705fca4180"/><file name="forgotpassword.phtml" hash="dc0a40f4420b46be1d7fe0cc82726445"/><file name="formkey.phtml" hash="a30e6417a0637091743b2ea2f37ec930"/><dir name="giftmessage"><file name="form.phtml" hash="7d9bd587f973da6785f717bbe38f883b"/><file name="giftoptionsform.phtml" hash="f12ca481dcd38ec15e363f286274264b"/><file name="helper.phtml" hash="f154667a3a93a999d7da9add164f4dd0"/><file name="popup.phtml" hash="251eb1e699735cc2d31c45c7b8e0adea"/><dir name="sales"><dir name="order"><dir name="create"><file name="giftoptions.phtml" hash="637e3a1524b3c069ffbd5d57f991e06a"/><file name="items.phtml" hash="d90c7a0759f3af7359f3ab72b2768617"/></dir><dir name="view"><file name="giftoptions.phtml" hash="a2187b52ce3765afb903c50a21e4b1c5"/><file name="items.phtml" hash="801bd28178fb07882711e630a4293e63"/></dir></dir></dir></dir><dir name="googlebase"><file name="captcha.phtml" hash="5a2d12232692876f6b6ff83b8f387524"/><file name="items.phtml" hash="b8eb257be832077c733937528aa8dd82"/><dir name="types"><dir name="edit"><file name="attributes.phtml" hash="6ceb197ddbf672122d61c99890affefd"/></dir></dir></dir><dir name="importexport"><file name="busy.phtml" hash="6c3c2c211a18a63cbc3835caa986678a"/><dir name="export"><dir name="form"><file name="after.phtml" hash="66a49e8e07b5c82353d9a560a88d0d2a"/><file name="before.phtml" hash="6b816ca61ec75a928e5072ef2648815f"/></dir></dir><dir name="import"><dir name="form"><file name="after.phtml" hash="c5dc3ad22c752a9e649557d0ffe2ea1b"/><file name="before.phtml" hash="590857b2535df4d5bfb440864b475456"/></dir><dir name="frame"><file name="result.phtml" hash="3fca7b1c37fcfaf904fe9e2a598afb98"/></dir></dir></dir><dir name="index"><file name="notifications.phtml" hash="a0e8d7264ea40704b3354560a087c515"/></dir><file name="login.phtml" hash="0d6bf9910c8a4edb87327a86fd59d69e"/><dir name="media"><file name="editor.phtml" hash="b7b2537551f5c5b016a692f40f45fd88"/><file name="uploader.phtml" hash="660610bb89e9e6f7bb5ff75cb17ed28c"/></dir><dir name="newsletter"><dir name="preview"><file name="iframeswitcher.phtml" hash="aba6cae6227dfc99c6f511a374a59abb"/><file name="store.phtml" hash="75072a8e402f88498069bb573f36a933"/></dir><dir name="problem"><file name="list.phtml" hash="ef529cbab533e46993ab1909cb4f1168"/></dir><dir name="queue"><file name="edit.phtml" hash="eeadb798c387cac5c780328b2b00900d"/><file name="list.phtml" hash="1ebb0a371a6ec987e81d7125078d8f5e"/><file name="preview.phtml" hash="6e9a7e260d5dc486c256cc2eaab1b006"/></dir><dir name="subscriber"><file name="list.phtml" hash="b2532471a402bc89cb98d9d2393708c8"/></dir><dir name="template"><file name="edit.phtml" hash="98af40620bce4e0b5c0f9edabbd661f5"/><file name="list.phtml" hash="aab1851c309c3506d6a7a08e3dcfd461"/><file name="preview.phtml" hash="6e9a7e260d5dc486c256cc2eaab1b006"/></dir></dir><dir name="notification"><file name="baseurl.phtml" hash="a679fe18d56450b4a5f2c72cf5f2753d"/><file name="curl.phtml" hash="9002113007eda972b15c1ec6012156a0"/><file name="formkey.phtml" hash="97d8da671d1839efea2494ea3fe3a806"/><file name="security.phtml" hash="2f174f9a35240b3f5612acf4d98491d4"/><file name="survey.phtml" hash="4ca551f9634d2050b60258044abfcea6"/><file name="symlink.phtml" hash="2c3138d8657eee6220f81c013bca307a"/><file name="toolbar.phtml" hash="5c4f406d5e58445c8bf972e06d3134c1"/><file name="window.phtml" hash="283519725b127c908f2a95b0a2b6b5c0"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="776fda121ee85dc44175b95297b8be5e"/><file name="button.phtml" hash="bb7a5f6b66c05558c1973d0d6e2ecf45"/><file name="confirm-simple.phtml" hash="94bf4c893a04516b31f13e0ecd5dfe17"/><file name="confirm.phtml" hash="ff2a8360ecc9e7f9f494f935893c0ff9"/><dir name="form"><file name="login-simple.phtml" hash="e645c349e503b0d7003c1a4c0e9d424e"/><file name="login.phtml" hash="d92a35d7081aa0ac1a023d73b1992e28"/></dir><file name="head-simple.phtml" hash="01b75eafcca0e6acd2f9770b585e860f"/><file name="reject-simple.phtml" hash="0cb7b4f8b241c1a2ef50b8350fea58cf"/><file name="reject.phtml" hash="7572e628c21bed02ffb4dade79693f2d"/></dir></dir><file name="overlay_popup.phtml" hash="0838d1a559ff0be9681cd6c2010cb730"/><dir name="page"><file name="footer.phtml" hash="554851584e03620c55bd84bdeb57c5e8"/><file name="head.phtml" hash="16f2e49d3be8f9ee595b014a8c4dff71"/><file name="header.phtml" hash="0b553cfa08a1102b037c5c8d6dc6b04a"/><dir name="js"><file name="calendar.phtml" hash="ab7d6b444d86a7d05b802f8f3bcd2138"/><file name="translate.phtml" hash="84eddc2ae9a622e3d4d78492a2ea9e05"/></dir><file name="menu.phtml" hash="fe8d3f634251c2071cd52ffc54913009"/><file name="notices.phtml" hash="93da2ad3ab7c7bc084ee9bbd94534c68"/></dir><file name="page.phtml" hash="9433872817ce316f64e069d4b27df009"/><dir name="pagecache"><dir name="cache"><file name="additional.phtml" hash="266522fd292e7ee15a2e8f5fb9651d84"/></dir></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="8ce42cf9493be215833c92cc8fa0d119"/></dir><dir name="info"><file name="cc.phtml" hash="ab67f6e39a87c34269b47f652e4ab82a"/><file name="pdf.phtml" hash="e9ffdb41ec0d853698f1779db0fe2981"/></dir></dir><dir name="payment"><dir name="form"><file name="banktransfer.phtml" hash="d28cf4cc1d898f8c0154e8e4ce879020"/><file name="cashondelivery.phtml" hash="56dc9b726ca3f4991fa80548d7eaa600"/><file name="cc.phtml" hash="a1d6306531292c445e28c7dd642c06a8"/><file name="ccsave.phtml" hash="8444df68a2e48e29589a232f4cc8b2ca"/><file name="checkmo.phtml" hash="4fd637914b4e26312232bb58d36b2664"/><file name="purchaseorder.phtml" hash="354903a4a6ab78687452c047c34b7b0d"/></dir><dir name="info"><file name="banktransfer.phtml" hash="1a29469c4268caaad2c3239895c688bf"/><file name="checkmo.phtml" hash="64ffb1d1e2a22225bf4e5d23110ced2b"/><file name="default.phtml" hash="1feb712a071d1fb8a12069168fa8eb3d"/><dir name="pdf"><file name="checkmo.phtml" hash="ce61e21e189b46758bb3704fd3293329"/><file name="default.phtml" hash="1c1df7e62a8243b99ad6f44d936cc078"/><file name="purchaseorder.phtml" hash="dfe200348a5ac58db7b147bfe991547d"/></dir><file name="purchaseorder.phtml" hash="dafc010e53b36de0876b75beaab4d760"/></dir></dir><dir name="paypal"><dir name="system"><dir name="config"><file name="api_wizard.phtml" hash="51393f8e3b16fe6c899da32f855dfea9"/><file name="bml_api_wizard.phtml" hash="dd7728bf602c2689a2a2f68453d8a220"/><dir name="fieldset"><file name="global.phtml" hash="c25901174f696022acf54f0e0d031438"/><file name="hint.phtml" hash="699d26296a1957b2960ec369c664cb7b"/><file name="store.phtml" hash="17ff85b1c8fe665b4ce57220d836ee8d"/></dir><dir name="payflowlink"><file name="advanced.phtml" hash="fec372a9e5b1282f73ddb08e7ff53143"/><file name="info.phtml" hash="4d175e6c1ef420294205100babb3dca2"/></dir></dir></dir></dir><dir name="permissions"><file name="role_users_grid_js.phtml" hash="4c17fcb2aa9478a7a37fb4552f4ff9d6"/><file name="roleinfo.phtml" hash="3efe8718836bc7f0d6d8ccddbcf7fe9c"/><file name="roles.phtml" hash="71008b5b96fcf64cbb5ed7210ba490d4"/><file name="rolesedit.phtml" hash="b8eed818db9cd53692b9b1d0212600f5"/><file name="rolesusers.phtml" hash="c7b229b2a85ad3a22ec7b3658cb81992"/><file name="user_roles_grid_js.phtml" hash="7c7c7d128fbc826704d8c3deb7e25831"/><file name="userinfo.phtml" hash="71d5c55d0baebbb17a7253d54dcf261f"/><file name="usernroles.phtml" hash="bef71e724dbb7b176ade07ddd895d249"/><file name="userroles.phtml" hash="c65d101f41a14ea2f6f9c5336c339ec2"/><file name="users.phtml" hash="79609ef733b95a347cc4d7551407da35"/></dir><dir name="poll"><dir name="answers"><file name="list.phtml" hash="4d6c40e5b346c112ae80223d76dfba36"/></dir></dir><file name="popup.phtml" hash="5be29b0dc97ad85da6489ee30f6b3a90"/><dir name="promo"><file name="fieldset.phtml" hash="fa4f25be8cd47e1e4d5295c512f047f8"/><file name="form.phtml" hash="6146a162be90f0a7e1a2be651a164210"/><file name="js.phtml" hash="bb4852a9b2184b2c87aaa810d752c3bf"/><file name="salesrulejs.phtml" hash="03068d2950ce492f05b13c0008dd51bf"/></dir><dir name="rating"><file name="detailed.phtml" hash="61853f9c83da153e976fe3624fb20095"/><file name="options.phtml" hash="52350ee6bbf7cccf92dd84e13c174f76"/><dir name="stars"><file name="detailed.phtml" hash="4645b1dd948f7f363b43155892a16261"/><file name="summary.phtml" hash="88ece0a64860556ddabd6b4f9184bef2"/></dir></dir><dir name="report"><dir name="grid"><file name="container.phtml" hash="6e071b59d7a6731bc98b6b5ef4604d76"/></dir><file name="grid.phtml" hash="67c2dce387d910177837da5177fcd038"/><dir name="refresh"><file name="statistics.phtml" hash="7dded0cf028a17b3165fde06ccbd66ae"/></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="7e1eeef91b89078f4dcaeaa730680791"/></dir><file name="switcher.phtml" hash="aee0f6079d494a7369859c8d5553c526"/></dir><file name="wishlist.phtml" hash="ded79ec8ab525638d4bf3e6bd17a6ca1"/></dir><file name="resetforgottenpassword.phtml" hash="b07b20a789151ab6f67c9db9de051ee0"/><dir name="review"><file name="add.phtml" hash="26ff68721e5d0a25f7cae44f2401cf4c"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="form.phtml" hash="181326925e1db25f8aeaa43b771d21e6"/><dir name="view"><file name="form.phtml" hash="c91a4929c452123c2b1dfe6df2e5fd74"/><dir name="tab"><file name="info.phtml" hash="6c8e148b5fc8fd1407122141325504ff"/></dir></dir></dir></dir><dir name="items"><dir name="column"><file name="name.phtml" hash="1642f371fe7d58777b5d05955f5e5e31"/><file name="qty.phtml" hash="45b9d6464511b05c6f2db52b9c0f5208"/></dir><dir name="renderer"><file name="default.phtml" hash="2fb6735f329fc9bb69adf2189fee4992"/></dir></dir><dir name="order"><dir name="address"><file name="form.phtml" hash="7294f3ab0f023727db823a883964c00c"/></dir><dir name="comments"><file name="view.phtml" hash="fe26683923eedcb0eb234e0d68f7a722"/></dir><dir name="create"><file name="abstract.phtml" hash="c2e218a1aac318936552095741d2b340"/><dir name="billing"><dir name="method"><file name="form.phtml" hash="805b57f301229bb30ccc33c73c221067"/></dir></dir><file name="comment.phtml" hash="fe0cddf6e65757251f3588aee2a066a0"/><dir name="coupons"><file name="form.phtml" hash="d484ce57dd690afbb108ef4825ff72e9"/></dir><file name="data.phtml" hash="e87f183fca97f9a20c2d230ba44e1ebb"/><dir name="form"><file name="account.phtml" hash="88424154c415379ec0786cf1e46be0c3"/><file name="address.phtml" hash="8c5f4d31ad0902b3c7087610ccdbbdf4"/></dir><file name="form.phtml" hash="a2e38a610776075edac5f510ae53a56d"/><file name="giftmessage.phtml" hash="0c027ad5e3d30c85dd42da2b3cf9cb83"/><dir name="items"><file name="grid.phtml" hash="88a9f94935b19b1425291d6453fc87ff"/></dir><file name="items.phtml" hash="a22a35447e4fa1f90539fd8be5462302"/><file name="js.phtml" hash="c9ca3fb7cbd178aee5518067dbb9bea9"/><dir name="newsletter"><file name="form.phtml" hash="d5e69ff1c8fad279a4c92b9bfb587b3c"/></dir><dir name="shipping"><dir name="method"><file name="form.phtml" hash="bc4a6457fbea465f5eb567cb47c68fbf"/></dir></dir><dir name="sidebar"><file name="items.phtml" hash="82e4cdb2deb65b33460627fca97818f9"/></dir><file name="sidebar.phtml" hash="12bc9eaee62aa219a006a0e3155ba252"/><dir name="store"><file name="select.phtml" hash="a4dc3b912c68fa9a8f063e5f3f7e59b9"/></dir><dir name="totals"><file name="default.phtml" hash="8b54d16c056cad822afe299a15c38aee"/><file name="grandtotal.phtml" hash="e488511ca0ec20a87d35ccca7312c7be"/><file name="shipping.phtml" hash="39ca3a2bbbce7d15bb2c512915032c8c"/><file name="subtotal.phtml" hash="49e6071343d14faea14237d85828e1ac"/><file name="tax.phtml" hash="2b11eea9c5b3790916f7c32755790e71"/></dir><file name="totals.phtml" hash="cb7a3f5366a56365e75514678d94c24a"/></dir><dir name="creditmemo"><dir name="create"><file name="form.phtml" hash="d14c63341143af1f35e46a2a15f7f75f"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="0ab90b981c1792d190a00b005f0269cb"/><file name="default.phtml" hash="3f44db0a17f06e4a8264b5190e20150d"/></dir></dir><file name="items.phtml" hash="5a4a10de7dc60fcf97be2ce73579be6a"/><dir name="totals"><file name="adjustments.phtml" hash="42f515928f2b140e6c8b5212be64c166"/></dir></dir><dir name="view"><file name="form.phtml" hash="d31bb6bc7f32e363c8e234f48d0de95c"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="694ea3093599d0ca05f1b8d944d1405f"/><file name="default.phtml" hash="1bb85088d1c945c244aa3b0ba43f6997"/></dir></dir><file name="items.phtml" hash="0410c2bf6845cb4dbb44f960f76e9dd7"/></dir></dir><file name="giftoptions.phtml" hash="16efe937436bd3f11934a0e672af6ec1"/><dir name="invoice"><dir name="create"><file name="form.phtml" hash="23d4686c5a0598f73735aa5cd1430b1b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="a83dff183c9ca6cdac2aa1e78b353a3e"/><file name="default.phtml" hash="457f9bd82a6bdb69e9af88b7c94d2641"/></dir></dir><file name="items.phtml" hash="7c10fabdcdb698d2e76b07d9e8c3b08c"/><file name="tracking.phtml" hash="802a61b5614c6b63902efb2bda98846d"/></dir><dir name="view"><file name="form.phtml" hash="eeb741062873bff59caf03ded25dd090"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="b376b226780666ba3fe21aa95d07c2d9"/><file name="default.phtml" hash="58909f72a7442c77f4fbbc6d237ffd7f"/></dir></dir><file name="items.phtml" hash="cce32fe2de57c75e4a283e9516f73a86"/></dir></dir><dir name="shipment"><dir name="create"><file name="form.phtml" hash="3f27f077b08e1ddec2225bd6c2387a56"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="d4bc2a93cce32c8c6d4bcbfa5c8e9253"/><file name="default.phtml" hash="355de5f1e68a292e3840fc0503f65b2d"/></dir></dir><file name="items.phtml" hash="05b64834dddae3fab411f18a84b00fb7"/><file name="tracking.phtml" hash="de9479ab0247d9895cbc8fc0eacb0c08"/></dir><dir name="packaging"><file name="grid.phtml" hash="819717f8946a778ca80b38a15093dcdc"/><file name="packed.phtml" hash="52d116e66eabb5ccb75e7edd76b22cec"/><file name="popup.phtml" hash="9c14d5036542105073a6b3c83bc09085"/></dir><dir name="tracking"><file name="info.phtml" hash="affbfa1005465bf2791e0395ed11f7cf"/></dir><dir name="view"><file name="form.phtml" hash="ca332f13b670841f22951f985d1fac2a"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="af86611668fa31c7a26ab10a854c8d99"/><file name="default.phtml" hash="c633a0dbe2592d3c22c9389b63a6075b"/></dir></dir><file name="items.phtml" hash="997d36e5884aebc67041cf7557205cf1"/><file name="tracking.phtml" hash="560ba2666c613daf3838e91d0c16da30"/></dir></dir><file name="totalbar.phtml" hash="2694bf45cd70e37b61a3ed26c65fdeaf"/><dir name="totals"><file name="discount.phtml" hash="7e46a74df3fdd14ce1603929bba8c36f"/><file name="due.phtml" hash="225f5adf66ade026a034ab88f64e82de"/><file name="footer.phtml" hash="b9b5f8c685609424d84ac03f5f36204d"/><file name="grand.phtml" hash="71dc9b4c7d63cc53295bc4d4a7963b81"/><file name="item.phtml" hash="5fc6e237c23cb0c07f9de72a0ef86c40"/><file name="main.phtml" hash="aa3a2b328c0ed56ec3033f0a03b0192b"/><file name="paid.phtml" hash="4a72f03f1eba9a1bea5c60ae5f483e39"/><file name="refunded.phtml" hash="d0d77ad1a22b80020b92723b9af76e30"/><file name="shipping.phtml" hash="3b744dbc10dbee085cd8f72db5ee6d84"/><file name="subtotal.phtml" hash="20498513f158db7085c9680637ec2b5a"/><file name="tax.phtml" hash="d0f5fa11ef701470a2d94aab50b060c8"/></dir><file name="totals.phtml" hash="f42766bcf04dc87047b8973b38999ef9"/><dir name="view"><file name="form.phtml" hash="b500333c1f094d736587aa7508632a16"/><file name="giftmessage.phtml" hash="ed1412500ee4218acea60434aaee9e2c"/><file name="history.phtml" hash="cef334a31165535d7aa6f4c7612930f0"/><file name="info.phtml" hash="6f7d6499734fe2ce6da4b9bded1e4534"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="82c8db12bb3bd2cd5019997f0a4eaed6"/></dir></dir><file name="items.phtml" hash="6ac2eacfbb3c8fa8123718e6f18affc2"/><dir name="tab"><file name="history.phtml" hash="40fb94d3e2a52ee1f01ff8da88523403"/><file name="info.phtml" hash="a4b0c91c76dff628892dafaf8727f39d"/></dir><file name="tracking.phtml" hash="f690451a0385289b9dcf74fd97502eb3"/></dir></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="818ea7819d66425c931791b9ee4aebbf"/></dir></dir></dir><dir name="recurring"><dir name="profile"><dir name="view"><file name="info.phtml" hash="9934cb555f40a72b9e5fb8bcc611e5ce"/></dir><file name="view.phtml" hash="119fb775ce3aaca04b195f52cb1061b1"/></dir></dir><dir name="transactions"><file name="detail.phtml" hash="52f5a5139596a03f7e3ebad2ebd91713"/></dir></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="f3bb6b4a2415830e1664a7e0bf7ca3a9"/><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="edb01080b194a3f6917dfcf8b3af1d4d"/></dir><file name="fieldset.phtml" hash="38b6d7731d90be9573a8e7ecd3e51c58"/></dir></dir></dir><file name="switcher.phtml" hash="1e710220e6d32f8da5be97ed2e6a654d"/></dir><dir name="system"><file name="autocomplete.phtml" hash="fc64a24a3fc2bf68dc738aec164c43fc"/><dir name="cache"><file name="additional.phtml" hash="24a29989cc8fc8d6a3157f69eed80d18"/><file name="edit.phtml" hash="d28ecf99674cc028dbf8e9eb4632d7a9"/><file name="notifications.phtml" hash="f43a4ee0c00c56b858d953d57b63c2fe"/></dir><dir name="config"><file name="edit.phtml" hash="26b2d69c2b7fbae4f98b01f028c1665c"/><dir name="form"><dir name="field"><file name="array.phtml" hash="bca28dc0a785b51bc6db391c8adc81f2"/></dir></dir><file name="js.phtml" hash="131d0744f376d30f7b65d5a611c935d2"/><file name="switcher.phtml" hash="b59b5b63e3927e468efd5ddac86dd7f8"/><dir name="system"><dir name="storage"><dir name="media"><file name="synchronize.phtml" hash="9b02c612c64074fccc947d6475c3ae10"/></dir></dir></dir><file name="tabs.phtml" hash="d9323db68f7e8f7997fa9dd5f14f0285"/></dir><dir name="convert"><dir name="profile"><file name="process.phtml" hash="7b26cbe522663de0c91edb59b5063377"/><file name="run.phtml" hash="ce173c4c2424412a7391ba11eb910e30"/><file name="upload.phtml" hash="58b059d9b65e88164cf118f4443e157f"/><file name="wizard.phtml" hash="b02d17e3ddb724b7e666127fe59b71fd"/></dir></dir><dir name="currency"><dir name="rate"><file name="matrix.phtml" hash="7213f259f7e2c703ee36214edca76f4b"/><file name="services.phtml" hash="529e6a2348ff59dc323b65435d399213"/></dir><file name="rates.phtml" hash="9b0362418c5e4d0ca9982883293500d0"/></dir><dir name="design"><file name="edit.phtml" hash="fd39451fd13f43f097427998105806a4"/><file name="index.phtml" hash="2d4559b612d2ab7d5d8840a6f67a2fc3"/></dir><dir name="email"><dir name="template"><file name="edit.phtml" hash="a07d8c3ae6cef4a0eed7fff766d2ca58"/><file name="list.phtml" hash="4146cbc4274bb22fdaceca25f2843051"/><file name="preview.phtml" hash="43b505dc9285dc041e914002fdda0a2e"/></dir></dir><file name="info.phtml" hash="f837e1b97454aecda4afb8b84af733e5"/><dir name="shipping"><file name="applicable_country.phtml" hash="70af25fda1ba1fc8467482da3002a200"/><file name="ups.phtml" hash="3b092c978b6b1b8da7577083635465ab"/></dir><dir name="store"><file name="cell.phtml" hash="667d7bc3f0891603f2ab8457a433ebfd"/><file name="container.phtml" hash="4b85761a428cf997e311a29c82a4a758"/><file name="tree.phtml" hash="58b6af797a21730fbef54d9936647085"/></dir><dir name="variable"><file name="js.phtml" hash="b8c43ef479f9a9ea36698a6dffdd3be5"/></dir></dir><dir name="tag"><dir name="edit"><file name="container.phtml" hash="511e6ebb2515f671aedf5450cb228228"/></dir><file name="index.phtml" hash="113da2d70889b8d591cf0e3e93086430"/></dir><dir name="tax"><dir name="class"><dir name="page"><file name="edit.phtml" hash="f7c79bf6ece6fba32da9fd729c612406"/></dir></dir><file name="importExport.phtml" hash="0e7b5145d66dc0c1f30f9d2f307523ee"/><file name="notifications.phtml" hash="e146f2b09ae8e2dbb8e444937af27640"/><dir name="rate"><file name="form.phtml" hash="ffdaa3a88647bb78d5af4c069efe8fad"/><file name="title.phtml" hash="c95cab61efb504ec0e57749e63dc90fe"/></dir><dir name="toolbar"><dir name="class"><file name="add.phtml" hash="98b2cbc14ee1b54f95e3dc6220094cc3"/><file name="save.phtml" hash="016dca9f5b983ad455dbee82a8f1a94a"/></dir><dir name="rate"><file name="add.phtml" hash="6e08770611b78d0981603e64a48d6a24"/><file name="save.phtml" hash="92b0b9e348c5a7cc4bb3f73b47dfc382"/></dir><dir name="rule"><file name="add.phtml" hash="a82e479ebbc764b8753cebafc3d94d76"/><file name="save.phtml" hash="2df9243d3ff7fbceed5a219d47dd6c59"/></dir></dir></dir><dir name="urlrewrite"><file name="categories.phtml" hash="0b9ad7cc814295877a499c265f6b28a0"/><file name="edit.phtml" hash="bddd73ea946213da74aeb976bcefd719"/><file name="selector.phtml" hash="9b0023699df9e39b205a8e44e3957a28"/></dir><dir name="usa"><dir name="dhl"><file name="unitofmeasure.phtml" hash="53f060afc8c07b1e41744d15c7987fa2"/></dir></dir><dir name="weee"><dir name="renderer"><file name="tax.phtml" hash="e7a32618be62ee2502fb03df3671ef17"/></dir></dir><dir name="widget"><file name="accordion.phtml" hash="62fc94398b8799e04ec06bad595cbebf"/><file name="breadcrumbs.phtml" hash="d07a08ba66f6b9c54c32bebb33d5a7f1"/><dir name="form"><file name="container.phtml" hash="4728b83c25edf04952078d3113b776a7"/><dir name="element"><file name="gallery.phtml" hash="c6a7f19c77d2c219d4f8a63cb0e6ecb2"/></dir><file name="element.phtml" hash="26bf4a29bc07852e142c74c7cbb5f787"/><dir name="renderer"><file name="element.phtml" hash="2b99f440e7777996b2e0b79d7254f5ff"/><dir name="fieldset"><file name="element.phtml" hash="99f61048f6fc113d365a0c5ed65a31ac"/></dir><file name="fieldset.phtml" hash="23a1eb7ed586b185b408d4bbcd3e94e2"/></dir></dir><file name="form.phtml" hash="499596a8e7a8c65e5ff631d903c772c7"/><dir name="grid"><file name="container.phtml" hash="4b85761a428cf997e311a29c82a4a758"/><file name="massaction.phtml" hash="1238689acae994fccefd28b268ea4240"/><file name="serializer.phtml" hash="b41a09764ae7bca5cd667cef1a53ae96"/></dir><file name="grid.phtml" hash="bbef7840300e68f547780f141eedacef"/><dir name="instance"><dir name="edit"><file name="layout.phtml" hash="962c5510fa3ddf1109764fa0dad116f1"/></dir><file name="js.phtml" hash="a0a8117a3bfaf775007e8c0a9a60a806"/></dir><file name="tabs.phtml" hash="5ce995fc612fee633ee96509a023c16e"/><file name="tabshoriz.phtml" hash="31ca469aad10ad489ee718b5b43c8940"/><file name="tabsleft.phtml" hash="05b54cfa72ea6391410eebc3a12fca65"/><dir name="view"><file name="container.phtml" hash="ca39d17b346fcaadfdadcb25460cdf48"/></dir></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><file name="below_ie7.css" hash="0e001acdf373859110b3402e724c59cd"/><file name="boxes.css" hash="7c050f817f0472a797f583ab121645c2"/><file name="custom.css" hash="b1ab65e10053f39b57ab8064cfd60d8a"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="ie7.css" hash="c2e775278e92e710be80715c31024c2c"/><file name="iestyles.css" hash="328c87560bcfe0261a039c65ce0454dd"/><dir name="images"><file name="accordion_close.gif" hash="875409122fc82f5f6705e20dd801fd3d"/><file name="accordion_close.png" hash="6213698b5f69bb2907a5c7bb94b5fe8d"/><file name="accordion_open.gif" hash="d9d50e220b0b676094c6134a9708194e"/><file name="accordion_open.png" hash="9fbc3aba23ce5e0465e4d1cf3f6a7aee"/><file name="add_btn_icon-disabled.gif" hash="c8f6a5cfb455ef121efb56a747821f82"/><file name="add_btn_icon.gif" hash="7300097305b577ee564dc49102822d16"/><file name="address_list_li.gif" hash="79b917b514e35ce0a7833a5e268fd9f7"/><file name="address_list_on_arrow.gif" hash="3a2884ddcc87ebd48883662530b9de1b"/><file name="address_list_over_arrow.gif" hash="e826883c71b1184bd4f29433e39c18ad"/><file name="address_list_over_bg.gif" hash="56291480cc89de9d817205a5f23b66dd"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="ajax-loader.gif" hash="e2a38f1e23288e315af3c55416bc1ce7"/><file name="application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="arrow_sort_move.gif" hash="f5ac151a2b0cb1f07d6e771b8aee0ea7"/><file name="bg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bg_create_order_totals.gif" hash="ff6ab75c050b959c539cc6a6fdff2934"/><file name="bg_notifications.gif" hash="a365594725a83585d989f722b3d8c458"/><file name="bg_window_mask.png" hash="93d6efad062d24c94c105802b138b6a5"/><file name="bkg_btn-close.gif" hash="df3f2332f0bad01e031deb22b81f630c"/><file name="bkg_btn-close2.gif" hash="822457d78fb3c21dc12e9777d83eb4f1"/><file name="bkg_config-advanced.png" hash="b898594a9f1849bf386c06979ef613a8"/><file name="bkg_config-nested.png" hash="7b0fdbf98746c3c916b432c37321ccc4"/><file name="bkg_config-shaddow.png" hash="9ee4318e3f4afc446d26e7f66d01cfbd"/><file name="bkg_tooltip.png" hash="56cfed3ed8a65b19f8de88946d1a0a01"/><file name="blank.gif" hash="5722d7bd0f1e1379d0a2005a0a9ea401"/><file name="box_bg.gif" hash="4c501bd6db9d361c18780f106a809b03"/><file name="breadcrumb_bg.gif" hash="72c4adf6c75b4640ca8f7cadffa42266"/><file name="btn_add-image_icon.gif" hash="1d42210fd29fc534d9ed6b41e811d40f"/><file name="btn_add-variable_icon.gif" hash="a2db02e318d107d5b57b444c8d80b8f8"/><file name="btn_add-widget_icon.gif" hash="b4f66ca7f6097fbafd672e0b3f076ef4"/><file name="btn_add-widget_icon2.gif" hash="467acd3a14fb8be37191f5d2ec5a5b13"/><file name="btn_back_bg.gif" hash="8be512788b8044fe31aa8d00cc16ba7b"/><file name="btn_bare_bg.gif" hash="ddbbab8c0d201c3e502d50e7d4a3d64b"/><file name="btn_bg-disabled.gif" hash="079971a9d2c385fe353d35716ec9f26b"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="btn_bg.png" hash="6e3b7003381f919e8f6533444afaa978"/><file name="btn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="btn_delete_bg.gif" hash="ad740d0c16f2f6603c8ef023004d6539"/><file name="btn_go.gif" hash="1bd787868713767cc205e2ee25e41f62"/><file name="btn_gr_bg.gif" hash="6cc324b79a512150fee24fb3517d22cb"/><file name="btn_gr_on.gif" hash="820c134df02f7bc12efa5a9ac3b4d3dd"/><file name="btn_gr_over.gif" hash="d4c8b807d64c1f493d17c6c9d2bab69a"/><file name="btn_loading-icon.gif" hash="45f500105be432a12c78fed2b4592cf9"/><file name="btn_login.gif" hash="79fa32d49d3f4e39d3fbf8327f9229e1"/><file name="btn_on_bg.gif" hash="709cf5b0be137db1ef8427688503bf37"/><file name="btn_over_bg.gif" hash="f91641168454c03d1fa72731ec97a2b3"/><file name="btn_show-hide_icon.gif" hash="0238c509b33ba56c25df9513bb48f804"/><file name="btn_task_bg.gif" hash="5e0594bd9cbfcc1e32ffa918d7f9c812"/><file name="button-close.png" hash="04d0907b2d7fc3240693497b199f64f5"/><file name="cancel_btn_active_bg.gif" hash="91ce403d286eef2b4e0c13733875882f"/><file name="cancel_btn_bg.gif" hash="26749cf4949ac27c30f597434d3bde65"/><file name="cancel_btn_icon.gif" hash="97e0cd94ed31d6f2a1181f627e60e9a3"/><file name="cancel_btn_over_bg.gif" hash="45eb4e883b17375961672f5390387c31"/><file name="cancel_icon.gif" hash="70a23b78353f0a7b9b118a937fcb7ea9"/><file name="config_tab_dt_bg.gif" hash="a33f71077ca4078caa794cae01d9fca7"/><file name="dashboard-close.gif" hash="5ae5afd61e937fcd2d5b84641255ee4d"/><file name="db-graph-bg.gif" hash="5d76efb7c3244f5684df2566782124ea"/><file name="db-graph-bottom-bg.gif" hash="b58ced87a38a10891106329ae882aa1c"/><file name="db-graph-line-bg.gif" hash="f16bb08e040c2c0a3e23b3f35c54b79b"/><file name="db-graph-line2-bg.gif" hash="744ebfdba20d050f4d252afc216394be"/><file name="db-graph-x-bg.png" hash="d5c26510718a78d22083916d80ef7a22"/><file name="db-header-bg.png" hash="3976cb6351e167686a501a85cf3a68e9"/><file name="db-menu-bg-hov.gif" hash="34ea76a6d105d90fcb63bf105aadb8f7"/><file name="db-menu-bg-up.gif" hash="b0f754872dff5f2f0dc57ba193fdfa4c"/><file name="db-menu-bg.gif" hash="ea534c3c09bb309e566b6ae876655e13"/><file name="db-menu-sep-last.gif" hash="a01fe34854e1187e466fd58d462c4106"/><file name="db-menu-sep.gif" hash="7c5ae1cd59a189261cc3244358d5c1ad"/><file name="db-menu-start.gif" hash="aa5cac2194d937cc7fa904ccfce70ecc"/><file name="db-scroll-bg.gif" hash="06d2411e3b5f350ab21b625439d2d69d"/><file name="db-scroll-but-bot-roll.png" hash="6bc5e482f3f6d8fb1fc5014ddea43706"/><file name="db-scroll-but-bot.png" hash="25c0181e76ff8ceb3c0ec59071b8c72c"/><file name="db-scroll-but-top-roll.png" hash="b7961f2a3b5b641694a9b0b30d58e46b"/><file name="db-scroll-but-top.png" hash="de7df96e961596be9ff556924259b98b"/><file name="db-scroll-roller.png" hash="e01dde7bd096c52179acf29a425a29e5"/><file name="db-tab-bottom-left-bg.gif" hash="124388d44ac58b029377c6311a4782d5"/><file name="db-tab-bottom-mid-bg.gif" hash="9c48f33aa8907cfcb227bc779c2e1dce"/><file name="db-tab-bottom-right-bg.gif" hash="1db45e6fd8abc67d59f96a676607b412"/><file name="db-tab-footer.gif" hash="cac8928acba75bc1edd73186ced78e5c"/><file name="db-tab-header-sep.gif" hash="580312af7441b6a62f7e32081c40fb0f"/><file name="db-tab-header.gif" hash="fdf493b9477fcff7e7be98405effc33d"/><file name="db-tab-left.gif" hash="3fe3c55267dbbdd1db2ff959ccc9e0be"/><file name="db-tab-right.gif" hash="b7a32c8b03efe2fbdb63215d0446e3be"/><file name="dotted_divider_dark.gif" hash="8bf1de196d9ea048bfb25155cedd2e9e"/><file name="dotted_divider_light.gif" hash="92e562bf2070110f6b0a15e29b845445"/><file name="edit_icon.gif" hash="dbda31751c78d964c04394e9d8533187"/><file name="entry_edit_head_arrow_down.gif" hash="985c3ce4439fbf8bb2216fc7e73a3f0b"/><file name="entry_edit_head_arrow_down2.gif" hash="d68dd0fbc2819858a26ea2835c05df77"/><file name="entry_edit_head_arrow_up.gif" hash="d2b90a1823fff9f3917f19b427410144"/><file name="entry_edit_head_bg.gif" hash="1086b7196e8b33c4f46e49fecef0f35f"/><file name="error-msg.png" hash="3cd27b642416dacdc28907c89d934886"/><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="fam_account.gif" hash="c910fd1ff41b940d71b0835e02fc143e"/><file name="fam_application_form_delete.png" hash="972c2d998fc19572dd64af6b5e2e898e"/><file name="fam_application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="fam_asterisk_orange.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="fam_bin.gif" hash="2fb388bc9f1d32d3802db8e91dc238bc"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="fam_bullet_disk.gif" hash="9fe82691d960c18d3d315c3f9164af4f"/><file name="fam_bullet_error.gif" hash="008802f44288b732b59cfe9fdbfecefe"/><file name="fam_bullet_success.gif" hash="465a056a3ba3d94367f51c3c0b751391"/><file name="fam_calendar.gif" hash="0614207ce4e3e0a9bd631b39e7692e3c"/><file name="fam_cart.gif" hash="1f2fd2c8ac6574488ea78302b6856191"/><file name="fam_comment.gif" hash="5138f9a4b6019a5b14b8ff9a32a3cb89"/><file name="fam_creditcards.gif" hash="b75b8ce2f4fceb58f8082c48344560c7"/><file name="fam_folder_database.gif" hash="e86175ff0f389ade1fc7bf15e03346eb"/><file name="fam_folder_palette.gif" hash="c0941b9145e06d53cc0d17ac4c151764"/><file name="fam_folder_table.gif" hash="e2914ba75944acd2a9e2d338fa339e16"/><file name="fam_group.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="fam_help.gif" hash="2b5ed4c13a8e24456207b757826c7b2c"/><file name="fam_house.gif" hash="8eb2d580c5a40b7974f4263ca64fb94a"/><file name="fam_layout.gif" hash="5366a5f02260d3a860ef0c4787282ad6"/><file name="fam_leaf.png" hash="078d4f24683331b4557356a59e67b125"/><file name="fam_link.gif" hash="78590d5d8375d1baabe7b66d7b9ceb7d"/><file name="fam_lorry.gif" hash="174e86e45e76e7008fa3510cefa85047"/><file name="fam_money.gif" hash="6996bad465222fb6487cab94b4607846"/><file name="fam_money_add.gif" hash="70ceed401fe9913305f2362f7e26225d"/><file name="fam_monitor.gif" hash="f3bc806ff9d0907320b03018ba2d00ea"/><file name="fam_newspaper.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="fam_newspaper_delete.gif" hash="41acabfc19102be92d3ccbc66d1fede3"/><file name="fam_newspaper_error.gif" hash="009bfa425298e1d2e44e38e58cd97938"/><file name="fam_newspaper_go.gif" hash="eb43105f8e13e3a752d7ca33bb086831"/><file name="fam_package.gif" hash="bf9be09ef64d006455baa211b7c03983"/><file name="fam_package_go.gif" hash="e4f8d380c2f8e5a7345e360293433764"/><file name="fam_page_white.gif" hash="26940eb67826c5af72b6048c7c5a8335"/><file name="fam_page_white_edit.gif" hash="a4f88300b74ad592a5c47ed54ff07af9"/><file name="fam_rainbow.gif" hash="e8b04cc945b3582a181d4ddbc2d2325f"/><file name="fam_refresh.gif" hash="01bbef614023c0890812e76bc7ecf7e0"/><file name="fam_server_database.gif" hash="7901fa06ffd68ed730cf43bb560756fd"/><file name="fam_status_online.gif" hash="a80019ffa3a573f709772ed1099343fc"/><file name="fam_tag_orange.gif" hash="6ce735a0e590bda040b6e1614c42e58a"/><file name="fam_user.gif" hash="63bbdd6d9d7a27591907a7b87898e259"/><file name="fam_user_comment.gif" hash="014dfd31d9af40e3d5960b2b0d900da3"/><file name="fam_user_edit.gif" hash="f5b36e803060c6b82e639a4fad57b9f7"/><file name="filter_row_bg.gif" hash="013a0929a7b2ddc6823bdda17d08acc0"/><file name="footer_bg.gif" hash="7724711d3ca07a5e46a6030e86743a71"/><file name="gift-message-collapse.gif" hash="5b710f5faa9c7352a39c10e3ebbee6fc"/><file name="gift-message-expand.gif" hash="fd53a70cbb1ea048754657a63787e9cb"/><file name="gift-message-grid-column-bg.gif" hash="97a8a9b8cc4ab68e7404ccf1320f50a6"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="grid_sort_asc.gif" hash="b78c3a1a27ac9672a31b7d1bbac60322"/><file name="grid_sort_desc.gif" hash="d958b946eba3dba863d724530a0dba1a"/><file name="grid_th_bg.gif" hash="8f4349fac728858374e17edf03390977"/><file name="grid_th_onclick_bg.gif" hash="7bf331e2a41e5331c4210bdc6adc4383"/><file name="grouped_to_order_icon.png" hash="4bdae9a6199655027b8b8aeee8f80ce4"/><file name="header_bg.gif" hash="cbe510856afa5cb0c32642c1f9a8eceb"/><file name="header_top_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="horiz_tabs_ul_bg.gif" hash="58dbd9c45f76993346c2bb788896248e"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_question-mark.png" hash="23201b7ac207eebd9be0776ea44098a4"/><file name="ico_success.gif" hash="0afb20898a704a106cb4c598868abf32"/><file name="icon-enabled.png" hash="5fa7c06b312cbea3675e844686e434af"/><file name="icon-tooltip.png" hash="5767601cd66b23d0b6fe8defc10dd48d"/><file name="icon_btn_add.gif" hash="7300097305b577ee564dc49102822d16"/><file name="icon_btn_back.gif" hash="89ed97cede3f68241446a62c96e3ce4c"/><file name="icon_btn_delete.gif" hash="dbde0b76d36cfd624bf0de166d0a265e"/><file name="icon_btn_save.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="icon_edit_address.gif" hash="d1ca2bb3a5c86afd379f25d9fc4352e3"/><file name="icon_export.gif" hash="9a13f20c6a17b41b9c357545c2da5636"/><file name="icon_export.png" hash="fb299dd13df666516eabe16f59193383"/><file name="icon_feed.gif" hash="0366583ed6e285d028442fcdebb05072"/><file name="icon_feed.png" hash="8537f6f88fcff4aac793247143d14e42"/><file name="icon_note_list.gif" hash="8d25ba225ca09b687a78bff510df5d10"/><file name="icon_remove_address.gif" hash="2de2b3d02c19adfb93e9e43a392db178"/><file name="login_box_bg.gif" hash="e4654826eaa8d5ebc0ab18e9bee71e1d"/><file name="login_box_bg.jpg" hash="404e37f4ee9f4ff9bfcb638741c7581d"/><file name="login_box_bg_auth.jpg" hash="d90a81db1064ec37b0cc92436725c24b"/><file name="login_box_bottom.jpg" hash="038f15261e74bc381484f2fcfa45a73b"/><file name="login_box_legal_bg.gif" hash="528ac4dd480c4fc00ac808bf17394c05"/><file name="login_logo.gif" hash="a15f85d59684e1ec548b758fb6165469"/><file name="logo-large.gif" hash="b938979c790d4aba4170054fc4a060be"/><file name="logo.gif" hash="c7e9f290d965f707e4c4a61bfdab58cb"/><file name="logo_email.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="massaction_bg.gif" hash="8b5f4db3ab3ea09cd5bd0164d67c4f0d"/><file name="massaction_button_bg.gif" hash="4c8262817e48d007237124ce0e7f4d18"/><file name="massaction_links_delimiter.gif" hash="9a0337183b5b67c0eed75993d7f14d10"/><file name="middle_bg.gif" hash="ba4f176d2c553201ebab4aba5c6d3d20"/><file name="more_arrow.gif" hash="38bb4c0e9270250151486d0bb36c476f"/><file name="nav1_active.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_bg.gif" hash="a1d4ef5b590ce0a425dc04e45ed06cbe"/><file name="nav1_off.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav1_on.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_over.gif" hash="2c70d6175f1c965c27dda0598a67e63c"/><file name="nav1_sep.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav2_last_li_bg.png" hash="279935c9799679fc5894337eaabc7cf0"/><file name="nav2_last_li_over_bg.png" hash="39536f00824293d11242888a76f40a5f"/><file name="nav2_li_bg.gif" hash="0a4f34b0e4436c519d31203f19503b83"/><file name="nav2_li_bg.png" hash="2fad219d162324e9a19f2745d5b6d562"/><file name="nav2_li_over_bg.png" hash="dc37c4a4aab40ea2ae44dea5ea133a9d"/><file name="nav2_link_bg.gif" hash="dce00ddad351e72e83bc87274cbaa54a"/><file name="nav2_parent_arrow.gif" hash="60e012a14a077bd2257343facc369c0c"/><file name="nav3_bg.png" hash="2bc7af80ad8886013da38401b63ab6df"/><file name="nav_bg.gif" hash="1b857c7d35f35ef9f6cae9e03a4e3dff"/><file name="nav_list_bg.gif" hash="7a4e2bdb887c12d8a1152bbcc8c02a3c"/><file name="nav_nest_link_bg.gif" hash="1d0c6b374bf02ac4b5aa012955c431de"/><file name="nav_nest_link_over_bg.gif" hash="fae3c579a4d432503b1f4f929d070609"/><file name="nav_on_bg.gif" hash="ac624b580cae5a76f6c92abc5a44191d"/><file name="nav_parent_arrow.gif" hash="3a95559263e569dc1c8065cb2d9b3f2c"/><file name="note_bg.gif" hash="105967d7c15ab4610726eea52d862a97"/><file name="note_cell_bg.gif" hash="71e656d42f8ba8c2d477c6866c499b71"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="notice-msg.png" hash="9cd1dfebccec8a2123d543fa49b17bd7"/><file name="pager_arrow_left.gif" hash="6e44f608dac8eb8be1d1ebee5a3285aa"/><file name="pager_arrow_left_off.gif" hash="30f5e56195ab3546b36f4016db5254be"/><file name="pager_arrow_right.gif" hash="cc79526156b7e0c8abce61fad3d53f77"/><file name="pager_arrow_right_off.gif" hash="f01b7dad9acf0180b5c62edbd7ea9939"/><dir name="paypal"><file name="logo-paypal.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="pp-allinone.png" hash="c457fe4bfe28a18c90d0abd36fe3f880"/><file name="pp-alt.png" hash="37a166931ca15c465bd86311d15e0422"/><file name="pp-gateways.png" hash="90acb72c2f46fa131351efe0492d52cf"/><file name="pp-uk.png" hash="e0830ccb14533051b8b0340471744228"/></dir><file name="paypal_logo.gif" hash="871e205a64292121f4c893373acfb581"/><file name="paypal_section.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="paypal_tick.gif" hash="e8685c1fb7c4c106ae4fd24e9bbf5a27"/><dir name="placeholder"><file name="thumbnail.jpg" hash="5c73b5aa515b1719f7b398f5131f91a8"/></dir><file name="process_spinner.gif" hash="345b30b4d0b6088d0151ecfbdf48c036"/><file name="product_rating_blank_star.gif" hash="5e20a299c0ff16168be38b6dde580eda"/><file name="product_rating_full_star.gif" hash="dd5aae332178d928a7f49dea7691b5f6"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><file name="rule-ajax-loader.gif" hash="32dc1f5901143d36fbd7a6df3950819f"/><file name="rule_chooser_trigger.gif" hash="9c498e789c3ce734f5301c2475e2a04c"/><file name="rule_component_add.gif" hash="7914e57701ca26f5c8bf23c6bc3e1f25"/><file name="rule_component_apply.gif" hash="3f9b9025551da6963a9ecf8d184a204a"/><file name="rule_component_remove.gif" hash="4d785bcecfbe716fa4d749d20738a8f0"/><file name="save_btn_icon.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="sec_nav_bg.gif" hash="99c6741591cdb2a2a128668a1d32d668"/><file name="section_menu_bg.gif" hash="f9edd44c92743a0c9ae9535a7992d6b1"/><file name="section_menu_bottom.gif" hash="167d2ef46ff80158c807b4b916501b28"/><file name="section_menu_link_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="section_menu_link_over_bg.gif" hash="7da7e56567633aab279cf3aec6f49d8d"/><file name="section_menu_over_span_bg.gif" hash="f5ea5292f15ed62b99f0f51d9fff2c66"/><file name="section_menu_span_bg.gif" hash="dbf3916358e794ee809b4cf33903af2c"/><file name="section_menu_ul_bg.gif" hash="3aea6e5452f548438ca34e17954a9d6b"/><file name="side_col_bg.gif" hash="b3691fd62663457af39eaf71dd8cda5a"/><file name="simple_container_bg.gif" hash="56f1ac91169eb4896b8c91384fc8bf15"/><file name="sort-arrow-down.gif" hash="fc2cd9f756ce510c4470478d720f81cd"/><file name="sort-arrow-down.png" hash="dc65160d9d4d6cdd6bfe1b397a931975"/><file name="sort-arrow-up.gif" hash="39026b0ff1f0c18091caa60384491163"/><file name="sort-arrow-up.png" hash="da54e5306bdce67551aa415f5d7f7ea7"/><file name="sort_heading_bg.gif" hash="6066d09f237f556b0a4770e4788e7598"/><file name="sort_on_bg.gif" hash="0cb36788ed4fbf19e657acbc75a3f1b8"/><file name="sort_row_bg.gif" hash="f2e1c5cb26b9f5211419b99d30745244"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="sub_button_bg.gif" hash="e3f66dd60510f9f7e937e2e55442c30a"/><file name="success-msg.png" hash="c64cb2acc3d0eeba48fdea83620913ed"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="tabs_link_bg.gif" hash="34447929f5e6591ba9b5795b983fdfd4"/><file name="tabs_link_over_bg.gif" hash="2cf3f56884096055fb0bdf9474f280c9"/><file name="tabs_span_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="tag_blue_edit.gif" hash="b2163ac3baf7d822b48593342846645a"/><file name="tn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="tooltip_bg.gif" hash="0aa4b866fc067a75f27ab749c1dabf74"/><file name="tooltip_corner.gif" hash="71146534671d5e0751505640b7c59859"/><file name="tooltip_top.gif" hash="032ff52a6ff5714cbdf6c1f62abaf7e5"/><dir name="tree_icons"><file name="join.gif" hash="4d5d614e0da056df815a4306d6368692"/><file name="joinbottom.gif" hash="4b3daa7f2cc584f1aac0d142275d7cba"/><file name="line.gif" hash="63ab38a6203262f15ca46c631232ea2c"/><file name="minus.gif" hash="d647fbbd0ec410b8f3bb3357b62eedcf"/><file name="minusbottom.gif" hash="b09d684cca7135ef728141aaf2464baa"/><file name="nolines_minus.gif" hash="eb2243a354ffcfac93ba0fe948f7167d"/><file name="nolines_plus.gif" hash="ec92b634b63608fb4b0dbf114e3b89e1"/></dir><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="varien_logo.gif" hash="6f10d0fe572cb012947c164217e9e428"/><file name="warning_msg_icon.gif" hash="4cf6ec7f59ab09f9c18b3a4301714c6d"/><dir name="widget"><file name="catalog__category_widget_link.gif" hash="8435943009f1f774bbd6a4809c719eb8"/><file name="catalog__product_widget_link.gif" hash="62f2d7020143f98ba7514469eb612a7f"/><file name="catalog__product_widget_new.gif" hash="37a5af9f98ae73e180ad0cca05c95324"/><file name="cms__widget_block.gif" hash="b7b0b1517cc38b18b92841b33b312190"/><file name="cms__widget_page_link.gif" hash="b839dee210e61850a5858cc8634cbccd"/><file name="default.gif" hash="684143ae5531aa6ba22215f4fadeea6c"/><file name="reports__product_widget_compared.gif" hash="bd3e5a5015eb2c5c64f1d11835166dc4"/><file name="reports__product_widget_viewed.gif" hash="44d5cd71e4fb7235f9cff0c7e2b2f531"/></dir><file name="widget_placeholder.gif" hash="2bd8d72cf12f8d7d0a6a3268f97786ff"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/><file name="window_content.png" hash="08361df29783d46a2493cf0d8ad733a7"/><file name="window_top.png" hash="555a8db5efa3a252c2ead3d3dadd1075"/><dir name="wysiwyg"><file name="skin_image.png" hash="a521b0c60b001de4a3405e73c4a6cd4a"/></dir></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="d17d29bfa01e6b3f469c1e34daa2d2c0"/></dir></dir></dir></dir><file name="menu.css" hash="5054c586a77cb903848cceaaf08b7736"/><file name="oauth-simple.css" hash="ec27a5e8451d3b26ca9ab881a0c0a256"/><file name="print.css" hash="cc6cbc1ef42dd17187b6961f75268c4e"/><file name="reset.css" hash="4bf260890fb34be804dc967b07b26e63"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Adminhtml_Default-1.9.4.1.xml b/var/package/Interface_Adminhtml_Default-1.9.4.1.xml
new file mode 100644
index 0000000..722653a
--- /dev/null
+++ b/var/package/Interface_Adminhtml_Default-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Adminhtml_Default</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Adminhtml</summary>
+    <description>Default interface for Adminhtml</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:40</time>
+    <contents><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="admin.xml" hash="dabe4a475e4bf891511520bb6127f887"/><file name="adminnotification.xml" hash="e3256c86976aac2056639c32001e8a0e"/><file name="api2.xml" hash="efa54fd6c59a1363bbe94c2bb8cfa890"/><file name="authorizenet.xml" hash="d7271b7b3fc35527209a3b04d57faff8"/><file name="bundle.xml" hash="b0b01c2c65ecf1bdcbcf14e28652b6f5"/><file name="captcha.xml" hash="b6a1b4b09245c75f1241b9c99686ee01"/><file name="catalog.xml" hash="63e9d4a5a4e684ce8d5f15407bd7e86b"/><file name="cms.xml" hash="0f94e157fc39272346cd117bf03f11d5"/><file name="connect.xml" hash="8e42fad0013633415525519d1d552fe4"/><file name="currencysymbol.xml" hash="956e1b2151a6c4fd61cf9978a5f8bc1c"/><file name="customer.xml" hash="27af64a8a5056032b918c95b9ff6f9f3"/><file name="dataflow.xml" hash="258e1380e65a62933ea37307d28ed23f"/><file name="downloadable.xml" hash="57bd6002f68c57cb4167290c92334216"/><file name="giftmessage.xml" hash="0954ee5081b424d41f7e168c232a8447"/><file name="importexport.xml" hash="5519e7dc10ee490f202f4927382e2b23"/><file name="index.xml" hash="c59a9d2f223297d33415d843c5ea4846"/><file name="main.xml" hash="27918ac6cb9dfaf1cba090cb800e83a4"/><file name="newsletter.xml" hash="eabb130f32301344970d65dc77fe9599"/><file name="oauth.xml" hash="3cc70c9ac89bbfacbd3a9f3289e26b9b"/><file name="pagecache.xml" hash="f33b8e37be4ab1dc681acbe7ffbe139e"/><file name="promo.xml" hash="20fd585dcaa9e830e09afb24212099ad"/><file name="report.xml" hash="cce97c488e21e10541e0a3d64bcf7b6b"/><file name="rss.xml" hash="604fb320683986266541ba4ff50e3ae7"/><file name="sales.xml" hash="afe4642654d3f556305a647805602861"/><file name="search.xml" hash="bea5b486b22bfd3ee84fc0e21826a88f"/><file name="tag.xml" hash="6fbf0da651787c6a8de2ea803db2c637"/><file name="tax.xml" hash="ed660cff4c94190b2825e41840731c19"/><file name="widget.xml" hash="6be580bc1ac273a9a0ccfe75f468e587"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="735c9ec66d1309f1206294f075fdcdd1"/></dir></dir><dir name="template"><file name="access_denied.phtml" hash="ff7e7628c69f5a6faf22ddb1c319ab55"/><dir name="api"><file name="role_users_grid_js.phtml" hash="bfd03f411c01f8c1eb8f60811afc65a6"/><file name="roleinfo.phtml" hash="ddb5db43337c1054fbee387945a91109"/><file name="roles.phtml" hash="420fbd2e487d332b71dddc3189a72ac3"/><file name="rolesedit.phtml" hash="236eec97598cfcabefe5694a08eb442c"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="e50593a7a375c0674b57c60b84bd294a"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="api2"><dir name="attribute"><file name="buttons.phtml" hash="b211cd2ef5c0515190f089fb70faef0e"/><file name="resource.phtml" hash="82b6b6062beb93e8d0f80e64b618a1b6"/></dir><dir name="permissions"><dir name="user"><dir name="edit"><dir name="tab"><dir name="roles"><file name="js.phtml" hash="19a9dee2c3675077d20d20b2fe9b7081"/></dir></dir></dir></dir></dir><dir name="role"><file name="buttons.phtml" hash="48f39c0ff4d551453dbaf74b38dfed97"/><file name="users_grid_js.phtml" hash="5b38183975d7068df675d2e74f32f944"/></dir></dir><dir name="authorizenet"><dir name="directpost"><file name="iframe.phtml" hash="ee7d99c196525961e4426023ed1f71d6"/><file name="info.phtml" hash="7af4958ced9ed0b820e31414712314e1"/></dir></dir><dir name="backup"><file name="dialogs.phtml" hash="1ab3bd9dd2d0dc4fe71e3ec05929bdfa"/><file name="left.phtml" hash="28abce5769ea95892ee4ffc0954e2682"/><file name="list.phtml" hash="3c5d531e2c6da63fd4f7628308f08051"/></dir><dir name="bundle"><dir name="product"><dir name="composite"><dir name="fieldset"><dir name="options"><file name="bundle.phtml" hash="13c049c3858aede8d9ec9c8d5bd93932"/><dir name="type"><file name="checkbox.phtml" hash="4a974f8962410393537df2bf89491e1e"/><file name="multi.phtml" hash="cb36c7cde9c2ded0f33583c201f22afa"/><file name="radio.phtml" hash="3307fc3c8236e3ea839c6d4d4ddeac95"/><file name="select.phtml" hash="860ff711964c822b79c7dbc70d408fdf"/></dir></dir></dir></dir><dir name="edit"><dir name="bundle"><dir name="option"><file name="search.phtml" hash="bed7e4793be8b2bfc39e68c6b4b7ea1f"/><file name="selection.phtml" hash="f13bd0f783f8711ed6434b1efdd37f19"/></dir><file name="option.phtml" hash="03a318c5cc7a7809ef301bdbf1e01cb7"/></dir><file name="bundle.phtml" hash="3c8c62637fe159dbea88b1f8f976f82d"/></dir></dir><dir name="sales"><dir name="creditmemo"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="bc57544cf9d1f53e0ba710cc12101ba9"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="3d68d4b17b2e26011f0b6b5839ceacb0"/></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="28d880e36253cbae2ba60f412b8ffe3b"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="197d154a2d0c1f464541037cf0131ad3"/></dir></dir></dir><dir name="order"><dir name="view"><dir name="items"><file name="renderer.phtml" hash="cb3cec0a08b12d62638c74b3da7cea69"/></dir></dir></dir><dir name="shipment"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="f97295be3a736aa634b241a804be43ea"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="998a2d676d93700cc8afa0465b8fa9ab"/></dir></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="37ca694eb77403ac744aab9101349c92"/></dir><dir name="catalog"><dir name="category"><dir name="checkboxes"><file name="tree.phtml" hash="95c7468be3636ff49a744228e47edcc8"/></dir><dir name="edit"><file name="form.phtml" hash="f17abf89515af569399d88388a94ef55"/></dir><file name="edit.phtml" hash="a4a0e994436988e9401d7f0ceb3ffd23"/><file name="tree.phtml" hash="76f3bcf4b961c262b33b09df17345f39"/><dir name="widget"><file name="tree.phtml" hash="4c079c7a8d860d5ff36fef46eada257d"/></dir></dir><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="d17e50690d1e14f9caaf5105d2b3d187"/></dir></dir></dir><dir name="product"><dir name="attribute"><file name="js.phtml" hash="fbcfb6db2da0c52ebd01a70f61b6ac5e"/><dir name="new"><file name="created.phtml" hash="f814e5ce1bf951e11a4370be354766e7"/></dir><file name="options.phtml" hash="b8a61b9f8a0817446f0d52cf739b3fb5"/><dir name="set"><dir name="main"><dir name="tree"><file name="attribute.phtml" hash="1cd780abd50e66840498ef241416ef6b"/><file name="group.phtml" hash="bc852da8df505f611965d2585972853b"/></dir></dir><file name="main.phtml" hash="a10ebf167915cbeb8aed5d76ba47d9b2"/><dir name="toolbar"><file name="add.phtml" hash="ce3c6895929df71e017ebc00c3183d78"/><file name="main.phtml" hash="615ca584ea71f9b7b8add861488894aa"/></dir></dir></dir><dir name="composite"><file name="configure.phtml" hash="31c28cd626e1059ee0d05b78df28fdea"/><dir name="fieldset"><file name="configurable.phtml" hash="571775f59c56c59a4ff6bea485b73710"/><file name="grouped.phtml" hash="843069b3d59fc05f86a2014177212569"/><dir name="options"><file name="js.phtml" hash="9c907b5b54ed2cd8ad1ec4afc45115f8"/><dir name="type"><file name="date.phtml" hash="75d46189d0e23f6aee5dbcc7ce5651c8"/><file name="default.phtml" hash="718bc5a7bd3013f43d544d3fe8ea8a77"/><file name="file.phtml" hash="00c647c6eb343bd8565f0b88ab392a39"/><file name="select.phtml" hash="277c942f79c0eb7a7b53b04643c9593d"/><file name="text.phtml" hash="acd27eac2f69153fec4e1865c787ea59"/></dir></dir><file name="options.phtml" hash="1df8f7845611e80a3f13c494b1b839ec"/><file name="qty.phtml" hash="4d0c8e4434be8c259435346d673a6dd0"/></dir></dir><file name="created.phtml" hash="1ed62146a00291e9c2b0230804f84fb7"/><dir name="edit"><dir name="action"><file name="attribute.phtml" hash="27488ec6201dc9d6820f9a788a1ada4f"/><file name="inventory.phtml" hash="52d619872155e6944f9e235111408ef7"/><file name="websites.phtml" hash="98bcd6fa5f51a0dfb57a3023272a27d2"/></dir><file name="categories.phtml" hash="81f284d1f0d81f1fa0d768cf8df4648c"/><dir name="options"><file name="option.phtml" hash="685f57480169653dde66b661bab9fe96"/><dir name="type"><file name="date.phtml" hash="d920b195727a51dac13285cc236927f7"/><file name="file.phtml" hash="c2f994dc12c6beb6fc585d6968f37e6e"/><file name="select.phtml" hash="d26e6090862d21f0d9c9cc2da834908e"/><file name="text.phtml" hash="99e1c0b3be182e27eba6a02e27c254a7"/></dir></dir><file name="options.phtml" hash="860eeb5fc3b47284ea970feb48d530a3"/><dir name="price"><file name="group.phtml" hash="aa91ad4e0d4cbe2059fd8f71a76d2e90"/><file name="tier.phtml" hash="11caea53a3f27beece051f05ebb2a8ae"/></dir><file name="serializer.phtml" hash="cc36239d24eb9233499aa8668504b9d0"/><dir name="super"><file name="config.phtml" hash="91024f4002467a6198884913e29f8da6"/></dir><file name="websites.phtml" hash="9b748765b6602c9b0ab7a6e710e96dfd"/></dir><file name="edit.phtml" hash="77abbac755fc5e40aa8d1a512f39e12c"/><dir name="helper"><file name="gallery.phtml" hash="9b662f0f2b7fa50aae506801877c319e"/></dir><file name="js.phtml" hash="fd68a3d0aa7de457a161512247d39012"/><file name="price.phtml" hash="c7950bff8c69ef04f373e05a05eaeeac"/><dir name="tab"><file name="alert.phtml" hash="2ca71d372fd28105043613448194a05a"/><file name="inventory.phtml" hash="33b3d392060951c904d71a474e898d01"/></dir><dir name="widget"><dir name="chooser"><file name="container.phtml" hash="898bcd75e7f5bc7b9ff9ef23578447c9"/></dir></dir></dir><file name="product.phtml" hash="3100e755e72f3e0459ec415076d6c2b8"/><dir name="wysiwyg"><file name="js.phtml" hash="200fe68eaccb7e5e1f1ab9f5fdb0d764"/></dir></dir><dir name="cms"><dir name="browser"><dir name="content"><file name="files.phtml" hash="edab20c3d693785605c339c829bc85bf"/><file name="newfolder.phtml" hash="d92a8c8b996e3052205465501f823d38"/><file name="uploader.phtml" hash="70f3a760ced2fe0fedd408790c808256"/></dir><file name="content.phtml" hash="911c2c7575b3697ddfbe5b54003b0480"/><file name="js.phtml" hash="3f793d09811f41ea12ab24e1d21004b7"/><file name="tree.phtml" hash="0d8036e58dc67a85c29d99ae51b24480"/></dir><dir name="page"><dir name="edit"><dir name="form"><dir name="renderer"><file name="content.phtml" hash="aa53277015b94a3632ff65600a2c132e"/></dir></dir></dir></dir></dir><file name="coming.phtml" hash="9d68f7d168d84f45f09dca6c8d5c57bb"/><dir name="connect"><dir name="extension"><dir name="custom"><file name="authors.phtml" hash="1c1e2ce7fe39bf549fea3fbb1fa25342"/><file name="contents.phtml" hash="4207fb35993aec2a4f0d2eb0fb50e587"/><file name="depends.phtml" hash="21a7c1f8a954b0bd706653776164b2c0"/><file name="load.phtml" hash="1ecf32a6aafbb1b7b79e10a7a980029a"/><file name="package.phtml" hash="f993c90b7b158b468533d7c591cc0537"/><file name="release.phtml" hash="0f17de2b77a9adc5a057f0018e5310dc"/></dir></dir></dir><dir name="currencysymbol"><file name="grid.phtml" hash="8faa3bbe598bc6bcf9e2ff2408effcc5"/></dir><dir name="customer"><dir name="edit"><file name="js.phtml" hash="a4981632e863b82ed494ccc99f3752c0"/><dir name="tab"><dir name="account"><dir name="form"><dir name="renderer"><file name="group.phtml" hash="77d7cb5f2f95ef643e0286a4605aeab8"/></dir></dir></dir><dir name="view"><dir name="grid"><file name="item.phtml" hash="204c9cd7d9b5237bf863659f2a132139"/></dir></dir></dir></dir><file name="online.phtml" hash="69ff950bec24490ffaf2831eea866169"/><dir name="sales"><dir name="order"><dir name="create"><dir name="address"><dir name="form"><dir name="renderer"><file name="vat.phtml" hash="6c63263ac2eed95d563ce140ce873b3e"/></dir></dir></dir></dir></dir></dir><dir name="system"><dir name="config"><file name="validatevat.phtml" hash="4bb7a42ea5a9a3b16bd4cfbd0c637828"/></dir></dir><dir name="tab"><file name="addresses.phtml" hash="a51dde4e46b0a6811e9db2090c23b04c"/><file name="cart.phtml" hash="517478d69773066a4ab664e08aba35d2"/><file name="newsletter.phtml" hash="3945cde3ca22107243119551245c233e"/><dir name="view"><file name="sales.phtml" hash="ce7336ea6b2f4d6daf50b88918b0dda2"/></dir><file name="view.phtml" hash="087b9d3222bcd38cb82b9be2dfc173bd"/><file name="wishlist.phtml" hash="6dee8733fd9c915efad6cb0cdb71e167"/></dir></dir><dir name="dashboard"><dir name="graph"><file name="disabled.phtml" hash="0210c1ddde1b52ad0f9a671fe84e81e0"/></dir><file name="graph.phtml" hash="e753293e33068c24515e6051a4856bc2"/><file name="grid.phtml" hash="4334e2a5bcab21ac44c0151bd9a51bf3"/><file name="index.phtml" hash="b1a268bcb5f2efb76022d68714f7f6fb"/><file name="salebar.phtml" hash="7860149f9449a9f4fd5cbccefd415d6b"/><file name="searches.phtml" hash="55227aa009d49c194950087f950041f5"/><dir name="store"><file name="switcher.phtml" hash="f0b25bc75ea67e63576a557bfe820797"/></dir><file name="totalbar.phtml" hash="5a4cd54f0075f07bec88efc9b5c47051"/></dir><dir name="directory"><dir name="js"><file name="optional_zip_countries.phtml" hash="836c6ea23ae98a076f38da313197ba08"/></dir></dir><dir name="downloadable"><dir name="product"><dir name="composite"><dir name="fieldset"><file name="downloadable.phtml" hash="5ef5535b8ce8e4bbe7659d444898f20d"/></dir></dir><dir name="edit"><dir name="downloadable"><file name="links.phtml" hash="b587b76cf094109587ac967f4e5a8120"/><file name="samples.phtml" hash="a73bf52f2ed419ad8668e57a1e3dc4ba"/></dir><file name="downloadable.phtml" hash="b66ab0dda0d0a7e096857b7e7c052174"/></dir></dir><dir name="sales"><dir name="items"><dir name="column"><dir name="downloadable"><dir name="creditmemo"><file name="name.phtml" hash="16588112504f00eec8cf47e4ce5da0d7"/></dir><dir name="invoice"><file name="name.phtml" hash="492f04ce08f8d68bd5388030ffd0d914"/></dir><file name="name.phtml" hash="187811540e032dd12b6feffd0bc598f9"/></dir></dir></dir><dir name="order"><dir name="creditmemo"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="95b422bd8627c1a8b45a1d4491d1bd93"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="3677d1c7be1a53b23a6b9f400a2935ef"/></dir></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="90bad224de57564dd250c37570595a21"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="9976312d106cd236ba87262d0a0cf54d"/></dir></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="c4ecbc15d7481fed9903b3dde6cb76d1"/></dir></dir></dir></dir></dir></dir><dir name="eav"><dir name="attribute"><dir name="edit"><file name="js.phtml" hash="1cd780abd50e66840498ef241416ef6b"/></dir><file name="options.phtml" hash="b62b35584ad6044df0a267434728892b"/></dir></dir><dir name="email"><dir name="order"><file name="items.phtml" hash="c13bc0e0bd288da910dbb2fd84a9ce58"/></dir></dir><file name="empty.phtml" hash="0aba206a799ac0a515730f28b8ac123e"/><file name="example.phtml" hash="a17fa4912638a68fbb3877f9bc220863"/><file name="forgotpassword.phtml" hash="2761d703cab381e6569ea17f1fda83cc"/><file name="formkey.phtml" hash="a9064df4a81e204582839b8edf2aed28"/><dir name="giftmessage"><file name="form.phtml" hash="e1868bbf88971067a158cd961a289a8d"/><file name="giftoptionsform.phtml" hash="5c0ef03699b2c2508e4eb9bfd5fc3443"/><file name="helper.phtml" hash="04e9edd7d8478a71e621bfad87865f7b"/><file name="popup.phtml" hash="e5c0a9152f647cecff3b604a7e061741"/><dir name="sales"><dir name="order"><dir name="create"><file name="giftoptions.phtml" hash="ae9310c826dc5935b140c2a8d9e5fd73"/><file name="items.phtml" hash="2802f85e9f389d59e69606540285f4ef"/></dir><dir name="view"><file name="giftoptions.phtml" hash="63382086c4c32d588796f1ab21adc147"/><file name="items.phtml" hash="69fdd1217ae8b3812310a5362c219e5b"/></dir></dir></dir></dir><dir name="googlebase"><file name="captcha.phtml" hash="d77c18f68c4abd9a1bb1c19de1d53c1b"/><file name="items.phtml" hash="c885e705bda18cc3bbf90dddb94918aa"/><dir name="types"><dir name="edit"><file name="attributes.phtml" hash="4795d282786fd7700b28a53e89eaa5aa"/></dir></dir></dir><dir name="importexport"><file name="busy.phtml" hash="f9f89cd954a79ca5f279a0d4fdb6b5d5"/><dir name="export"><dir name="form"><file name="after.phtml" hash="b7f2e5154d620c04f04499feabb63bd7"/><file name="before.phtml" hash="c3f67125078e60f4dfd40e844f9acb9a"/></dir></dir><dir name="import"><dir name="form"><file name="after.phtml" hash="b42f0f4cf9c476ce84ed9962e97fc248"/><file name="before.phtml" hash="4155be820c93e301c7de2801e44fe3ed"/></dir><dir name="frame"><file name="result.phtml" hash="0c5d520411595f63ba45ed502adca5a7"/></dir></dir></dir><dir name="index"><file name="notifications.phtml" hash="fa648c216c2aefb82e2634cf657abdf7"/></dir><file name="login.phtml" hash="d263b066415db4f2a2f4eaddc4845896"/><dir name="media"><file name="editor.phtml" hash="86638654991aa6836230755dd3077527"/><file name="uploader.phtml" hash="4a5de3593d5d3ab0a117b0c04c9fc520"/></dir><dir name="newsletter"><dir name="preview"><file name="iframeswitcher.phtml" hash="11d9f85bb1aca38f02ed619f5c2494b7"/><file name="store.phtml" hash="f2acb163734214fe61b00bfa64fcab94"/></dir><dir name="problem"><file name="list.phtml" hash="b8de157e83d8c9a84b769e834029ff80"/></dir><dir name="queue"><file name="edit.phtml" hash="3f9016faa03f1873a123e6294e265624"/><file name="list.phtml" hash="0771254da01ac42a7c19cffd21916598"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir><dir name="subscriber"><file name="list.phtml" hash="dc927044644ed99d71e9f94f6c6054d2"/></dir><dir name="template"><file name="edit.phtml" hash="5cdb64a34fa36c6fe2696a8a139b9468"/><file name="list.phtml" hash="88495852292533931dd9ccc1297c22cd"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir></dir><dir name="notification"><file name="baseurl.phtml" hash="ace29ea97f986e6af7f68ff769024a08"/><file name="curl.phtml" hash="4d6bb471fc24d2fac093f5a6ba54eb2b"/><file name="formkey.phtml" hash="10cefd4b04d9167dc36b15d146d67792"/><file name="security.phtml" hash="09f80eb2e65d5f3eb864b69a8de0bb7b"/><file name="survey.phtml" hash="e81aa7a0204d2af52937c2179b3226a0"/><file name="symlink.phtml" hash="1a44ab56d54fb00ff8aa9174fbd5aacd"/><file name="toolbar.phtml" hash="c81daccdcaa9752fd63b40965991bb40"/><file name="window.phtml" hash="cc3ac0b29613c6c70262db9100c41f96"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="dabf9325f335361b849aa50056c24f94"/><file name="button.phtml" hash="d9e9b183d42e52a250ce0c5e1aa51a2d"/><file name="confirm-simple.phtml" hash="65e940cd75ab146adf369de3b6900ef5"/><file name="confirm.phtml" hash="3fd54b782715757eb7e6d94cb85ec207"/><dir name="form"><file name="login-simple.phtml" hash="2f1989f21643335d93da793c5048b40c"/><file name="login.phtml" hash="311ecd3b9fe3ac1b34a5c685754fab9a"/></dir><file name="head-simple.phtml" hash="9b1d56c7b532c4b5249df0ad5654634b"/><file name="reject-simple.phtml" hash="b424a12924735b3579d1a99f02c40779"/><file name="reject.phtml" hash="e39aeff75e3b8ddfc88dca8323e6e954"/></dir></dir><file name="overlay_popup.phtml" hash="93042aacbf5f63ac20d73af7529adb9e"/><dir name="page"><file name="footer.phtml" hash="66b29c98ee96825c589df8eb448f5c7d"/><file name="head.phtml" hash="21ef5cb055b23d9e539cd470c6227569"/><file name="header.phtml" hash="18653a55fab64c9b173bfca72ded1c93"/><dir name="js"><file name="calendar.phtml" hash="05ad9d43d629be8c5e328d40b97725b1"/><file name="translate.phtml" hash="9a4a8ff517585fae47478d963e6012c6"/></dir><file name="menu.phtml" hash="e7a10b2a4c8ac756d36c1925e54e4ccf"/><file name="notices.phtml" hash="1da5145293a029071c77817fbda3736c"/></dir><file name="page.phtml" hash="b83ddcffabe164c96979fa9f761f0e52"/><dir name="pagecache"><dir name="cache"><file name="additional.phtml" hash="fbc4928f817e21a76a876510c04134f7"/></dir></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="f30991c8c4ffe39a426e7a18b67a357e"/></dir><dir name="info"><file name="cc.phtml" hash="c07e6426f4b89547d95b7971cd40df24"/><file name="pdf.phtml" hash="44b8fe88a963653eac67d3e7e18a7e06"/></dir></dir><dir name="payment"><dir name="form"><file name="banktransfer.phtml" hash="365b2e7ad83c8fc3579fb10e21000e43"/><file name="cashondelivery.phtml" hash="9ee032367a799e485e9490300d50f923"/><file name="cc.phtml" hash="a9e654db08418dd198b1ddad0481836d"/><file name="ccsave.phtml" hash="a88ffde3b02d476b5ef8c302616662b3"/><file name="checkmo.phtml" hash="6e9a71f5bc7d249839487adcdea9e1a6"/><file name="purchaseorder.phtml" hash="6991195785bb67b47e3aaf2b19906e8e"/></dir><dir name="info"><file name="banktransfer.phtml" hash="57bf7dc47f93db636e4669dd0a13db15"/><file name="checkmo.phtml" hash="0844a4de163d70530af55a89ff4fee1a"/><file name="default.phtml" hash="34760442900ba7b17d52d6bc8d6e8732"/><dir name="pdf"><file name="checkmo.phtml" hash="331eb71760b1b91013a242adc2e7850c"/><file name="default.phtml" hash="3dbdf5ee79c5835d3e8a68bf896fe7f0"/><file name="purchaseorder.phtml" hash="b72078c393f9fc8a72469cb4f60cf740"/></dir><file name="purchaseorder.phtml" hash="66328b8bd3bffcf251e83b190aa1674c"/></dir></dir><dir name="paypal"><dir name="system"><dir name="config"><file name="api_wizard.phtml" hash="d1dcd0ac566a48d087a02d9fb5aa7681"/><file name="bml_api_wizard.phtml" hash="1edb19592c4fec6213fed297a8a7a68b"/><dir name="fieldset"><file name="global.phtml" hash="32e284583341b991d9db598d0f20562f"/><file name="hint.phtml" hash="749bdb7e9a11df10ad5ba07f1296a6d0"/><file name="store.phtml" hash="ff8de41b3fc398c7ca56f2d977c243a9"/></dir><dir name="payflowlink"><file name="advanced.phtml" hash="61e36b2fb2436c279361a8bf0a912095"/><file name="info.phtml" hash="bc613c199e8f8d876e673383a2265a17"/></dir></dir></dir></dir><dir name="permissions"><file name="role_users_grid_js.phtml" hash="039d1507a9d84a5e2afdf5d8621d54e3"/><file name="roleinfo.phtml" hash="8df7874910110a250fec05fc56e9b98e"/><file name="roles.phtml" hash="a2f4af140d0ce98fb93c7a59e13a89ef"/><file name="rolesedit.phtml" hash="d576cb5bb8ba92748cd0c63bc6d6bc2f"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="8187202fb98a78f90337e321c1d26bef"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="poll"><dir name="answers"><file name="list.phtml" hash="ab3de09500ac824dbdfa531ccc8b5148"/></dir></dir><file name="popup.phtml" hash="85b7139ff08a023f58c95469513ba241"/><dir name="promo"><file name="fieldset.phtml" hash="88f350e4aeafab8d60adbf812ebb5882"/><file name="form.phtml" hash="de3b47937cd0734513668d65a1685192"/><file name="js.phtml" hash="f583f3d25029a4e6e5543f8ef9fd4e1d"/><file name="salesrulejs.phtml" hash="59b1be9b748c984ec700d5db96cf9b4c"/></dir><dir name="rating"><file name="detailed.phtml" hash="eecfd5103a29cc884cd7769353249c3c"/><file name="options.phtml" hash="91e48ca064c209467a95ebb4106098d3"/><dir name="stars"><file name="detailed.phtml" hash="425a39a4861305eb7d488557d1f29b1f"/><file name="summary.phtml" hash="81f09d08d8f13602dbb6fc47c9e0c4dc"/></dir></dir><dir name="report"><dir name="grid"><file name="container.phtml" hash="492edaeb36c99759e601f69d09d8ce63"/></dir><file name="grid.phtml" hash="4df44d5bfe605dcf1f4de209c3251d3a"/><dir name="refresh"><file name="statistics.phtml" hash="0134889b333e23b21dd9338b5a8c672f"/></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="97ff2bbd0264f2f48655b85c31ec42d5"/></dir><file name="switcher.phtml" hash="6d59b52c5c4b637186877c1b64081733"/></dir><file name="wishlist.phtml" hash="3763e4bc8859b4dde13a882433400112"/></dir><file name="resetforgottenpassword.phtml" hash="7f718933a22551f4448477d3482d5119"/><dir name="review"><file name="add.phtml" hash="e259fc69d280b3d4f89516be872292a3"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="form.phtml" hash="38dd2395d72f2485bebe46b154e36567"/><dir name="view"><file name="form.phtml" hash="4e5530d7218b4e29fdb657f3afdd32be"/><dir name="tab"><file name="info.phtml" hash="1980a461df367b8917a1334d73e67f61"/></dir></dir></dir></dir><dir name="items"><dir name="column"><file name="name.phtml" hash="bde8b8b434583ba4a17234232b4b436d"/><file name="qty.phtml" hash="df2ef73497c3145b42497e0be0b0ac6a"/></dir><dir name="renderer"><file name="default.phtml" hash="8e6bdcd0a0e30f8bf1ff6a4a68321183"/></dir></dir><dir name="order"><dir name="address"><file name="form.phtml" hash="8d8997f272ff6f7704ae8da2309e5c26"/></dir><dir name="comments"><file name="view.phtml" hash="3e593f32eb91950ada970136e635039a"/></dir><dir name="create"><file name="abstract.phtml" hash="450fd33745d12b718eadb477cb97169a"/><dir name="billing"><dir name="method"><file name="form.phtml" hash="f373edeac1e14f15cc192104b3c06799"/></dir></dir><file name="comment.phtml" hash="89d6f617055bcaf9f017ac3325153b9d"/><dir name="coupons"><file name="form.phtml" hash="22d58a1fdece0789f9fb075d12f7655f"/></dir><file name="data.phtml" hash="844bb85968eca4ce2899a81f571a69a2"/><dir name="form"><file name="account.phtml" hash="ae06153e8c74cbf90b9192ae1cf73f3a"/><file name="address.phtml" hash="6869a9b9cafd7172eebcbbb260624f70"/></dir><file name="form.phtml" hash="91bae87423c95fa1feee87f39533c186"/><file name="giftmessage.phtml" hash="d060ea7a368d682336160e2c3a6de71e"/><dir name="items"><file name="grid.phtml" hash="1cd6c75f076b5157ec50a44870ea17b1"/></dir><file name="items.phtml" hash="81eac8351d529461343eaf3ccdd0dd75"/><file name="js.phtml" hash="57a05543973a5f3b3dc9604d7681dd61"/><dir name="newsletter"><file name="form.phtml" hash="bd490b0117568c4338318ced6558fe84"/></dir><dir name="shipping"><dir name="method"><file name="form.phtml" hash="69ab67e875d5c69f19da9200488fdbd4"/></dir></dir><dir name="sidebar"><file name="items.phtml" hash="52ef961d1108ba56b8fbd95ee6fc99b5"/></dir><file name="sidebar.phtml" hash="1491271d8b4b001e27e024072dd425d4"/><dir name="store"><file name="select.phtml" hash="b4e047779e15d495e99b71420c87b476"/></dir><dir name="totals"><file name="default.phtml" hash="e0dae5956e25f189f645d644b9bd61db"/><file name="grandtotal.phtml" hash="76c14c414df70b9e0fc2e7a1efe83ed0"/><file name="shipping.phtml" hash="8e7d48743a790b46137bcaf7adf46c4f"/><file name="subtotal.phtml" hash="75ba127e657699c654a6e32c6065a56f"/><file name="tax.phtml" hash="74594996a9b8e9f829f0e0e4177f0e09"/></dir><file name="totals.phtml" hash="7b23f88369b46bc4ab5038ec95ef83e0"/></dir><dir name="creditmemo"><dir name="create"><file name="form.phtml" hash="6c0de85b0b6f77bad60444775b1838b6"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="a082ae2d22e324e83fec20f26051f533"/><file name="default.phtml" hash="1704c99d6351e2e1abd6c330332b2cce"/></dir></dir><file name="items.phtml" hash="fa8f2d1b0b7f1a518e09a4c98b45398d"/><dir name="totals"><file name="adjustments.phtml" hash="d07ae2fccc399b065421afabb53e225d"/></dir></dir><dir name="view"><file name="form.phtml" hash="a3dee338f777091321c67d051794ac8d"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="2e13d26b8abf2c1ec41f4e934c45ff3e"/><file name="default.phtml" hash="f5d7b87ab43b377628f5f0c654ecfb75"/></dir></dir><file name="items.phtml" hash="db0d0fdfbb092d62668517474e73ab9d"/></dir></dir><file name="giftoptions.phtml" hash="af9be7a4c53bc915eafdb8c36363d4f9"/><dir name="invoice"><dir name="create"><file name="form.phtml" hash="a1c5e849f07ac623de58c44ee5bb788b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="59cb8f69057a081397a7d08b1d44de03"/><file name="default.phtml" hash="4e066e654dd4905f9248cb58e6202dc7"/></dir></dir><file name="items.phtml" hash="b59bc8cbdf561361ec74b64e57e3d6a9"/><file name="tracking.phtml" hash="e267501bbb03bcbbf0c95a0e19b2a161"/></dir><dir name="view"><file name="form.phtml" hash="670a59453a48856bf7dba0d7e3841e4b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="f3fd595909d713740f78fcc18bb165d4"/><file name="default.phtml" hash="efa3a5f3b0544d4b3453e54c511a7bdc"/></dir></dir><file name="items.phtml" hash="0b0174f23e9694f4ffb6bd4639ff222f"/></dir></dir><dir name="shipment"><dir name="create"><file name="form.phtml" hash="4b2d19de5e5522bcba94ae76f13077fe"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="47a7a02503e6ce8185f220ec014b616c"/><file name="default.phtml" hash="cb6088852de61af50134bfddfc9aadfd"/></dir></dir><file name="items.phtml" hash="2b6c3e9982fa8ec9a5986c1094ab4b37"/><file name="tracking.phtml" hash="adaaa3f1debf0abbd8369328762007e8"/></dir><dir name="packaging"><file name="grid.phtml" hash="c7149c55a5c36f0ed429484a47d12447"/><file name="packed.phtml" hash="f4f5982a47487915b4f0e281cc52ac5a"/><file name="popup.phtml" hash="781f87de153aedc68d87e918f0489505"/></dir><dir name="tracking"><file name="info.phtml" hash="936830f51a16c0304d0f5cf8440cd214"/></dir><dir name="view"><file name="form.phtml" hash="f00f611ae348eb4296063cec99e08535"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="c1088e05631ed09666d9b3027e51020b"/><file name="default.phtml" hash="14f57ff7e16a97169be8dca512309e4a"/></dir></dir><file name="items.phtml" hash="1e5e39056014e0b7c4264203a8156c95"/><file name="tracking.phtml" hash="6cfca1785d2a0023ebd96f8d822b2339"/></dir></dir><file name="totalbar.phtml" hash="9dd03f8ece3dc8a066182a63e750d3bb"/><dir name="totals"><file name="discount.phtml" hash="fe5af2981c988ee51a156066e0a5d30e"/><file name="due.phtml" hash="a8bb79f030ee27f4cc5fbd3a945aee84"/><file name="footer.phtml" hash="7a3146c9823d4412bb0431a9eb880208"/><file name="grand.phtml" hash="c42431c3da562b0c7f87717bf234de86"/><file name="item.phtml" hash="ef9cb2aa093c6b55a22d137d1798a958"/><file name="main.phtml" hash="75720ac86b02cf404f76051b29ce3e34"/><file name="paid.phtml" hash="011dd3a39e180f1ffcb10921ae6f08e3"/><file name="refunded.phtml" hash="d846f8f28c34d745e7e79c8c108286e7"/><file name="shipping.phtml" hash="729980faf9c31e1bfe5821a3378430cd"/><file name="subtotal.phtml" hash="2a87b7f269291096bd3500f6b56e357d"/><file name="tax.phtml" hash="68edfed16527ef713812dc6c8d5815ea"/></dir><file name="totals.phtml" hash="f5ea5e7f19419b72297a24a9860e9e0c"/><dir name="view"><file name="form.phtml" hash="b2ae23cf63e436a00dab747a32209d41"/><file name="giftmessage.phtml" hash="c6f8701e8c220cf71cd465310b576b36"/><file name="history.phtml" hash="fa87a814656708aaea4eaa863e22bf11"/><file name="info.phtml" hash="3aef9dc16a51f414442a59c690e573a4"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="3d3def9dad4e5842bdc182c756f0d9a3"/></dir></dir><file name="items.phtml" hash="e71776c9f5d744c972304706cb5477b6"/><dir name="tab"><file name="history.phtml" hash="801abf66aff3f3036fd9ad7ac1731fbe"/><file name="info.phtml" hash="2a7132e5976c34bab03a7fb8996fb910"/></dir><file name="tracking.phtml" hash="faf1ca869164dbd44513ca9e8a267434"/></dir></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="ad004e28a0852b50f068d37915d4d903"/></dir></dir></dir><dir name="recurring"><dir name="profile"><dir name="view"><file name="info.phtml" hash="7324c965675a482a0b0c3c7ac8e822ff"/></dir><file name="view.phtml" hash="879c3de013c31794597198feeea52531"/></dir></dir><dir name="transactions"><file name="detail.phtml" hash="9e3fa2b5112e90db65172a9a13d22574"/></dir></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="938ea5cf69346302b37a36d2a494fab2"/><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="0374f50a623b74df54a48010e5a0b587"/></dir><file name="fieldset.phtml" hash="c91fe72f4eaac1944751201191fe79a6"/></dir></dir></dir><file name="switcher.phtml" hash="1b7165f0fcee6aa73a83d369faef0aae"/></dir><dir name="system"><file name="autocomplete.phtml" hash="7decf3f54f0ed293448ca2a84ec826c7"/><dir name="cache"><file name="additional.phtml" hash="f55be32d13e9ca88bc5ad05359ac594c"/><file name="edit.phtml" hash="392cc02350f73d675ae8f6b65811bfc8"/><file name="notifications.phtml" hash="a019d0760ea6cfdd4e2c93665f5f019a"/></dir><dir name="config"><file name="edit.phtml" hash="5f971d7aca8e1a70103f34ea2f8e16e0"/><dir name="form"><dir name="field"><file name="array.phtml" hash="50ce1dd35ed11a8db3d3ad59e515b0bf"/></dir></dir><file name="js.phtml" hash="874834fe0b24c249efc0a0adb19e32eb"/><file name="switcher.phtml" hash="5a899f08580bc511f7cb308ad5434a0f"/><dir name="system"><dir name="storage"><dir name="media"><file name="synchronize.phtml" hash="79259b6b21df8a122050099622badbc8"/></dir></dir></dir><file name="tabs.phtml" hash="090b7d99c6f946ec07797a3de3ed9357"/></dir><dir name="convert"><dir name="profile"><file name="process.phtml" hash="e9728649b4581052be5f66bbe38107d6"/><file name="run.phtml" hash="67ccdf7c3b9558a1136e182f61466f00"/><file name="upload.phtml" hash="2a4eaa90c21f90f8dd397077a1995a81"/><file name="wizard.phtml" hash="e8aaabfac5406b86cbeae1f2dbfbcbab"/></dir></dir><dir name="currency"><dir name="rate"><file name="matrix.phtml" hash="022728817b25592125cd5aea0589be59"/><file name="services.phtml" hash="fd18998930424daa0dba5eb946accc48"/></dir><file name="rates.phtml" hash="bd8cba7764024b9d4f81e70b92d379ee"/></dir><dir name="design"><file name="edit.phtml" hash="a6748502e84e6f8c1ce7a7b6fb3fd3f5"/><file name="index.phtml" hash="d4d25161838ba0272e01b70031a54702"/></dir><dir name="email"><dir name="template"><file name="edit.phtml" hash="d791749a092eae1c401456f5e50b8215"/><file name="list.phtml" hash="4bd2cfbe71edbb3924dc49cbc4c5b909"/><file name="preview.phtml" hash="5790831f8fcca232e851b8fb3ddf1a82"/></dir></dir><file name="info.phtml" hash="d350dcbdd09f2bed44c3b663c40b514c"/><dir name="shipping"><file name="applicable_country.phtml" hash="1662a0971b90b4f392bf7f36fe036a92"/><file name="ups.phtml" hash="cebcd62310d874f6ed19940ddc95fc2e"/></dir><dir name="store"><file name="cell.phtml" hash="70aca9a7aaf50e07a2cb446b32dae429"/><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="tree.phtml" hash="5c3d3ccfbbed1b062a0d78eed7e2ca74"/></dir><dir name="variable"><file name="js.phtml" hash="3e5e5f42e64fb8534d830b271cb934a1"/></dir></dir><dir name="tag"><dir name="edit"><file name="container.phtml" hash="d16c22231434354b1a08ce9cb04e5bb5"/></dir><file name="index.phtml" hash="4b4e9eb77ef2a3f503c478ebc301ab55"/></dir><dir name="tax"><dir name="class"><dir name="page"><file name="edit.phtml" hash="f7c55192b773349cc38cad7258624fcc"/></dir></dir><file name="importExport.phtml" hash="561e99d910bf37bb5e887e626dade6ba"/><file name="notifications.phtml" hash="dd5cb30e2fa2f269848bbb0b235c97a3"/><dir name="rate"><file name="form.phtml" hash="b5ef7d7e4990797250fbf332cf548085"/><file name="title.phtml" hash="2021a60ac40d770ae2f50907d6357e86"/></dir><dir name="toolbar"><dir name="class"><file name="add.phtml" hash="ef10a2d566c82bad8cd9c48873ec6e67"/><file name="save.phtml" hash="f27f7178cbb164d5fca297a1b4ae1fd6"/></dir><dir name="rate"><file name="add.phtml" hash="8b2172962f50b656d6a11b1a0d9fc8c8"/><file name="save.phtml" hash="787a3b092e394ebd99479c69f3e6cd5d"/></dir><dir name="rule"><file name="add.phtml" hash="ba96d2206f0a6b14c04dca48fc6b0e1f"/><file name="save.phtml" hash="9fd8b6602eaa2f8ee60c617de66c633f"/></dir></dir></dir><dir name="urlrewrite"><file name="categories.phtml" hash="0114448eaaebd4f9e9f9bd7dd7b5863e"/><file name="edit.phtml" hash="4eba179dbd4543f97066b99a17becf28"/><file name="selector.phtml" hash="585e7778cd87ec02d3d75a402f1485b9"/></dir><dir name="usa"><dir name="dhl"><file name="unitofmeasure.phtml" hash="1ad7c6f0001c1429f0185ff86e6fb7f9"/></dir></dir><dir name="weee"><dir name="renderer"><file name="tax.phtml" hash="4d51f086a09c7b32da91fdc9b7c5bd0a"/></dir></dir><dir name="widget"><file name="accordion.phtml" hash="f337eec9f160cc17c11d286426ce8afe"/><file name="breadcrumbs.phtml" hash="991d357316a969714c23258a66a1488a"/><dir name="form"><file name="container.phtml" hash="2aacc340af12481a12a1345e78598037"/><dir name="element"><file name="gallery.phtml" hash="6b750f7c975a7911d77194f9aa79d390"/></dir><file name="element.phtml" hash="a163cbf6f7252551f04e552fd5271c16"/><dir name="renderer"><file name="element.phtml" hash="709a892360b1544df89694feaa71793c"/><dir name="fieldset"><file name="element.phtml" hash="024b35eaad113635230eef181c04ad90"/></dir><file name="fieldset.phtml" hash="9155081d516a44ae8b030e9b206bd8c9"/></dir></dir><file name="form.phtml" hash="681abe7da55410a5ee1eb45fa0c778d5"/><dir name="grid"><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="massaction.phtml" hash="f374ea890a3ccde0a03d9255f93d744d"/><file name="serializer.phtml" hash="db5ddba9dd04c804f40d56a08600239d"/></dir><file name="grid.phtml" hash="c64266d252f382825455fc1b5bcd9fe2"/><dir name="instance"><dir name="edit"><file name="layout.phtml" hash="85d914937a630b43e8d866e00b5ce474"/></dir><file name="js.phtml" hash="f98ce37698081930093320eefe9e11ff"/></dir><file name="tabs.phtml" hash="30dbd04b9cd29abf06f3c10dc607eca7"/><file name="tabshoriz.phtml" hash="6f4b7df458502430d1711aa1b8eec3fc"/><file name="tabsleft.phtml" hash="1ed0a68afd01801d1667e4ae5907a9ec"/><dir name="view"><file name="container.phtml" hash="2765ba04c97ff6f78219f296bf479ae3"/></dir></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><file name="below_ie7.css" hash="a9c27fe40eb9d5e3a722be488edd7309"/><file name="boxes.css" hash="a479266072fcf8f86316d2ee59dc1029"/><file name="custom.css" hash="56ea43791cd4ae989b797928019aa7f2"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="ie7.css" hash="bee9b016e93c1a478c0f8c62303421fe"/><file name="iestyles.css" hash="86ac157e19adb69da98938158173aed1"/><dir name="images"><file name="accordion_close.gif" hash="875409122fc82f5f6705e20dd801fd3d"/><file name="accordion_close.png" hash="6213698b5f69bb2907a5c7bb94b5fe8d"/><file name="accordion_open.gif" hash="d9d50e220b0b676094c6134a9708194e"/><file name="accordion_open.png" hash="9fbc3aba23ce5e0465e4d1cf3f6a7aee"/><file name="add_btn_icon-disabled.gif" hash="c8f6a5cfb455ef121efb56a747821f82"/><file name="add_btn_icon.gif" hash="7300097305b577ee564dc49102822d16"/><file name="address_list_li.gif" hash="79b917b514e35ce0a7833a5e268fd9f7"/><file name="address_list_on_arrow.gif" hash="3a2884ddcc87ebd48883662530b9de1b"/><file name="address_list_over_arrow.gif" hash="e826883c71b1184bd4f29433e39c18ad"/><file name="address_list_over_bg.gif" hash="56291480cc89de9d817205a5f23b66dd"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="ajax-loader.gif" hash="e2a38f1e23288e315af3c55416bc1ce7"/><file name="application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="arrow_sort_move.gif" hash="f5ac151a2b0cb1f07d6e771b8aee0ea7"/><file name="bg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bg_create_order_totals.gif" hash="ff6ab75c050b959c539cc6a6fdff2934"/><file name="bg_notifications.gif" hash="a365594725a83585d989f722b3d8c458"/><file name="bg_window_mask.png" hash="93d6efad062d24c94c105802b138b6a5"/><file name="bkg_btn-close.gif" hash="df3f2332f0bad01e031deb22b81f630c"/><file name="bkg_btn-close2.gif" hash="822457d78fb3c21dc12e9777d83eb4f1"/><file name="bkg_config-advanced.png" hash="b898594a9f1849bf386c06979ef613a8"/><file name="bkg_config-nested.png" hash="7b0fdbf98746c3c916b432c37321ccc4"/><file name="bkg_config-shaddow.png" hash="9ee4318e3f4afc446d26e7f66d01cfbd"/><file name="bkg_tooltip.png" hash="56cfed3ed8a65b19f8de88946d1a0a01"/><file name="blank.gif" hash="5722d7bd0f1e1379d0a2005a0a9ea401"/><file name="box_bg.gif" hash="4c501bd6db9d361c18780f106a809b03"/><file name="breadcrumb_bg.gif" hash="72c4adf6c75b4640ca8f7cadffa42266"/><file name="btn_add-image_icon.gif" hash="1d42210fd29fc534d9ed6b41e811d40f"/><file name="btn_add-variable_icon.gif" hash="a2db02e318d107d5b57b444c8d80b8f8"/><file name="btn_add-widget_icon.gif" hash="b4f66ca7f6097fbafd672e0b3f076ef4"/><file name="btn_add-widget_icon2.gif" hash="467acd3a14fb8be37191f5d2ec5a5b13"/><file name="btn_back_bg.gif" hash="8be512788b8044fe31aa8d00cc16ba7b"/><file name="btn_bare_bg.gif" hash="ddbbab8c0d201c3e502d50e7d4a3d64b"/><file name="btn_bg-disabled.gif" hash="079971a9d2c385fe353d35716ec9f26b"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="btn_bg.png" hash="6e3b7003381f919e8f6533444afaa978"/><file name="btn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="btn_delete_bg.gif" hash="ad740d0c16f2f6603c8ef023004d6539"/><file name="btn_go.gif" hash="1bd787868713767cc205e2ee25e41f62"/><file name="btn_gr_bg.gif" hash="6cc324b79a512150fee24fb3517d22cb"/><file name="btn_gr_on.gif" hash="820c134df02f7bc12efa5a9ac3b4d3dd"/><file name="btn_gr_over.gif" hash="d4c8b807d64c1f493d17c6c9d2bab69a"/><file name="btn_loading-icon.gif" hash="45f500105be432a12c78fed2b4592cf9"/><file name="btn_login.gif" hash="79fa32d49d3f4e39d3fbf8327f9229e1"/><file name="btn_on_bg.gif" hash="709cf5b0be137db1ef8427688503bf37"/><file name="btn_over_bg.gif" hash="f91641168454c03d1fa72731ec97a2b3"/><file name="btn_show-hide_icon.gif" hash="0238c509b33ba56c25df9513bb48f804"/><file name="btn_task_bg.gif" hash="5e0594bd9cbfcc1e32ffa918d7f9c812"/><file name="button-close.png" hash="04d0907b2d7fc3240693497b199f64f5"/><file name="cancel_btn_active_bg.gif" hash="91ce403d286eef2b4e0c13733875882f"/><file name="cancel_btn_bg.gif" hash="26749cf4949ac27c30f597434d3bde65"/><file name="cancel_btn_icon.gif" hash="97e0cd94ed31d6f2a1181f627e60e9a3"/><file name="cancel_btn_over_bg.gif" hash="45eb4e883b17375961672f5390387c31"/><file name="cancel_icon.gif" hash="70a23b78353f0a7b9b118a937fcb7ea9"/><file name="config_tab_dt_bg.gif" hash="a33f71077ca4078caa794cae01d9fca7"/><file name="dashboard-close.gif" hash="5ae5afd61e937fcd2d5b84641255ee4d"/><file name="db-graph-bg.gif" hash="5d76efb7c3244f5684df2566782124ea"/><file name="db-graph-bottom-bg.gif" hash="b58ced87a38a10891106329ae882aa1c"/><file name="db-graph-line-bg.gif" hash="f16bb08e040c2c0a3e23b3f35c54b79b"/><file name="db-graph-line2-bg.gif" hash="744ebfdba20d050f4d252afc216394be"/><file name="db-graph-x-bg.png" hash="d5c26510718a78d22083916d80ef7a22"/><file name="db-header-bg.png" hash="3976cb6351e167686a501a85cf3a68e9"/><file name="db-menu-bg-hov.gif" hash="34ea76a6d105d90fcb63bf105aadb8f7"/><file name="db-menu-bg-up.gif" hash="b0f754872dff5f2f0dc57ba193fdfa4c"/><file name="db-menu-bg.gif" hash="ea534c3c09bb309e566b6ae876655e13"/><file name="db-menu-sep-last.gif" hash="a01fe34854e1187e466fd58d462c4106"/><file name="db-menu-sep.gif" hash="7c5ae1cd59a189261cc3244358d5c1ad"/><file name="db-menu-start.gif" hash="aa5cac2194d937cc7fa904ccfce70ecc"/><file name="db-scroll-bg.gif" hash="06d2411e3b5f350ab21b625439d2d69d"/><file name="db-scroll-but-bot-roll.png" hash="6bc5e482f3f6d8fb1fc5014ddea43706"/><file name="db-scroll-but-bot.png" hash="25c0181e76ff8ceb3c0ec59071b8c72c"/><file name="db-scroll-but-top-roll.png" hash="b7961f2a3b5b641694a9b0b30d58e46b"/><file name="db-scroll-but-top.png" hash="de7df96e961596be9ff556924259b98b"/><file name="db-scroll-roller.png" hash="e01dde7bd096c52179acf29a425a29e5"/><file name="db-tab-bottom-left-bg.gif" hash="124388d44ac58b029377c6311a4782d5"/><file name="db-tab-bottom-mid-bg.gif" hash="9c48f33aa8907cfcb227bc779c2e1dce"/><file name="db-tab-bottom-right-bg.gif" hash="1db45e6fd8abc67d59f96a676607b412"/><file name="db-tab-footer.gif" hash="cac8928acba75bc1edd73186ced78e5c"/><file name="db-tab-header-sep.gif" hash="580312af7441b6a62f7e32081c40fb0f"/><file name="db-tab-header.gif" hash="fdf493b9477fcff7e7be98405effc33d"/><file name="db-tab-left.gif" hash="3fe3c55267dbbdd1db2ff959ccc9e0be"/><file name="db-tab-right.gif" hash="b7a32c8b03efe2fbdb63215d0446e3be"/><file name="dotted_divider_dark.gif" hash="8bf1de196d9ea048bfb25155cedd2e9e"/><file name="dotted_divider_light.gif" hash="92e562bf2070110f6b0a15e29b845445"/><file name="edit_icon.gif" hash="dbda31751c78d964c04394e9d8533187"/><file name="entry_edit_head_arrow_down.gif" hash="985c3ce4439fbf8bb2216fc7e73a3f0b"/><file name="entry_edit_head_arrow_down2.gif" hash="d68dd0fbc2819858a26ea2835c05df77"/><file name="entry_edit_head_arrow_up.gif" hash="d2b90a1823fff9f3917f19b427410144"/><file name="entry_edit_head_bg.gif" hash="1086b7196e8b33c4f46e49fecef0f35f"/><file name="error-msg.png" hash="3cd27b642416dacdc28907c89d934886"/><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="fam_account.gif" hash="c910fd1ff41b940d71b0835e02fc143e"/><file name="fam_application_form_delete.png" hash="972c2d998fc19572dd64af6b5e2e898e"/><file name="fam_application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="fam_asterisk_orange.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="fam_bin.gif" hash="2fb388bc9f1d32d3802db8e91dc238bc"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="fam_bullet_disk.gif" hash="9fe82691d960c18d3d315c3f9164af4f"/><file name="fam_bullet_error.gif" hash="008802f44288b732b59cfe9fdbfecefe"/><file name="fam_bullet_success.gif" hash="465a056a3ba3d94367f51c3c0b751391"/><file name="fam_calendar.gif" hash="0614207ce4e3e0a9bd631b39e7692e3c"/><file name="fam_cart.gif" hash="1f2fd2c8ac6574488ea78302b6856191"/><file name="fam_comment.gif" hash="5138f9a4b6019a5b14b8ff9a32a3cb89"/><file name="fam_creditcards.gif" hash="b75b8ce2f4fceb58f8082c48344560c7"/><file name="fam_folder_database.gif" hash="e86175ff0f389ade1fc7bf15e03346eb"/><file name="fam_folder_palette.gif" hash="c0941b9145e06d53cc0d17ac4c151764"/><file name="fam_folder_table.gif" hash="e2914ba75944acd2a9e2d338fa339e16"/><file name="fam_group.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="fam_help.gif" hash="2b5ed4c13a8e24456207b757826c7b2c"/><file name="fam_house.gif" hash="8eb2d580c5a40b7974f4263ca64fb94a"/><file name="fam_layout.gif" hash="5366a5f02260d3a860ef0c4787282ad6"/><file name="fam_leaf.png" hash="078d4f24683331b4557356a59e67b125"/><file name="fam_link.gif" hash="78590d5d8375d1baabe7b66d7b9ceb7d"/><file name="fam_lorry.gif" hash="174e86e45e76e7008fa3510cefa85047"/><file name="fam_money.gif" hash="6996bad465222fb6487cab94b4607846"/><file name="fam_money_add.gif" hash="70ceed401fe9913305f2362f7e26225d"/><file name="fam_monitor.gif" hash="f3bc806ff9d0907320b03018ba2d00ea"/><file name="fam_newspaper.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="fam_newspaper_delete.gif" hash="41acabfc19102be92d3ccbc66d1fede3"/><file name="fam_newspaper_error.gif" hash="009bfa425298e1d2e44e38e58cd97938"/><file name="fam_newspaper_go.gif" hash="eb43105f8e13e3a752d7ca33bb086831"/><file name="fam_package.gif" hash="bf9be09ef64d006455baa211b7c03983"/><file name="fam_package_go.gif" hash="e4f8d380c2f8e5a7345e360293433764"/><file name="fam_page_white.gif" hash="26940eb67826c5af72b6048c7c5a8335"/><file name="fam_page_white_edit.gif" hash="a4f88300b74ad592a5c47ed54ff07af9"/><file name="fam_rainbow.gif" hash="e8b04cc945b3582a181d4ddbc2d2325f"/><file name="fam_refresh.gif" hash="01bbef614023c0890812e76bc7ecf7e0"/><file name="fam_server_database.gif" hash="7901fa06ffd68ed730cf43bb560756fd"/><file name="fam_status_online.gif" hash="a80019ffa3a573f709772ed1099343fc"/><file name="fam_tag_orange.gif" hash="6ce735a0e590bda040b6e1614c42e58a"/><file name="fam_user.gif" hash="63bbdd6d9d7a27591907a7b87898e259"/><file name="fam_user_comment.gif" hash="014dfd31d9af40e3d5960b2b0d900da3"/><file name="fam_user_edit.gif" hash="f5b36e803060c6b82e639a4fad57b9f7"/><file name="filter_row_bg.gif" hash="013a0929a7b2ddc6823bdda17d08acc0"/><file name="footer_bg.gif" hash="7724711d3ca07a5e46a6030e86743a71"/><file name="gift-message-collapse.gif" hash="5b710f5faa9c7352a39c10e3ebbee6fc"/><file name="gift-message-expand.gif" hash="fd53a70cbb1ea048754657a63787e9cb"/><file name="gift-message-grid-column-bg.gif" hash="97a8a9b8cc4ab68e7404ccf1320f50a6"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="grid_sort_asc.gif" hash="b78c3a1a27ac9672a31b7d1bbac60322"/><file name="grid_sort_desc.gif" hash="d958b946eba3dba863d724530a0dba1a"/><file name="grid_th_bg.gif" hash="8f4349fac728858374e17edf03390977"/><file name="grid_th_onclick_bg.gif" hash="7bf331e2a41e5331c4210bdc6adc4383"/><file name="grouped_to_order_icon.png" hash="4bdae9a6199655027b8b8aeee8f80ce4"/><file name="header_bg.gif" hash="cbe510856afa5cb0c32642c1f9a8eceb"/><file name="header_top_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="horiz_tabs_ul_bg.gif" hash="58dbd9c45f76993346c2bb788896248e"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_question-mark.png" hash="23201b7ac207eebd9be0776ea44098a4"/><file name="ico_success.gif" hash="0afb20898a704a106cb4c598868abf32"/><file name="icon-enabled.png" hash="5fa7c06b312cbea3675e844686e434af"/><file name="icon-tooltip.png" hash="5767601cd66b23d0b6fe8defc10dd48d"/><file name="icon_btn_add.gif" hash="7300097305b577ee564dc49102822d16"/><file name="icon_btn_back.gif" hash="89ed97cede3f68241446a62c96e3ce4c"/><file name="icon_btn_delete.gif" hash="dbde0b76d36cfd624bf0de166d0a265e"/><file name="icon_btn_save.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="icon_edit_address.gif" hash="d1ca2bb3a5c86afd379f25d9fc4352e3"/><file name="icon_export.gif" hash="9a13f20c6a17b41b9c357545c2da5636"/><file name="icon_export.png" hash="fb299dd13df666516eabe16f59193383"/><file name="icon_feed.gif" hash="0366583ed6e285d028442fcdebb05072"/><file name="icon_feed.png" hash="8537f6f88fcff4aac793247143d14e42"/><file name="icon_note_list.gif" hash="8d25ba225ca09b687a78bff510df5d10"/><file name="icon_remove_address.gif" hash="2de2b3d02c19adfb93e9e43a392db178"/><file name="login_box_bg.gif" hash="e4654826eaa8d5ebc0ab18e9bee71e1d"/><file name="login_box_bg.jpg" hash="404e37f4ee9f4ff9bfcb638741c7581d"/><file name="login_box_bg_auth.jpg" hash="d90a81db1064ec37b0cc92436725c24b"/><file name="login_box_bottom.jpg" hash="038f15261e74bc381484f2fcfa45a73b"/><file name="login_box_legal_bg.gif" hash="528ac4dd480c4fc00ac808bf17394c05"/><file name="login_logo.gif" hash="a15f85d59684e1ec548b758fb6165469"/><file name="logo-large.gif" hash="b938979c790d4aba4170054fc4a060be"/><file name="logo.gif" hash="c7e9f290d965f707e4c4a61bfdab58cb"/><file name="logo_email.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="massaction_bg.gif" hash="8b5f4db3ab3ea09cd5bd0164d67c4f0d"/><file name="massaction_button_bg.gif" hash="4c8262817e48d007237124ce0e7f4d18"/><file name="massaction_links_delimiter.gif" hash="9a0337183b5b67c0eed75993d7f14d10"/><file name="middle_bg.gif" hash="ba4f176d2c553201ebab4aba5c6d3d20"/><file name="more_arrow.gif" hash="38bb4c0e9270250151486d0bb36c476f"/><file name="nav1_active.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_bg.gif" hash="a1d4ef5b590ce0a425dc04e45ed06cbe"/><file name="nav1_off.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav1_on.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_over.gif" hash="2c70d6175f1c965c27dda0598a67e63c"/><file name="nav1_sep.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav2_last_li_bg.png" hash="279935c9799679fc5894337eaabc7cf0"/><file name="nav2_last_li_over_bg.png" hash="39536f00824293d11242888a76f40a5f"/><file name="nav2_li_bg.gif" hash="0a4f34b0e4436c519d31203f19503b83"/><file name="nav2_li_bg.png" hash="2fad219d162324e9a19f2745d5b6d562"/><file name="nav2_li_over_bg.png" hash="dc37c4a4aab40ea2ae44dea5ea133a9d"/><file name="nav2_link_bg.gif" hash="dce00ddad351e72e83bc87274cbaa54a"/><file name="nav2_parent_arrow.gif" hash="60e012a14a077bd2257343facc369c0c"/><file name="nav3_bg.png" hash="2bc7af80ad8886013da38401b63ab6df"/><file name="nav_bg.gif" hash="1b857c7d35f35ef9f6cae9e03a4e3dff"/><file name="nav_list_bg.gif" hash="7a4e2bdb887c12d8a1152bbcc8c02a3c"/><file name="nav_nest_link_bg.gif" hash="1d0c6b374bf02ac4b5aa012955c431de"/><file name="nav_nest_link_over_bg.gif" hash="fae3c579a4d432503b1f4f929d070609"/><file name="nav_on_bg.gif" hash="ac624b580cae5a76f6c92abc5a44191d"/><file name="nav_parent_arrow.gif" hash="3a95559263e569dc1c8065cb2d9b3f2c"/><file name="note_bg.gif" hash="105967d7c15ab4610726eea52d862a97"/><file name="note_cell_bg.gif" hash="71e656d42f8ba8c2d477c6866c499b71"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="notice-msg.png" hash="9cd1dfebccec8a2123d543fa49b17bd7"/><file name="pager_arrow_left.gif" hash="6e44f608dac8eb8be1d1ebee5a3285aa"/><file name="pager_arrow_left_off.gif" hash="30f5e56195ab3546b36f4016db5254be"/><file name="pager_arrow_right.gif" hash="cc79526156b7e0c8abce61fad3d53f77"/><file name="pager_arrow_right_off.gif" hash="f01b7dad9acf0180b5c62edbd7ea9939"/><dir name="paypal"><file name="logo-paypal.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="pp-allinone.png" hash="c457fe4bfe28a18c90d0abd36fe3f880"/><file name="pp-alt.png" hash="37a166931ca15c465bd86311d15e0422"/><file name="pp-gateways.png" hash="90acb72c2f46fa131351efe0492d52cf"/><file name="pp-uk.png" hash="e0830ccb14533051b8b0340471744228"/></dir><file name="paypal_logo.gif" hash="871e205a64292121f4c893373acfb581"/><file name="paypal_section.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="paypal_tick.gif" hash="e8685c1fb7c4c106ae4fd24e9bbf5a27"/><dir name="placeholder"><file name="thumbnail.jpg" hash="5c73b5aa515b1719f7b398f5131f91a8"/></dir><file name="process_spinner.gif" hash="345b30b4d0b6088d0151ecfbdf48c036"/><file name="product_rating_blank_star.gif" hash="5e20a299c0ff16168be38b6dde580eda"/><file name="product_rating_full_star.gif" hash="dd5aae332178d928a7f49dea7691b5f6"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><file name="rule-ajax-loader.gif" hash="32dc1f5901143d36fbd7a6df3950819f"/><file name="rule_chooser_trigger.gif" hash="9c498e789c3ce734f5301c2475e2a04c"/><file name="rule_component_add.gif" hash="7914e57701ca26f5c8bf23c6bc3e1f25"/><file name="rule_component_apply.gif" hash="3f9b9025551da6963a9ecf8d184a204a"/><file name="rule_component_remove.gif" hash="4d785bcecfbe716fa4d749d20738a8f0"/><file name="save_btn_icon.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="sec_nav_bg.gif" hash="99c6741591cdb2a2a128668a1d32d668"/><file name="section_menu_bg.gif" hash="f9edd44c92743a0c9ae9535a7992d6b1"/><file name="section_menu_bottom.gif" hash="167d2ef46ff80158c807b4b916501b28"/><file name="section_menu_link_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="section_menu_link_over_bg.gif" hash="7da7e56567633aab279cf3aec6f49d8d"/><file name="section_menu_over_span_bg.gif" hash="f5ea5292f15ed62b99f0f51d9fff2c66"/><file name="section_menu_span_bg.gif" hash="dbf3916358e794ee809b4cf33903af2c"/><file name="section_menu_ul_bg.gif" hash="3aea6e5452f548438ca34e17954a9d6b"/><file name="side_col_bg.gif" hash="b3691fd62663457af39eaf71dd8cda5a"/><file name="simple_container_bg.gif" hash="56f1ac91169eb4896b8c91384fc8bf15"/><file name="sort-arrow-down.gif" hash="fc2cd9f756ce510c4470478d720f81cd"/><file name="sort-arrow-down.png" hash="dc65160d9d4d6cdd6bfe1b397a931975"/><file name="sort-arrow-up.gif" hash="39026b0ff1f0c18091caa60384491163"/><file name="sort-arrow-up.png" hash="da54e5306bdce67551aa415f5d7f7ea7"/><file name="sort_heading_bg.gif" hash="6066d09f237f556b0a4770e4788e7598"/><file name="sort_on_bg.gif" hash="0cb36788ed4fbf19e657acbc75a3f1b8"/><file name="sort_row_bg.gif" hash="f2e1c5cb26b9f5211419b99d30745244"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="sub_button_bg.gif" hash="e3f66dd60510f9f7e937e2e55442c30a"/><file name="success-msg.png" hash="c64cb2acc3d0eeba48fdea83620913ed"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="tabs_link_bg.gif" hash="34447929f5e6591ba9b5795b983fdfd4"/><file name="tabs_link_over_bg.gif" hash="2cf3f56884096055fb0bdf9474f280c9"/><file name="tabs_span_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="tag_blue_edit.gif" hash="b2163ac3baf7d822b48593342846645a"/><file name="tn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="tooltip_bg.gif" hash="0aa4b866fc067a75f27ab749c1dabf74"/><file name="tooltip_corner.gif" hash="71146534671d5e0751505640b7c59859"/><file name="tooltip_top.gif" hash="032ff52a6ff5714cbdf6c1f62abaf7e5"/><dir name="tree_icons"><file name="join.gif" hash="4d5d614e0da056df815a4306d6368692"/><file name="joinbottom.gif" hash="4b3daa7f2cc584f1aac0d142275d7cba"/><file name="line.gif" hash="63ab38a6203262f15ca46c631232ea2c"/><file name="minus.gif" hash="d647fbbd0ec410b8f3bb3357b62eedcf"/><file name="minusbottom.gif" hash="b09d684cca7135ef728141aaf2464baa"/><file name="nolines_minus.gif" hash="eb2243a354ffcfac93ba0fe948f7167d"/><file name="nolines_plus.gif" hash="ec92b634b63608fb4b0dbf114e3b89e1"/></dir><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="varien_logo.gif" hash="6f10d0fe572cb012947c164217e9e428"/><file name="warning_msg_icon.gif" hash="4cf6ec7f59ab09f9c18b3a4301714c6d"/><dir name="widget"><file name="catalog__category_widget_link.gif" hash="8435943009f1f774bbd6a4809c719eb8"/><file name="catalog__product_widget_link.gif" hash="62f2d7020143f98ba7514469eb612a7f"/><file name="catalog__product_widget_new.gif" hash="37a5af9f98ae73e180ad0cca05c95324"/><file name="cms__widget_block.gif" hash="b7b0b1517cc38b18b92841b33b312190"/><file name="cms__widget_page_link.gif" hash="b839dee210e61850a5858cc8634cbccd"/><file name="default.gif" hash="684143ae5531aa6ba22215f4fadeea6c"/><file name="reports__product_widget_compared.gif" hash="bd3e5a5015eb2c5c64f1d11835166dc4"/><file name="reports__product_widget_viewed.gif" hash="44d5cd71e4fb7235f9cff0c7e2b2f531"/></dir><file name="widget_placeholder.gif" hash="2bd8d72cf12f8d7d0a6a3268f97786ff"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/><file name="window_content.png" hash="08361df29783d46a2493cf0d8ad733a7"/><file name="window_top.png" hash="555a8db5efa3a252c2ead3d3dadd1075"/><dir name="wysiwyg"><file name="skin_image.png" hash="a521b0c60b001de4a3405e73c4a6cd4a"/></dir></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="27083525fe48622ce931f01c0dcdfcc7"/></dir></dir></dir></dir><file name="menu.css" hash="a1dea5350cfe01b4e27c2606a27762cd"/><file name="oauth-simple.css" hash="08c16d55aef90c4668473326fa11f86a"/><file name="print.css" hash="0003cbfda260e9eee2fefbaf45e8d40f"/><file name="reset.css" hash="e1cccd2f5ec4178349bde538b1f3fb30"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Base_Default-1.9.4.0.xml b/var/package/Interface_Frontend_Base_Default-1.9.4.0.xml
deleted file mode 100644
index 33fd55c..0000000
--- a/var/package/Interface_Frontend_Base_Default-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Base_Default</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This is a Magento themes base</summary>
-    <description>This is a Magento themes base</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:58</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="etc"><file name="theme.xml" hash="8456ce6bc50c16bc6eb2f858d3551274"/><file name="widget.xml" hash="b039c91603c077fce6e6fb5697779eea"/></dir><dir name="layout"><file name="authorizenet.xml" hash="74589d8b92c296319407f0bcc46a5df3"/><file name="bml.xml" hash="85d0410a866de04e1035fccca375c830"/><file name="bundle.xml" hash="0d991090c4db718e54ac8a346d96c588"/><file name="captcha.xml" hash="85e393327f1b260421eb23b1df8f3047"/><file name="catalog.xml" hash="c123ba1f6a458fda2e9eb51cf9dfccaf"/><file name="catalog_msrp.xml" hash="617274bff686d2f4b7d968dad552ee8c"/><file name="cataloginventory.xml" hash="9f6066ff94eb73268af2e88b3eff411a"/><file name="catalogsearch.xml" hash="2032722cd8e7b792531bf23c1df03638"/><file name="checkout.xml" hash="a64880bf5f26a1ff63288611b4a402e0"/><file name="cms.xml" hash="2d7ead19f6967420ca1cf940689eeeef"/><file name="contacts.xml" hash="d63ec031ede1c113f9c8fdb1cb519c30"/><file name="core.xml" hash="d647dcd1e20bb299db3a0b7cc3aed2a8"/><file name="customer.xml" hash="372dcd60eb3076bac088a4c7f0d46b9c"/><file name="directory.xml" hash="d07d5dba3781de15fbaba737b42ef768"/><file name="downloadable.xml" hash="6591f5c7a59395059d6e220f561bffb4"/><file name="googleanalytics.xml" hash="8bb73d5563e553513684959a2ef2c332"/><file name="newsletter.xml" hash="ed64264aa5085d7c65c2628497dcc993"/><file name="oauth.xml" hash="6d1407d7b05af1d4ceb9b30449453dd4"/><file name="page.xml" hash="058a8ae61f2cdc1f79c8b4c51f3e17e8"/><file name="pagecache.xml" hash="66e331999d7509dd1a9c9b46bcd3eebb"/><file name="payment.xml" hash="5a2f743709d22c929c677475e3b8c6f3"/><file name="paypal.xml" hash="a760b0e6576eba3b28aba0e7bd8f8c68"/><file name="paypaluk.xml" hash="3951356c6f2d3ad52c5233158b45d070"/><file name="persistent.xml" hash="1f41380c13b127caa9df0aa4525f18cd"/><file name="poll.xml" hash="2e686135cb1a9ed5520bdef6a48da5d8"/><file name="productalert.xml" hash="84db302990121c0f40a95a6735895c15"/><file name="reports.xml" hash="e0243c38b1651d54b61044735a0eb242"/><file name="review.xml" hash="9f7dfb8bfdee047060697a0c2c05bb20"/><file name="rss.xml" hash="cb5df441e86a2fc6bfd6b3796cff3833"/><dir name="sales"><file name="billing_agreement.xml" hash="b6d7c6bcd1d34544ca17f816f6791922"/><file name="recurring_profile.xml" hash="cff2aa70bf8b88b5f0425086e61a4494"/></dir><file name="sales.xml" hash="84f65b624bed5a53b350572e81cdc928"/><file name="sendfriend.xml" hash="ab32892a9dc0055ba5073521ffc02576"/><file name="shipping.xml" hash="37470069637ffb1073c8d763f9878ce1"/><file name="tag.xml" hash="24224280175e238661d69ca681ad83c5"/><file name="weee.xml" hash="4a2cfd66198d46972ca85ae7b5629914"/><file name="wishlist.xml" hash="36019bd4ce8edd30cd728092b9e68696"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="d5cdd7b78c891bfff70e8790d6ffc12a"/><file name="iframe.phtml" hash="53746666b8a8db3b04729ade2ff6e2b2"/><file name="info.phtml" hash="fbc5be2a2c57b140b8514f1c82c33ef6"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="list"><file name="partof.phtml" hash="20cfdaaca70ab5e35d0e2ccff8171273"/></dir><file name="price.phtml" hash="12e500578adc44420ec61286ce8bd9fe"/><dir name="view"><file name="option_tierprices.phtml" hash="29e771d963a3e0792ba1e95077ca2ec4"/><dir name="options"><file name="notice.phtml" hash="25150590765a6c50755e78047a202ff5"/></dir><file name="price.phtml" hash="61c5cb33985a75c3cef3f27eac22afb5"/><file name="tierprices.phtml" hash="1b3f9b2ba01c7202725d82abd01cc655"/><dir name="type"><dir name="bundle"><dir name="option"><file name="checkbox.phtml" hash="bc049a4508679dc542f5d5581926ba08"/><file name="multi.phtml" hash="11c5e1ed6a2673073f30fec116b1879d"/><file name="radio.phtml" hash="5c33d673c9d985711e4921ece0fd2c48"/><file name="select.phtml" hash="f75bdcb3b0bd7f6916d051687cb5a299"/></dir><file name="options.phtml" hash="b4f3e35dc1b5b57aee26e8da085e9979"/></dir><file name="bundle.phtml" hash="399cc732170698b099b8174e2b2de454"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="73e79f44b21bbd6ddeabff037e3706ee"/></dir><dir name="invoice"><file name="default.phtml" hash="ffc454b565cdb7aed698e1a41011d557"/></dir><dir name="order"><file name="default.phtml" hash="5445bb5670c0e7d43b4ad5f410bcee8d"/></dir><dir name="shipment"><file name="default.phtml" hash="c4aa6f9c29b8827264a733c6e4501768"/></dir></dir></dir></dir><dir name="rss"><dir name="catalog"><dir name="product"><file name="price.phtml" hash="ddf72b1d237e37ccbdc0cf6728bdb36c"/></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><file name="renderer.phtml" hash="392bef3029c29fb7c817df6212939166"/></dir></dir><dir name="invoice"><dir name="items"><file name="renderer.phtml" hash="5a876fc9dc7e9a686369262113ebbe93"/></dir></dir><dir name="items"><file name="renderer.phtml" hash="0ec902774af6f316712bc4a08894e98e"/></dir><dir name="shipment"><dir name="items"><file name="renderer.phtml" hash="9320433232f7529a1084e4912c843e9b"/></dir></dir></dir></dir></dir><dir name="callouts"><file name="left_col.phtml" hash="5924c31ef60634a290acb1363febff88"/><file name="right_col.phtml" hash="5924c31ef60634a290acb1363febff88"/></dir><dir name="captcha"><file name="zend.phtml" hash="dded7aa771db7b3935063f825765e8f4"/></dir><dir name="catalog"><dir name="category"><file name="page.phtml" hash="f65ed1cc0f8590be0f1ce42df42082e2"/><file name="view.phtml" hash="ca926a5109914e411e848c59e67f902e"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="1ecdd16fc4e6edca73f2f47ccbf578df"/><file name="link_inline.phtml" hash="05d5399253bd9fdd3e544162c07bae2d"/></dir></dir></dir><dir name="layer"><file name="filter.phtml" hash="f60ce6a217bed17895e272974fea7295"/><file name="state.phtml" hash="aef918cb1dc87a6e19f15e9933ccdbf5"/><file name="view.phtml" hash="feefd9951d1a5f09f5afbdc6f172bfb5"/></dir><dir name="msrp"><file name="popup.phtml" hash="7c3cc106d79b705a4116fd9177e84781"/></dir><dir name="navigation"><file name="left.phtml" hash="5cd031a95462120d260f83986b7976a1"/><file name="top.phtml" hash="37273f3692f8d3202e34bab12db12448"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="2be9b104504b50e12736ba4335be1fcf"/><file name="sidebar.phtml" hash="e4a99b7993ef2f606cb145c0758e1874"/></dir><file name="gallery.phtml" hash="e5e78dccbf7d78232b19513c1c70ec0e"/><dir name="list"><file name="related.phtml" hash="7e3571c754e92568e49001f2e2774571"/><file name="toolbar.phtml" hash="98f9fbfb6baf00753121771d7d821638"/><file name="upsell.phtml" hash="95f6aa43904bbf23f708a2492ca1bf92"/></dir><file name="list.phtml" hash="a3819339b3ab9e332f5f4376a5bcf3d5"/><file name="new.phtml" hash="dfbd7b61a13fe64e621c552af68c3711"/><file name="price.phtml" hash="11c8607758a73dc990fe7210bc305a47"/><file name="price_msrp.phtml" hash="d47b6e3a6af79ba55d41ba7250a92233"/><file name="price_msrp_item.phtml" hash="7c98887e105b59df267d690a19a24812"/><file name="price_msrp_noform.phtml" hash="413603cebbf863156462956523e4fb21"/><file name="price_msrp_rss.phtml" hash="93dfe7555e290c626e4ca521fd8bdbc5"/><dir name="view"><file name="additional.phtml" hash="69b4be4cb728488c7258d59e02946888"/><file name="addto.phtml" hash="27212ac80f9f4f83ae82946bc935d5d2"/><file name="addtocart.phtml" hash="367552b5951f38a477f2770e345580ef"/><file name="attributes.phtml" hash="b4c881aded9930fe1bdd6fcceb32655e"/><file name="description.phtml" hash="210eb7ef6b1d8a89a789115dafc45bc0"/><file name="media.phtml" hash="9ce45ff36e3169883ba5388d8c63eb08"/><dir name="options"><file name="js.phtml" hash="4ac667882951aec76435d122ce5316e1"/><dir name="type"><file name="date.phtml" hash="59cc3b678a8e389fee9cadcdb9c10f2e"/><file name="default.phtml" hash="b39a69f3f00d6a5c3fd95afe6abc9c22"/><file name="file.phtml" hash="52140af4caec9b58dc2e4b68d6b1d097"/><file name="select.phtml" hash="eccbd8d8de7c8e92932aca2ace9e61c8"/><file name="text.phtml" hash="acaa8e0e08b174ec7da420e4294b646f"/></dir><dir name="wrapper"><file name="bottom.phtml" hash="763e684c32f170448930fb60d10f2a12"/></dir><file name="wrapper.phtml" hash="a99a31b8b2e50e972632a5e8cf969ddd"/></dir><file name="options.phtml" hash="20f2f16105aff5089d66c73edcac4f30"/><file name="price.phtml" hash="c162b62db5616ab0c13cf5899c8cf88e"/><file name="price_clone.phtml" hash="bb525601f75b38803c975fa76595604a"/><file name="tierprices.phtml" hash="46347b577e07c8472c548e64d9dc9426"/><dir name="type"><file name="configurable.phtml" hash="f7a80a8ac392000a0b0d5549d8999fae"/><file name="default.phtml" hash="8204682fcc86d1bdad4d81b6ba3cc191"/><file name="grouped.phtml" hash="629d1a2b1e6a4b755153a3d15e72b346"/><dir name="options"><file name="configurable.phtml" hash="802457191b401d09a9fd035df97d7991"/></dir><file name="simple.phtml" hash="f7a80a8ac392000a0b0d5549d8999fae"/><file name="virtual.phtml" hash="f7a80a8ac392000a0b0d5549d8999fae"/></dir></dir><file name="view.phtml" hash="59eff20144fa118bd9f2a636b269bfae"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="aa60331637ee730e126e9259919dafc6"/><file name="link_inline.phtml" hash="ee6bac1fa8335c20361de2430b5160cd"/></dir><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="1ddf2d721a61fb4738f33a00fa7154d1"/><file name="new_images_list.phtml" hash="0886eb747ae3c78f3f90da6266b00f45"/><file name="new_names_list.phtml" hash="c13201f54054a71e9262a11cab75056e"/></dir><dir name="content"><file name="new_grid.phtml" hash="46e953204b8f7712aad512e90946664a"/><file name="new_list.phtml" hash="62b1c60b7d165a66ec7c98a1409703f7"/></dir></dir></dir></dir><dir name="rss"><dir name="product"><file name="price.phtml" hash="2e871c42449bc31765773c46004c1435"/></dir></dir><dir name="seo"><dir name="sitemap"><file name="container.phtml" hash="429b70d3cee186c5276609482dba7b6b"/></dir><file name="sitemap.phtml" hash="adf9fd9f748d0382e9c3acc00b16da0a"/><file name="tree.phtml" hash="5b027e5d45c1f9370de6f2de1396d764"/></dir></dir><dir name="cataloginventory"><file name="qtyincrements.phtml" hash="274918325bb27a3de7c94298b6c381a1"/><dir name="stockqty"><file name="composite.phtml" hash="b90787e9f5559fa3546dc8c30e230ae9"/><file name="default.phtml" hash="f2196ea260bf5525c6c7ff44650cbd22"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="8417f817a3e6efbd5246bad1b62d0379"/><file name="result.phtml" hash="c13ee8c748a87933cc5a7ac111e3b924"/></dir><file name="form.mini.phtml" hash="eff2a2da159402068716e20faa4b42a6"/><file name="result.phtml" hash="398972ab3766eae5c2d290087d2607b9"/><file name="term.phtml" hash="03bca86ff71856e21f23fbc97b8e1489"/></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="61c8f7e500b54e9d988d8c97675f1d4e"/><file name="crosssell.phtml" hash="742e7d3489f9de170b79e78fb00928d7"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="98cd2a4a2cd71544c0612d76cb025984"/></dir><file name="default.phtml" hash="6cd6494f6a2651e921a037248fd3d7b6"/></dir><file name="noItems.phtml" hash="facfb03068b35b2bd351207286b02965"/><dir name="render"><file name="default.phtml" hash="33069ecebf9d11167e06f6c378315170"/><file name="simple.phtml" hash="7c2bb379ef071f854b3d6d8ac8e716ea"/></dir><file name="shipping.phtml" hash="7ed957412c64efb699db25642fc253c2"/><dir name="sidebar"><file name="default.phtml" hash="081e90f7e63a9243ab332eabc493cd4f"/></dir><file name="sidebar.phtml" hash="115c2cd1173ea4f073fab02a3007c0af"/><file name="totals.phtml" hash="10a59ce27180f0669e3fe02e9223f958"/></dir><file name="cart.phtml" hash="86aec6a4c52a841a19c1d60f7cbf7bf6"/><dir name="multishipping"><dir name="address"><file name="select.phtml" hash="fd2dbf03021661802dac6ba03d3189a4"/></dir><file name="addresses.phtml" hash="5d849deb8cd4d551d7f5f99597917ec6"/><file name="agreements.phtml" hash="72f8e7f0bcc4d72894ae6ca1041ebb9d"/><dir name="billing"><file name="items.phtml" hash="ff4ab0494c91e0b20effd1178a8df61b"/></dir><file name="billing.phtml" hash="5f789e827930c0a71f726e9d1c173f0b"/><dir name="item"><file name="default.phtml" hash="e52d0159c19c93fc5ba013c1f2ae5763"/></dir><file name="link.phtml" hash="0224f87f7b72da1e1e0d08dd38bd59cd"/><dir name="overview"><file name="item.phtml" hash="ce783a3ca3ac43bb52afb99eccc5ed00"/></dir><file name="overview.phtml" hash="3b3fa136cf6df9fe320ad72e4e5fdba9"/><file name="shipping.phtml" hash="5245d3b0579c17dab58500e205d71eb2"/><file name="state.phtml" hash="c125a8a52d97ceddc91c0dcb909e9849"/><file name="success.phtml" hash="d0f060fe4b50de86976973afa86bed74"/></dir><dir name="onepage"><file name="agreements.phtml" hash="45404001934939beee9eaed4f9ad16a0"/><file name="billing.phtml" hash="a1a2e307821a7a3a509516e25afad2b8"/><file name="failure.phtml" hash="6224a687fe25e0553491930fd6c2bfc1"/><file name="link.phtml" hash="63de860e4aa4c4a04bc81d8667bc1ffc"/><file name="login.phtml" hash="70d025b1cfa9fc5fdd2d7cb27d5058fc"/><dir name="payment"><file name="info.phtml" hash="c3199c3811d71236690c831b1f1806df"/><file name="methods.phtml" hash="6c680a1884378c0710b52da66ad4cd46"/></dir><file name="payment.phtml" hash="f0a0fe0496bbb19a1a460f583450e652"/><dir name="progress"><file name="billing.phtml" hash="1451ce8d849cd278b53494b924bee481"/><file name="payment.phtml" hash="210b7df0f97d8e30489f0e772077246e"/><file name="shipping.phtml" hash="04872e976465952fc7abeaea7b8c6d11"/><file name="shipping_method.phtml" hash="7fbd89f26fcce262232245633075d058"/></dir><file name="progress.phtml" hash="046556b8f5c0c0543a395a3cc096ba77"/><dir name="review"><file name="button.phtml" hash="9a37eea9980800d8e6e27e1b3bf0ebf3"/><file name="info.phtml" hash="4408d4e7e8b3c7119c74fde483db3f5c"/><file name="item.phtml" hash="f632c9cbb1c4504becbc7dea63dee81c"/><file name="totals.phtml" hash="ad34c45e104fbd91f5d37dddcce1282f"/></dir><file name="review.phtml" hash="fc140818bdb8a23094130d07cabd2933"/><file name="shipping.phtml" hash="27970a39acdba5d3ad1afb7ced73891c"/><dir name="shipping_method"><file name="additional.phtml" hash="8ab69ff9d687aaf1cbd4a84549767876"/><file name="available.phtml" hash="7713b0e4557977c9a3c7bb0e7cb3c4e4"/></dir><file name="shipping_method.phtml" hash="6bf0240797cd436ec542aa144fc435c4"/></dir><file name="onepage.phtml" hash="f08317a8d5d1d6195df40ae2d79e766e"/><file name="success.phtml" hash="8c638c68a1b2c9940cb35b5e0f5aed25"/><dir name="total"><file name="default.phtml" hash="732dcd5519918052dde74d5f8c706703"/><file name="nominal.phtml" hash="e79744c0722a6a52664b3db28db34726"/><file name="tax.phtml" hash="f04650078c8702105bb6e59ef8ffd7b7"/></dir></dir><dir name="cms"><file name="content.phtml" hash="38cbe3b1972b721c2d367bd21f74817b"/><file name="content_heading.phtml" hash="c6b0ffdd3ed68a9882888ac564224930"/><dir name="default"><file name="home.phtml" hash="bfc8946e23275a5a7438918169d9f2c5"/><file name="no-route.phtml" hash="b3f0906f2b159d8abace9bc3dcdd6625"/></dir><file name="meta.phtml" hash="e51ef9c07e2e628e142a427512fd9137"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="624195969fabb9ac9d03b64e2a06e0b3"/><file name="link_inline.phtml" hash="2be71411f75e519e22043344eaccde1e"/></dir><dir name="static_block"><file name="default.phtml" hash="754d0192532d02bae5004d853670c5ca"/></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="c478a8c54c27c4683f60f8e80bd054c0"/></dir><dir name="core"><file name="formkey.phtml" hash="52f90aeb452765e92c5f7346768b513f"/><file name="link.phtml" hash="4e046010dbb7f5a248b389a1119b63db"/><file name="messages.phtml" hash="abc3e82d903030a00eeaacdfc46d313e"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="8d61408b412552263191f615379cd49e"/><file name="hello.phtml" hash="91006427be928ffd256ef3ca93c505c5"/><file name="info.phtml" hash="511f2299dd3299c0240d27da77e945b7"/><file name="newsletter.phtml" hash="a391459ffeac54b4e1e3a0d8bec91323"/></dir><file name="dashboard.phtml" hash="d66833deed9605f0217340ed3fd9d2cc"/><dir name="link"><file name="back.phtml" hash="a480026329e7b4f0ecda541162cdd370"/></dir><file name="navigation.phtml" hash="87023699db2126337b1ea8d88e4fd1c3"/></dir><dir name="address"><file name="book.phtml" hash="84f5e86e8d4857d8f8a94d3f99247594"/><file name="edit.phtml" hash="d4b56d385495b06bd0adfab247bccaa6"/></dir><file name="address.phtml" hash="2e9c6138dfab41d1c3cb824d27847b31"/><file name="balance.phtml" hash="38a6b224814284f34e215c3aeac08322"/><dir name="form"><file name="address.phtml" hash="0c1bcd2ddfc5a4844319d47205efc861"/><file name="changepassword.phtml" hash="864791f80064a75baf213684785f4785"/><file name="confirmation.phtml" hash="b09f339dad56e1bd32a9efea027a5242"/><file name="edit.phtml" hash="5c2f9978a5deb516a3ff7c4b87a0fe40"/><file name="forgotpassword.phtml" hash="df8a3447845149d968ca8d766b9c3f92"/><file name="login.phtml" hash="bc8ec2d0e1cf939ff8a9d13462df6080"/><file name="mini.login.phtml" hash="adf6356f12c48feb2c66e0dcad96d22a"/><file name="newsletter.phtml" hash="7b21f20e8965b2925ddab6cd3d25d8a8"/><file name="register.phtml" hash="9ec12739a03da9c1f1f5fb9ab01d37a9"/><file name="resetforgottenpassword.phtml" hash="00aafc38934f088a89922535340398b1"/></dir><file name="logout.phtml" hash="692bf6a91293dca20ac1d8d423cd4842"/><file name="orders.phtml" hash="415f7beedbc75c4b1444d8dfa43ef1a0"/><dir name="widget"><file name="dob.phtml" hash="1005a4b61b78219d1a24d2451f5721b9"/><file name="gender.phtml" hash="9ab80b2f02547be4910049747fccb44d"/><file name="name.phtml" hash="341bc06f2b7fc35de3f05fbe3fb286ee"/><file name="taxvat.phtml" hash="235c425c7329ba45ea9473f92148270e"/></dir><file name="wishlist.phtml" hash="3eb53b8ac5008e5ceda023bfd9244fcd"/></dir><dir name="directory"><dir name="currency"><file name="switch.phtml" hash="f3bdbd94aed70f0d5d5c172e58b4d767"/></dir><file name="currency.phtml" hash="3c8644ea81c5775ad3aff629c8c8d977"/><dir name="js"><file name="optional_zip_countries.phtml" hash="12e03bc68425dbade51f09c2175d55a8"/></dir></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="links.phtml" hash="42654e1abddd0b611a1993c08bc45fbb"/><file name="samples.phtml" hash="ea6139e298479fe9a3b9c9f477f5b754"/><file name="type.phtml" hash="6c50a8e98b8dd31ac03e6c5fb6690b38"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="c0637e971f56b908960fc3dd7dbf5a8a"/></dir></dir><dir name="multishipping"><dir name="item"><file name="downloadable.phtml" hash="dbcdbf5ea8a8803bb76f4929c70c49c2"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="e583ad71dd97f2e3b556ccb8f868db28"/></dir></dir><file name="success.phtml" hash="bc6f469a75bc1de8dfa15aded5d1f30e"/></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="18a141d934609d40a3f078df20a3508e"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="a01adea37e9830daeda2298a057dc283"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="2db18119c16c37edfab236c653a7047e"/></dir><dir name="order"><file name="downloadable.phtml" hash="41671123f6b166e6248c7aaf47fcfd92"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="62281fb39c468a3c72ea4bafb0c34e04"/></dir></dir></dir><dir name="invoice"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="db789ff872ad20bdee90b7910bc04d5e"/></dir></dir></dir><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="b19302cf47d0f5f83dbdedbb2ed6778d"/></dir></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="97b06e756e0dd6b49748a465ee6ac99d"/></dir><dir name="invoice"><file name="items.phtml" hash="66caf7d5ca0015a03fc713687dcaba7b"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="f2a289aa7803a166604144486cb67893"/></dir><dir name="invoice"><file name="default.phtml" hash="f2a289aa7803a166604144486cb67893"/></dir><dir name="order"><file name="default.phtml" hash="f9b82d8136205af87f1248ec7894b436"/></dir><dir name="shipment"><file name="default.phtml" hash="de24831f6b719d9029fd891356e37340"/></dir></dir><file name="items.phtml" hash="50ccdd1b18c1646044ed4591182c1a81"/><dir name="shipment"><file name="items.phtml" hash="d27af9b1d046423b8b9336a579b2e86c"/><file name="track.phtml" hash="8f996f39588c8bcd7250074940445084"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="b678f3974a9bc48e6abe0e090eccca58"/><file name="stock.phtml" hash="ef910dfede9981c99d26bd417672899a"/></dir></dir><dir name="giftmessage"><file name="inline.phtml" hash="19f369b97a63e187dfe4cbbf59b92875"/></dir><dir name="googleanalytics"><file name="ga.phtml" hash="ae4de836406da8b74f83e002c1dd045f"/></dir><dir name="newsletter"><file name="subscribe.phtml" hash="010ce9bf3338f5cc67e74cd39d74061e"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="7b7c4eddad3a6daa4ebc653d3c354aad"/><file name="button.phtml" hash="faf402dae0f6e2ee1498e3311ed20867"/><file name="confirm-simple.phtml" hash="654be81300352000efad878dc6790939"/><file name="confirm.phtml" hash="411e649a95a12f01e313f47415670bdc"/><dir name="form"><file name="login-simple.phtml" hash="5707d1b6ed9d5c9f760947af49b7afdd"/><file name="login.phtml" hash="a1f0159424c7deff76d7671b844e7314"/></dir><file name="head-simple.phtml" hash="35385fe88fa3969db9eb4c4ff4f0858d"/><file name="reject-simple.phtml" hash="30a809f48943c115e834f975d0706e6c"/><file name="reject.phtml" hash="dc70d7ac0460d0086ccee822d273aed6"/></dir><dir name="customer"><dir name="token"><file name="list.phtml" hash="c786ee5b27d4b2fe53f24fc762311607"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="ba560885185c4174f30b34a83e74d1d7"/><file name="2columns-left.phtml" hash="15e087a80a45babc5f31d1210f1a8f16"/><file name="2columns-right.phtml" hash="b6bfd3f33b2c52dccc39b61649c4f411"/><file name="3columns.phtml" hash="605fc8c99f65573d0cd0d5028f70ab22"/><file name="empty.phtml" hash="d5ce8a6aa99a9312e36f8f30bbace818"/><dir name="html"><file name="breadcrumbs.phtml" hash="387c80cc4409b7d80fc0e109b5c26468"/><file name="cookienotice.phtml" hash="c1ab166aaca1f37131ade1df47b46f3b"/><file name="footer.phtml" hash="165f2e189ea95fbfdea4e2362a3f070a"/><file name="head.phtml" hash="dca7c9be1b47837f389b9e8c5760bc2d"/><file name="header.phtml" hash="b78450b9af7254cb3eca5b3239f2821b"/><file name="notices.phtml" hash="96f1d387f046315a1029acb6cec49ded"/><file name="pager.phtml" hash="a43620a9590e1c18ad866f45e21e55a0"/><file name="top.links.phtml" hash="8ee81889b89096fb2c73f15bc24625d7"/><file name="topmenu.phtml" hash="1f4ebb56d60d4c9e7a50e514ac33def4"/><file name="wrapper.phtml" hash="c5d2f15bf230989d4f932d1121df5fc7"/></dir><dir name="js"><file name="calendar.phtml" hash="b51f1073a88be80c620ca69b14c6afa9"/><file name="cookie.phtml" hash="583347e0052989c5b551f69c52cde80b"/></dir><file name="popup.phtml" hash="0d87ff223bbd31ab6b18e9cc0d7d48a0"/><file name="print.phtml" hash="1983a1945db0b690536338b03daa698c"/><file name="redirect.phtml" hash="205bdbdafaa0c29b3c48787ac5342aaa"/><dir name="switch"><file name="flags.phtml" hash="edb6a15d64c0ef384e70e92eab7f53c8"/><file name="languages.phtml" hash="8f26fa4d37ac034c48a63d5c066272c4"/><file name="stores.phtml" hash="00221806ad7ca5e599f88eca41b14000"/></dir><dir name="template"><file name="container.phtml" hash="6478f20491c01cef5a83f3ffa07b1383"/><file name="links.phtml" hash="83d62cf22893e64ae9b9548a5ba249e4"/><file name="linksblock.phtml" hash="cf2c5f3b4efccc1c6adbec81af428ab3"/></dir></dir><dir name="pagecache"><file name="cookie.phtml" hash="a803aa11c5e463f6ff7c31a22e3e938d"/></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="df6342dd4fc3a3700ee31e35e28963af"/></dir><dir name="info"><file name="cc.phtml" hash="d070d6bde2301d2dadf6da2069fcbe0e"/></dir></dir><dir name="payment"><dir name="catalog"><dir name="product"><dir name="view"><dir name="profile"><file name="options.phtml" hash="c169fdadee257741239dfc0a4ba99012"/><file name="schedule.phtml" hash="e3e2b2e6028163ac3349c3dd911d3ada"/></dir></dir></dir></dir><dir name="form"><file name="banktransfer.phtml" hash="1e5d9ed7e5afb0892ea5e9fdbee3d555"/><file name="cashondelivery.phtml" hash="74a08676d6e701110c5f77f1ca34775e"/><file name="cc.phtml" hash="b9883effd675b829993ff08552c7a8ff"/><file name="ccsave.phtml" hash="679e2f094fc2c2d78fa4210d7664f6ac"/><file name="checkmo.phtml" hash="3c750279b924b87776eafca6f95dfb62"/><file name="purchaseorder.phtml" hash="8bc2d0ce1aedd9206e62e6f8ee31425d"/></dir><dir name="info"><file name="banktransfer.phtml" hash="af54b6d8084d85a700bceaa8709a2d88"/><file name="checkmo.phtml" hash="b099571826a7253a0916a70c37b30f99"/><file name="default.phtml" hash="153c9c6e57f693a1d36c18b3273436b3"/><file name="purchaseorder.phtml" hash="a59afd0455a29faf454dae91919b959e"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="d1737b9d0742bfa69bd753f3c926aae9"/><dir name="express"><dir name="review"><file name="details.phtml" hash="bbf6399883c3a37ea12ec642692d17b3"/><dir name="shipping"><file name="method.phtml" hash="fa2893274e2e7c4ae48d1f595c87b4ab"/></dir></dir><file name="review.phtml" hash="7e9ed9af0177629fdcf6ce31dfc50f01"/><file name="shortcut.phtml" hash="7ae8c4de2e8e9994b6f33e320b19e393"/></dir><dir name="hss"><file name="form.phtml" hash="332124520ec379e3c0f0c5129a5631d6"/><file name="iframe.phtml" hash="947917ebd57fa7ca7a929548b2d394a4"/><file name="info.phtml" hash="98863ef8eacb97dd4c40f10a951b41c5"/><file name="js.phtml" hash="75a8ac107c1dbe16dcedd54b1dcfdbe9"/><file name="redirect.phtml" hash="3e8bc931bb1d3d1774d2104da54060e5"/><dir name="review"><file name="button.phtml" hash="b770ff4a61635fde04ae6a658df4f1a2"/></dir></dir><dir name="partner"><file name="logo.phtml" hash="bebdef15e1f7096908e07c5628f5c97f"/><file name="us_logo.phtml" hash="aa3285338078dbe88f9cae53f03551f8"/></dir><dir name="payflowadvanced"><file name="iframe.phtml" hash="2cbb140c3a6bd223354cfa06e7db3031"/><file name="info.phtml" hash="3dcb904ba9473835730e5b2c56f74b0b"/><file name="redirect.phtml" hash="e6b72ca7bde83d2243113054380ebe62"/></dir><dir name="payflowlink"><file name="iframe.phtml" hash="45e82ba69ec4e473867ca6bc96cb227b"/><file name="info.phtml" hash="669b0d5c5aa916bddf1b0b142c6cfa34"/><file name="redirect.phtml" hash="c5b14f888d014be722ee15b3702c7441"/></dir><dir name="payment"><file name="mark.phtml" hash="4bc2dbb74ebfd552b2c76c74104808f7"/><file name="redirect.phtml" hash="19911b7032f0ba43eef333c633dd7ef6"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="13434ce2442e0bc63dab47d7b9aaf06d"/><file name="login.phtml" hash="de9645ce1e4c75455d9146f4e2982f27"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="b878c732491c0a5195d6d40e7f464512"/><file name="register.phtml" hash="f53d23fdf5cc4d1711a917fa2a5ebdb8"/></dir></dir><file name="remember_me.phtml" hash="cd504465947d05dc5ae2b493c9c80119"/><file name="remember_me_tooltip.phtml" hash="36dade6318d828301d4cf41042fbd37b"/></dir><dir name="poll"><file name="active.phtml" hash="0bf9205a188d855687b431ec89ed1e23"/><file name="result.phtml" hash="65c1789af783de03d56462b40d01938a"/></dir><dir name="productalert"><file name="price.phtml" hash="65b7fb1b0cc1317e26a08f8648d96973"/><dir name="product"><file name="view.phtml" hash="ca66dfca016135d50c6f8939c48295c6"/></dir><file name="stock.phtml" hash="65b7fb1b0cc1317e26a08f8648d96973"/></dir><dir name="rating"><file name="detailed.phtml" hash="202e2d6270853475a79753d8bdd2c756"/><file name="empty.phtml" hash="7ba87f02c70b4f4b60a297cb5ac1b00d"/></dir><dir name="reports"><file name="home_product_compared.phtml" hash="552602ca1266ff755cbafd01535e59d7"/><file name="home_product_viewed.phtml" hash="f9c3451781a20f671f7080b4a9ee9044"/><file name="product_compared.phtml" hash="bd5d89a05002b08fcbd3dce160480a80"/><file name="product_viewed.phtml" hash="3ccf378d26c2345860c783d7f632e28e"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="113c005db1e886e4662c4904bff55cd7"/><file name="compared_images_list.phtml" hash="d64687ca7c578c319ed9697b08f3b29c"/><file name="compared_names_list.phtml" hash="ba1804e5e322f6f1dd5a94974db7df51"/></dir><dir name="content"><file name="compared_grid.phtml" hash="d6474c91d4868134e56f7242a4094bba"/><file name="compared_list.phtml" hash="f191a8126f3309f6f7c13d151b49ffeb"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="961efa3b5cbe37e4504e18e31468f807"/><file name="viewed_images_list.phtml" hash="15be6c66f9bad0e5103c7f43029be986"/><file name="viewed_names_list.phtml" hash="4ef13573ae93d66ac51b7873cd81888e"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="a5e25525c30eeb6b9b7774e5538d7c18"/><file name="viewed_list.phtml" hash="164ba084766cbdd2b68aed4e0f26b565"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="list.phtml" hash="721598720e994135f3bc3e761b5266a9"/><file name="recent.phtml" hash="6460425ed956730056a9aea8bd6031ef"/><file name="view.phtml" hash="6c3895ddd69a8f55686ea8eb42328517"/></dir><file name="form.phtml" hash="bbfe207a22dc8fb09a91e9044b2e341a"/><dir name="helper"><file name="summary.phtml" hash="33a57af6b85492f060524b88625df882"/><file name="summary_short.phtml" hash="a60b251515c67da4038edf90f5dc3ef9"/></dir><dir name="product"><dir name="view"><file name="count.phtml" hash="8ab723f1249140f0ca48b364f8112a43"/><file name="list.phtml" hash="92d20ae766c890ace8304ac9e58be10f"/><file name="other.phtml" hash="efebc986f3a44c6f49cdf9d3c52b9a1d"/></dir></dir><file name="view.phtml" hash="48005db2881558b6e03eaaaf697b7422"/></dir><dir name="rss"><file name="list.phtml" hash="8f0a100373d0b9521dbbd57fe2f28cae"/><file name="nofeed.phtml" hash="66b5883f325d7112ab78fd9dfb5a1117"/><dir name="order"><file name="details.phtml" hash="b286a9ad7b09fa5c87b053d7b957b604"/></dir></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="49dcbf01b83da977a979bc36797430ea"/></dir><file name="agreements.phtml" hash="cb14430a9ac54ccfdbf17bc9f1f79299"/></dir><dir name="guest"><file name="form.phtml" hash="fd9701f4c8a38c70c7024da2537514c6"/></dir><dir name="order"><file name="comments.phtml" hash="4e2bbb7e35c890cab07b4d7a5e5fb52a"/><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="28a876d2806cee7eeae3224c6526a799"/></dir></dir><file name="items.phtml" hash="2b4d90d22cc6f0ceef638ce69616ed1f"/></dir><file name="creditmemo.phtml" hash="8d29146bb68bbd7dfd4d2ab3e724fd09"/><file name="details.phtml" hash="9bf14dad4e85563b3ba95ccce0516161"/><file name="history.phtml" hash="d2d4c47407a2f06570c480aaea40e2b4"/><dir name="info"><file name="buttons.phtml" hash="d71041b3b80aee3f88874c0f80ec23d6"/></dir><file name="info.phtml" hash="778f1b6ca9c5e9dccd09bd7b1307c16a"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="08290f0c4d459f1f18edcc617c1692c2"/></dir></dir><file name="items.phtml" hash="e9228aa6b8d6957eefc50adf8a3efac7"/></dir><file name="invoice.phtml" hash="da51c35209055d6576995fafd6694dfe"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="b5c769b54abe5b1f669a0c9af2d80616"/></dir></dir><file name="items.phtml" hash="8c0ab3ba6e5fb341cd42f02bed989d41"/><dir name="print"><file name="creditmemo.phtml" hash="d3272d37df20fee50f5a792cc464d64e"/><file name="invoice.phtml" hash="7d301500e9f9be183fc3c666b9e3be5e"/><file name="shipment.phtml" hash="ebd77328f43e38fa138804f2547b2917"/></dir><file name="print.phtml" hash="4e5cdf5e75e52df86b2ece184870b028"/><file name="recent.phtml" hash="f4bc187330665a28891fc6284f2a422e"/><dir name="shipment"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="a7ce46546d4a4f490f366637c54e1e2e"/></dir></dir><file name="items.phtml" hash="731a8fb134a9c193792b0f7d4aa0fd45"/></dir><file name="shipment.phtml" hash="c53a270ef07998878ec596ef3d1ae9ec"/><file name="totals.phtml" hash="8a54cd1c5037413b76f4206da5550c2d"/><file name="trackinginfo.phtml" hash="913f8450b0cbe6f4da4faf39118e973b"/><file name="view.phtml" hash="26c6f0ed0d4091349f2163af7e7165d5"/></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="75af26f317cdfe9017f4b57e4dc7a9f5"/></dir></dir></dir><dir name="recurring"><file name="grid.phtml" hash="ddae03730b2834a5a3619cda9425902b"/><dir name="profile"><dir name="view"><file name="info.phtml" hash="9ca55ba84d3536d690d09a8aa5b8e4bd"/></dir><file name="view.phtml" hash="c5d47bcc570afc9c694926a1ad81a161"/></dir><file name="profiles.phtml" hash="4d10f8ec5ff497f1926b6ef0323f2119"/></dir><dir name="reorder"><file name="sidebar.phtml" hash="7f9cefbde5700ac8ce8951df0e9699c7"/></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="eb6a798e961ffd5509176ad49d3edf89"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="4b8db87c894c94ad1f6587e4534d43cb"/></dir><dir name="shipping"><dir name="tracking"><file name="ajax.phtml" hash="f66b2a0722264981df2a5b37fe412c03"/><file name="popup.phtml" hash="dc8f61e5b30a79dd6b2c83ed39f7ec76"/></dir></dir><dir name="tag"><file name="cloud.phtml" hash="450830cdc8597f910f6eb406dde31f39"/><dir name="customer"><file name="recent.phtml" hash="71cd14d5ad4c95f9b0926b9b6aedc177"/><file name="tags.phtml" hash="4c62c7110a730b8d5325258b202de606"/><file name="view.phtml" hash="b559a661a42c03b70141dd7bbac20168"/></dir><file name="list.phtml" hash="ae6c7fde0813b471c999c7556121e69a"/><file name="popular.phtml" hash="e4012fefdbc97e5295ead2e872d0df02"/></dir><dir name="tax"><dir name="checkout"><file name="discount.phtml" hash="c27b58ad087dce0120af93a4cbe27150"/><file name="grandtotal.phtml" hash="571eec758ad2003cd201e2d8960bc2b8"/><file name="shipping.phtml" hash="f0a361a6d087fdf81b8c6dfa1b2cbfc8"/><file name="subtotal.phtml" hash="8d5e27373ab8bf9b0fb1ac2acb342513"/><file name="tax.phtml" hash="160b232674df65b96070e69cd66a8cda"/></dir><dir name="order"><file name="tax.phtml" hash="9fe704470fc18713b97e5e8deedb861e"/></dir></dir><dir name="wishlist"><dir name="button"><file name="share.phtml" hash="61798dad1157c98ed4e98b0af7a82149"/><file name="tocart.phtml" hash="2891dfcfd82fab82350afcefed091c10"/><file name="update.phtml" hash="53c08f709457b5885a30ec835958e5d6"/></dir><dir name="email"><file name="items.phtml" hash="d28fff1f899382b415164a4584ef0087"/><file name="rss.phtml" hash="a1087b27ab809a5998e622c137087c86"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="b084c2519f69de1a224605fc2adf23df"/><file name="image.phtml" hash="3d83a3268391dd756ef455bce3778253"/><file name="info.phtml" hash="b8c1b96ca6e00ab7c09db07b5b8d326b"/><file name="remove.phtml" hash="b028e9054c4892f403c276d75dbfc7cf"/></dir><dir name="configure"><file name="addto.phtml" hash="3abe455fd4f539f37c51217bf2a8a355"/></dir><file name="list.phtml" hash="4d2fb3e1a08425db2feebe2fa6ed5277"/></dir><file name="options_list.phtml" hash="b2aa9909656e715ca5155dadaefc89a3"/><dir name="render"><dir name="item"><file name="price.phtml" hash="e26c2ea7e209ccb0984c955dbb57875c"/><file name="price_msrp_item.phtml" hash="e1454858a70d8a612b3e54b46dff3b70"/><file name="price_msrp_rss.phtml" hash="e8b55402752b78d9ec9c373cd3ae762e"/></dir></dir><file name="shared.phtml" hash="62a2177ed3649e54aa4382db12123d73"/><file name="sharing.phtml" hash="8cf5ada655b53ccd49415a5216ed3b48"/><file name="sidebar.phtml" hash="be14014de1603cc7b1ffc27240b50578"/><file name="view.phtml" hash="82cf14f404a5f44f3443dbc5e7a20bc1"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="css"><file name="email-inline.css" hash="34e8133bb13499f73c46f89667e27ae8"/><file name="email-non-inline.css" hash="a84a967a0edf5b7b3d811fed2ba13590"/><file name="widgets.css" hash="1f452e26e107856cc540fb69b6a2bdc3"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><dir name="cookies"><file name="firefox.png" hash="425e1b2ddc38c0bba431fb54357c66a4"/><file name="ie6-1.gif" hash="5c27700e245762bc89ed8c3ee7183f21"/><file name="ie6-2.gif" hash="d8c55e15e1f711e5c259300a9c19551b"/><file name="ie7-1.gif" hash="d61edcc8a514a3c81ea116b7d38ddcb6"/><file name="ie7-2.gif" hash="0526a654e94c54866cad977c0a47d3e5"/><file name="ie7-3.gif" hash="4fb142def3f6cfd8d8d23e1315528a1e"/><file name="ie7-4.gif" hash="575c276231c6a91e28935ec98215e146"/><file name="ie7-5.gif" hash="3ae5fcc11fe89da91674d183872337c1"/><file name="ie7-6.gif" hash="95a4981a41785a8cde273c9b2edbfbc7"/><file name="opera.png" hash="34070d92180d4ee0e37b1dd8bb731cd7"/></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><dir name="widgets"><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_widget-link.gif" hash="1bf753578171f147f0203e7b13bdd0c4"/><file name="i_widget-new.gif" hash="a75377ffed51b711cbc608ffaa1a2e7d"/></dir><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/></dir><dir name="js"><file name="bundle.js" hash="0155fef3bde8ab4abcc3f233836bc33a"/><dir name="checkout"><file name="review.js" hash="579ed9bec667e810c07e75e7c4d9a059"/></dir><file name="giftmessage.js" hash="064bddbe613eb95862bdb2891d0d0cc6"/><file name="ie6.js" hash="5c623b1d30911e8d7d5ce3f488040637"/><file name="msrp.js" hash="a4ffe8a1d7442b48e74a03a610b25c1b"/><file name="opcheckout.js" hash="d46da63f5a4cfa08c4106e089cf5521d"/></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="69a5ff04546ca7849b8bb33c4da2a281"/></dir></dir></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml
new file mode 100644
index 0000000..32728a8
--- /dev/null
+++ b/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Base_Default</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This is a Magento themes base</summary>
+    <description>This is a Magento themes base</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:40</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="etc"><file name="theme.xml" hash="1b3f57d0a5774c3ee81f1647dd726a07"/><file name="widget.xml" hash="1b115ea6ec3f8c6db45e36760706be65"/></dir><dir name="layout"><file name="authorizenet.xml" hash="855c24dbd6d10c3ba28c17a8ce23601a"/><file name="bml.xml" hash="24d1888c05d081f537c3f57b9a29c4aa"/><file name="bundle.xml" hash="ee537028ca8d08e4c13ec6a4b3fbffb3"/><file name="captcha.xml" hash="428f52561c29ce5476468d41693b23cd"/><file name="catalog.xml" hash="284510e876c6f8e94fdcd1e00b1acd81"/><file name="catalog_msrp.xml" hash="cffdf3f5839375aa454f900093675ba8"/><file name="cataloginventory.xml" hash="06296ed114aa7c924a6aab916e6255aa"/><file name="catalogsearch.xml" hash="ddf280146c63bac6fff420c441845fab"/><file name="checkout.xml" hash="db3054a77255f3abf914545019160cfa"/><file name="cms.xml" hash="23faafff4439ede1d8a16e679e57d89c"/><file name="contacts.xml" hash="1eab2e4a72bf322f2233a22ece428fed"/><file name="core.xml" hash="f148469b0dbf2d204bb65312da9c301d"/><file name="customer.xml" hash="ab5cb799d48a7d7f1e51cbc05730eda9"/><file name="directory.xml" hash="2405153a0f2c424ca4fc1d076ad04631"/><file name="downloadable.xml" hash="491be3217bc4b128edf3cd7928fedd38"/><file name="googleanalytics.xml" hash="51aaaecaa23e340e5175d4bd6340f671"/><file name="newsletter.xml" hash="acf4cdc3756727420cc5151a60c059fe"/><file name="oauth.xml" hash="be99a8e31ef178e9cbd15b23027888a1"/><file name="page.xml" hash="795fa23724151dd8a7601b83aa45840b"/><file name="pagecache.xml" hash="bd3f4873b9dc907304e3161d8d026a0d"/><file name="payment.xml" hash="59b2f3f0947d2baae8cee91b96927a72"/><file name="paypal.xml" hash="e8cef6dbfd787dc0c7706ae6573253b2"/><file name="paypaluk.xml" hash="b374285cf042a5cc0e0a092568912c6a"/><file name="persistent.xml" hash="0bccb7bc4884346c44d91cd333cc3cda"/><file name="poll.xml" hash="176c92c32872efbf8175d8b02b5c9077"/><file name="productalert.xml" hash="6e7c0fff4fd537bcfa031fc088b6f3e7"/><file name="reports.xml" hash="764393665f03973464133dbc50a0a248"/><file name="review.xml" hash="378afb80fec6d583a0e8450a20495cb0"/><file name="rss.xml" hash="92d39fcc26eb6d590abc36661441ce03"/><dir name="sales"><file name="billing_agreement.xml" hash="5411e2c9dcf1681917db2cedb11ec5de"/><file name="recurring_profile.xml" hash="dab9149e5fd8fb3923165ca88de4ad74"/></dir><file name="sales.xml" hash="e3031185eae6df20c1ee281206bbfa9c"/><file name="sendfriend.xml" hash="eb574c649d054ffb9eef58e704f6ed2c"/><file name="shipping.xml" hash="96441af87095085b4f40c628b9dcc6de"/><file name="tag.xml" hash="e502cb505ee72082ca8d72cb8a3e5762"/><file name="weee.xml" hash="5c9f1bd15a6c8245071bcc13d7943c0b"/><file name="wishlist.xml" hash="593d574973f72aa189321a794d4af0f9"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="00f7a6eba53a3a693566ec7285fcafbd"/><file name="iframe.phtml" hash="ae37639a5bfc9361080156be19957bce"/><file name="info.phtml" hash="7d70e1b79f91cf902d66f2b14722da85"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="list"><file name="partof.phtml" hash="b19a017f8ca29e890244c35b8d94f6a9"/></dir><file name="price.phtml" hash="aa614de35a91fb7f70a02270771ff3dd"/><dir name="view"><file name="option_tierprices.phtml" hash="94e43618af517cb5a72094b59599f4cd"/><dir name="options"><file name="notice.phtml" hash="ade99bac4130350e9ddc572374704e4e"/></dir><file name="price.phtml" hash="a87dfbf46fbe9e3da8ffcdc6957f79a0"/><file name="tierprices.phtml" hash="6d3b049e6f2febbf5dbbf1f508bf9de5"/><dir name="type"><dir name="bundle"><dir name="option"><file name="checkbox.phtml" hash="6e63147acaf0e63969d7f0056dac34c7"/><file name="multi.phtml" hash="a8a4aebc5dc270253baba340272bcf63"/><file name="radio.phtml" hash="e453d2c5f3da4d74c3862c8cde6acb6f"/><file name="select.phtml" hash="8d12adecc1335ab12d573d1ed15b9129"/></dir><file name="options.phtml" hash="a26af0c38ea071f890137e475c4a17da"/></dir><file name="bundle.phtml" hash="b9ffd5141b2913ff07ea855d8a7f93dd"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="895472cc9effc91924cce1dd6dfd9281"/></dir><dir name="invoice"><file name="default.phtml" hash="55998534e0e4e4902ce6af2bf353ae1c"/></dir><dir name="order"><file name="default.phtml" hash="b07e5afb8efedbf59175fcd77627e9f7"/></dir><dir name="shipment"><file name="default.phtml" hash="04ab3570798d203a0b42f97b19ee3dae"/></dir></dir></dir></dir><dir name="rss"><dir name="catalog"><dir name="product"><file name="price.phtml" hash="4cfcfe5be3f454977ec20ea6018b336c"/></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><file name="renderer.phtml" hash="61a8ed5607b9666c529e032e9546f4c9"/></dir></dir><dir name="invoice"><dir name="items"><file name="renderer.phtml" hash="2388aa265abe8acfd42b20fae31ec8c9"/></dir></dir><dir name="items"><file name="renderer.phtml" hash="c333af80eeb8d3f4391b2469494a0eab"/></dir><dir name="shipment"><dir name="items"><file name="renderer.phtml" hash="4c29f3aa573ebf5957824efd12ab34d6"/></dir></dir></dir></dir></dir><dir name="callouts"><file name="left_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/><file name="right_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/></dir><dir name="captcha"><file name="zend.phtml" hash="4ad7facdc381d1989da09ca588a08a48"/></dir><dir name="catalog"><dir name="category"><file name="page.phtml" hash="3e0e8f84c473bdfef97df156b170b23f"/><file name="view.phtml" hash="c3d126426f18f3851c9166bac7633475"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="0ecdcde11fc703fe21b2a57959440d7a"/><file name="link_inline.phtml" hash="038c644f25cf294d9f25ee5948c934fb"/></dir></dir></dir><dir name="layer"><file name="filter.phtml" hash="9daa0a45ccb872fe0a81b5d557c61d1d"/><file name="state.phtml" hash="142da1859cc91dce318b3d0914bb937d"/><file name="view.phtml" hash="dc3784fa579a95756170ec2e2ca6b4b7"/></dir><dir name="msrp"><file name="popup.phtml" hash="e74b3a4515baf615434e344194eb6157"/></dir><dir name="navigation"><file name="left.phtml" hash="7c9b95894ae693ea0091d85351c2708d"/><file name="top.phtml" hash="12672ad077c0c77b75b5fcf61c5752bf"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="f95646d2609bd187ff238e9f0f5c577b"/><file name="sidebar.phtml" hash="73d8e6ff3a49e0e13b903cab88511869"/></dir><file name="gallery.phtml" hash="50522f1290b268c72ac01c52fc150ba8"/><dir name="list"><file name="related.phtml" hash="7214653e8f19a685422064404435efff"/><file name="toolbar.phtml" hash="d1c66674abe8d65b884973fe58aa16d6"/><file name="upsell.phtml" hash="ffadd368be3cdf5033c1ca64de7ee5ad"/></dir><file name="list.phtml" hash="59b34c8c4b1a541029779c1581be2c71"/><file name="new.phtml" hash="7242fa0ea560a5fef7412d5d7f263200"/><file name="price.phtml" hash="d1a72f0b86a3fd002f70f952a0efe712"/><file name="price_msrp.phtml" hash="eb5f9dea211d5a136895920bb24aa504"/><file name="price_msrp_item.phtml" hash="0752e07eca2b095097048cc4673d737a"/><file name="price_msrp_noform.phtml" hash="150d188b6569613bda1486aba82345fe"/><file name="price_msrp_rss.phtml" hash="458e3fc5ff8d78da7aecc310c6d3356d"/><dir name="view"><file name="additional.phtml" hash="8bf11962c3c417b8fc337b79ccb96613"/><file name="addto.phtml" hash="c08c21c0a4593b9f20ced4660800e6b1"/><file name="addtocart.phtml" hash="12f6abb6c764fb87fa82bff3cb3a5069"/><file name="attributes.phtml" hash="b63af5e2aa6016dbee380c97bab61663"/><file name="description.phtml" hash="baf5465eea9b60f61e7b5ffc35ebad59"/><file name="media.phtml" hash="ceab5af9d9c32ef24352644a3f2bd154"/><dir name="options"><file name="js.phtml" hash="9fa94005f0cce3e3c194cb4e8dced133"/><dir name="type"><file name="date.phtml" hash="db6bbf3bdcc0a3680f259ad8d19c75fb"/><file name="default.phtml" hash="a54bc2bd868275275b2de2bf0a2c9686"/><file name="file.phtml" hash="f405962e8758758aced946f39988a1a3"/><file name="select.phtml" hash="1a0b802c9144abfb7bac5718e740aa46"/><file name="text.phtml" hash="39ba731885d8033ccfde950532be0827"/></dir><dir name="wrapper"><file name="bottom.phtml" hash="99622405f360fc6b1f69be608a18cf59"/></dir><file name="wrapper.phtml" hash="a10b15930010e7b0b94368f74ee07d24"/></dir><file name="options.phtml" hash="185b4376b5c8f926534f5522ef817176"/><file name="price.phtml" hash="3f14660f164c43324c765f6e5fb769b1"/><file name="price_clone.phtml" hash="7a8daa84610660f1be752cf0df60ed30"/><file name="tierprices.phtml" hash="886a860c22f8bd46bd83b19e93a6c776"/><dir name="type"><file name="configurable.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="default.phtml" hash="e06292be7becf92e2c8f55b10e7ca3c0"/><file name="grouped.phtml" hash="ba9e60156e779e4dad7fcffd0fb1ebe9"/><dir name="options"><file name="configurable.phtml" hash="6c64bea4fd84db79072866ccb8ae424a"/></dir><file name="simple.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="virtual.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/></dir></dir><file name="view.phtml" hash="d3eb40754189b82eb38f5f599b1fde9e"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="9a806959c5c414720e46469ef6834763"/><file name="link_inline.phtml" hash="514176db5de5c36abb618521d24cb237"/></dir><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="c57acf54bea4e724780bc970ebd028f7"/><file name="new_images_list.phtml" hash="0551ac1792e6b0803577f2108ffca082"/><file name="new_names_list.phtml" hash="20160816ea5bf6e94d66edc0c2bcb5aa"/></dir><dir name="content"><file name="new_grid.phtml" hash="dbfe8328eab155033191b84efd2f3152"/><file name="new_list.phtml" hash="6b6f1197393ac2af8e34e79553614fe6"/></dir></dir></dir></dir><dir name="rss"><dir name="product"><file name="price.phtml" hash="b2a96e4dfb6b818313fdb0eb493ecb9e"/></dir></dir><dir name="seo"><dir name="sitemap"><file name="container.phtml" hash="e64087817a512c8060d35dba48d1fef1"/></dir><file name="sitemap.phtml" hash="7b6518bb6846ed7e43fc6cc0d52b237b"/><file name="tree.phtml" hash="9176ae4df84a0356870d879a2e65fe60"/></dir></dir><dir name="cataloginventory"><file name="qtyincrements.phtml" hash="54afce4d3ba1bbead406befdf06ed7f1"/><dir name="stockqty"><file name="composite.phtml" hash="99e78924ebc0290f6fb39cef21a909c0"/><file name="default.phtml" hash="f12fd9722adfd128b1efcaa3c50aabf7"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5dd4260177e17ae350d2a283678deee4"/><file name="result.phtml" hash="125e8d77b8ab634da046a243f093ca93"/></dir><file name="form.mini.phtml" hash="3ca70be7e95f9c64415c5366968ba681"/><file name="result.phtml" hash="fbc91d34b804e97f30e1c2713def14b0"/><file name="term.phtml" hash="900bec348bfc6331c53832a176cb684a"/></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="4e2adcaa7e3ef72d26df8831c799e929"/><file name="crosssell.phtml" hash="0e7a1a545636daabf9f6f44fbd914500"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="925b6697f3edd41e52896feedbe212d8"/></dir><file name="default.phtml" hash="667a6fff0e50e2c5d9eeff32d421cc69"/></dir><file name="noItems.phtml" hash="72ba12d8a6ac165241910bf56d5b382f"/><dir name="render"><file name="default.phtml" hash="35a21249ea35f9fbb9fe9fbc5c01da00"/><file name="simple.phtml" hash="7eddd5db12cdc96213fcf2d69e567b03"/></dir><file name="shipping.phtml" hash="f1bfd43ef0e1b2d2d56c6c2beffbfb45"/><dir name="sidebar"><file name="default.phtml" hash="3aa4196c077f9b6c9137f45771df0118"/></dir><file name="sidebar.phtml" hash="bfa1f7e53dc361b68da14cf5edea3572"/><file name="totals.phtml" hash="bcf0133b72d8e70eb5a9285c0aae582a"/></dir><file name="cart.phtml" hash="8f4a6f818d6c29d3cccd8b92c94febf2"/><dir name="multishipping"><dir name="address"><file name="select.phtml" hash="d4400f34a601c4792fae8a694a9fb72b"/></dir><file name="addresses.phtml" hash="b00f072f232a89e3922432549db65c4b"/><file name="agreements.phtml" hash="a97c13b4fcf0bf31dc30b47f4ec9a3b4"/><dir name="billing"><file name="items.phtml" hash="0e2f790555e36eeca4c752fb10477266"/></dir><file name="billing.phtml" hash="356b1d85f7e78e4453fa4b2afd702b42"/><dir name="item"><file name="default.phtml" hash="9834befaf665771cd0aa24d67949da57"/></dir><file name="link.phtml" hash="4171ed501b67a73a8643de4fd24cb371"/><dir name="overview"><file name="item.phtml" hash="9d7d07a2fed6c207060bcf06547dbb5e"/></dir><file name="overview.phtml" hash="fdd94e42a0d861f25a2883c4ea0d2392"/><file name="shipping.phtml" hash="12eb547e08175d83bc66db197e2e958a"/><file name="state.phtml" hash="162bc8518f21c5ec0ad9716f8f628c34"/><file name="success.phtml" hash="d0fa6a04db0648f16ad740547a7381c0"/></dir><dir name="onepage"><file name="agreements.phtml" hash="9fe1c65c816b7857225d03646ed513d8"/><file name="billing.phtml" hash="f394e9db32ca986c31d1e2de5a4a4ba9"/><file name="failure.phtml" hash="7fef71bf3d691da514d9938099dd4a4a"/><file name="link.phtml" hash="744c5e6417fc1f16480ff47683cd059c"/><file name="login.phtml" hash="d20b228d44f3a8ecd1705dca4d711991"/><dir name="payment"><file name="info.phtml" hash="f4ae4c946643de8812b3b3af03687845"/><file name="methods.phtml" hash="86b3b5650883324fc50bd0ff8de5218a"/></dir><file name="payment.phtml" hash="35463d9e41512ff417899cfceae4948a"/><dir name="progress"><file name="billing.phtml" hash="b25fa3a5543ae6a35100881fc332e5d5"/><file name="payment.phtml" hash="f519b6de231333174e0ada183b1cd770"/><file name="shipping.phtml" hash="56c67f2192e305173616cf2e2a845947"/><file name="shipping_method.phtml" hash="afd02339abd3acfb3494fcfd5da14079"/></dir><file name="progress.phtml" hash="11557f64819329b4c71ac6997c071389"/><dir name="review"><file name="button.phtml" hash="096f57ab7f1ae1a7d68df2958dc15588"/><file name="info.phtml" hash="1928ceec84a3c06a180e4b3a3d4ee4eb"/><file name="item.phtml" hash="0c8e678f45f04e7bacb3ed2b8acdd638"/><file name="totals.phtml" hash="26a8fb780ca6c1204c77e8c051e63d2d"/></dir><file name="review.phtml" hash="c40cd3703b88209ef63294149246d1f8"/><file name="shipping.phtml" hash="5a8989220ddfbb1baeec0f5d27baea3d"/><dir name="shipping_method"><file name="additional.phtml" hash="cc1af94a4a57113165cc011f424cb574"/><file name="available.phtml" hash="f409ce94cd1958ab53ec45883869dfd5"/></dir><file name="shipping_method.phtml" hash="23304175b52b98d396c45118bcab359f"/></dir><file name="onepage.phtml" hash="b01aa8ccbd44412d9ff311053be4dcee"/><file name="success.phtml" hash="54532084f1ca5254cdbde78ff59e2f8b"/><dir name="total"><file name="default.phtml" hash="11a5b62ed106db4aa77787581139d0e2"/><file name="nominal.phtml" hash="76954822adebe842f7a104f3a9b62c50"/><file name="tax.phtml" hash="d4c20b40f89fae2c062073cf77e177a1"/></dir></dir><dir name="cms"><file name="content.phtml" hash="0f2efd3647a9319dbe0b17f6642d132b"/><file name="content_heading.phtml" hash="2726376d588d681b6cd02d4d58057fb3"/><dir name="default"><file name="home.phtml" hash="2b57f402d6ca4b4b54c993145bd44521"/><file name="no-route.phtml" hash="2983ed00d24504860951a2eb6ce7050f"/></dir><file name="meta.phtml" hash="061437b39a71a620f5d8dfcd2d87ae48"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="82b815707a48370c6690e74e67fe4a6c"/><file name="link_inline.phtml" hash="3abf5400edfc202f744059eacf62e0ce"/></dir><dir name="static_block"><file name="default.phtml" hash="2fc86aba2c9ef60b71743e47dcfd1d59"/></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="4714b3b5ea1eda3feb0e5ad54b085e72"/></dir><dir name="core"><file name="formkey.phtml" hash="263e41286f028b6dec2947a1a446bf2a"/><file name="link.phtml" hash="e03350191ace122fa9c34063312c6533"/><file name="messages.phtml" hash="bd8667f1ffc239439e6190e9ffc52ef9"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="333ea98610f509bdc359cb303ca70c3e"/><file name="hello.phtml" hash="29ba7a5aa97b26f28a6665b4f8392634"/><file name="info.phtml" hash="b5ee86beb72aa339fd026bc6748349d2"/><file name="newsletter.phtml" hash="5c68dee01a377e4201978d8cf4048916"/></dir><file name="dashboard.phtml" hash="bcb9a7f6f277bf9d85e3cdb8ae3cc9a7"/><dir name="link"><file name="back.phtml" hash="1e0faa823b7711804fd2f50cdc978636"/></dir><file name="navigation.phtml" hash="7e44a6f6764060f0d56f431cc68c2ee3"/></dir><dir name="address"><file name="book.phtml" hash="bbf5537e3faee9e2dfadbae868567520"/><file name="edit.phtml" hash="79b653bb2839ff572f0ebe9bd234031b"/></dir><file name="address.phtml" hash="9349365bab7abce0fe817a3b94155560"/><file name="balance.phtml" hash="94ead5465bce64fc7a692c18fcf680a9"/><dir name="form"><file name="address.phtml" hash="d7fa999f35bc97823a8f84f3ef497427"/><file name="changepassword.phtml" hash="e425ef79f0c97812959b2c608b71b785"/><file name="confirmation.phtml" hash="6e6a828f0ad7d3a5e3445c58ab3a52de"/><file name="edit.phtml" hash="f1fd6e9aed48d95c66a31e7ca2cf8758"/><file name="forgotpassword.phtml" hash="6de384b06caaa526b5de1f1b68630696"/><file name="login.phtml" hash="d3e0f02c693e80d328c7b60d440bb3dc"/><file name="mini.login.phtml" hash="cdfbbe341600e29628231922773b0af8"/><file name="newsletter.phtml" hash="ceeb846b27b8d3f9297955f656735543"/><file name="register.phtml" hash="d348abc82b9dbc571f113b00d06eaeef"/><file name="resetforgottenpassword.phtml" hash="c010c0765b372fc8c48f540cdf2fbd4a"/></dir><file name="logout.phtml" hash="172f5347d5a023d4334abef1aa3977c6"/><file name="orders.phtml" hash="4c303879cb23f65e9cd0e9bb8b65865d"/><dir name="widget"><file name="dob.phtml" hash="e372ec9d277b7088f8b48896ec08b962"/><file name="gender.phtml" hash="05a1a495e023e3319198353bfd50fc0e"/><file name="name.phtml" hash="ea23821e17d5a1597a2fc1e2555d9a14"/><file name="taxvat.phtml" hash="5c4aa1b4750d65d2c7e74374ddd5202b"/></dir><file name="wishlist.phtml" hash="d44319f1d59bfa6211bf8952424c5aea"/></dir><dir name="directory"><dir name="currency"><file name="switch.phtml" hash="1c0932731812287fb4a0e18e8fc29c3b"/></dir><file name="currency.phtml" hash="3ef16e68def3da63e57a41e6839e1a39"/><dir name="js"><file name="optional_zip_countries.phtml" hash="b0f6c136b0783e63285ba517530f60ce"/></dir></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="links.phtml" hash="1fb175f4fbe1826e4bcd12fe6c6a8980"/><file name="samples.phtml" hash="9e792010ec01db0fd604aa17d2d237e6"/><file name="type.phtml" hash="94ab0f22d76fd27678ce37f645c7b0b7"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="4b77efdabe1268e1ec996bf98f824eb0"/></dir></dir><dir name="multishipping"><dir name="item"><file name="downloadable.phtml" hash="862d25f45190fb92f6a8333a2bad83ce"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="7a964953ef437a72fa32a5fff4fe5cb3"/></dir></dir><file name="success.phtml" hash="71222f7927a32e2e9c0c070e00c90c73"/></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="10c18a118ab581ffc7dbd4f933cfbf7d"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="8705f11767570de48d6c16012a92817b"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="e797c59867ae63bd075181ccd94841a4"/></dir><dir name="order"><file name="downloadable.phtml" hash="e50b2cd8bd961025158da7cd2da42d0e"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="88755e0b50f6228ec22cdd09b1f8bc6e"/></dir></dir></dir><dir name="invoice"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="2f2e6ad8ac5d978294209486352e353d"/></dir></dir></dir><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="4b0868954102488e967d021f5acda87a"/></dir></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="bf74b493051105c3e282e06a50d7a2ed"/></dir><dir name="invoice"><file name="items.phtml" hash="8ee940f84f087f750afc4b80ef957d8a"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="invoice"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="order"><file name="default.phtml" hash="958a64e81514aecccc097e3e8552aba1"/></dir><dir name="shipment"><file name="default.phtml" hash="9715115d536ad893920c6f622ce70a55"/></dir></dir><file name="items.phtml" hash="dee5bcb1bc9cdac1919418d8a34d7412"/><dir name="shipment"><file name="items.phtml" hash="ee1f86874c4229314da7a220118529b9"/><file name="track.phtml" hash="13512e2e87b8fc119bbd837bfafe4b52"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="e9933387271aa3e59b8016c8ff9f269e"/><file name="stock.phtml" hash="9fa439a220bb26cab1245424a08fa7ab"/></dir></dir><dir name="giftmessage"><file name="inline.phtml" hash="b20d3bd8564ce077895d1764ba01a592"/></dir><dir name="googleanalytics"><file name="ga.phtml" hash="ce5cf1c86947107320e017cab90de120"/></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4cb081a98d6976c9609b143dded5ebcb"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="4e92348c8c54671c5bc76850bced0fbb"/><file name="button.phtml" hash="e3f4c8d69e0c017d129d93856095d865"/><file name="confirm-simple.phtml" hash="96f18bcb396a06899d067aea4cd63c28"/><file name="confirm.phtml" hash="80fe79fb81267d1c28f105f162b9a1cd"/><dir name="form"><file name="login-simple.phtml" hash="781d9df03ec9f1a5b2cc591317234ef9"/><file name="login.phtml" hash="46e9874b2d4be3fa27a6d74d8a420ea8"/></dir><file name="head-simple.phtml" hash="66437fdd869089b7fb0a860153cd9b2a"/><file name="reject-simple.phtml" hash="d2571e0e80575b9cc53a0e40f9eea1d9"/><file name="reject.phtml" hash="61bb4df718751608c863733ecb5de83a"/></dir><dir name="customer"><dir name="token"><file name="list.phtml" hash="d43d12d9c756d067cae01a0ed1669408"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="2f28b8bc1312b1b11ba7d2f1f2b78a66"/><file name="2columns-left.phtml" hash="0024fe5305585fc0cf4cf7ae80d5838e"/><file name="2columns-right.phtml" hash="75488f0c01877445567482cedb2c6006"/><file name="3columns.phtml" hash="e6a8b6357a1da225a490826eb9cc8827"/><file name="empty.phtml" hash="5aca0a348771071491dd500a558c091f"/><dir name="html"><file name="breadcrumbs.phtml" hash="52cd1f3a07db32ce024a3116d617e273"/><file name="cookienotice.phtml" hash="0428982e6c5a266ec20eca5f2d2035d2"/><file name="footer.phtml" hash="0d97b569b6915b4be53b6c6724d5d7b1"/><file name="head.phtml" hash="85bcd92a83e87f598cb4c7d15867b3e0"/><file name="header.phtml" hash="f19b0f01d5677952f508ac93e4098d8e"/><file name="notices.phtml" hash="9b7c04f5a19179d38a211e5dba5e3910"/><file name="pager.phtml" hash="1a2ca93836f4b551bf2dd05cee7edd7b"/><file name="top.links.phtml" hash="433dec7d3cccaaf8703ceb829545505e"/><file name="topmenu.phtml" hash="d03d5c9c89a7f8ce75d6e5d8c00848fa"/><file name="wrapper.phtml" hash="d70ba3d18317da939220eeb6378b8b9d"/></dir><dir name="js"><file name="calendar.phtml" hash="079523259fc194567d43e7aa27489cd2"/><file name="cookie.phtml" hash="a77c76484cb5872fecebda2602a37fe5"/></dir><file name="popup.phtml" hash="4306400c2744bc9eb7af3b1a83f89b50"/><file name="print.phtml" hash="a4c90428aacb75ada2d139b4e7a88fff"/><file name="redirect.phtml" hash="5a0a5d49735977c2c7f8cc0520e0f2e0"/><dir name="switch"><file name="flags.phtml" hash="3773969d016ca51cb38430f9e0ba68b3"/><file name="languages.phtml" hash="6fd9c35bbae31f38c7c55361371d44c0"/><file name="stores.phtml" hash="25a9c815893021fcc60dcaa75c779407"/></dir><dir name="template"><file name="container.phtml" hash="d345b0dac282eaf0bcf5f536d6755dc3"/><file name="links.phtml" hash="234bd8290e8c7ef4dab851a8d0c4c1f7"/><file name="linksblock.phtml" hash="969adc4a616d8df917ff14d4eb13b892"/></dir></dir><dir name="pagecache"><file name="cookie.phtml" hash="035507d94de53497b159469e55ee78f3"/></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="84192eecd8722839916f93ae90829564"/></dir><dir name="info"><file name="cc.phtml" hash="9a2f8d4396e1f578518ada1bda138f59"/></dir></dir><dir name="payment"><dir name="catalog"><dir name="product"><dir name="view"><dir name="profile"><file name="options.phtml" hash="d3dcef75cedeeef895b9f04de11b5a9a"/><file name="schedule.phtml" hash="2d85bb574937a22e66f47614261e7bb2"/></dir></dir></dir></dir><dir name="form"><file name="banktransfer.phtml" hash="0fda9a3b383e988ab6ced55acf987aff"/><file name="cashondelivery.phtml" hash="3e746cfdcbd77990765f7c80ca43f1f6"/><file name="cc.phtml" hash="26c3112455ecbbb1052b993047ff5e52"/><file name="ccsave.phtml" hash="20c0c2c4ec5be56b1799e964d573e45a"/><file name="checkmo.phtml" hash="2ac027643d66cc553a6927b79cea3dff"/><file name="purchaseorder.phtml" hash="b95359c73d4c2d81c16da09e78e227a9"/></dir><dir name="info"><file name="banktransfer.phtml" hash="6614593500cde5800dbd3842a3c7d6b1"/><file name="checkmo.phtml" hash="5e7604185b017eb617cb1eabf627d78f"/><file name="default.phtml" hash="e75249dc084ebd439de93fd9a953c6ee"/><file name="purchaseorder.phtml" hash="d51db6b3bc18bace55bd9ab7deddb5ad"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="662bf3cbce3dcae68832bc9074c3195d"/><dir name="express"><dir name="review"><file name="details.phtml" hash="7b2f9803b98ac6f9977ac46c30a056b0"/><dir name="shipping"><file name="method.phtml" hash="76b33e8c603b7bbf473a0abd33d2b50c"/></dir></dir><file name="review.phtml" hash="8d3751d9ee6ac6db76c978f2116c78f2"/><file name="shortcut.phtml" hash="718cea497013c53b26a2751d48e3d366"/></dir><dir name="hss"><file name="form.phtml" hash="9757d18296d999b5f5d34fa71f44a3ff"/><file name="iframe.phtml" hash="7517f586ac595f3ba52b92075298a71c"/><file name="info.phtml" hash="d00f850302d1eaaccacc297504b4ec8b"/><file name="js.phtml" hash="26a2aeeda31c99bf6b193e74fbd9e947"/><file name="redirect.phtml" hash="c7e6e7db49037161f51ef2df05e84813"/><dir name="review"><file name="button.phtml" hash="b2b1512b59d6870274a6e73389c831ca"/></dir></dir><dir name="partner"><file name="logo.phtml" hash="61ea270c13e8a38f9f42d79c5e185050"/><file name="us_logo.phtml" hash="7be14fa277b2ef84b2e5e152065f4e97"/></dir><dir name="payflowadvanced"><file name="iframe.phtml" hash="36abe5417ed7365ade7f54f2fb4d247b"/><file name="info.phtml" hash="d2c950064b208f2e03c731a3075a758f"/><file name="redirect.phtml" hash="92de41b8668ef48fe42a4c4665ae7f8b"/></dir><dir name="payflowlink"><file name="iframe.phtml" hash="9b9d0dfa78662761224ae3864e1539c0"/><file name="info.phtml" hash="8543012e16288427d8bd1de4538f467e"/><file name="redirect.phtml" hash="3cdc6f86f7a276766ff88a35bc04ab6a"/></dir><dir name="payment"><file name="mark.phtml" hash="201878accb60de622de7d468a2c510c6"/><file name="redirect.phtml" hash="19ac3d145545dd3c6db5f768db272574"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="6f03626c2f5d45f234110070a13510fe"/><file name="login.phtml" hash="330d57a2225b9debac9cc5c1be6149de"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="1dba15f3adf7043f6f9fdc51c126c049"/><file name="register.phtml" hash="131701dde1353b2e156fc066c91996bb"/></dir></dir><file name="remember_me.phtml" hash="15f59793748c3e36ddc5b0f16509466b"/><file name="remember_me_tooltip.phtml" hash="8bd2b026e64d4786d53d3a77d9d7fc79"/></dir><dir name="poll"><file name="active.phtml" hash="60079807bb8714bfb0e0ca521e6aec5d"/><file name="result.phtml" hash="15bbe5e8c12747db4f4ef50c896001fd"/></dir><dir name="productalert"><file name="price.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/><dir name="product"><file name="view.phtml" hash="b3ce17535d2f2e83066935b961702b9a"/></dir><file name="stock.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/></dir><dir name="rating"><file name="detailed.phtml" hash="b66b269ba801555012062fd02d001a33"/><file name="empty.phtml" hash="6aa7cab7575d4edc00a3285df5dab5c2"/></dir><dir name="reports"><file name="home_product_compared.phtml" hash="8cfa1979d8192d1a45312710de87d7be"/><file name="home_product_viewed.phtml" hash="6c58c4e73cfef7b83583feeb602b9e26"/><file name="product_compared.phtml" hash="47370bb002b5c02d1d4450ad1caeb1d7"/><file name="product_viewed.phtml" hash="d52c81400b12ee44a435dfe5fb394b25"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="819711aca802f1d53a13c4537cb94c63"/><file name="compared_images_list.phtml" hash="2087786b92aa18dd722a6ad90f2e6eda"/><file name="compared_names_list.phtml" hash="0243a47a11b4c096fdeebccbfd235b27"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fc2cd5910b11ac5080e2672f8461dcea"/><file name="compared_list.phtml" hash="7863917524e8fb63b8d7724fd73e3e73"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="a111917f600af1d54dd52710d65086b2"/><file name="viewed_images_list.phtml" hash="229134e29a14e2add151ba73ecf5ccd3"/><file name="viewed_names_list.phtml" hash="73e1ad6c721e2b0ddfb45ec0f250ecda"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="0b9293c8169bf230785d09042381eea0"/><file name="viewed_list.phtml" hash="14a998690bb5f37c44ad7543ff524b03"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="list.phtml" hash="21a0b2f11c06bf8a0e0af918a36486ec"/><file name="recent.phtml" hash="4c7eb30f707e02ed19ebfd0e48b59d92"/><file name="view.phtml" hash="7fc63fc197b7f69255ee6dd7176c1309"/></dir><file name="form.phtml" hash="19504d5f6405e47775eb821653e584fd"/><dir name="helper"><file name="summary.phtml" hash="8af5150b4c2c147bde4a06436e297b68"/><file name="summary_short.phtml" hash="2cbc486cb472266f3139a5cd281d8d4e"/></dir><dir name="product"><dir name="view"><file name="count.phtml" hash="09dcc9c9e9dc860f7f94415f6632d405"/><file name="list.phtml" hash="db87f4af149979c0c2b6211b94951b3b"/><file name="other.phtml" hash="454e2d215bc06773e73137623ad69a03"/></dir></dir><file name="view.phtml" hash="9071f84c610db079a9ca1470c250106f"/></dir><dir name="rss"><file name="list.phtml" hash="38fa9c4fb95737eeaa00fd0489411401"/><file name="nofeed.phtml" hash="92e1a1121f0608ed8438a89346f335d3"/><dir name="order"><file name="details.phtml" hash="30700dffcdc96558e89ae4f4ac5d062b"/></dir></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="ca55c7d479961dd005c0d839e2646e05"/></dir><file name="agreements.phtml" hash="ee98549f1b7e1fb42afa537ba8de8818"/></dir><dir name="guest"><file name="form.phtml" hash="509b6ba571fc7aff64565379ffd542ad"/></dir><dir name="order"><file name="comments.phtml" hash="cdc875ed3a37727d5cc403c342eab1bb"/><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="83eacbdf4dd635e5f9c94dbd97cf6793"/></dir></dir><file name="items.phtml" hash="7c9205260c4f0c8e16d3192b97033715"/></dir><file name="creditmemo.phtml" hash="082f3e41013326307878edefae9f12fa"/><file name="details.phtml" hash="427260fa04f2f412197fa4ab30949c07"/><file name="history.phtml" hash="081e7f1104707953c5a4ac5ebd901b09"/><dir name="info"><file name="buttons.phtml" hash="f4396a7de6170b8d920859ffb8e9a259"/></dir><file name="info.phtml" hash="6c44ca5d08b0dff46a0429fe92e7f057"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="61bac326041daebb7781db3a33d2223e"/></dir></dir><file name="items.phtml" hash="b76c99d2ef43a028b16a334a42a79b15"/></dir><file name="invoice.phtml" hash="d9f96a0911418669b76d7a579de0f45a"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="552e7453d0da2449f3720aaf18e768ba"/></dir></dir><file name="items.phtml" hash="531cdacc2b7b99f7e74978d83e6f9c99"/><dir name="print"><file name="creditmemo.phtml" hash="bea90d3be8eaa01131eda35dec526192"/><file name="invoice.phtml" hash="6631161daf44f42e5876f85a35882b1b"/><file name="shipment.phtml" hash="87ec2797d4fb4e965ed2b3c12fdcb747"/></dir><file name="print.phtml" hash="67b90f2d6512c83b44b16d1eb75685b6"/><file name="recent.phtml" hash="ea339a8cea8f1dfda8a9e6dc22f68e73"/><dir name="shipment"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="081db6648f65fd6b0fb34abd7fa16441"/></dir></dir><file name="items.phtml" hash="d64f6bb38b064d6b111482a99594d158"/></dir><file name="shipment.phtml" hash="8e56ba664cd9cdc01bf19f4dd6b0b783"/><file name="totals.phtml" hash="9ac8837db67bcd5a49197b5a00720df5"/><file name="trackinginfo.phtml" hash="d0eb20dd14a19d1185c5d61a67ebfb3e"/><file name="view.phtml" hash="580d296f4fd1c049cc061852d6f122a2"/></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="2006888669e168052d61ec198f38ee6b"/></dir></dir></dir><dir name="recurring"><file name="grid.phtml" hash="58261dc0e83512ffff4d5b076317b1f8"/><dir name="profile"><dir name="view"><file name="info.phtml" hash="614ba6f33d50ef89026b9cee0e0c30bd"/></dir><file name="view.phtml" hash="34a224e0cfec4e5716f0f86fe12fb0e7"/></dir><file name="profiles.phtml" hash="e91a9c209303c1702dae8ed09604e76d"/></dir><dir name="reorder"><file name="sidebar.phtml" hash="bf0a4c9ea18df3377d83b4273cde7149"/></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="38e6e2aff228a2aad3b0437e61bb5522"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="f0a055a14b97e0e6b4d38e310021a5b3"/></dir><dir name="shipping"><dir name="tracking"><file name="ajax.phtml" hash="e3b41fd33ba626ae7b9bfb7f23c07e93"/><file name="popup.phtml" hash="131eafbe3bb46b4ed6af3f6aff33a6b4"/></dir></dir><dir name="tag"><file name="cloud.phtml" hash="62c7ffab99fec479b343b21fea0fde3b"/><dir name="customer"><file name="recent.phtml" hash="8050f20856a9785fc37d0d6c5379020a"/><file name="tags.phtml" hash="e2a84aef98e491e2b36071757249a3d5"/><file name="view.phtml" hash="db81e635e46ef0cc5170ca0c64ff07d9"/></dir><file name="list.phtml" hash="dca4ad345072f43496e9870582b490f1"/><file name="popular.phtml" hash="093fad41b8786721d484400ab9bc8557"/></dir><dir name="tax"><dir name="checkout"><file name="discount.phtml" hash="168322a5454576d07c7597ffe24164db"/><file name="grandtotal.phtml" hash="153eeee2fc47d7d9b89cef439c676d23"/><file name="shipping.phtml" hash="f54b101deb4b0245a166ccdac5dd43f1"/><file name="subtotal.phtml" hash="1457075b05ef9d9bdfcad36095af71bc"/><file name="tax.phtml" hash="06f54cf61021e9e6e9495cab97c22bc0"/></dir><dir name="order"><file name="tax.phtml" hash="06c5f3b434b69e766bc508b5c527bda0"/></dir></dir><dir name="wishlist"><dir name="button"><file name="share.phtml" hash="335c1ca165cb0dd3789f64ea036096a8"/><file name="tocart.phtml" hash="68cc0db51b5a5c44fa477f049d85b970"/><file name="update.phtml" hash="0cbff9376749be9f6e8779b59a17e4d5"/></dir><dir name="email"><file name="items.phtml" hash="29344b6abfa99373e582db5a00fb5966"/><file name="rss.phtml" hash="f6df3dcfdb66431aff62d364c36f6467"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="39d152a5424161fbbb1e08d69e3955b2"/><file name="image.phtml" hash="c2fa04784d650dbe8663bde989ea206b"/><file name="info.phtml" hash="276b4e69a507fd4ec5b9a9980eac61d1"/><file name="remove.phtml" hash="09bc779e5db907482a09ec7fd6b95aa9"/></dir><dir name="configure"><file name="addto.phtml" hash="1e2c74806897a11bcbdc29dec4a34a30"/></dir><file name="list.phtml" hash="c6c3b95119f22f2a5fcf6599d2f468fa"/></dir><file name="options_list.phtml" hash="29585958c2328f45c62fad5192b83276"/><dir name="render"><dir name="item"><file name="price.phtml" hash="027e4f748e6039217b32de1455bf8a97"/><file name="price_msrp_item.phtml" hash="9ea3988c02dd93121dfcd12179d5c9d0"/><file name="price_msrp_rss.phtml" hash="59057882123117bea1169d3bac674164"/></dir></dir><file name="shared.phtml" hash="ce133ff86ad7ccbb5f380dbf36367a79"/><file name="sharing.phtml" hash="234fc41c319bcb050d32804cff0baebc"/><file name="sidebar.phtml" hash="3c91d09df73be7dd00a307fdb74ae4be"/><file name="view.phtml" hash="41ff38bf278e110732b4b05a5deb8328"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="css"><file name="email-inline.css" hash="72d47d85352353f347dd2b0f8c0104ac"/><file name="email-non-inline.css" hash="e889edd400833a1b5841b26a0a4b61eb"/><file name="widgets.css" hash="c1f91d1c4f18176ad2e95c8f79b1b435"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><dir name="cookies"><file name="firefox.png" hash="425e1b2ddc38c0bba431fb54357c66a4"/><file name="ie6-1.gif" hash="5c27700e245762bc89ed8c3ee7183f21"/><file name="ie6-2.gif" hash="d8c55e15e1f711e5c259300a9c19551b"/><file name="ie7-1.gif" hash="d61edcc8a514a3c81ea116b7d38ddcb6"/><file name="ie7-2.gif" hash="0526a654e94c54866cad977c0a47d3e5"/><file name="ie7-3.gif" hash="4fb142def3f6cfd8d8d23e1315528a1e"/><file name="ie7-4.gif" hash="575c276231c6a91e28935ec98215e146"/><file name="ie7-5.gif" hash="3ae5fcc11fe89da91674d183872337c1"/><file name="ie7-6.gif" hash="95a4981a41785a8cde273c9b2edbfbc7"/><file name="opera.png" hash="34070d92180d4ee0e37b1dd8bb731cd7"/></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><dir name="widgets"><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_widget-link.gif" hash="1bf753578171f147f0203e7b13bdd0c4"/><file name="i_widget-new.gif" hash="a75377ffed51b711cbc608ffaa1a2e7d"/></dir><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/></dir><dir name="js"><file name="bundle.js" hash="2f2bf27d13a85d6ebc665880c9dfb05c"/><dir name="checkout"><file name="review.js" hash="5582b2d213070aa9ad488f9e69516574"/></dir><file name="giftmessage.js" hash="57f753b9e257228017a835b899d4979f"/><file name="ie6.js" hash="c6c7baa57cdad02f56d6e72945fcebdd"/><file name="msrp.js" hash="72e4385e32df5e2c07ab56f40bcfce76"/><file name="opcheckout.js" hash="60ed6e7c4c6d5f01a7b8447931fdc875"/></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="cdb89dfeea9f6bb9c87e1abd1d8660f5"/></dir></dir></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Default-1.9.4.0.xml b/var/package/Interface_Frontend_Default-1.9.4.0.xml
deleted file mode 100644
index 9db24e1..0000000
--- a/var/package/Interface_Frontend_Default-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Default</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Frontend</summary>
-    <description>Default interface for Frontend</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="2b8a8e5c60e4784255103ef960654b5c"/><file name="widget.xml" hash="b67cab283e77190dc897087a6bdfd33e"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="793e1ff86039f24caff6fad87a094fa1"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="default"><dir name="default"><dir name="css"><file name="oauth-simple.css" hash="16e8d5c0e09ea21fffc8441fc9f4cf0a"/><file name="print.css" hash="ed25669784811928c0c181045b88d271"/><file name="styles-ie.css" hash="233d06a6b6f356ddc90fee396d407edf"/><file name="styles.css" hash="3e3d61b127b7b6df60d4c5c89eb04370"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="best_selling_tr_even_bg.gif" hash="5022d648379090e306f00cd64738b146"/><file name="best_selling_tr_odd_bg.gif" hash="926622704f53796801bb5d097e116c8e"/><file name="bkg_account_box.gif" hash="dd98174b6e3e5605a3f9551a59c66841"/><file name="bkg_block-actions.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_block-currency.gif" hash="bfaad1b64557c05ad6f4b124ad3d3532"/><file name="bkg_block-layered-dd.gif" hash="6ae6f8184e87de496fb74eeec65737c9"/><file name="bkg_block-layered-dt.gif" hash="ba8229068657b80f2c42111c5a1a307e"/><file name="bkg_block-layered-label.gif" hash="14687dfa3921cfd12d2149c1497d9765"/><file name="bkg_block-layered-li.gif" hash="753ebb76a4fc2b5b6915c536fcf4d487"/><file name="bkg_block-layered-title.gif" hash="c92e29b30af7abf4e0bc3f714a246f55"/><file name="bkg_block-layered1.gif" hash="607167f198572e83a0e728b6b9383a70"/><file name="bkg_block-title-account.gif" hash="a64f1df5a7e3d0f6a58b017f74311cb1"/><file name="bkg_block-title.gif" hash="f8c1f130ad69464fe7aff2f589b2ec75"/><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_buttons-set1.gif" hash="2c641e927bc83156b7004ea37920513c"/><file name="bkg_checkout.gif" hash="11258fe49feff5513c9608f2ea486776"/><file name="bkg_collapse-gm.gif" hash="37418f23e65006dcfde07ce9b249e057"/><file name="bkg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bkg_divider1.gif" hash="260ebae91ffb1b7c663906b29a069925"/><file name="bkg_form-search.gif" hash="2ca36eb80ea705e063409153f3821f78"/><file name="bkg_grand-total.gif" hash="10f1c3d82d78170706fa3e9c4baa7e04"/><file name="bkg_grid.gif" hash="a6f64fedbac51fb1b86184cd488cc4e6"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_login-box.gif" hash="5538675d7f1c35d96a2b8013948f42a6"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="bkg_nav0.jpg" hash="f9ac3f31e293cf075471d2d3fe07353a"/><file name="bkg_nav1.gif" hash="f4e26840c8cca0e74aba5b810341c5c0"/><file name="bkg_nav2.gif" hash="a64c8f5165b239e432d26a62ae5f79b6"/><file name="bkg_opc-title-off.gif" hash="f69b40b5331ab3760f54d038daf287eb"/><file name="bkg_pipe1.gif" hash="7852290f6a443000ead96b8cec5cd7c7"/><file name="bkg_pipe2.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="bkg_pipe3.gif" hash="11bfac1e590f0c77fb12f37d7f05cd3c"/><file name="bkg_product-view.gif" hash="7078a7f2827156d5ae0a1cb59da3c418"/><file name="bkg_product_collateral.gif" hash="1d4d6b22e5108aefae52709d3934f397"/><file name="bkg_rating.gif" hash="0a8777c815350ddf1e316a537ad0c335"/><file name="bkg_sp-methods.gif" hash="17d68b5449adaa87dafc62ae0afa1b9a"/><file name="bkg_tfoot.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_th-v.gif" hash="b0d17555dfc6060941e0c067718189df"/><file name="bkg_th.gif" hash="f249911b08f2822fc0b561b7f98575d2"/><file name="bkg_toolbar.gif" hash="fb7ed019476eaa1643af922b59ede4fb"/><file name="btn_checkout.gif" hash="d2060501e14e86c29e28137130e5726e"/><file name="btn_edit.gif" hash="df3565eb4e4d0dc578201df60de54b47"/><file name="btn_gm-close.gif" hash="346e26eece27449a2f224aef76ae372e"/><file name="btn_google_checkout.gif" hash="843d75249ce05b5d87ca5419f37b1c3b"/><file name="btn_paypal_checkout.gif" hash="6edd61270b7b5632eafad10557129114"/><file name="btn_place_order.gif" hash="d35219f86ae2c983ee1a31557e37b612"/><file name="btn_previous.gif" hash="63473a1520a73bb0c9b47b685d17cd21"/><file name="btn_proceed_to_checkout.gif" hash="4daac687b514fecfd1068539500ac3d7"/><file name="btn_proceed_to_checkout_dis.gif" hash="9e152c01d5d88f690dc52cb62428f3b6"/><file name="btn_remove.gif" hash="6182e723aa2a253dc6cf334a3dfaaa84"/><file name="btn_remove2.gif" hash="234bddc4c5878c5ef16407a944824236"/><file name="btn_search.gif" hash="2d93b43c0a1c1182358677661e26a978"/><file name="btn_trash.gif" hash="bcb22f558a0eb32243a2a36645189e9f"/><file name="btn_window_close.gif" hash="c83f3cbbb2aedfc580dff78d5cfb63ed"/><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="cvv.jpg" hash="e27210d810bbab732935d9410936ef87"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="free_shipping_callout.jpg" hash="cbf2e494ef7ca50acf8826321d739559"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="home_left_callout.jpg" hash="ee99a5586cf52e85c986d1275958a7da"/><file name="home_main_callout.jpg" hash="e6d1c119d5b24a5916fe394cb4b5cdc3"/><file name="i_arrow-top.gif" hash="3dbb0584e8eb1d96cc3d3c40c17d7aaf"/><file name="i_asc_arrow.gif" hash="40aa554212d6a1f60593c27d78d85fa3"/><file name="i_availability_only.gif" hash="bca1f00a50864171ad98317b778e869c"/><file name="i_availability_only_arrow.gif" hash="0cf32b72fefc94b89b74e4f3f02c2e93"/><file name="i_block-cart.gif" hash="cc19e21f9c89b70cc10354ff588ca8ab"/><file name="i_block-currency.gif" hash="643024bcae5ece554fdbbc041aeb297c"/><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_block-poll.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="i_block-related.gif" hash="4e277173b6372b1a90b0f19e0388ad54"/><file name="i_block-subscribe.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="i_block-tags.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-viewed.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-wishlist.gif" hash="8f8cda89ca20ba4a9b2f8c91f73fdff9"/><file name="i_desc_arrow.gif" hash="92fd194bfae4ce5ae3354e1e47d7ac7d"/><file name="i_discount.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="i_folder-table.gif" hash="bf006ddb591d8ac95d2e895bf2fdbc8d"/><file name="i_ma-info.gif" hash="91259557447ee80eb1110fe0c85cb3b5"/><file name="i_ma-reviews.gif" hash="859c97695ec396c0b284a0c3c7c416ad"/><file name="i_ma-tags.gif" hash="1e83e3b0b677c92b3aa8a252268f7b86"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_page1.gif" hash="704f7d4eccbdf9cabbad7770f18856ff"/><file name="i_page2.gif" hash="57a04ca584e05e28dc94c7e68f0af62e"/><file name="i_pager-next.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="i_pager-prev.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="i_print.gif" hash="0aed138181495642e9ab29e55d194d40"/><file name="i_rss-big.png" hash="6cf70e7c52a3f3d7b833ccadb041a555"/><file name="i_rss.gif" hash="e5bbc388d818c142868b4a1df0b48793"/><file name="i_search_criteria.gif" hash="cf67b9cc5c311ae3f99e68cd29ae17be"/><file name="i_shipping.gif" hash="91a0d2cc2eb2391f90ec8a75c04b3183"/><file name="i_tag_add.gif" hash="a736baa992aa55b6fb71e8742a04dc82"/><file name="i_tier.gif" hash="c5189e25afeb7c1a8c4902a42832593e"/><file name="i_type_grid.gif" hash="a1e5d8ac36fb2891ea16e729b95c552c"/><file name="i_type_list.gif" hash="61333d383ec142b8d270abe77324aa5d"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="logo_email.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="logo_print.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="magnifier_handle.gif" hash="238fbdd7959f517db11c6f57ee4daaf4"/><file name="map_popup_arrow.gif" hash="6383b40a9e7bd3c95260bef4fbb1b163"/><dir name="media"><file name="404_callout1.jpg" hash="834e53a03e2921a2fd3c135c0c7189df"/><file name="404_callout2.jpg" hash="016984b4a1579df34147f9407098db73"/><file name="about_us_img.jpg" hash="726f36dd75b5a709a1a14acab1660188"/><file name="best_selling_img01.jpg" hash="5e7337a4061a636df8ee4bf979a092ac"/><file name="best_selling_img02.jpg" hash="b9a49c0964938ec72fb834cb166b9352"/><file name="best_selling_img03.jpg" hash="e3581487fb4589baecc553f2ce8d5247"/><file name="best_selling_img04.jpg" hash="7e59bf99f5f813e327595c52d3320174"/><file name="best_selling_img05.jpg" hash="e396892daec7ffcf7244082b3e596911"/><file name="best_selling_img06.jpg" hash="2702839637efbe0fd0a4bad41cd6a551"/><file name="cell_phone_landing_banner1.jpg" hash="b25562360fc470f1091ca7ea014a3290"/><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="electronics_cellphones.jpg" hash="8f6badbc32ce806c6109c788df6ef5e9"/><file name="electronics_digitalcameras.jpg" hash="953b8d7db6f0bdcd53b1d6b1386962b9"/><file name="electronics_laptops.jpg" hash="e050e92d72000e6bdc763a7b5888ec8a"/><file name="furniture_callout_spot.jpg" hash="28edc7d72486ab2362324995550d87af"/><file name="furnitures_bed_room.jpg" hash="b8616c5bffc23a92d2a1c97dae57b262"/><file name="furnitures_living_room.jpg" hash="2663737f3997cb1a49ce24d07dc8aefb"/><file name="head_electronics_cellphones.gif" hash="a69425966444ea597fb7c629114d5165"/><file name="head_electronics_digicamera.gif" hash="bde3cec3fc16b2d0ae57e7783eb00652"/><file name="head_electronics_laptops.gif" hash="b2c55387ffa92277315bdedeb4cb9b8f"/><file name="laptop_callout_mid1.jpg" hash="4ffb50bd3b7b32a78fd059b1571c202e"/><file name="laptop_callout_mid2.jpg" hash="662cf3881b06b090e9500496b19b03e4"/><file name="laptop_callout_mid3.jpg" hash="22aa71ecfe0aa9b6936a1eddb62d889e"/><file name="laptop_callout_spot.jpg" hash="2e469d1bd871355eaef6076487a973db"/><file name="shirts_landing_banner1.jpg" hash="4acc8620b009d835e5c25587671ea25d"/></dir><file name="np_cart_thumb.gif" hash="e9fdd943e0947e15f0638506f477e358"/><file name="np_more_img.gif" hash="ace357bfe3e81ffb62137cd5b25ae5e1"/><file name="np_product_main.gif" hash="d0cccda76de50efa025215ce85dacb1c"/><file name="np_thumb.gif" hash="e46270c89358ecc8341d1565c14644b8"/><file name="np_thumb2.gif" hash="8502866cdabc5c74aca7d7bd32a06a03"/><file name="opc-ajax-loader.gif" hash="e805ea7eca1f34c75ba0f93780d32d38"/><file name="pager_arrow_left.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="pager_arrow_right.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="ph_callout_left_rebel.jpg" hash="0ce8ad0026d8b8a83ed7acdf6209129b"/><file name="ph_callout_left_top.gif" hash="f17a036d75e5065eb76bafbb2c8ad7ff"/><file name="product_zoom_overlay_magnif.gif" hash="83834893e162221d6d9257fe67847370"/><file name="slider_bg.gif" hash="87bc1b46d87de4f6252c7216216627c3"/><file name="slider_btn_zoom_in.gif" hash="ef0fc67f77f30827ee67f4e744b60781"/><file name="slider_btn_zoom_out.gif" hash="68b3d1c28dc5aec4f6b64d70a6996b6f"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/><dir name="xmlconnect"><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Default-1.9.4.1.xml
new file mode 100644
index 0000000..b1dfe7f
--- /dev/null
+++ b/var/package/Interface_Frontend_Default-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Default</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Frontend</summary>
+    <description>Default interface for Frontend</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:41</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/><file name="widget.xml" hash="7770e002017593cf180f6f7cdff4fb61"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="793e1ff86039f24caff6fad87a094fa1"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="default"><dir name="default"><dir name="css"><file name="oauth-simple.css" hash="8ffcc427e25d192ed04fdb70a344ac2a"/><file name="print.css" hash="d07ecb64ce91e4eb3e9b14e1e47e4399"/><file name="styles-ie.css" hash="4a2b6232a15bf9e8a65fcd39e94bf5b3"/><file name="styles.css" hash="6f175060983a46cdb217cead35b8cd9f"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="best_selling_tr_even_bg.gif" hash="5022d648379090e306f00cd64738b146"/><file name="best_selling_tr_odd_bg.gif" hash="926622704f53796801bb5d097e116c8e"/><file name="bkg_account_box.gif" hash="dd98174b6e3e5605a3f9551a59c66841"/><file name="bkg_block-actions.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_block-currency.gif" hash="bfaad1b64557c05ad6f4b124ad3d3532"/><file name="bkg_block-layered-dd.gif" hash="6ae6f8184e87de496fb74eeec65737c9"/><file name="bkg_block-layered-dt.gif" hash="ba8229068657b80f2c42111c5a1a307e"/><file name="bkg_block-layered-label.gif" hash="14687dfa3921cfd12d2149c1497d9765"/><file name="bkg_block-layered-li.gif" hash="753ebb76a4fc2b5b6915c536fcf4d487"/><file name="bkg_block-layered-title.gif" hash="c92e29b30af7abf4e0bc3f714a246f55"/><file name="bkg_block-layered1.gif" hash="607167f198572e83a0e728b6b9383a70"/><file name="bkg_block-title-account.gif" hash="a64f1df5a7e3d0f6a58b017f74311cb1"/><file name="bkg_block-title.gif" hash="f8c1f130ad69464fe7aff2f589b2ec75"/><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_buttons-set1.gif" hash="2c641e927bc83156b7004ea37920513c"/><file name="bkg_checkout.gif" hash="11258fe49feff5513c9608f2ea486776"/><file name="bkg_collapse-gm.gif" hash="37418f23e65006dcfde07ce9b249e057"/><file name="bkg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bkg_divider1.gif" hash="260ebae91ffb1b7c663906b29a069925"/><file name="bkg_form-search.gif" hash="2ca36eb80ea705e063409153f3821f78"/><file name="bkg_grand-total.gif" hash="10f1c3d82d78170706fa3e9c4baa7e04"/><file name="bkg_grid.gif" hash="a6f64fedbac51fb1b86184cd488cc4e6"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_login-box.gif" hash="5538675d7f1c35d96a2b8013948f42a6"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="bkg_nav0.jpg" hash="f9ac3f31e293cf075471d2d3fe07353a"/><file name="bkg_nav1.gif" hash="f4e26840c8cca0e74aba5b810341c5c0"/><file name="bkg_nav2.gif" hash="a64c8f5165b239e432d26a62ae5f79b6"/><file name="bkg_opc-title-off.gif" hash="f69b40b5331ab3760f54d038daf287eb"/><file name="bkg_pipe1.gif" hash="7852290f6a443000ead96b8cec5cd7c7"/><file name="bkg_pipe2.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="bkg_pipe3.gif" hash="11bfac1e590f0c77fb12f37d7f05cd3c"/><file name="bkg_product-view.gif" hash="7078a7f2827156d5ae0a1cb59da3c418"/><file name="bkg_product_collateral.gif" hash="1d4d6b22e5108aefae52709d3934f397"/><file name="bkg_rating.gif" hash="0a8777c815350ddf1e316a537ad0c335"/><file name="bkg_sp-methods.gif" hash="17d68b5449adaa87dafc62ae0afa1b9a"/><file name="bkg_tfoot.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_th-v.gif" hash="b0d17555dfc6060941e0c067718189df"/><file name="bkg_th.gif" hash="f249911b08f2822fc0b561b7f98575d2"/><file name="bkg_toolbar.gif" hash="fb7ed019476eaa1643af922b59ede4fb"/><file name="btn_checkout.gif" hash="d2060501e14e86c29e28137130e5726e"/><file name="btn_edit.gif" hash="df3565eb4e4d0dc578201df60de54b47"/><file name="btn_gm-close.gif" hash="346e26eece27449a2f224aef76ae372e"/><file name="btn_google_checkout.gif" hash="843d75249ce05b5d87ca5419f37b1c3b"/><file name="btn_paypal_checkout.gif" hash="6edd61270b7b5632eafad10557129114"/><file name="btn_place_order.gif" hash="d35219f86ae2c983ee1a31557e37b612"/><file name="btn_previous.gif" hash="63473a1520a73bb0c9b47b685d17cd21"/><file name="btn_proceed_to_checkout.gif" hash="4daac687b514fecfd1068539500ac3d7"/><file name="btn_proceed_to_checkout_dis.gif" hash="9e152c01d5d88f690dc52cb62428f3b6"/><file name="btn_remove.gif" hash="6182e723aa2a253dc6cf334a3dfaaa84"/><file name="btn_remove2.gif" hash="234bddc4c5878c5ef16407a944824236"/><file name="btn_search.gif" hash="2d93b43c0a1c1182358677661e26a978"/><file name="btn_trash.gif" hash="bcb22f558a0eb32243a2a36645189e9f"/><file name="btn_window_close.gif" hash="c83f3cbbb2aedfc580dff78d5cfb63ed"/><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="cvv.jpg" hash="e27210d810bbab732935d9410936ef87"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="free_shipping_callout.jpg" hash="cbf2e494ef7ca50acf8826321d739559"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="home_left_callout.jpg" hash="ee99a5586cf52e85c986d1275958a7da"/><file name="home_main_callout.jpg" hash="e6d1c119d5b24a5916fe394cb4b5cdc3"/><file name="i_arrow-top.gif" hash="3dbb0584e8eb1d96cc3d3c40c17d7aaf"/><file name="i_asc_arrow.gif" hash="40aa554212d6a1f60593c27d78d85fa3"/><file name="i_availability_only.gif" hash="bca1f00a50864171ad98317b778e869c"/><file name="i_availability_only_arrow.gif" hash="0cf32b72fefc94b89b74e4f3f02c2e93"/><file name="i_block-cart.gif" hash="cc19e21f9c89b70cc10354ff588ca8ab"/><file name="i_block-currency.gif" hash="643024bcae5ece554fdbbc041aeb297c"/><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_block-poll.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="i_block-related.gif" hash="4e277173b6372b1a90b0f19e0388ad54"/><file name="i_block-subscribe.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="i_block-tags.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-viewed.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-wishlist.gif" hash="8f8cda89ca20ba4a9b2f8c91f73fdff9"/><file name="i_desc_arrow.gif" hash="92fd194bfae4ce5ae3354e1e47d7ac7d"/><file name="i_discount.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="i_folder-table.gif" hash="bf006ddb591d8ac95d2e895bf2fdbc8d"/><file name="i_ma-info.gif" hash="91259557447ee80eb1110fe0c85cb3b5"/><file name="i_ma-reviews.gif" hash="859c97695ec396c0b284a0c3c7c416ad"/><file name="i_ma-tags.gif" hash="1e83e3b0b677c92b3aa8a252268f7b86"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_page1.gif" hash="704f7d4eccbdf9cabbad7770f18856ff"/><file name="i_page2.gif" hash="57a04ca584e05e28dc94c7e68f0af62e"/><file name="i_pager-next.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="i_pager-prev.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="i_print.gif" hash="0aed138181495642e9ab29e55d194d40"/><file name="i_rss-big.png" hash="6cf70e7c52a3f3d7b833ccadb041a555"/><file name="i_rss.gif" hash="e5bbc388d818c142868b4a1df0b48793"/><file name="i_search_criteria.gif" hash="cf67b9cc5c311ae3f99e68cd29ae17be"/><file name="i_shipping.gif" hash="91a0d2cc2eb2391f90ec8a75c04b3183"/><file name="i_tag_add.gif" hash="a736baa992aa55b6fb71e8742a04dc82"/><file name="i_tier.gif" hash="c5189e25afeb7c1a8c4902a42832593e"/><file name="i_type_grid.gif" hash="a1e5d8ac36fb2891ea16e729b95c552c"/><file name="i_type_list.gif" hash="61333d383ec142b8d270abe77324aa5d"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="logo_email.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="logo_print.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="magnifier_handle.gif" hash="238fbdd7959f517db11c6f57ee4daaf4"/><file name="map_popup_arrow.gif" hash="6383b40a9e7bd3c95260bef4fbb1b163"/><dir name="media"><file name="404_callout1.jpg" hash="834e53a03e2921a2fd3c135c0c7189df"/><file name="404_callout2.jpg" hash="016984b4a1579df34147f9407098db73"/><file name="about_us_img.jpg" hash="726f36dd75b5a709a1a14acab1660188"/><file name="best_selling_img01.jpg" hash="5e7337a4061a636df8ee4bf979a092ac"/><file name="best_selling_img02.jpg" hash="b9a49c0964938ec72fb834cb166b9352"/><file name="best_selling_img03.jpg" hash="e3581487fb4589baecc553f2ce8d5247"/><file name="best_selling_img04.jpg" hash="7e59bf99f5f813e327595c52d3320174"/><file name="best_selling_img05.jpg" hash="e396892daec7ffcf7244082b3e596911"/><file name="best_selling_img06.jpg" hash="2702839637efbe0fd0a4bad41cd6a551"/><file name="cell_phone_landing_banner1.jpg" hash="b25562360fc470f1091ca7ea014a3290"/><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="electronics_cellphones.jpg" hash="8f6badbc32ce806c6109c788df6ef5e9"/><file name="electronics_digitalcameras.jpg" hash="953b8d7db6f0bdcd53b1d6b1386962b9"/><file name="electronics_laptops.jpg" hash="e050e92d72000e6bdc763a7b5888ec8a"/><file name="furniture_callout_spot.jpg" hash="28edc7d72486ab2362324995550d87af"/><file name="furnitures_bed_room.jpg" hash="b8616c5bffc23a92d2a1c97dae57b262"/><file name="furnitures_living_room.jpg" hash="2663737f3997cb1a49ce24d07dc8aefb"/><file name="head_electronics_cellphones.gif" hash="a69425966444ea597fb7c629114d5165"/><file name="head_electronics_digicamera.gif" hash="bde3cec3fc16b2d0ae57e7783eb00652"/><file name="head_electronics_laptops.gif" hash="b2c55387ffa92277315bdedeb4cb9b8f"/><file name="laptop_callout_mid1.jpg" hash="4ffb50bd3b7b32a78fd059b1571c202e"/><file name="laptop_callout_mid2.jpg" hash="662cf3881b06b090e9500496b19b03e4"/><file name="laptop_callout_mid3.jpg" hash="22aa71ecfe0aa9b6936a1eddb62d889e"/><file name="laptop_callout_spot.jpg" hash="2e469d1bd871355eaef6076487a973db"/><file name="shirts_landing_banner1.jpg" hash="4acc8620b009d835e5c25587671ea25d"/></dir><file name="np_cart_thumb.gif" hash="e9fdd943e0947e15f0638506f477e358"/><file name="np_more_img.gif" hash="ace357bfe3e81ffb62137cd5b25ae5e1"/><file name="np_product_main.gif" hash="d0cccda76de50efa025215ce85dacb1c"/><file name="np_thumb.gif" hash="e46270c89358ecc8341d1565c14644b8"/><file name="np_thumb2.gif" hash="8502866cdabc5c74aca7d7bd32a06a03"/><file name="opc-ajax-loader.gif" hash="e805ea7eca1f34c75ba0f93780d32d38"/><file name="pager_arrow_left.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="pager_arrow_right.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="ph_callout_left_rebel.jpg" hash="0ce8ad0026d8b8a83ed7acdf6209129b"/><file name="ph_callout_left_top.gif" hash="f17a036d75e5065eb76bafbb2c8ad7ff"/><file name="product_zoom_overlay_magnif.gif" hash="83834893e162221d6d9257fe67847370"/><file name="slider_bg.gif" hash="87bc1b46d87de4f6252c7216216627c3"/><file name="slider_btn_zoom_in.gif" hash="ef0fc67f77f30827ee67f4e744b60781"/><file name="slider_btn_zoom_out.gif" hash="68b3d1c28dc5aec4f6b64d70a6996b6f"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/><dir name="xmlconnect"><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Rwd_Default-1.9.4.0.xml b/var/package/Interface_Frontend_Rwd_Default-1.9.4.0.xml
deleted file mode 100644
index cda6c93..0000000
--- a/var/package/Interface_Frontend_Rwd_Default-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Rwd_Default</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This is a RWD themes base</summary>
-    <description>This is a RWD themes base</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="etc"><file name="theme.xml" hash="b2a69156a1174ff2f31b6c58a406aae2"/><file name="widget.xml" hash="bc759364e57df39fe21fee0a8b67b5d5"/></dir><dir name="layout"><file name="bundle.xml" hash="a715eb3119841a5b4d4677bbab24b9fc"/><file name="catalog.xml" hash="2f954db36d01cf64381f5ee1bd3f7ce3"/><file name="catalog_msrp.xml" hash="88989cab2f9e5da358bfc6c5ee4659d2"/><file name="catalogsearch.xml" hash="9a1574f756ad991f560891da5246d0d9"/><file name="checkout.xml" hash="0ab4f0bb734abfedcc2003fb2ad0ca4d"/><file name="cms.xml" hash="17125b1617bde45d80fda64e8c0f5759"/><file name="configurableswatches.xml" hash="0241108f4b79242802c5831a7d0d1b62"/><file name="contacts.xml" hash="5b45ef85df7aa65dca34a26137cb36d8"/><file name="customer.xml" hash="4f9b20ae2fcd5cdc6be819cfb8e5ebf3"/><file name="directory.xml" hash="6abb61f6a2b48b0d484b7f54f83b60a9"/><file name="downloadable.xml" hash="aaf69b45f0de1734b86f2382bf1cafc9"/><file name="newsletter.xml" hash="653ce3bec784a79a742f102298edc7d5"/><file name="oauth.xml" hash="2efda6d5664c7c2dd9ab41c189b62a18"/><file name="page.xml" hash="ede2b40ae0e9ad35a4236850f26b5a09"/><file name="paypal.xml" hash="46861e221b66b4116ad78f605f6ba8de"/><file name="persistent.xml" hash="72804d8e0f27cbdea8e4bf2be789d05f"/><file name="review.xml" hash="8b7203312ad5d2a917d015ca925d483e"/><file name="rss.xml" hash="aa87cf19e7429e782acbbf1150da0092"/><file name="sales.xml" hash="6fac00269851d98c1657fcb96556c43f"/><file name="wishlist.xml" hash="3c0f8e83d2efec2d8a9586d74464d9bd"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="f942e5c7fd83675d53aaaeacfb97c1fa"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="view"><dir name="type"><dir name="bundle"><file name="availability.phtml" hash="d17e41c21cd887181fc36f69697b8f7b"/><dir name="option"><file name="select.phtml" hash="15c9836abe158cb3e749c1f9cf0a42c3"/></dir></dir><file name="bundle.phtml" hash="8e89d8e4084af8424ab74b29cd33f2c4"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="8a3a591e1ad974821dda52bb88887960"/></dir><dir name="invoice"><file name="default.phtml" hash="a23860eafae1159e04c62563315aee22"/></dir><dir name="order"><file name="default.phtml" hash="340b74124298efbf9c2cd78da918c42d"/></dir><dir name="shipment"><file name="default.phtml" hash="07066ce5f4d1fc3207bc404be3b4805d"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><file name="renderer.phtml" hash="edc999ba901b1e1019f17a7f589a70db"/></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="ddc2a17ee6665bef97d4e3df65cdf5ff"/></dir><dir name="catalog"><dir name="layer"><file name="filter.phtml" hash="d7f9d6c377402fe2f4b8884604c81a08"/><file name="state.phtml" hash="e0e6ad4037aaddebdd6262c229c84ee3"/><file name="view.phtml" hash="7633e62b9097d563b7e5935caa69816c"/></dir><dir name="msrp"><file name="popup.phtml" hash="17959ae24c464e15d396dc7718ba41da"/></dir><dir name="navigation"><file name="left.phtml" hash="8147f13c74b194abfa9364e2ccf87bfe"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="23e2ab54e8efb8f40af3044cf139b2c1"/><file name="sidebar.phtml" hash="2f150ddfde326c4491743cb3201dff6d"/></dir><dir name="list"><file name="related.phtml" hash="bfd36eaecca1316fac9093e13f8d57f0"/><file name="toolbar.phtml" hash="4da6f535d64316236f96375079bd3af7"/><file name="upsell.phtml" hash="74383226e851d393877027448b202bbd"/></dir><file name="list.phtml" hash="ca83ecbdd87fc9f95cd55430efdf982a"/><file name="price.phtml" hash="d5e7d023237bc8e28296c9c815b20b25"/><dir name="view"><file name="addto.phtml" hash="d2686089523841c703851af3818511e5"/><file name="addtocart.phtml" hash="a68639819ba009c8e7af9ede6121d5e9"/><file name="media.phtml" hash="e92c39869cc703e530f88a53c4099587"/><file name="sharing.phtml" hash="e62dfe3626003760a7f12b5df1f5b8bf"/><dir name="type"><dir name="availability"><file name="default.phtml" hash="ade2605d9f21591877c86def935c0985"/><file name="grouped.phtml" hash="5141db76a5eccc9f136dd4aca8de4ee5"/></dir><file name="default.phtml" hash="ea05946d1fc0d9b543575a30dac35b98"/><file name="grouped.phtml" hash="c916b8e0eab6092ec4ae1e5eccced5fb"/><dir name="options"><file name="configurable.phtml" hash="773160249a91428474a17a3453a52821"/></dir></dir></dir><file name="view.phtml" hash="b8dca08c44f76055de3622da9ecbad16"/><dir name="widget"><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="28f887be48a2e636097e9abe54712c42"/><file name="new_images_list.phtml" hash="8fcfbe34861cdec02a8cf60131c5f673"/><file name="new_names_list.phtml" hash="ccb2f5d414cd6606654e3f9d59285776"/></dir><dir name="content"><file name="new_grid.phtml" hash="4cc962df6eb72c9d94ced9b80c5c609d"/><file name="new_list.phtml" hash="cd58e2462fa8fea042c160afee292831"/></dir></dir></dir></dir></dir><dir name="cataloginventory"><dir name="stockqty"><file name="composite.phtml" hash="7aed9454ef90de54c19de543a8bbc734"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="cf9d110b5ea7d85e583bc536d708ed38"/></dir><file name="form.mini.phtml" hash="58fc82484aba2a6cdb5169621bf73a7c"/><file name="result.phtml" hash="754d72a8a1acb320ff4a3386c789d293"/></dir><dir name="centinel"><dir name="authentication"><file name="start.phtml" hash="e066c848c47bd193bbd68b4668ce0345"/></dir></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="bdc2b5f413b5e65b114f03c30d0b9775"/><file name="crosssell.phtml" hash="247beab0d3780189ef6c060e0408569d"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="e435c3d45e2dde30dfa6ec32bdbd46b0"/></dir><file name="default.phtml" hash="ea115f2ea1aa442e125ca7016bf78c70"/></dir><dir name="minicart"><file name="default.phtml" hash="6a8baaa5986f3d8e5fbf4b614cfdd1d9"/><file name="items.phtml" hash="8c456416c7343aeb94f49ff186fcaddb"/></dir><file name="minicart.phtml" hash="91813c69b48fa20571bee15aa768a367"/><dir name="render"><file name="default.phtml" hash="5d33795c46ee79589ff3ea39ab257bc7"/><file name="simple.phtml" hash="8107d83abd4fb6b7cf4de3115fe63616"/></dir><file name="shipping.phtml" hash="8b000bacb4504d56de9ca53c5d2cef5d"/><dir name="sidebar"><file name="default.phtml" hash="6df63cb9d11b83b45a021a6bb73c8f1f"/></dir><file name="sidebar.phtml" hash="a1914db11300714fe5ad82ccaaa5dcb0"/></dir><file name="cart.phtml" hash="e9b4f7d92d8e0b43c8e108c64bda073c"/><dir name="multishipping"><file name="addresses.phtml" hash="461240bec3b53a83233c64c9bdd951b8"/><file name="billing.phtml" hash="160f5e12676c6655c70e370d8c68efcd"/><dir name="item"><file name="default.phtml" hash="c25ff8100d7eae2bdea228440bf6a9fc"/></dir><dir name="overview"><file name="item.phtml" hash="d59426451eccfd4fd53d67a2110a7ccb"/></dir><file name="overview.phtml" hash="27619da9d8f12eef488a4b4a666e2190"/></dir><dir name="onepage"><file name="payment.phtml" hash="44ac8e54e1df03410c97ed9bf3a5b274"/><file name="progress.phtml" hash="16b5f8a0b850849fe07f34418d590643"/><dir name="review"><file name="info.phtml" hash="6dda7d2e901658b4f450e51f300d7225"/><file name="item.phtml" hash="a5b7762e95cc8ea6260a5e7f65982dcc"/></dir><file name="shipping.phtml" hash="2ea286244f18151dec311b02b0d679db"/></dir><file name="onepage.phtml" hash="f712dbbc0ad2bfbd730305ce6d93b854"/></dir><dir name="configurableswatches"><dir name="catalog"><dir name="layer"><dir name="filter"><file name="swatches.phtml" hash="e16ca9d33f00e6508d4e906f4c628fa8"/></dir><dir name="state"><file name="swatch.phtml" hash="c1dea9d4ff7aa1031bb02920c8868afe"/></dir></dir><dir name="media"><file name="js.phtml" hash="6d51a736b921ef01e7a54bcb785fd938"/></dir><dir name="product"><dir name="list"><dir name="price"><file name="js.phtml" hash="8a5a13f63349d3da860dd34ad3abae45"/></dir><file name="swatches.phtml" hash="f20fae51f921f3e5aca09f1c31059595"/></dir><dir name="view"><dir name="type"><dir name="configurable"><file name="swatch-js.phtml" hash="e05534e7fa1f9a3e66c225af6c5c912e"/></dir><dir name="options"><dir name="configurable"><file name="swatches.phtml" hash="a023938249dbf26cc6d36147ea2f795c"/></dir></dir></dir></dir></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="281fb727a489a5eaf736e5a3778e396a"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="2feccb593467b669d9b970c27d91731f"/></dir><file name="dashboard.phtml" hash="023a322a491fe0b1612a635f654180c3"/><file name="navigation.phtml" hash="85e45b71f1a96e5253d8f80777505267"/></dir><dir name="address"><file name="edit.phtml" hash="a2ce171a87c482276ac0cf3927c90e05"/></dir><dir name="form"><file name="address.phtml" hash="800d025d15cf24193cdd7edff99250f2"/><file name="changepassword.phtml" hash="43867738c705bff9e55017a34ccbf392"/><file name="confirmation.phtml" hash="da5cbec38f05fdaa8aa90e35a75f483b"/><file name="edit.phtml" hash="446f236638ae0c394525a8c0f22818e5"/><file name="forgotpassword.phtml" hash="0006dd07a38bf902a5e6ce45747e6e73"/><file name="mini.login.phtml" hash="c17a74dccc85e5a80588b7edd9005dc8"/><file name="resetforgottenpassword.phtml" hash="c35070792513e8c3700e37c565c07338"/></dir></dir><dir name="directory"><file name="currency.phtml" hash="e6c82279ce81d014f8d360f2df799c8f"/></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="type.phtml" hash="805a2877587adc919c17625a76899c67"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="4da8e640b1cdfe5173faa63d61116688"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="84bf8341e9c44b29ae6513f5dad110ad"/></dir></dir></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="c175e938d4dbae8eb6ddfdb2d4eec509"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="57583119e35bf464cd3c6f917e21546f"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="b713d9268caa8f0c6f05a8d41e62c3eb"/></dir><dir name="order"><file name="downloadable.phtml" hash="f778e7eba8982bb235d09e2a2488b11d"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="d15d0dea0bd936e3dab938bdd4c6535a"/></dir></dir></dir></dir></dir><dir name="email"><dir name="catalog"><dir name="product"><file name="list.phtml" hash="986134172956e21500b84787f6cec388"/><file name="new.phtml" hash="6bc8123b2f36d8c04e25161598f12fc5"/></dir></dir><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="98e983e11f6b6ebbd39e22bf22318a4c"/></dir><dir name="invoice"><file name="items.phtml" hash="f9dc307b1f5dfe2df393038735132cf6"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="22495dca6f47504ec716f8a2e3bd7b06"/></dir><dir name="invoice"><file name="default.phtml" hash="22495dca6f47504ec716f8a2e3bd7b06"/></dir><dir name="order"><file name="default.phtml" hash="f555f74e3f801fef35dc2daa766c039c"/></dir><dir name="shipment"><file name="default.phtml" hash="b412da02960836b26352ca5b760039c1"/></dir></dir><file name="items.phtml" hash="39119f6889710ff44370b452d4c99bdb"/><dir name="shipment"><file name="items.phtml" hash="b26c762b51e2ca50a02b542b9c22ddb3"/><file name="track.phtml" hash="5a7dae48bb8550646d47766305037f01"/></dir><dir name="totals"><file name="wrapper.phtml" hash="d57ed586ccb245d528c201e2ebb00e7f"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="677588b65b56b6d4fb72264521b9b841"/><file name="stock.phtml" hash="dd96d2380d74c47d518d398de6982fb1"/></dir></dir><dir name="newsletter"><file name="subscribe.phtml" hash="98ed115e79ca4f156f1e10f67407d1f5"/></dir><dir name="oauth"><dir name="authorize"><dir name="form"><file name="login-simple.phtml" hash="97f6694fb6f2bfe3680653a0b2767767"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="df3fcec30378b0a4719aa6c05b3b3d45"/><file name="2columns-left.phtml" hash="b4f3a625ea3d8e901fd3a706a687634d"/><file name="2columns-right.phtml" hash="93ed4b3331134023951d4216762a21e7"/><file name="3columns.phtml" hash="a7a2ad542214b908eb4c4bfa72b45618"/><file name="empty.phtml" hash="8be188d867d5c0fdd76c9f945de9f482"/><dir name="html"><file name="footer.phtml" hash="f51a89f353cbac5dcdff9559770e343c"/><file name="header.phtml" hash="6005e3285a785ef73c728ae0d11b8e49"/><file name="pager.phtml" hash="e2afd8e23e55216508ebb63b8ee79184"/><dir name="topmenu"><file name="renderer.phtml" hash="099f471a68c819813df058501914df6d"/></dir><file name="topmenu.phtml" hash="2f8421c90d403f3cc89f90ad4b1da495"/></dir><file name="popup.phtml" hash="a7f34bdd8a280057296c8f59bd14bd75"/><file name="print.phtml" hash="547d87181e28d46332e395c0728d5284"/><dir name="template"><file name="links.phtml" hash="653c6c543f2b4155b6ab56a3f0fbe2fe"/></dir></dir><dir name="payment"><dir name="form"><file name="cc.phtml" hash="ffda3eaf58016bf2e691356773731c78"/><file name="ccsave.phtml" hash="0efed4f140983c1462cd7812930dbb00"/></dir><dir name="info"><file name="default.phtml" hash="04d4159c072e98a5cbb1451ed6660d3b"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="ea94f68a523635b97bf5dd05641dad85"/><dir name="express"><dir name="minicart"><file name="shortcut.phtml" hash="2142960dd17e25fad9e6351ef0ee1478"/></dir><dir name="product"><file name="shortcut.phtml" hash="ce1e009b74dc9ca6a85576e469d16584"/></dir><dir name="review"><file name="address.phtml" hash="c56035d8007cb5f84446c8d0cf24a864"/><file name="details.phtml" hash="18909790f28faa286f51912f349b51f3"/><dir name="shipping"><file name="method.phtml" hash="2cd9ba78ee125e4e9f7118915872c0b0"/></dir></dir><file name="review.phtml" hash="898229c6db7c342596b2c4c4e82732e1"/></dir><dir name="partner"><file name="us_logo.phtml" hash="d582c8de45f4f6e4338bcf59ac8dcf05"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="010e9e29369eebd9416e5b1275a42468"/><file name="login.phtml" hash="cc35ee7b2c4f0ff398a3bc8d6847cc86"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="9d293574433074731be99465b66241c6"/><file name="register.phtml" hash="11d218e8ad865ba65ba7e2b7e980b607"/></dir></dir><dir name="header"><file name="links.phtml" hash="196c7f6d8cb889b189cb68dd72d52254"/></dir><file name="remember_me.phtml" hash="a94253926d306c1894a2ba0c867bcbed"/><file name="remember_me_tooltip.phtml" hash="6cf1da6c19645f765ade807fa68b30de"/></dir><dir name="rating"><file name="detailed.phtml" hash="548e2a79e95eb32781d6c6069bf48ae5"/></dir><dir name="reports"><file name="product_viewed.phtml" hash="9726d711b1082bc6e3838247051d99f9"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="36937f4de1aa6d5fdc830bc081cf67c4"/><file name="compared_images_list.phtml" hash="75bf29c90737d53284ff45aca7836531"/><file name="compared_names_list.phtml" hash="ef44286a7ba6e20896310fd63dfa06f3"/></dir><dir name="content"><file name="compared_grid.phtml" hash="39df06ea7e8f3660cef8d1f77d1ed80b"/><file name="compared_list.phtml" hash="1008914fb16e5ff8ffae3253044e844a"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="d50e6206b966a9901226b1d9fd3b04e8"/><file name="viewed_images_list.phtml" hash="01e0a72e62b251cb2daa452872d49333"/><file name="viewed_names_list.phtml" hash="6b28050d242fa1c26afa14f260da97f8"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="e89603e8499b62e4524f56d09a1feae6"/><file name="viewed_list.phtml" hash="d221dc3cbbf9739243395e6e5ac94595"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="view.phtml" hash="ad85c9717a69c8762300e29f311582d5"/></dir><file name="form.phtml" hash="a796965b823303c19c4a8bb600a1f8e4"/><dir name="product"><dir name="view"><file name="list.phtml" hash="7e41b3d49553d67dee807d596b273de4"/></dir></dir><file name="view.phtml" hash="8c6b45c5bb9cbe252238054a9eba5360"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="d73ba9291aa194de8efe1865ab395ae8"/></dir><file name="agreements.phtml" hash="f6d88ecfca79207abd9b9789d2da5633"/></dir><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="346c54f4534913f80136e0a18c9c8e13"/></dir></dir><file name="items.phtml" hash="23d74304e9ee4ef85daf0ad526b9f82b"/></dir><file name="history.phtml" hash="bdea6c7cadc75184a45408fcce33ece8"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="b266163872b1fecb84dd6461a812db9f"/></dir></dir><file name="items.phtml" hash="e9ac03baecb7a4c111eb5396b793c322"/></dir><dir name="items"><dir name="renderer"><file name="default.phtml" hash="19d2940363708fd69043d32a4a501ced"/></dir></dir><file name="items.phtml" hash="55ed05b16bf49bf3d5c5d5630eec8d12"/><file name="recent.phtml" hash="7501563b57b22b3b65e95f7b0cbe23da"/><dir name="shipment"><file name="items.phtml" hash="d86445644e86272ef16ab8c4d8ea2707"/></dir></dir><dir name="recurring"><file name="grid.phtml" hash="a82651c574e2b7e282d42653fd0c8b21"/><dir name="profile"><file name="view.phtml" hash="60522e84040c4ab7e60cc3db302b22dc"/></dir></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="4362cc620cf76097f7f37434921d1daf"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="9ccf097d7dae02373e1c4e9cab437339"/></dir><dir name="wishlist"><dir name="button"><file name="update.phtml" hash="f592505e415cbcdf2b9ec05a8c4722e4"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="ea48fd63bc29db7f736a8c6acdec96af"/><file name="info.phtml" hash="61f6aff2a766debfa00e5de72b3bb7e3"/><file name="price.phtml" hash="cb52b3c96870eb9e9d078db58c95c900"/><file name="quantity.phtml" hash="b1e6601b988a9eb9ff52f04c45292ca4"/></dir><file name="list.phtml" hash="f27eafc6a13a08728db62d08f7204ed9"/></dir><file name="shared.phtml" hash="59b31b93ed8290e45cae603f36f18e32"/><file name="sidebar.phtml" hash="20c961c05b6a3c83542dd4f8aae0a5b5"/><file name="view.phtml" hash="6e65f49752f33e6313c32b07bee1cb1e"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="css"><file name="madisonisland-ie8.css" hash="965c41e8830dc52b76eff8ecec4a16b3"/><file name="madisonisland.css" hash="d77d84a3527193463a1c502f32dace63"/><file name="scaffold-forms.css" hash="d2e97b5f51473b094bf569fa2c54bad0"/><file name="styles-ie8.css" hash="c41e900c701e5a1557fd6866c30baa12"/><file name="styles.css" hash="aee82704347f57061af9de5cc6c8a369"/></dir><dir name="images"><file name="ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="bg_x.png" hash="c321c67f6929326129426c9e83207ea3"/><file name="demo-logo.png" hash="c6f4b110e5379547e71d367479f0f945"/><file name="demo_logo.png" hash="7694461c41abb69ca60c086c69e312cc"/><file name="icon_sprite.png" hash="e15f0103ef5ebe3baf48960bb9ccfaab"/><file name="icon_sprite@2x.png" hash="2e9c31d760a33d9f27951210f8311341"/><file name="logo.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_email.gif" hash="9024e782b5ef7fb76e935a47c39f53c6"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><dir name="media"><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="homepage_banner_1.jpg" hash="267b2827f3db118d99f7a623ee02ad8f"/><file name="homepage_banner_1@2x.jpg" hash="3baa6702111d6f5f5dd40d96f148fc60"/><file name="homepage_banner_2.jpg" hash="67f70cfb1690b5de6e185769fb55cd28"/><file name="homepage_callout_1.jpg" hash="4b8451e4e99e87b6c60a015f659d32b6"/><file name="homepage_callout_1@2x.jpg" hash="fb5e215f6cb623abf6f0365b5de1541d"/><file name="homepage_callout_2.jpg" hash="057ab6200f6ea05d4a6793969c5edac3"/><file name="homepage_callout_2@2x.jpg" hash="e923c6323d22235876fe61a9c5588c85"/><file name="homepage_callout_3.jpg" hash="b2cf1e73e87b3330df17425044d22f52"/><file name="homepage_callout_3@2x.jpg" hash="8b98dee63a61608b09c26bd60acea65e"/></dir><file name="opc-ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="social_icons.png" hash="a6d0bdaea0ca0f507bd36628a6ad31a2"/><file name="social_icons@2x.png" hash="531cc696a7b949dbc8121809c1bb4d46"/></dir><dir name="js"><file name="app.js" hash="3ce0f2bf7c7888013e278a0e51f222e5"/><dir name="configurableswatches"><file name="configurable-swatch-prices.js" hash="4d13ea12fdf69832fbd5f8dda60f3b6f"/><file name="product-media.js" hash="af6bac22c9dc14136fdc7ce812ec2feb"/><file name="swatches-list.js" hash="d23baf5076b63c71d8d3e96e303d7571"/><file name="swatches-product.js" hash="1fd081174c8b78557bd0f95698d7044f"/></dir><dir name="lib"><dir name="elevatezoom"><file name="jquery.elevateZoom-3.0.8.min.js" hash="a18ff8649464a0c999f5d063a081da61"/><file name="jquery.elevatezoom.js" hash="76494c5afa372e08d0a8a5f4ba7e58ed"/></dir><file name="enquire.js" hash="c11ca42a1f2bf189d004f9a4f42e3ca2"/><file name="fastclick.js" hash="7f1e1673fa395e43cbdc584c8798541b"/><file name="imagesloaded.js" hash="f70def9bddf45be549ec0575645b8038"/><file name="jquery.cycle2.min.js" hash="24f809434b3e494cc7b98c6c08404b33"/><file name="jquery.cycle2.swipe.min.js" hash="15747fbd45dd1adcaf8f04a2d8a71d68"/><file name="matchMedia.addListener.js" hash="6f47448212550bd3157c4265e3ebf085"/><file name="matchMedia.js" hash="89f369588d629240d6a8d4f8788490c8"/><file name="modernizr.custom.min.js" hash="e508acbc792b5761fe98dc892a1fd952"/><file name="selectivizr.js" hash="8e596ea5ffac3cf3eb53f75a15cdc7eb"/></dir><file name="minicart.js" hash="dc3a5fb30ec84d7ef2a045e0b6869feb"/><file name="msrp_rwd.js" hash="502177837071323efcc1b061c3fb359c"/><file name="opcheckout_rwd.js" hash="609dd969261120edc12019e8acb19713"/><file name="slideshow.js" hash="0d450c0571b6b13c6f1f535aab75128b"/></dir><dir name="scss"><file name="_core.scss" hash="906a7cffa2b03c241c562365a0d08fa0"/><file name="_framework.scss" hash="3cb92d145bc178ac486dab0a7f89c845"/><file name="_var.scss" hash="3c0cf1b84cb2e12a40f66ba4ddb99154"/><file name="config.rb" hash="5f50b4dc5eefbab9e22abdfb80f4d689"/><dir name="content"><file name="_category.scss" hash="583ef5cb950e988c133b9f3e0a6a9916"/><file name="_home.scss" hash="d6d819ded02e0b84aa3b7440eaebd3c7"/></dir><dir name="core"><file name="_common.scss" hash="6f8ed0cdab1e84b7c7eb3267eca92baa"/><file name="_form.scss" hash="9298d66ab4f09e9c1b052f972e8cffd2"/><file name="_reset.scss" hash="e10fdce9a02b1d7ade124075708fef31"/><file name="_table.scss" hash="77f81924b6c7a71c448f1a639c960a11"/></dir><file name="email-inline.scss" hash="1be1c74ae6d1852f57ff6fd4919c5a67"/><file name="email-non-inline.scss" hash="4b0cf21e043ca9887fc6509edb8dde1d"/><dir name="function"><file name="_black.scss" hash="e10de44b696ff22e13f1a60695b2dbfd"/><file name="_white.scss" hash="646f8a153606ee49dd2e066295de5d12"/></dir><dir name="layout"><file name="_footer.scss" hash="029890b10ca1c0fe226cc9b4ae73ccaf"/><file name="_global.scss" hash="6b4a022de1ca80630fa7b6841c36e0b9"/><file name="_header-account.scss" hash="257e8c4c563ce341b2072c10262e4fa4"/><file name="_header-cart.scss" hash="142f0d057e42458b65fd1389a1aa8f2c"/><file name="_header-nav.scss" hash="e299cb37d3cd0b72400c05adcc708039"/><file name="_header-search.scss" hash="eb14d9e3d408072b89fc75b4ae430fde"/><file name="_header.scss" hash="c222b86c64f6bae8f7eb17c8b60faf94"/></dir><file name="madisonisland-ie8.scss" hash="726ce86a8e549ae2a575443a124f98de"/><file name="madisonisland.scss" hash="cebbbd38450eef37f128a6c9fcac0d55"/><dir name="mixin"><file name="_breakpoint.scss" hash="faed8ebe353dc4386a387b371f423834"/><file name="_clearfix.scss" hash="c5bc9f75034dbf7897b25efb0fb0484e"/><file name="_if-resolution.scss" hash="1fa7135f41d4602e7cd28d545ccdf25a"/><file name="_image-replacement.scss" hash="7020fbf5fbda338b60c86d95ff7f7176"/><file name="_loading-overlay.scss" hash="c57e8e2775a2d475047558bc13f8ffc3"/><file name="_menu.scss" hash="ba9ce8e03e0a467fd9fa42918f46ce83"/><file name="_not-selectable.scss" hash="32504f52ec7698d2d61d206377b3cf90"/><file name="_toggle-content.scss" hash="d77b1587d918179dbd74b62447f6837b"/><file name="_triangle.scss" hash="21be7b64008c27c1e01b6239e5022c8f"/><file name="_typography.scss" hash="2f050ccbdb43ae73fe777396b638237a"/></dir><dir name="module"><file name="_account-orders.scss" hash="293c980d4de1fe57b43e2d6409e99540"/><file name="_account-reviews.scss" hash="6ebd23607d9bcf331216f59ff4fb12bc"/><file name="_billing-agreements.scss" hash="67c334dd9fd2cb81b55e121cc3871380"/><file name="_captcha.scss" hash="8b85d4f13c6cd724cc7da006cbd08d4a"/><file name="_catalog-compare.scss" hash="cfe6377c5ee119e0f6867ae38655cf79"/><file name="_catalog-msrp.scss" hash="520ff7d05207c4401b43dcec5011c523"/><file name="_catalog-product.scss" hash="f460f8813875dc65d12552ef93229152"/><file name="_checkout-cart-minicart.scss" hash="f69a2ba625f23812a598b9129e2ca50c"/><file name="_checkout-cart.scss" hash="dedd939651d2bba9bd48cea660fac522"/><file name="_checkout-multi-address.scss" hash="c01e9d610d7382c245549e4674b2f699"/><file name="_checkout-onepage.scss" hash="e256f304486fdba9db03be390da5d694"/><file name="_checkout-success.scss" hash="1472505a93ac91c6a15fff10f8641da3"/><file name="_cms.scss" hash="b77cc6efa28d4143a40825fe2926d65f"/><file name="_configurableswatches.scss" hash="4fbe40f48bee8876e139d5891e0efa1f"/><file name="_contacts.scss" hash="8abe19542fce2b4a3275d1f0f87cbaa9"/><file name="_cookies.scss" hash="0b17ddce789b76ea4400c8b5221fecc7"/><file name="_customer.scss" hash="43a94c1671551b131a3ec871b81fea0c"/><file name="_paypal.scss" hash="400f636fdfd06c6e55c104a4aa7d39da"/><file name="_popular-terms.scss" hash="0ae8fc23d9504bbeabce51ed05f9aa69"/><file name="_pricing_conditions.scss" hash="c85df2720194e267460f6ba312040b88"/><file name="_product-list.scss" hash="dea9f90a619fa13e248ba3629fc4a9a6"/><file name="_recurring-profiles.scss" hash="0f9e84245fe6ddeaf10333e5ee3f259b"/><file name="_review.scss" hash="c6490833602f5ec9e9a351bb360fb7ab"/><file name="_search.scss" hash="3b01e69f5629cfbd1a1db1165d1daf7c"/><file name="_slideshow.scss" hash="fef56455471076cff90923f5288d5c4e"/><file name="_tags.scss" hash="19362180cf177e8c423965ed6a28945b"/><file name="_widget.scss" hash="ce115e226c4e33a73a976a4a2b1a78f2"/><file name="_wishlist.scss" hash="5fa9ea34b116ed6ec843cf3053c706f3"/></dir><dir name="override"><file name="_plugin.scss" hash="1526ff50255380d8ccd09e5c18abb3e5"/></dir><file name="scaffold-forms.scss" hash="bcf97a99e6b64ff60a1a47a68053b3ea"/><file name="styles-ie8.scss" hash="50d49b08f1e77392aae3dad1cd3634dc"/><file name="styles.scss" hash="d2fc153728136ebf5411455c681c9249"/><dir name="vendor"><file name="_normalize.scss" hash="d9edffd350bd218571fd141a9c658d29"/></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml
new file mode 100644
index 0000000..31ad16d
--- /dev/null
+++ b/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Rwd_Default</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This is a RWD themes base</summary>
+    <description>This is a RWD themes base</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:41</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="etc"><file name="theme.xml" hash="9d42933c3a4f2b1c291d5b5bbf11d6dd"/><file name="widget.xml" hash="00f1e461d9062e53090b4a894354b80a"/></dir><dir name="layout"><file name="bundle.xml" hash="aa8e8659b158139fbcb9eb1d548a519e"/><file name="catalog.xml" hash="ffb44336e278a04a6c175f07bc562fe7"/><file name="catalog_msrp.xml" hash="0d5a348db930eed42bc35d4ccf9908c1"/><file name="catalogsearch.xml" hash="4dde9f7a881e3cea3ec129bef1b13ee5"/><file name="checkout.xml" hash="20916639cb2d9994c091895da15a0b0f"/><file name="cms.xml" hash="2a6ec2cd93843f7f75061973934af241"/><file name="configurableswatches.xml" hash="9f029376440a19b8099a5b6e6665e984"/><file name="contacts.xml" hash="dfd97d1b8395cc271125a357e6811727"/><file name="customer.xml" hash="beaeb5e3415f50a80d9f91c758accefa"/><file name="directory.xml" hash="7b3ced90cf254b76500d5f8a363b28fc"/><file name="downloadable.xml" hash="6fb6aec95bd307fc8d848cdef16a87ea"/><file name="newsletter.xml" hash="99458a6f3e73b33348de623f83f44581"/><file name="oauth.xml" hash="705c8cc50c26f7e4285bb7416ab1f051"/><file name="page.xml" hash="187dd31efe8ba00dbae87c0522bc9676"/><file name="paypal.xml" hash="0ff834afd3728b32196e721ade5256aa"/><file name="persistent.xml" hash="5f744e61a14e2a072beff3857567d45f"/><file name="review.xml" hash="578157e3a9ef9539b06349fde10ddcbc"/><file name="rss.xml" hash="362997d9980766b785e50417795fcfde"/><file name="sales.xml" hash="8c19fa843eca0ddc45fc20e4678adec3"/><file name="wishlist.xml" hash="44d782a89f00808a097b43531e546c75"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="385a4bdbbb17021d7c8c725c5ca16dbb"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="view"><dir name="type"><dir name="bundle"><file name="availability.phtml" hash="cd7b4f76fe9ccb4862fcfe9fdf735bce"/><dir name="option"><file name="select.phtml" hash="fd5bdffd5c80730d26c432773fd929c9"/></dir></dir><file name="bundle.phtml" hash="390f520b82259a27539742c060d70cb8"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b9f0008d961f945d3102de4ebff06746"/></dir><dir name="invoice"><file name="default.phtml" hash="50c01c93a68ac239d23ac746ef8eecc6"/></dir><dir name="order"><file name="default.phtml" hash="6bae6cb6699a7e67fbcc0be01a9e3958"/></dir><dir name="shipment"><file name="default.phtml" hash="12efaca5f48e8e6216af313a93a0c836"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><file name="renderer.phtml" hash="01de9221542d4576b428002af5450038"/></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="5b2f1638d0d2a79ea51b34328bb376e5"/></dir><dir name="catalog"><dir name="layer"><file name="filter.phtml" hash="a9800445835d95e47b4667562c5504c9"/><file name="state.phtml" hash="68b812651343d8efe2f52396ae4b8bff"/><file name="view.phtml" hash="43ef898fd0184a34e8153eb45337bcf5"/></dir><dir name="msrp"><file name="popup.phtml" hash="dbeb5ac9707c288e9657d3082547890b"/></dir><dir name="navigation"><file name="left.phtml" hash="6575fb3943bd8962da3faa5f16d3eb55"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="51d60c165c9f6f9eec45e2c929a46665"/><file name="sidebar.phtml" hash="0be3217397d6d11966530589a98a5021"/></dir><dir name="list"><file name="related.phtml" hash="689fd2ed824260f8ce0e26c9923323dd"/><file name="toolbar.phtml" hash="ab66060531cfb82eb8e362c90cc83791"/><file name="upsell.phtml" hash="4b200ec4f7ff016917709dfddb751e31"/></dir><file name="list.phtml" hash="1a1d32406dd64a50691dc1e38b8e6398"/><file name="price.phtml" hash="c5e841d59f7f6bbf84f9c879f1ebed27"/><dir name="view"><file name="addto.phtml" hash="8117d1b5d647bf4b3fc8dd84f3dbc6ca"/><file name="addtocart.phtml" hash="63d5573173bbc198b29057b86a60fe54"/><file name="media.phtml" hash="5fb346c580f635b927a5412ae2556b6b"/><file name="sharing.phtml" hash="b9a62aeaeb1f1345c894d035bc5c98d8"/><dir name="type"><dir name="availability"><file name="default.phtml" hash="7fed915ce32b155a045301ee867c283e"/><file name="grouped.phtml" hash="9c467e68c5d5787181b9b54f71715b2b"/></dir><file name="default.phtml" hash="60d57df7bd2c9e0175a067c21c40c1ec"/><file name="grouped.phtml" hash="6740aff8dc4282a212c98d18da65a29c"/><dir name="options"><file name="configurable.phtml" hash="82d4bd6957faafaed86d3c2ea0610a04"/></dir></dir></dir><file name="view.phtml" hash="febb0fe90db741820576d0be0c4b701f"/><dir name="widget"><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="0048f859bd6db690859e81c704553455"/><file name="new_images_list.phtml" hash="6a3c1362ad5f86062f30aca148442a01"/><file name="new_names_list.phtml" hash="c1555ea48bcdf69eacf6d3d41ed52530"/></dir><dir name="content"><file name="new_grid.phtml" hash="e9fd476dbb4621d76c1918ad12caff6f"/><file name="new_list.phtml" hash="f4bb956b74a3ae4b8de53f4ddec18eb0"/></dir></dir></dir></dir></dir><dir name="cataloginventory"><dir name="stockqty"><file name="composite.phtml" hash="77b673795f6d199055461d07deeb6c73"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5f3f10ad173037b8aaaa8104d9c48a1b"/></dir><file name="form.mini.phtml" hash="5d203d602572292ab563b724026b2d3e"/><file name="result.phtml" hash="7c6e68ae4bf4edf13b90d7bba68b1208"/></dir><dir name="centinel"><dir name="authentication"><file name="start.phtml" hash="d80d808774fac08fef28c647bb76414e"/></dir></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="f2591f5cadb027ea4e5085946c8f9f80"/><file name="crosssell.phtml" hash="68afc918f0414b31b5f88df4cc6e3e92"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="a7f1e2c2d26c9b1ddb2e0269235ce499"/></dir><file name="default.phtml" hash="6ff4fd36c9a72e589ea0c92e9556301d"/></dir><dir name="minicart"><file name="default.phtml" hash="fee4b446fa9077b4dc17af56899d6383"/><file name="items.phtml" hash="e639d64e913ad9b8d3b1a56165574d3f"/></dir><file name="minicart.phtml" hash="b55c9a51a9eb6057a41d4e4c2b48e910"/><dir name="render"><file name="default.phtml" hash="9850aac16db5fc6263c25b07443bdafa"/><file name="simple.phtml" hash="bc76fc52fec4bc1b24c311cad53dc2b2"/></dir><file name="shipping.phtml" hash="2f462cead90bb493a2ce874e4d5a8747"/><dir name="sidebar"><file name="default.phtml" hash="3adc91979d26188830db7bc0b3731742"/></dir><file name="sidebar.phtml" hash="9ffb85ddaa41e91c9233ec5c82c7ae82"/></dir><file name="cart.phtml" hash="9a943d16f3d981366e5d613e88af7d34"/><dir name="multishipping"><file name="addresses.phtml" hash="bda46e6cb1800933a114258b47a5a0da"/><file name="billing.phtml" hash="884d9b8dd0879897e6d43c50440039c3"/><dir name="item"><file name="default.phtml" hash="d7beeb4d8edc0fec58e226f5ce525c6d"/></dir><dir name="overview"><file name="item.phtml" hash="0597f23f2cf6e05371e40ee5c7e2315d"/></dir><file name="overview.phtml" hash="e2c461b9e67959e849135b5d079c0537"/></dir><dir name="onepage"><file name="payment.phtml" hash="61cf9454d8f6169c9f3d4bdc6b10a8c2"/><file name="progress.phtml" hash="955bc23d4addd0efe3e7feac8d8feb5d"/><dir name="review"><file name="info.phtml" hash="34c7f8cf5827594b16c11e6ee3411513"/><file name="item.phtml" hash="c8e48375afa925eb2321e3aff1b0bf4c"/></dir><file name="shipping.phtml" hash="0ce8393c48e2bd2503b004e0a29e04fe"/></dir><file name="onepage.phtml" hash="af546fa00f2884b9fc6335bf1c0cba60"/></dir><dir name="configurableswatches"><dir name="catalog"><dir name="layer"><dir name="filter"><file name="swatches.phtml" hash="f9eee1bdd31e706a560d074efcd5313c"/></dir><dir name="state"><file name="swatch.phtml" hash="9d3f9998bc24cbe06b99046c8cc2a5f3"/></dir></dir><dir name="media"><file name="js.phtml" hash="57e9acda00f28629670ba5e84ea9cabb"/></dir><dir name="product"><dir name="list"><dir name="price"><file name="js.phtml" hash="b57be935901c4285b6f57f2077adf2eb"/></dir><file name="swatches.phtml" hash="d71db2c1ecc49b7bd1f5c3cb91692bac"/></dir><dir name="view"><dir name="type"><dir name="configurable"><file name="swatch-js.phtml" hash="7502a7498d8fc0d11e3aaae2f64f4c60"/></dir><dir name="options"><dir name="configurable"><file name="swatches.phtml" hash="75198b3138a8c825572830d13f42c443"/></dir></dir></dir></dir></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="7368ea4443c1bc85a880ba2fe84d9a0c"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="3a5ee9d2564cff6c85b9a8d81650ed12"/></dir><file name="dashboard.phtml" hash="f9bf153b12b881cd3aff3f874776e006"/><file name="navigation.phtml" hash="f573f85c06b8da6cd04fe30043a26986"/></dir><dir name="address"><file name="edit.phtml" hash="9ec6de2e18779d3f83469b2c08a9ba22"/></dir><dir name="form"><file name="address.phtml" hash="29ca055fce63adb7e7b781d9c5b44d37"/><file name="changepassword.phtml" hash="85e3a3f61d387ad99a724c49b50cb77b"/><file name="confirmation.phtml" hash="f7e3c2f26a601d85744676cd36310640"/><file name="edit.phtml" hash="aa5035754de40c1da9e6481a04fa686e"/><file name="forgotpassword.phtml" hash="19b6dcb57c9401398335ded1c669f7f0"/><file name="mini.login.phtml" hash="bfd6855770d271913c4c5b4b30cdbd56"/><file name="resetforgottenpassword.phtml" hash="0180eb6f13153ea9b9a4399a1687c68a"/></dir></dir><dir name="directory"><file name="currency.phtml" hash="a827c080db81adc467b091cbfd7001ba"/></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="type.phtml" hash="ac98a769be2e41a26702f9245d9d3c06"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="99baf0b573a57793538763745961d3e2"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="39b625a969337c7b42092ca989d3a6ce"/></dir></dir></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="9f13aedbb1a5a22ecc9ed803915eeafc"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="cd99c9d650bf7b3aa755b337cbd104db"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="1d056b77b1aa8edabe1d5cc39810910f"/></dir><dir name="order"><file name="downloadable.phtml" hash="70fb86f91a456322d7e39626ab2ab475"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="b996432e3f9ee66b75ba7f881a3ee7ac"/></dir></dir></dir></dir></dir><dir name="email"><dir name="catalog"><dir name="product"><file name="list.phtml" hash="e9151bd0765f84a45ddc640d1f0c5184"/><file name="new.phtml" hash="257a76796d136ec5d6a60407ad36978e"/></dir></dir><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="d28d47025ff2c145a6b974f002d9a231"/></dir><dir name="invoice"><file name="items.phtml" hash="f190f4c7af76fae8a78a329bf81de99e"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="invoice"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="order"><file name="default.phtml" hash="82d4fe9be011e52561450f65405dbf05"/></dir><dir name="shipment"><file name="default.phtml" hash="2719db4c14bbc1b2d608ee305a5ea133"/></dir></dir><file name="items.phtml" hash="2c838581f36f73ae6b637c081345bf34"/><dir name="shipment"><file name="items.phtml" hash="aad8aa56e8cbcd61f55c7d20d96e1c38"/><file name="track.phtml" hash="f4f2933f0b10a997e0448c00c30a3a6e"/></dir><dir name="totals"><file name="wrapper.phtml" hash="8c6c83bbe4597b477690a26eb302b1dc"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="01a800642590e4309af5a625b92c8798"/><file name="stock.phtml" hash="a9dfc2adb4cebcba4e49e4c64927d135"/></dir></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4181b6514038da8aded97015a970514f"/></dir><dir name="oauth"><dir name="authorize"><dir name="form"><file name="login-simple.phtml" hash="8151e5955a9d7abc37c6dea81169c272"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="5ec6b024c9566631ece9ce301757665b"/><file name="2columns-left.phtml" hash="3b4af8953d95de0d6bb065e98194ad5d"/><file name="2columns-right.phtml" hash="744f7542ceb13f537f2a5f9d21773142"/><file name="3columns.phtml" hash="97ae6d8ff601f9209017045a0042222b"/><file name="empty.phtml" hash="1af42c9aa138f5c963935eebcd1366fb"/><dir name="html"><file name="footer.phtml" hash="ac1eec00d1d9b5c0afe25b3368a6c9a7"/><file name="header.phtml" hash="ed448619d831b6305102888437f61961"/><file name="pager.phtml" hash="f8f400b9c0f28d4c74e2e0dbff1ea317"/><dir name="topmenu"><file name="renderer.phtml" hash="9faff6909c510d25b5f07aad435a715f"/></dir><file name="topmenu.phtml" hash="11a10215d1c7a30add262314285d3f8e"/></dir><file name="popup.phtml" hash="10f4360428b634fdeb2373268f0fa55a"/><file name="print.phtml" hash="a027a5fadfb452e75383342a9ca480d8"/><dir name="template"><file name="links.phtml" hash="54b4b7f1f7d3222a4d5df99282eddcd3"/></dir></dir><dir name="payment"><dir name="form"><file name="cc.phtml" hash="51dec65c95c89e69dd63bc5cc1898bb3"/><file name="ccsave.phtml" hash="3fa1af18be1f7968452b8bbdcb313b93"/></dir><dir name="info"><file name="default.phtml" hash="c0092cc9835da90892f58cb948a39e16"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="ae960a6fca0d31b9a68323c4b8e9da5f"/><dir name="express"><dir name="minicart"><file name="shortcut.phtml" hash="63c44eb36ddd6612a6eec4e6a9db47bc"/></dir><dir name="product"><file name="shortcut.phtml" hash="26b1caeb5c5f8dc2d37c06faa109a5b0"/></dir><dir name="review"><file name="address.phtml" hash="d1072f15dbab96e2c93950af5f1bef3a"/><file name="details.phtml" hash="cbd47ec4da46b1571a8f6f0ccbd19e75"/><dir name="shipping"><file name="method.phtml" hash="bd95f49f1b5367fee037f14f2af3b2e9"/></dir></dir><file name="review.phtml" hash="a3a5e9bcd232fc007a91a9f8e9f5ca5b"/></dir><dir name="partner"><file name="us_logo.phtml" hash="ba4e761f47080206c675082e6f514a2f"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="5695e84eb9dbd0511ea3715359f3cc38"/><file name="login.phtml" hash="23c302cccd47f395654a5746ed0f814d"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="72ea1858f6b6208b23725ebaddce91ff"/><file name="register.phtml" hash="e4b53536f0d2b7a61da4c6ea365f83c4"/></dir></dir><dir name="header"><file name="links.phtml" hash="7aaff67c92dae241de0bacc3417c23ba"/></dir><file name="remember_me.phtml" hash="c8f47428cc00f2806375a1136452ecad"/><file name="remember_me_tooltip.phtml" hash="8d280b3ef7a16f026e0bc7b29caca0f0"/></dir><dir name="rating"><file name="detailed.phtml" hash="3d2c39a5084f2b666bd8d6ea6560979d"/></dir><dir name="reports"><file name="product_viewed.phtml" hash="b4a4a62b93e19a093d0d01c06da0d6f7"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="7936d68ecb10a62a58b5fc5eee05132c"/><file name="compared_images_list.phtml" hash="5245694348fc74ee15a4505d446e11b7"/><file name="compared_names_list.phtml" hash="e6f2df68ea562b19b77de78c71bcafa6"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fcaf2c0999c4cb451a102b9af1f2b53a"/><file name="compared_list.phtml" hash="5ca659200e2a9e9b0de1564953b1a1b6"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="dc2e9b85e5f868d25bf6a32a45e105ce"/><file name="viewed_images_list.phtml" hash="44f93a1f2f8e0ac0ca4b4ea952d40c13"/><file name="viewed_names_list.phtml" hash="7f2cf572ac3b52e1638dd86ad18da88b"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="97b3189ef278cf2c4cd0155a614c9d8f"/><file name="viewed_list.phtml" hash="533d700a14b98d50e0e0ccd2ec9b2d13"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="view.phtml" hash="865b92d13fbffbd9fb3f6310ab58bdf7"/></dir><file name="form.phtml" hash="e8597f08333bc80f80ee7a7ed9626bd7"/><dir name="product"><dir name="view"><file name="list.phtml" hash="83c0ce228661a67de4ec7aaf96444d00"/></dir></dir><file name="view.phtml" hash="4217282c57ac3500a8d72bd028f343c0"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="0cc1dcc5c3bd87e0d7d732462586b008"/></dir><file name="agreements.phtml" hash="8377b6c1e9762b7b5043cd9a9638ea74"/></dir><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="d36c09b0c7dca4a92165796ad3fb2ee3"/></dir></dir><file name="items.phtml" hash="bdef8dbc88a3ee59541f61c01d80cf10"/></dir><file name="history.phtml" hash="031d84ed8ece9bc780aeb6dba97ef037"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="c800c5c9c1ca76d6e36e8703deb2a370"/></dir></dir><file name="items.phtml" hash="391ef549dec7247c0a30a1762133fe0d"/></dir><dir name="items"><dir name="renderer"><file name="default.phtml" hash="607386a20e19e5e4f3d227287eb6981b"/></dir></dir><file name="items.phtml" hash="04bec14b9ddccde555e95e2f8c1e8472"/><file name="recent.phtml" hash="2f33fdf671d8254bf122642365973e0f"/><dir name="shipment"><file name="items.phtml" hash="cb4cacfdd182b2dd4239e9e2caf4185a"/></dir></dir><dir name="recurring"><file name="grid.phtml" hash="48b8868e8e5fc11d72610bf5c3827c76"/><dir name="profile"><file name="view.phtml" hash="0d9092c3dd42a1fa5aa139992b9a58cb"/></dir></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="4d1db3053ea6e8232aaa45f14627fa08"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="ddda414b087a42b80412f1382a3249d9"/></dir><dir name="wishlist"><dir name="button"><file name="update.phtml" hash="717f14026c791d69ff37759b19e49c73"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="aec2495e407f50759911c0014e5e7f41"/><file name="info.phtml" hash="59dcab344169fed593b2bdbb9c0c6b3e"/><file name="price.phtml" hash="7c9c32c6584fb68a9826c249e987b62c"/><file name="quantity.phtml" hash="44aaab6cb59b9348df315d36a6ec9637"/></dir><file name="list.phtml" hash="9bbbb395f3dcb41d53c4ce300118715e"/></dir><file name="shared.phtml" hash="840e2ef47cc948131a71e29230759df7"/><file name="sidebar.phtml" hash="4a8d26e059ffe2f70ccefe3e4c4c0c64"/><file name="view.phtml" hash="576f56d55c297b1f56b61cc471a094f4"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="css"><file name="madisonisland-ie8.css" hash="95cb9c107091e9aa93e37e6ceac3b136"/><file name="madisonisland.css" hash="66e3dcea3cf2b034cb363780b584a071"/><file name="scaffold-forms.css" hash="cb597486f48e3a96acad3778eae91d20"/><file name="styles-ie8.css" hash="219b3af9795b072430d31928b985fa91"/><file name="styles.css" hash="f63fa8788b086198fb89164128630f40"/></dir><dir name="images"><file name="ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="bg_x.png" hash="c321c67f6929326129426c9e83207ea3"/><file name="demo-logo.png" hash="c6f4b110e5379547e71d367479f0f945"/><file name="demo_logo.png" hash="7694461c41abb69ca60c086c69e312cc"/><file name="icon_sprite.png" hash="e15f0103ef5ebe3baf48960bb9ccfaab"/><file name="icon_sprite@2x.png" hash="2e9c31d760a33d9f27951210f8311341"/><file name="logo.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_email.gif" hash="9024e782b5ef7fb76e935a47c39f53c6"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><dir name="media"><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="homepage_banner_1.jpg" hash="267b2827f3db118d99f7a623ee02ad8f"/><file name="homepage_banner_1@2x.jpg" hash="3baa6702111d6f5f5dd40d96f148fc60"/><file name="homepage_banner_2.jpg" hash="67f70cfb1690b5de6e185769fb55cd28"/><file name="homepage_callout_1.jpg" hash="4b8451e4e99e87b6c60a015f659d32b6"/><file name="homepage_callout_1@2x.jpg" hash="fb5e215f6cb623abf6f0365b5de1541d"/><file name="homepage_callout_2.jpg" hash="057ab6200f6ea05d4a6793969c5edac3"/><file name="homepage_callout_2@2x.jpg" hash="e923c6323d22235876fe61a9c5588c85"/><file name="homepage_callout_3.jpg" hash="b2cf1e73e87b3330df17425044d22f52"/><file name="homepage_callout_3@2x.jpg" hash="8b98dee63a61608b09c26bd60acea65e"/></dir><file name="opc-ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="social_icons.png" hash="a6d0bdaea0ca0f507bd36628a6ad31a2"/><file name="social_icons@2x.png" hash="531cc696a7b949dbc8121809c1bb4d46"/></dir><dir name="js"><file name="app.js" hash="de11809cde5667fe0efbb34889297cba"/><dir name="configurableswatches"><file name="configurable-swatch-prices.js" hash="69fb27c7bd77969e55a4842240892a13"/><file name="product-media.js" hash="14bcc410b70b000042434f750b2bf209"/><file name="swatches-list.js" hash="7be11df83b3f7bdd147b8938b299f905"/><file name="swatches-product.js" hash="50c047d9e0bf8d051aa6a041731248ec"/></dir><dir name="lib"><dir name="elevatezoom"><file name="jquery.elevateZoom-3.0.8.min.js" hash="a18ff8649464a0c999f5d063a081da61"/><file name="jquery.elevatezoom.js" hash="76494c5afa372e08d0a8a5f4ba7e58ed"/></dir><file name="enquire.js" hash="c11ca42a1f2bf189d004f9a4f42e3ca2"/><file name="fastclick.js" hash="7f1e1673fa395e43cbdc584c8798541b"/><file name="imagesloaded.js" hash="f70def9bddf45be549ec0575645b8038"/><file name="jquery.cycle2.min.js" hash="24f809434b3e494cc7b98c6c08404b33"/><file name="jquery.cycle2.swipe.min.js" hash="15747fbd45dd1adcaf8f04a2d8a71d68"/><file name="matchMedia.addListener.js" hash="6f47448212550bd3157c4265e3ebf085"/><file name="matchMedia.js" hash="89f369588d629240d6a8d4f8788490c8"/><file name="modernizr.custom.min.js" hash="e508acbc792b5761fe98dc892a1fd952"/><file name="selectivizr.js" hash="8e596ea5ffac3cf3eb53f75a15cdc7eb"/></dir><file name="minicart.js" hash="773d889227f7cb229ca4763df44e91cf"/><file name="msrp_rwd.js" hash="9360b9b788ddd45d46c5348e16624b94"/><file name="opcheckout_rwd.js" hash="166e1b25d0692833e241947f4d9f9c7e"/><file name="slideshow.js" hash="d95865e4fb72c8fc5aa2a09e6dbcd458"/></dir><dir name="scss"><file name="_core.scss" hash="8191f7bb4f132a9c0d1b823c7c285912"/><file name="_framework.scss" hash="9472094353a56c22a11b7704b0a38f6c"/><file name="_var.scss" hash="a0f35fb7e96b3cf79997afa3cae0f70b"/><file name="config.rb" hash="5f50b4dc5eefbab9e22abdfb80f4d689"/><dir name="content"><file name="_category.scss" hash="6dfe07f59c4c5f9005b716a57474bc88"/><file name="_home.scss" hash="4f72bbb962144c4c819418a469a4d273"/></dir><dir name="core"><file name="_common.scss" hash="101c56abd1bc1b1042ae8f8b1e4bdd5f"/><file name="_form.scss" hash="6d385bf6b997c595dd25a6d6340defcb"/><file name="_reset.scss" hash="e0457b30f892cfab4e9681713096a441"/><file name="_table.scss" hash="fc2d07038f3c159fd62ceca84f01f2f2"/></dir><file name="email-inline.scss" hash="6ce915b8334bc7aaa934cc4d1819685a"/><file name="email-non-inline.scss" hash="500aeb9f5a3662f1630f3d7d2002c092"/><dir name="function"><file name="_black.scss" hash="fefb3ce075b124fb155c7220f7b39d33"/><file name="_white.scss" hash="044a214db61206ec54be9305146c235c"/></dir><dir name="layout"><file name="_footer.scss" hash="4ddf8c6325300bbf8844d51ae4a5c4a3"/><file name="_global.scss" hash="4a023b134df7966469600212523a65fb"/><file name="_header-account.scss" hash="bf00cd96647d85aba09f00d283fdbdad"/><file name="_header-cart.scss" hash="3aadde0e39464bfdaf50155aabc48528"/><file name="_header-nav.scss" hash="2aaab0e5db6f416b57c3293adcb8cb91"/><file name="_header-search.scss" hash="079ecdcc3ebb7cc414946c0e78c19371"/><file name="_header.scss" hash="b7859a0931057ad1536db69b12241982"/></dir><file name="madisonisland-ie8.scss" hash="8b0cb6e8691a39a24fb33b7a3c82baf8"/><file name="madisonisland.scss" hash="b2a45438233a36258e66e6a5c8af6208"/><dir name="mixin"><file name="_breakpoint.scss" hash="cb02339d9740c3c6a8cde39183ed0166"/><file name="_clearfix.scss" hash="55e23e69145f99d1e38392b1a9420698"/><file name="_if-resolution.scss" hash="9d49ea0dac1bc376c581ba724fa0218b"/><file name="_image-replacement.scss" hash="f99ce5066b956b247bf8fdb7628c4c72"/><file name="_loading-overlay.scss" hash="a3a33484d034229193568e03384f12e7"/><file name="_menu.scss" hash="2330eab00fde007f3c826bf86b0e04b4"/><file name="_not-selectable.scss" hash="7e27705f1e57d8077e7edb5a39fdee6e"/><file name="_toggle-content.scss" hash="91e198e313fda382c9c2e9fb12bb342e"/><file name="_triangle.scss" hash="6df09b47978dcb46faabe8a789bcf412"/><file name="_typography.scss" hash="0634899cf1572349341ad02e68f3e5af"/></dir><dir name="module"><file name="_account-orders.scss" hash="1566481ee469c96ba9947e366912cbb3"/><file name="_account-reviews.scss" hash="a207a4b2e3f953f316dba7e97a4a87c9"/><file name="_billing-agreements.scss" hash="f9984020bb88042d857d6b4a165b7e8e"/><file name="_captcha.scss" hash="6a478cb360bb39aa978ce8b0dbfd8a2c"/><file name="_catalog-compare.scss" hash="1a72cc87d13992643ab826bf9e028929"/><file name="_catalog-msrp.scss" hash="d2c03f98dc9b2a31dbbedc3a56968619"/><file name="_catalog-product.scss" hash="217ee56f122c4ac9cf37320cbc0b31a1"/><file name="_checkout-cart-minicart.scss" hash="159fef349f60e392aecb7ab5f112a508"/><file name="_checkout-cart.scss" hash="d8d24dfb4dc5538b764b2a0b6e25a9e2"/><file name="_checkout-multi-address.scss" hash="b3d7777c347a55f00568c1b8d8d3470a"/><file name="_checkout-onepage.scss" hash="d532ce0af5ec92002ea3bca4df010911"/><file name="_checkout-success.scss" hash="8a27a309ed45f117b9a3f28121455dc7"/><file name="_cms.scss" hash="2d008923d1c787e8c9201428411ede0b"/><file name="_configurableswatches.scss" hash="42ff6cf4d1fe159a17c5ba6cdc82e3f6"/><file name="_contacts.scss" hash="67e9b5079eb38a1313df5abaf8dcbe8a"/><file name="_cookies.scss" hash="b6ef04bd507c26c5b8c277c398788579"/><file name="_customer.scss" hash="1c7dfda996e88a5f6517225738da3283"/><file name="_paypal.scss" hash="3c9550307fdfa293977b21f437d4c0a7"/><file name="_popular-terms.scss" hash="b3ec891b1706fb9bc914f1f0f9b36b19"/><file name="_pricing_conditions.scss" hash="36887033cc7ebadce1872a9d2c9e3ed2"/><file name="_product-list.scss" hash="8ba0f2f9b9c9e41509af955e5858cf41"/><file name="_recurring-profiles.scss" hash="1c06e6561e57aacd8c6f5c4342290964"/><file name="_review.scss" hash="28275bb7f69b44011618f0e534c6b60f"/><file name="_search.scss" hash="bf3eb603fbd3b8bff5b5ceb135ea4642"/><file name="_slideshow.scss" hash="7ec125b75db0a049d507e833bea8edb7"/><file name="_tags.scss" hash="712ac8bd4f7a99d144fb2af7e17bd5d8"/><file name="_widget.scss" hash="e41baab99ea2020e6ff006778f3de9b4"/><file name="_wishlist.scss" hash="72efb048a2242ca332f973404dc51a76"/></dir><dir name="override"><file name="_plugin.scss" hash="ec60b0b35e840eb6347f21a95f16b719"/></dir><file name="scaffold-forms.scss" hash="983e1df0846a9a75048825abb8405304"/><file name="styles-ie8.scss" hash="4d20f2d2b4317945b5350c91c91efddc"/><file name="styles.scss" hash="3ad39f7c860c02e9b0d7cc95cd0e8863"/><dir name="vendor"><file name="_normalize.scss" hash="d9edffd350bd218571fd141a9c658d29"/></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Install_Default-1.9.4.0.xml b/var/package/Interface_Install_Default-1.9.4.0.xml
deleted file mode 100644
index f108bb9..0000000
--- a/var/package/Interface_Install_Default-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Install_Default</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Install</summary>
-    <description>Default interface for Install</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magedesign"><dir name="install"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="2b8a8e5c60e4784255103ef960654b5c"/></dir><dir name="layout"><file name="main.xml" hash="2cb06d08ba540edaa57211ab1e6b71e3"/></dir><dir name="template"><dir name="install"><file name="begin.phtml" hash="edc909883a0dd894799b11e35ecd4d78"/><file name="config.phtml" hash="23e3cd8fb40fe450f53c8f2989b64628"/><file name="create_admin.phtml" hash="5a3493606f6c6f8dc3aa18c07a26197a"/><dir name="db"><file name="main.phtml" hash="085af57b1eabf603853a5ad54933c8ee"/><file name="mysql4.phtml" hash="3f1311b2485d576e2a5242bf160ce5e3"/></dir><file name="download.phtml" hash="7ea367eccbea0474cc9bfaeb5f5768c4"/><file name="end.phtml" hash="a8dcb42695cf6b34f5818b4d3e4fbb46"/><file name="locale.phtml" hash="19017a22e20311eeaa8c1ca03a388e4e"/><file name="state.phtml" hash="717f306783e754c422b1842dd1cc7830"/></dir><file name="page.phtml" hash="d14f695b33a604ac37d13782ac57464b"/></dir></dir></dir></dir></target><target name="mageskin"><dir name="install"><dir name="default"><dir name="default"><dir name="css"><file name="boxes.css" hash="9a5a383865b0a339a338b5c7dba4d2ef"/><file name="clears.css" hash="385643f0c918bfebaa7a99e04e251bb5"/><file name="ie7minus.css" hash="44645224adb1d5285c44369468391487"/><file name="iestyles.css" hash="5ad54798fe1e80145aac277e420fe2dc"/><file name="reset.css" hash="88f8f9c255d960d4313426de37ba1832"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Install_Default-1.9.4.1.xml b/var/package/Interface_Install_Default-1.9.4.1.xml
new file mode 100644
index 0000000..1a25d29
--- /dev/null
+++ b/var/package/Interface_Install_Default-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Install_Default</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Install</summary>
+    <description>Default interface for Install</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:41</time>
+    <contents><target name="magedesign"><dir name="install"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="main.xml" hash="1e4690304e35af0f0a4c0cf9ef3f871b"/></dir><dir name="template"><dir name="install"><file name="begin.phtml" hash="23e3039f3bd2f10952b25fca26c56d83"/><file name="config.phtml" hash="35b2debe9ab7dbb8fcd5ccf6ccf38a91"/><file name="create_admin.phtml" hash="f64acc16592d95dade30ffe810d56e5c"/><dir name="db"><file name="main.phtml" hash="814787c7d6882395bf8d44305bf678ce"/><file name="mysql4.phtml" hash="73a36d4eb1fe1fb571bfdbd108ee6223"/></dir><file name="download.phtml" hash="65f06ef8c58668dfe5b83ba4a5904df1"/><file name="end.phtml" hash="0fe6c358345f60570aa20c3a1cbff04a"/><file name="locale.phtml" hash="837b860853ca7e11e28273acd7b6be69"/><file name="state.phtml" hash="2964d0ec1dd7fe1e06e245ed70b0668f"/></dir><file name="page.phtml" hash="87adbd0e0ea8c046e66e4a88bace376c"/></dir></dir></dir></dir></target><target name="mageskin"><dir name="install"><dir name="default"><dir name="default"><dir name="css"><file name="boxes.css" hash="390ba9f8f8ae5deb254622b05f3a60cf"/><file name="clears.css" hash="5b5cefde368a471bc2ee25aee6752617"/><file name="ie7minus.css" hash="bf2d04f3e9e03a8dfb1424225694a350"/><file name="iestyles.css" hash="c22edc91efe49e87714c280cfb9eee52"/><file name="reset.css" hash="4c7ab20bcae42337b30ca4b5e4c9feb0"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Cm-1.9.4.0.xml b/var/package/Lib_Cm-1.9.4.0.xml
deleted file mode 100644
index dd66b93..0000000
--- a/var/package/Lib_Cm-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Cm</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Redis adapter for Zend_Cache</summary>
-    <description>Redis adapter for Zend_Cache</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magelib"><dir name="Cm"><dir name="Cache"><dir name="Backend"><file name="Redis.php" hash="1c137eef42b9c034fa0b6d5258092c00"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_Cm-1.9.4.1.xml b/var/package/Lib_Cm-1.9.4.1.xml
new file mode 100644
index 0000000..a409487
--- /dev/null
+++ b/var/package/Lib_Cm-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Cm</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Redis adapter for Zend_Cache</summary>
+    <description>Redis adapter for Zend_Cache</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="magelib"><dir name="Cm"><dir name="Cache"><dir name="Backend"><file name="Redis.php" hash="1c137eef42b9c034fa0b6d5258092c00"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Credis-1.9.4.0.xml b/var/package/Lib_Credis-1.9.4.0.xml
deleted file mode 100644
index adf6a30..0000000
--- a/var/package/Lib_Credis-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Credis</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Credis Library</summary>
-    <description>Credis Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magelib"><dir name="Credis"><file name="Client.php" hash="1fde64fdcd768d51758ec437d5952861"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Credis-1.9.4.1.xml b/var/package/Lib_Credis-1.9.4.1.xml
new file mode 100644
index 0000000..ecf29c4
--- /dev/null
+++ b/var/package/Lib_Credis-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Credis</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Credis Library</summary>
+    <description>Credis Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="magelib"><dir name="Credis"><file name="Client.php" hash="1fde64fdcd768d51758ec437d5952861"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Google_Checkout-1.9.4.0.xml b/var/package/Lib_Google_Checkout-1.9.4.0.xml
deleted file mode 100644
index 97bf664..0000000
--- a/var/package/Lib_Google_Checkout-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Google_Checkout</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>Apache License</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Google Checkout Library</summary>
-    <description>Google Checkout Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Google_Checkout-1.9.4.1.xml b/var/package/Lib_Google_Checkout-1.9.4.1.xml
new file mode 100644
index 0000000..4877d6f
--- /dev/null
+++ b/var/package/Lib_Google_Checkout-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Google_Checkout</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>Apache License</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Google Checkout Library</summary>
+    <description>Google Checkout Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_IDNA2-1.9.4.0.xml b/var/package/Lib_IDNA2-1.9.4.0.xml
deleted file mode 100644
index 3cde3b9..0000000
--- a/var/package/Lib_IDNA2-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_IDNA2</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/lgpl-3.0.en.html">GNU Lesser General Public License</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="magelib"><dir name="Net"><file name="IDNA2.php" hash="def073c649f1033d8a75189f6a99cf9d"/><dir name="IDNA2"><dir name="Exception"><file name="Nameprep.php" hash="06c4217024082f0f3b6c5a7e61ac7130"/></dir><file name="Exception.php" hash="72f605f2f6d9d56e07bb6bcec099d03a"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_IDNA2-1.9.4.1.xml b/var/package/Lib_IDNA2-1.9.4.1.xml
new file mode 100644
index 0000000..fb8c756
--- /dev/null
+++ b/var/package/Lib_IDNA2-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_IDNA2</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/lgpl-3.0.en.html">GNU Lesser General Public License</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="magelib"><dir name="Net"><file name="IDNA2.php" hash="def073c649f1033d8a75189f6a99cf9d"/><dir name="IDNA2"><dir name="Exception"><file name="Nameprep.php" hash="06c4217024082f0f3b6c5a7e61ac7130"/></dir><file name="Exception.php" hash="72f605f2f6d9d56e07bb6bcec099d03a"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Calendar-1.51.1.17.xml b/var/package/Lib_Js_Calendar-1.51.1.17.xml
deleted file mode 100644
index f37ab52..0000000
--- a/var/package/Lib_Js_Calendar-1.51.1.17.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Calendar</name>
-    <version>1.51.1.17</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Javascript Calendar for Magento</summary>
-    <description>Javascript Calendar for Magento</description>
-    <notes>1.51.1.17</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="calendar"><file name="calendar-blue.css" hash="b8bb29e3c1573d0d2917cd3112b5052d"/><file name="calendar-blue2.css" hash="654dfacebcdd70c75ccaf2b4aee2d059"/><file name="calendar-brown.css" hash="f326a6a84037e549a9cd71a92346f210"/><file name="calendar-green.css" hash="b44e2c25ff56efaa6e37d84df202e5d5"/><file name="calendar-setup.js" hash="0c21b9e48ecfad87b4c4885cfb1aca8d"/><file name="calendar-system.css" hash="9b446e2ee0e9e4420fce20922405cec7"/><file name="calendar-tas.css" hash="fa3baa9367504954ef03c1f05d44f1a6"/><file name="calendar-win2k-1.css" hash="e3c61212e6abc28844005381d8fe9690"/><file name="calendar-win2k-2.css" hash="332d8bc7dab6acd575dba49a15b62947"/><file name="calendar-win2k-cold-1.css" hash="b0810ce949e6c954c54053c52b21e74a"/><file name="calendar-win2k-cold-2.css" hash="3487ec4e054141057673d794ce6d1032"/><file name="calendar.js" hash="97705cd3aa011e9671c4441643cc704a"/><file name="img.gif" hash="c1e5255bd358fcd5a0779a0cc310a2fe"/><file name="menuarrow.gif" hash="b5a91d7a2755198b2eb729541ad3288c"/><file name="menuarrow2.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><dir name="skins"><dir name="aqua"><file name="active-bg.gif" hash="f8fb9f2b7428c94b41320aa1bc9cf601"/><file name="dark-bg.gif" hash="949f6a11667cbdfbb96f8986464ba81b"/><file name="hover-bg.gif" hash="803ac4dbc56c05739f515d6ac6a66163"/><file name="menuarrow.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><file name="normal-bg.gif" hash="851134e42206fd3b173a3db654981bb6"/><file name="rowhover-bg.gif" hash="c097de7289bcf68723e89c248b9a2749"/><file name="status-bg.gif" hash="123882ca533030f07ee55c3818fc46b9"/><file name="theme.css" hash="ec69465f70d45213258fe1f89c52eceb"/><file name="title-bg.gif" hash="8d652fc5b683706fcbbf1103131c6ac2"/><file name="today-bg.gif" hash="9befc7d912cad22ddf2ec3fc21188bfd"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Calendar-1.51.1.18.xml b/var/package/Lib_Js_Calendar-1.51.1.18.xml
new file mode 100644
index 0000000..7ae61bc
--- /dev/null
+++ b/var/package/Lib_Js_Calendar-1.51.1.18.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Calendar</name>
+    <version>1.51.1.18</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Javascript Calendar for Magento</summary>
+    <description>Javascript Calendar for Magento</description>
+    <notes>1.51.1.18</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="calendar"><file name="calendar-blue.css" hash="b8bb29e3c1573d0d2917cd3112b5052d"/><file name="calendar-blue2.css" hash="654dfacebcdd70c75ccaf2b4aee2d059"/><file name="calendar-brown.css" hash="f326a6a84037e549a9cd71a92346f210"/><file name="calendar-green.css" hash="b44e2c25ff56efaa6e37d84df202e5d5"/><file name="calendar-setup.js" hash="0c21b9e48ecfad87b4c4885cfb1aca8d"/><file name="calendar-system.css" hash="9b446e2ee0e9e4420fce20922405cec7"/><file name="calendar-tas.css" hash="fa3baa9367504954ef03c1f05d44f1a6"/><file name="calendar-win2k-1.css" hash="e3c61212e6abc28844005381d8fe9690"/><file name="calendar-win2k-2.css" hash="332d8bc7dab6acd575dba49a15b62947"/><file name="calendar-win2k-cold-1.css" hash="b0810ce949e6c954c54053c52b21e74a"/><file name="calendar-win2k-cold-2.css" hash="3487ec4e054141057673d794ce6d1032"/><file name="calendar.js" hash="97705cd3aa011e9671c4441643cc704a"/><file name="img.gif" hash="c1e5255bd358fcd5a0779a0cc310a2fe"/><file name="menuarrow.gif" hash="b5a91d7a2755198b2eb729541ad3288c"/><file name="menuarrow2.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><dir name="skins"><dir name="aqua"><file name="active-bg.gif" hash="f8fb9f2b7428c94b41320aa1bc9cf601"/><file name="dark-bg.gif" hash="949f6a11667cbdfbb96f8986464ba81b"/><file name="hover-bg.gif" hash="803ac4dbc56c05739f515d6ac6a66163"/><file name="menuarrow.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><file name="normal-bg.gif" hash="851134e42206fd3b173a3db654981bb6"/><file name="rowhover-bg.gif" hash="c097de7289bcf68723e89c248b9a2749"/><file name="status-bg.gif" hash="123882ca533030f07ee55c3818fc46b9"/><file name="theme.css" hash="ec69465f70d45213258fe1f89c52eceb"/><file name="title-bg.gif" hash="8d652fc5b683706fcbbf1103131c6ac2"/><file name="today-bg.gif" hash="9befc7d912cad22ddf2ec3fc21188bfd"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Ext-1.9.4.0.xml b/var/package/Lib_Js_Ext-1.9.4.0.xml
deleted file mode 100644
index ff83553..0000000
--- a/var/package/Lib_Js_Ext-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Ext</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Extjs Javascript Libraries for Magento</summary>
-    <description>Extjs Javascript Libraries for Magento</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:31:59</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="extjs"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="8fefe8397b484ac4855de7232d00fc5d"/><file name="box.css" hash="e042e86fe72ac68849bb2c927d1b94be"/><file name="button.css" hash="0baa72e592fb9cfddb48491ce74040c2"/><file name="combo.css" hash="5f3457b94b882c6037da7b62b10fd50b"/><file name="core.css" hash="49c87f77493ccaa4867c4c4b54e2f297"/><file name="date-picker.css" hash="cb973d925a5fe95e3a8a23393b9db283"/><file name="dd.css" hash="67c5b243c56a99eb1bdbd4d57fea7ce1"/><file name="debug.css" hash="e22d97cc54ad2f42b4f06daa921da622"/><file name="editor.css" hash="ab513287f9e04386f48980e399d4a0b1"/><file name="ext-all.css" hash="e5acad04d0e7877b829bac608437522c"/><file name="form.css" hash="22877998588bc093dcf9375b8707079c"/><file name="grid.css" hash="79cefd1763bb64802f99177f233bd676"/><file name="layout.css" hash="2ba12ec3ceff9989de97e02296c94281"/><file name="menu.css" hash="13b8de4d5f155bb5d526318431b8317f"/><file name="panel.css" hash="fb6624b2dfc4ef99e08bc11eac723e20"/><file name="qtips.css" hash="67b76bbd4ad59a7341ed74a07c8e2524"/><file name="reset-min.css" hash="9c797c4b3949999b27f0e4108132cb57"/><file name="resizable.css" hash="2271ebacebaa1e429d42ba09da460647"/><file name="tabs.css" hash="d19d0773d75a9e2fe2032b1c35a22161"/><file name="toolbar.css" hash="ff85187d3b869bf3b98a72db95fca184"/><file name="tree.css" hash="d8a55f993187bc822efc5beb03722369"/><file name="ytheme-aero.css" hash="e555e0439f7fc0a43de37784e3df23c6"/><file name="ytheme-gray.css" hash="9d08035f3b052a9c604b0116f9a6c0be"/><file name="ytheme-vista.css" hash="8b13f7980b254be7e7c54abc0d8dcc3f"/></dir><file name="ext-tree-checkbox.js" hash="b9d12cc79c28a69f86390a0c52f4b9c7"/><file name="ext-tree.js" hash="cbf1e494c6a179530e7defa99b15d67e"/><file name="fix-defer-before.js" hash="85d779f5372a11855a09263021f73eaa"/><file name="fix-defer.js" hash="e3f23509ac352690c649b6963be6cad8"/><dir name="resources"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="4cc973c87f79ea230f372cea597963ba"/><file name="box.css" hash="3809db7ee254d629d52dba0aad472d35"/><file name="button.css" hash="d3f29c8497579832fe5d7aafff7c3544"/><file name="combo.css" hash="483a1a701ca9c7db718e0e767f3d4585"/><file name="core.css" hash="6e82710d5206b6b7c0f70399cf649449"/><file name="date-picker.css" hash="fa68b668561d477e702318fb5d59636c"/><file name="dd.css" hash="f0e5f55969aeda8f65a01033613181c5"/><file name="debug.css" hash="6ef466c0c857e0c405cac7b8911f0824"/><file name="editor.css" hash="2fdb75e85a247c362285d4f079c0a12f"/><file name="ext-all.css" hash="c5e12af950c3ea3a243d0b9ca0dc4dba"/><file name="form.css" hash="38bd5bd602a83075325696af2c447e65"/><file name="grid.css" hash="c6d110f89542c04e4cbf98de73e97e9b"/><file name="layout.css" hash="89251906d248b3756f0ed354491651a6"/><file name="menu.css" hash="88eb8b3754612496ccf9d386694a39e0"/><file name="panel.css" hash="deaf7ccb5526687fadd67c093da9e604"/><file name="qtips.css" hash="2a6e683a7b23cbdf52177d7141d17435"/><file name="reset-min.css" hash="8fddbb1b7930f2817f2d5d215be98d5f"/><file name="resizable.css" hash="a50b8d1ea8e9dfbdd101a43bc63857c3"/><file name="tabs.css" hash="323d6f11f1550a43a02a617e39242ed5"/><file name="toolbar.css" hash="d09eb7507f57178967d217caeaa8b046"/><file name="tree.css" hash="b0104f954fbe1f04ebf49acffcec74ef"/><file name="ytheme-aero.css" hash="c25b48ba1b913f2ea094065fa916e9da"/><file name="ytheme-galdaka.css" hash="8b1917749205e64bdbcecc893e188b09"/><file name="ytheme-gray.css" hash="c45ba874b89038c9c8d9a79a1c591f26"/><file name="ytheme-magento.css" hash="94c3fc72743ad6d1fe7d8e74d713750e"/><file name="ytheme-vista.css" hash="2092ef97154cf5f6b33893bf5e178e21"/></dir><dir name="images"><dir name="default"><dir name="basic-dialog"><file name="btn-arrow.gif" hash="9e2365ef98c6096f6b5f411ab618bb4e"/><file name="btn-sprite.gif" hash="73a8327c23c12ed9ec42ac8f52b072e0"/><file name="close.gif" hash="2d54069e9355f295dd27027f7f779eb9"/><file name="collapse.gif" hash="63b2687a2dc81537765a7d22f9e480da"/><file name="e-handle.gif" hash="f9357e6c1dfbd00da007cf6705e08225"/><file name="expand.gif" hash="740af52fb7de6ca9fd888184e86a5308"/><file name="hd-sprite.gif" hash="6a54ae98bef53397d52282201852c204"/><file name="progress.gif" hash="baff9a083b93588fa7ff3548844a9e1a"/><file name="progress2.gif" hash="339036f9eb530c1b180c77f9a109ef3e"/><file name="s-handle.gif" hash="36b90844c0b35da23da21aac599957d4"/><file name="se-handle.gif" hash="668b22581100befcf947e806599dc0ce"/></dir><dir name="box"><file name="corners-blue.gif" hash="86fd4c5664e0971bfc11959e8442604c"/><file name="corners.gif" hash="d2d1bc2085b369ce35ffd20c0121676e"/><file name="l-blue.gif" hash="ced9ffbf66ea39e77083a591f8257267"/><file name="l.gif" hash="c4d9dbbdc59ae06b5e9e72a6a865c981"/><file name="r-blue.gif" hash="82dbb522a80e3246f6297719371a9494"/><file name="r.gif" hash="bf1e1d4a45f951ae656968a8c834f04a"/><file name="tb-blue.gif" hash="7c4b19eb682afdc1bde0640d2321fb25"/><file name="tb.gif" hash="dd3f63afe7ba90983ba73dad1c66bf2f"/></dir><dir name="dd"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-no.gif" hash="ae536c37391ba78143b5c8283cec8d13"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/></dir><dir name="editor"><file name="tb-sprite.gif" hash="8908365d736426795ce46de7e328b508"/></dir><dir name="form"><file name="clear-trigger.gif" hash="97b3e5e9edf27b50d63d48098c2f1eae"/><file name="date-trigger.gif" hash="9245675ed8931df277184b419cf4cdad"/><file name="error-tip-corners.gif" hash="364474276178c7b48b6270056b42b808"/><file name="exclamation.gif" hash="40491021e901fa801dbbc09b6c59d73e"/><file name="search-trigger.gif" hash="559ef372cf27a38678d84e8c0b7237fc"/><file name="text-bg.gif" hash="d5ba54c1f417e6a72cbce8b909078727"/><file name="trigger-tpl.gif" hash="d7be20f0dc38f4f46cd318fe32cf3ce3"/><file name="trigger.gif" hash="45019efdf75528242c5a68742821dc57"/></dir><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><dir name="grid"><file name="Thumbs.db" hash="c3affff39ba36b80da43a08c34a61391"/><file name="arrow-left-white.gif" hash="b04e859bdcbd21ad1f06b8bfa7881df8"/><file name="arrow-right-white.gif" hash="714eb00f8134dde3a65c83f3f71ad2c4"/><file name="col-move-bottom.gif" hash="9c38bcb5cee1dc9b4ce64ad9ab1386f8"/><file name="col-move-top.gif" hash="c4584202d5172464050f675d396d1c6f"/><file name="dirty.gif" hash="decca3b96e2c37cf6eb04ddb0d9f669b"/><file name="done.gif" hash="365266930a93451414fe51ffc524a196"/><file name="drop-no.gif" hash="b53ca86d60fbcc7a45c8917299218bfd"/><file name="drop-yes.gif" hash="af96f4c3b32a470db2f38abb521b5c97"/><file name="footer-bg.gif" hash="65ed63e44c6149f1127ad3b4be4e0108"/><file name="grid-blue-hd.gif" hash="dd35d5c1202c440c2d1a945b335984d3"/><file name="grid-blue-split.gif" hash="0494ba49974ff2bc1bf81e1d82dfee18"/><file name="grid-hrow.gif" hash="55972a5063d80f35fb6b95a79bb0018a"/><file name="grid-loading.gif" hash="9ac6f737eb9b15272f12b00bfeb3c3c6"/><file name="grid-split.gif" hash="3ef419d4b9421d8e94f673a6238dc4c0"/><file name="grid-vista-hd.gif" hash="675f403e8a9cb5ab4bed725da9fe2023"/><file name="grid3-hd-btn.gif" hash="e3e77072c16a6b27556236961f29c552"/><file name="grid3-hrow-over.gif" hash="a92d8f6c106943995720f2884634670e"/><file name="grid3-hrow.gif" hash="4c58074bb961c8f184522355f1b0eb90"/><file name="grid3-special-col-bg.gif" hash="c9df03a1c107360128da89fa47066405"/><file name="grid3-special-col-sel-bg.gif" hash="a94039f89dec164896ceff1fbdf6dbc5"/><file name="hd-pop.gif" hash="e5f27a2f68cc2d13b11cf41c46d298dc"/><file name="hmenu-asc.gif" hash="048e0bc30f7c39d473dad5dabcbe03f2"/><file name="hmenu-desc.gif" hash="f0a987b34b003b25a7c82624d41f018a"/><file name="hmenu-lock.gif" hash="bcef18e25342c69c37c44dab87086065"/><file name="hmenu-lock.png" hash="2a3b0b441834f443c1086930939efdae"/><file name="hmenu-unlock.gif" hash="8cc8205dafa587ef02d8a86903ae8074"/><file name="hmenu-unlock.png" hash="c1f61df70b98c5498ea81e7e7b9effbb"/><file name="invalid_line.gif" hash="04a88e97b56e8a8ece4a66d49cc78828"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="mso-hd.gif" hash="37fba9c02f0eefe57f655890eef1c4a1"/><file name="nowait.gif" hash="23c91166dbb16ba8655363321bf5a400"/><file name="page-first-disabled.gif" hash="8d3185028c541cbcce67b5909c04824e"/><file name="page-first.gif" hash="16ec00fa770d860b768cf5034ddfca96"/><file name="page-last-disabled.gif" hash="1d123237ceeb5109a1b9274f0cf19d73"/><file name="page-last.gif" hash="ef524dd0b8dfe4eefecffaa1c0bb8edd"/><file name="page-next-disabled.gif" hash="0f4b8681772c91921fa93ede9c755ea0"/><file name="page-next.gif" hash="f6f9d2209dfc99912ffc9848d97646db"/><file name="page-prev-disabled.gif" hash="eefcbed15c8d37a89618b08f7b224297"/><file name="page-prev.gif" hash="80daad880483eed682b22ec70514ecc4"/><file name="pick-button.gif" hash="b431fdf306f1e2f033d0a431996de93f"/><file name="refresh.gif" hash="8dae08d3581dcd9a04ca73877eab4b53"/><file name="row-check-sprite.gif" hash="2d0aa7e501c3e6f97a97faf75e35d3c3"/><file name="row-expand-sprite.gif" hash="be81199d9d4fa69bef47a8f036a5a7d8"/><file name="row-over.gif" hash="f639094bd0560aefabc86e51a825f23d"/><file name="row-sel.gif" hash="ca87d6b950386edd5e17c985769d9101"/><file name="sort_asc.gif" hash="cc186187e31b0c39abbb7d2394916292"/><file name="sort_desc.gif" hash="fcfe91243fac2e5f24d05bb44f78ded4"/><file name="wait.gif" hash="b0cd5a5dc070c705ebf8814a909802c3"/></dir><dir name="layout"><file name="collapse.gif" hash="dfcec0803d488a783916c750fd83a897"/><file name="expand.gif" hash="c9c9b0ea5311c3dc016c69dc234912bc"/><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><file name="ns-collapse.gif" hash="efa9fbd7a1f3f0f1f22360391e16126f"/><file name="ns-expand.gif" hash="da1f9d40c091d3b6dc7a8dee4fc02ac6"/><file name="panel-close.gif" hash="b185da1837344529bfb684a96d8371b5"/><file name="panel-title-bg.gif" hash="b66384c309a397963389a76b07e9ecd4"/><file name="panel-title-light-bg.gif" hash="688d3a263442db125da170e5d3aebf70"/><file name="stick.gif" hash="be9e67ae0b61b01cfd15928ca7a3da51"/><file name="stuck.gif" hash="745e0cacb51250ea0216efc4a1cb50cb"/><file name="tab-close-on.gif" hash="0ae2c978e85391a69f0dce8da18d8b23"/><file name="tab-close.gif" hash="f92107cc6b4cb78af084648a628e01d2"/></dir><dir name="menu"><file name="checked.gif" hash="692bc97badf50c05495f6109143b4b11"/><file name="group-checked.gif" hash="f7973443d91e5e074013f1b07ee79479"/><file name="menu-parent.gif" hash="d303ad7e3ced891736e80f77e1d4e51d"/><file name="menu.gif" hash="5d34732294bbe06a862961dd02bcc962"/><file name="unchecked.gif" hash="9b90ed7c9e8f0892ce09f3b35b19db53"/></dir><dir name="panel"><file name="corners-sprite.gif" hash="06daef2335218cdfd900ce8bf7a68738"/><file name="left-right.gif" hash="49344fefef7c6f866f910b9067f0990f"/><file name="tool-sprite-tpl.gif" hash="e0449768cd5dce80b18fac904818ab33"/><file name="tool-sprites.gif" hash="31ccd74ac8dab4b5669887310a2341df"/><file name="top-bottom.gif" hash="d9a86e8466a31bd1cb87aae2cf55faf2"/><file name="white-corners-sprite.gif" hash="de8b3036676d19b9635f319a8a4aad36"/><file name="white-left-right.gif" hash="77a6389c6737ad507ca5330ad8816524"/><file name="white-top-bottom.gif" hash="f865d7237bff3c45fd4a8c448f97d236"/></dir><dir name="qtip"><file name="bg.gif" hash="49c0a530cc16357bb39d51c13065a88f"/><file name="close.gif" hash="0379d036250096cae2e42b427b3df2e7"/><file name="tip-sprite.gif" hash="11637a20b1f3f2331bf0627146c2f433"/></dir><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/><file name="shadow-c.png" hash="3abbfce345687daada53445adf6fddc7"/><file name="shadow-lr.png" hash="986270d8ab4330fa7499dc33ed135598"/><file name="shadow.png" hash="860bf4f690d2ea2aba7b11500925da62"/><dir name="shared"><file name="calendar.gif" hash="81296cff1f97f5365524f2b9dcf626da"/><file name="glass-bg.gif" hash="bc2cd5c5ac9b3874d956c892d23f2119"/><file name="left-btn.gif" hash="6bf30c6cf0b5d70436c3e463b5532b35"/><file name="right-btn.gif" hash="e7ad3a7f4814791cecf1b90e77e9e139"/><file name="warning.gif" hash="448dc934a7f0dd6092b51f88a1e47b2d"/></dir><dir name="sizer"><file name="e-handle-dark.gif" hash="b86289f41d7ad1a7401dd2b2a9b3c3d8"/><file name="e-handle.gif" hash="510edc95ebaa36306916c50ca10596f7"/><file name="ne-handle-dark.gif" hash="115f71b851c7f0b5f354caa7b8dfff15"/><file name="ne-handle.gif" hash="8e268b962dc909d275997b572ff17a72"/><file name="nw-handle-dark.gif" hash="4a361e6920b2e34a39fd425a515c83b9"/><file name="nw-handle.gif" hash="1120600505249c38c3d1cc2ab120cd13"/><file name="s-handle-dark.gif" hash="4a6bf15d308a4ae580dd03cbd431a95c"/><file name="s-handle.gif" hash="5e3338cb09e9df7f52383d6b1423fc86"/><file name="se-handle-dark.gif" hash="f3d8d8aac23e3e9633072e2366cda847"/><file name="se-handle.gif" hash="71edc3f63f79f447d2c81ee09e1fbbc3"/><file name="square.gif" hash="4431ea1954bfd2a9cea0931f07fc7ffa"/><file name="sw-handle-dark.gif" hash="44b2400d873cf8a23d84424827cde44d"/><file name="sw-handle.gif" hash="c3e0befc4208a51180344765fd7deeda"/></dir><dir name="tabs"><file name="tab-btm-inactive-left-bg.gif" hash="4f141a6abf25d3c9409b6c381333c138"/><file name="tab-btm-inactive-right-bg.gif" hash="eb2423d3b9dd072976ce955ab0c683d6"/><file name="tab-btm-left-bg.gif" hash="a36eb9382ed8b858eff2c5d4e5d7011a"/><file name="tab-btm-right-bg.gif" hash="9e4245776f0f7b6b6c7ddbf40a43103a"/><file name="tab-sprite.gif" hash="6a7d481bf5b74acfbfa0b01a35bd6620"/></dir><dir name="toolbar"><file name="btn-arrow-light.gif" hash="fa49b39a0fd88ef26264da44a2b4edea"/><file name="btn-arrow.gif" hash="12bda29a4c8016cfa047e852c4353f59"/><file name="btn-over-bg.gif" hash="faddf9b24cefa721326ba3f87f3ef31f"/><file name="gray-bg.gif" hash="cf2d9408f320e696e607d8472afa7ff0"/><file name="tb-bg.gif" hash="5309337fd7a22cab9d9467fd9eaa0a0c"/><file name="tb-btn-sprite.gif" hash="3aed28dd646d22e215c8a6a3e983322f"/></dir><dir name="tree"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-between.gif" hash="edb544a0de58547d4a39c526e06e3c82"/><file name="drop-no.gif" hash="67f83ea04a2eb1c50614a96faf625f25"/><file name="drop-over.gif" hash="d6b303cfa3de8784057d9d7e66cdaa86"/><file name="drop-under.gif" hash="55e5dbc9451cfa91423832260b0753aa"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/><file name="elbow-end-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-end-minus.gif" hash="a469f6a4394d797c2efeffc70409f6db"/><file name="elbow-end-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-end-plus.gif" hash="ec1482391363612d9e5f8c7087fddaba"/><file name="elbow-end.gif" hash="345551384aa325189ba28a1c20f3405e"/><file name="elbow-line.gif" hash="90e478158df476dc989a60daaafc87e6"/><file name="elbow-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-minus.gif" hash="71bb1bd44b1274c60d30dba1de472ed7"/><file name="elbow-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-plus.gif" hash="945572d06a74b5f952251a86c595f2da"/><file name="elbow.gif" hash="27679f3b1222ba95d9925885d7d82d02"/><file name="folder-open.gif" hash="c569141d6ae7c61d838ed8af26aa9380"/><file name="folder.gif" hash="b7209740bb4a825a06beb8698d92c2b1"/><file name="leaf.gif" hash="23757d6e353f343e3c7edfe28428f198"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/></dir><dir name="window"><file name="corners-sprite.gif" hash="b485d6e69678822a0fb77cc312487874"/><file name="left-right.gif" hash="3fe626d6ca2f71d36fc62c32cb1cc52a"/><file name="top-bottom.gif" hash="8a227016c401438e602c2f770a611d5b"/></dir></dir><dir name="magento"><dir name="basic-dialog"><file name="collapse-on.gif" hash="b60dfdc0d00cfb30a8a622e0c22eed84"/><file name="collapse.gif" hash="8525b9d2e93d31e0b071b1f9bf9550e5"/><file name="expand-on.gif" hash="0dfb4ac6d626cdcaa931c14dbb45848e"/><file name="expand.gif" hash="0eb5c03da8b8415e0568784c959e536a"/><file name="hd-sprite.gif" hash="035bf2296afd70af7020cf06b60bf3f6"/><file name="ns-collapse-on.gif" hash="88ed8b7578c803f68d9f1eb171454e00"/><file name="ns-collapse.gif" hash="44b91376c040f91672aaa98c1fcc062b"/><file name="ns-expand-on.gif" hash="587c2ce90066280e5e6cd731bb9d346c"/><file name="ns-expand.gif" hash="57b479b168f8a54200bd1770b5591630"/><file name="panel_close.gif" hash="686c6dfcf341de25487ab4d8ea5954ce"/><file name="pop_close.gif" hash="dd3605531f9959901eff6f089f084bdc"/><file name="pop_collapse.gif" hash="2b8007242ae1c9ae9f26c60a878a63f7"/></dir><dir name="grid"><file name="grid-body-bg.gif" hash="b5fe585c01f57b2171a2b723abcc4a38"/><file name="grid-split.gif" hash="32e210451e8dc4295b53cf7ca13bb4a6"/></dir><dir name="layout"><file name="checkered-bg.gif" hash="f0a0cd29a6120377c289fd39e2ee7e80"/><file name="icon-catalog.gif" hash="435ff2300ddefb9f8a4bad8ee806fb1a"/><file name="icon-category.gif" hash="ce2a146851bb5ec1e41670b68183b56a"/><file name="icon-my-tasks.gif" hash="0ecb888b160701845e25a7140d038af0"/><file name="icon-product.gif" hash="a0707878c5221052209e5ae6a4de0bd2"/></dir><file name="loading_bg.gif" hash="e202ef7e03d0ef3e9beac7480dae65bf"/><dir name="tabs"><file name="tab-sprite.gif" hash="049fb2f4186b6dc9de747ad96456b1ab"/></dir><dir name="toolbar"><file name="btn-arrow.gif" hash="938cffb6de5cc8b1febfd1851fd983c2"/><file name="header_bg.gif" hash="3696842a32740fa159484cabc3340d13"/><file name="toolbar-bg.gif" hash="8d1b465c2a75963407b536d9081f649f"/></dir><dir name="tree"><file name="elbow-end-minus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-minus.gif" hash="3dbdb88a9297fe5631e832f046b0350b"/><file name="elbow-end-plus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-plus.gif" hash="5470e5712a9742ba666c26cb429baaeb"/><file name="elbow-end.gif" hash="63fe879440e2784e0cc0d316ce017745"/><file name="elbow-line.gif" hash="b316a39455304e20e01dbc437f57fd32"/><file name="elbow-minus-nl.gif" hash="0e3129bff70475c8f7f297e0e59d1608"/><file name="elbow-minus.gif" hash="e7b18ff6800e65c6e171bbb2a911762e"/><file name="elbow-plus-nl.gif" hash="78a8f737941fa658f1e770258a3791cd"/><file name="elbow-plus.gif" hash="b02cb264df55aef2105b1b245d075e56"/><file name="elbow.gif" hash="b6bd0e0237e3cd413fa2dac27701c724"/><file name="folder-open.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="folder.gif" hash="03eb26c42137ac792609822862ef4d0f"/><file name="leaf.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="s.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/></dir></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Ext-1.9.4.1.xml b/var/package/Lib_Js_Ext-1.9.4.1.xml
new file mode 100644
index 0000000..aedf9d5
--- /dev/null
+++ b/var/package/Lib_Js_Ext-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Ext</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Extjs Javascript Libraries for Magento</summary>
+    <description>Extjs Javascript Libraries for Magento</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="extjs"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="8fefe8397b484ac4855de7232d00fc5d"/><file name="box.css" hash="e042e86fe72ac68849bb2c927d1b94be"/><file name="button.css" hash="0baa72e592fb9cfddb48491ce74040c2"/><file name="combo.css" hash="5f3457b94b882c6037da7b62b10fd50b"/><file name="core.css" hash="49c87f77493ccaa4867c4c4b54e2f297"/><file name="date-picker.css" hash="cb973d925a5fe95e3a8a23393b9db283"/><file name="dd.css" hash="67c5b243c56a99eb1bdbd4d57fea7ce1"/><file name="debug.css" hash="e22d97cc54ad2f42b4f06daa921da622"/><file name="editor.css" hash="ab513287f9e04386f48980e399d4a0b1"/><file name="ext-all.css" hash="e5acad04d0e7877b829bac608437522c"/><file name="form.css" hash="22877998588bc093dcf9375b8707079c"/><file name="grid.css" hash="79cefd1763bb64802f99177f233bd676"/><file name="layout.css" hash="2ba12ec3ceff9989de97e02296c94281"/><file name="menu.css" hash="13b8de4d5f155bb5d526318431b8317f"/><file name="panel.css" hash="fb6624b2dfc4ef99e08bc11eac723e20"/><file name="qtips.css" hash="67b76bbd4ad59a7341ed74a07c8e2524"/><file name="reset-min.css" hash="9c797c4b3949999b27f0e4108132cb57"/><file name="resizable.css" hash="2271ebacebaa1e429d42ba09da460647"/><file name="tabs.css" hash="d19d0773d75a9e2fe2032b1c35a22161"/><file name="toolbar.css" hash="ff85187d3b869bf3b98a72db95fca184"/><file name="tree.css" hash="d8a55f993187bc822efc5beb03722369"/><file name="ytheme-aero.css" hash="e555e0439f7fc0a43de37784e3df23c6"/><file name="ytheme-gray.css" hash="9d08035f3b052a9c604b0116f9a6c0be"/><file name="ytheme-vista.css" hash="8b13f7980b254be7e7c54abc0d8dcc3f"/></dir><file name="ext-tree-checkbox.js" hash="b9d12cc79c28a69f86390a0c52f4b9c7"/><file name="ext-tree.js" hash="cbf1e494c6a179530e7defa99b15d67e"/><file name="fix-defer-before.js" hash="90cb0013791fb2ad864a09e821d58186"/><file name="fix-defer.js" hash="0c809c43ba95bfaa7eca20f073103b51"/><dir name="resources"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="4cc973c87f79ea230f372cea597963ba"/><file name="box.css" hash="3809db7ee254d629d52dba0aad472d35"/><file name="button.css" hash="d3f29c8497579832fe5d7aafff7c3544"/><file name="combo.css" hash="483a1a701ca9c7db718e0e767f3d4585"/><file name="core.css" hash="6e82710d5206b6b7c0f70399cf649449"/><file name="date-picker.css" hash="fa68b668561d477e702318fb5d59636c"/><file name="dd.css" hash="f0e5f55969aeda8f65a01033613181c5"/><file name="debug.css" hash="6ef466c0c857e0c405cac7b8911f0824"/><file name="editor.css" hash="2fdb75e85a247c362285d4f079c0a12f"/><file name="ext-all.css" hash="c5e12af950c3ea3a243d0b9ca0dc4dba"/><file name="form.css" hash="38bd5bd602a83075325696af2c447e65"/><file name="grid.css" hash="c6d110f89542c04e4cbf98de73e97e9b"/><file name="layout.css" hash="89251906d248b3756f0ed354491651a6"/><file name="menu.css" hash="88eb8b3754612496ccf9d386694a39e0"/><file name="panel.css" hash="deaf7ccb5526687fadd67c093da9e604"/><file name="qtips.css" hash="2a6e683a7b23cbdf52177d7141d17435"/><file name="reset-min.css" hash="8fddbb1b7930f2817f2d5d215be98d5f"/><file name="resizable.css" hash="a50b8d1ea8e9dfbdd101a43bc63857c3"/><file name="tabs.css" hash="323d6f11f1550a43a02a617e39242ed5"/><file name="toolbar.css" hash="d09eb7507f57178967d217caeaa8b046"/><file name="tree.css" hash="b0104f954fbe1f04ebf49acffcec74ef"/><file name="ytheme-aero.css" hash="c25b48ba1b913f2ea094065fa916e9da"/><file name="ytheme-galdaka.css" hash="8b1917749205e64bdbcecc893e188b09"/><file name="ytheme-gray.css" hash="c45ba874b89038c9c8d9a79a1c591f26"/><file name="ytheme-magento.css" hash="94c3fc72743ad6d1fe7d8e74d713750e"/><file name="ytheme-vista.css" hash="2092ef97154cf5f6b33893bf5e178e21"/></dir><dir name="images"><dir name="default"><dir name="basic-dialog"><file name="btn-arrow.gif" hash="9e2365ef98c6096f6b5f411ab618bb4e"/><file name="btn-sprite.gif" hash="73a8327c23c12ed9ec42ac8f52b072e0"/><file name="close.gif" hash="2d54069e9355f295dd27027f7f779eb9"/><file name="collapse.gif" hash="63b2687a2dc81537765a7d22f9e480da"/><file name="e-handle.gif" hash="f9357e6c1dfbd00da007cf6705e08225"/><file name="expand.gif" hash="740af52fb7de6ca9fd888184e86a5308"/><file name="hd-sprite.gif" hash="6a54ae98bef53397d52282201852c204"/><file name="progress.gif" hash="baff9a083b93588fa7ff3548844a9e1a"/><file name="progress2.gif" hash="339036f9eb530c1b180c77f9a109ef3e"/><file name="s-handle.gif" hash="36b90844c0b35da23da21aac599957d4"/><file name="se-handle.gif" hash="668b22581100befcf947e806599dc0ce"/></dir><dir name="box"><file name="corners-blue.gif" hash="86fd4c5664e0971bfc11959e8442604c"/><file name="corners.gif" hash="d2d1bc2085b369ce35ffd20c0121676e"/><file name="l-blue.gif" hash="ced9ffbf66ea39e77083a591f8257267"/><file name="l.gif" hash="c4d9dbbdc59ae06b5e9e72a6a865c981"/><file name="r-blue.gif" hash="82dbb522a80e3246f6297719371a9494"/><file name="r.gif" hash="bf1e1d4a45f951ae656968a8c834f04a"/><file name="tb-blue.gif" hash="7c4b19eb682afdc1bde0640d2321fb25"/><file name="tb.gif" hash="dd3f63afe7ba90983ba73dad1c66bf2f"/></dir><dir name="dd"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-no.gif" hash="ae536c37391ba78143b5c8283cec8d13"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/></dir><dir name="editor"><file name="tb-sprite.gif" hash="8908365d736426795ce46de7e328b508"/></dir><dir name="form"><file name="clear-trigger.gif" hash="97b3e5e9edf27b50d63d48098c2f1eae"/><file name="date-trigger.gif" hash="9245675ed8931df277184b419cf4cdad"/><file name="error-tip-corners.gif" hash="364474276178c7b48b6270056b42b808"/><file name="exclamation.gif" hash="40491021e901fa801dbbc09b6c59d73e"/><file name="search-trigger.gif" hash="559ef372cf27a38678d84e8c0b7237fc"/><file name="text-bg.gif" hash="d5ba54c1f417e6a72cbce8b909078727"/><file name="trigger-tpl.gif" hash="d7be20f0dc38f4f46cd318fe32cf3ce3"/><file name="trigger.gif" hash="45019efdf75528242c5a68742821dc57"/></dir><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><dir name="grid"><file name="Thumbs.db" hash="c3affff39ba36b80da43a08c34a61391"/><file name="arrow-left-white.gif" hash="b04e859bdcbd21ad1f06b8bfa7881df8"/><file name="arrow-right-white.gif" hash="714eb00f8134dde3a65c83f3f71ad2c4"/><file name="col-move-bottom.gif" hash="9c38bcb5cee1dc9b4ce64ad9ab1386f8"/><file name="col-move-top.gif" hash="c4584202d5172464050f675d396d1c6f"/><file name="dirty.gif" hash="decca3b96e2c37cf6eb04ddb0d9f669b"/><file name="done.gif" hash="365266930a93451414fe51ffc524a196"/><file name="drop-no.gif" hash="b53ca86d60fbcc7a45c8917299218bfd"/><file name="drop-yes.gif" hash="af96f4c3b32a470db2f38abb521b5c97"/><file name="footer-bg.gif" hash="65ed63e44c6149f1127ad3b4be4e0108"/><file name="grid-blue-hd.gif" hash="dd35d5c1202c440c2d1a945b335984d3"/><file name="grid-blue-split.gif" hash="0494ba49974ff2bc1bf81e1d82dfee18"/><file name="grid-hrow.gif" hash="55972a5063d80f35fb6b95a79bb0018a"/><file name="grid-loading.gif" hash="9ac6f737eb9b15272f12b00bfeb3c3c6"/><file name="grid-split.gif" hash="3ef419d4b9421d8e94f673a6238dc4c0"/><file name="grid-vista-hd.gif" hash="675f403e8a9cb5ab4bed725da9fe2023"/><file name="grid3-hd-btn.gif" hash="e3e77072c16a6b27556236961f29c552"/><file name="grid3-hrow-over.gif" hash="a92d8f6c106943995720f2884634670e"/><file name="grid3-hrow.gif" hash="4c58074bb961c8f184522355f1b0eb90"/><file name="grid3-special-col-bg.gif" hash="c9df03a1c107360128da89fa47066405"/><file name="grid3-special-col-sel-bg.gif" hash="a94039f89dec164896ceff1fbdf6dbc5"/><file name="hd-pop.gif" hash="e5f27a2f68cc2d13b11cf41c46d298dc"/><file name="hmenu-asc.gif" hash="048e0bc30f7c39d473dad5dabcbe03f2"/><file name="hmenu-desc.gif" hash="f0a987b34b003b25a7c82624d41f018a"/><file name="hmenu-lock.gif" hash="bcef18e25342c69c37c44dab87086065"/><file name="hmenu-lock.png" hash="2a3b0b441834f443c1086930939efdae"/><file name="hmenu-unlock.gif" hash="8cc8205dafa587ef02d8a86903ae8074"/><file name="hmenu-unlock.png" hash="c1f61df70b98c5498ea81e7e7b9effbb"/><file name="invalid_line.gif" hash="04a88e97b56e8a8ece4a66d49cc78828"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="mso-hd.gif" hash="37fba9c02f0eefe57f655890eef1c4a1"/><file name="nowait.gif" hash="23c91166dbb16ba8655363321bf5a400"/><file name="page-first-disabled.gif" hash="8d3185028c541cbcce67b5909c04824e"/><file name="page-first.gif" hash="16ec00fa770d860b768cf5034ddfca96"/><file name="page-last-disabled.gif" hash="1d123237ceeb5109a1b9274f0cf19d73"/><file name="page-last.gif" hash="ef524dd0b8dfe4eefecffaa1c0bb8edd"/><file name="page-next-disabled.gif" hash="0f4b8681772c91921fa93ede9c755ea0"/><file name="page-next.gif" hash="f6f9d2209dfc99912ffc9848d97646db"/><file name="page-prev-disabled.gif" hash="eefcbed15c8d37a89618b08f7b224297"/><file name="page-prev.gif" hash="80daad880483eed682b22ec70514ecc4"/><file name="pick-button.gif" hash="b431fdf306f1e2f033d0a431996de93f"/><file name="refresh.gif" hash="8dae08d3581dcd9a04ca73877eab4b53"/><file name="row-check-sprite.gif" hash="2d0aa7e501c3e6f97a97faf75e35d3c3"/><file name="row-expand-sprite.gif" hash="be81199d9d4fa69bef47a8f036a5a7d8"/><file name="row-over.gif" hash="f639094bd0560aefabc86e51a825f23d"/><file name="row-sel.gif" hash="ca87d6b950386edd5e17c985769d9101"/><file name="sort_asc.gif" hash="cc186187e31b0c39abbb7d2394916292"/><file name="sort_desc.gif" hash="fcfe91243fac2e5f24d05bb44f78ded4"/><file name="wait.gif" hash="b0cd5a5dc070c705ebf8814a909802c3"/></dir><dir name="layout"><file name="collapse.gif" hash="dfcec0803d488a783916c750fd83a897"/><file name="expand.gif" hash="c9c9b0ea5311c3dc016c69dc234912bc"/><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><file name="ns-collapse.gif" hash="efa9fbd7a1f3f0f1f22360391e16126f"/><file name="ns-expand.gif" hash="da1f9d40c091d3b6dc7a8dee4fc02ac6"/><file name="panel-close.gif" hash="b185da1837344529bfb684a96d8371b5"/><file name="panel-title-bg.gif" hash="b66384c309a397963389a76b07e9ecd4"/><file name="panel-title-light-bg.gif" hash="688d3a263442db125da170e5d3aebf70"/><file name="stick.gif" hash="be9e67ae0b61b01cfd15928ca7a3da51"/><file name="stuck.gif" hash="745e0cacb51250ea0216efc4a1cb50cb"/><file name="tab-close-on.gif" hash="0ae2c978e85391a69f0dce8da18d8b23"/><file name="tab-close.gif" hash="f92107cc6b4cb78af084648a628e01d2"/></dir><dir name="menu"><file name="checked.gif" hash="692bc97badf50c05495f6109143b4b11"/><file name="group-checked.gif" hash="f7973443d91e5e074013f1b07ee79479"/><file name="menu-parent.gif" hash="d303ad7e3ced891736e80f77e1d4e51d"/><file name="menu.gif" hash="5d34732294bbe06a862961dd02bcc962"/><file name="unchecked.gif" hash="9b90ed7c9e8f0892ce09f3b35b19db53"/></dir><dir name="panel"><file name="corners-sprite.gif" hash="06daef2335218cdfd900ce8bf7a68738"/><file name="left-right.gif" hash="49344fefef7c6f866f910b9067f0990f"/><file name="tool-sprite-tpl.gif" hash="e0449768cd5dce80b18fac904818ab33"/><file name="tool-sprites.gif" hash="31ccd74ac8dab4b5669887310a2341df"/><file name="top-bottom.gif" hash="d9a86e8466a31bd1cb87aae2cf55faf2"/><file name="white-corners-sprite.gif" hash="de8b3036676d19b9635f319a8a4aad36"/><file name="white-left-right.gif" hash="77a6389c6737ad507ca5330ad8816524"/><file name="white-top-bottom.gif" hash="f865d7237bff3c45fd4a8c448f97d236"/></dir><dir name="qtip"><file name="bg.gif" hash="49c0a530cc16357bb39d51c13065a88f"/><file name="close.gif" hash="0379d036250096cae2e42b427b3df2e7"/><file name="tip-sprite.gif" hash="11637a20b1f3f2331bf0627146c2f433"/></dir><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/><file name="shadow-c.png" hash="3abbfce345687daada53445adf6fddc7"/><file name="shadow-lr.png" hash="986270d8ab4330fa7499dc33ed135598"/><file name="shadow.png" hash="860bf4f690d2ea2aba7b11500925da62"/><dir name="shared"><file name="calendar.gif" hash="81296cff1f97f5365524f2b9dcf626da"/><file name="glass-bg.gif" hash="bc2cd5c5ac9b3874d956c892d23f2119"/><file name="left-btn.gif" hash="6bf30c6cf0b5d70436c3e463b5532b35"/><file name="right-btn.gif" hash="e7ad3a7f4814791cecf1b90e77e9e139"/><file name="warning.gif" hash="448dc934a7f0dd6092b51f88a1e47b2d"/></dir><dir name="sizer"><file name="e-handle-dark.gif" hash="b86289f41d7ad1a7401dd2b2a9b3c3d8"/><file name="e-handle.gif" hash="510edc95ebaa36306916c50ca10596f7"/><file name="ne-handle-dark.gif" hash="115f71b851c7f0b5f354caa7b8dfff15"/><file name="ne-handle.gif" hash="8e268b962dc909d275997b572ff17a72"/><file name="nw-handle-dark.gif" hash="4a361e6920b2e34a39fd425a515c83b9"/><file name="nw-handle.gif" hash="1120600505249c38c3d1cc2ab120cd13"/><file name="s-handle-dark.gif" hash="4a6bf15d308a4ae580dd03cbd431a95c"/><file name="s-handle.gif" hash="5e3338cb09e9df7f52383d6b1423fc86"/><file name="se-handle-dark.gif" hash="f3d8d8aac23e3e9633072e2366cda847"/><file name="se-handle.gif" hash="71edc3f63f79f447d2c81ee09e1fbbc3"/><file name="square.gif" hash="4431ea1954bfd2a9cea0931f07fc7ffa"/><file name="sw-handle-dark.gif" hash="44b2400d873cf8a23d84424827cde44d"/><file name="sw-handle.gif" hash="c3e0befc4208a51180344765fd7deeda"/></dir><dir name="tabs"><file name="tab-btm-inactive-left-bg.gif" hash="4f141a6abf25d3c9409b6c381333c138"/><file name="tab-btm-inactive-right-bg.gif" hash="eb2423d3b9dd072976ce955ab0c683d6"/><file name="tab-btm-left-bg.gif" hash="a36eb9382ed8b858eff2c5d4e5d7011a"/><file name="tab-btm-right-bg.gif" hash="9e4245776f0f7b6b6c7ddbf40a43103a"/><file name="tab-sprite.gif" hash="6a7d481bf5b74acfbfa0b01a35bd6620"/></dir><dir name="toolbar"><file name="btn-arrow-light.gif" hash="fa49b39a0fd88ef26264da44a2b4edea"/><file name="btn-arrow.gif" hash="12bda29a4c8016cfa047e852c4353f59"/><file name="btn-over-bg.gif" hash="faddf9b24cefa721326ba3f87f3ef31f"/><file name="gray-bg.gif" hash="cf2d9408f320e696e607d8472afa7ff0"/><file name="tb-bg.gif" hash="5309337fd7a22cab9d9467fd9eaa0a0c"/><file name="tb-btn-sprite.gif" hash="3aed28dd646d22e215c8a6a3e983322f"/></dir><dir name="tree"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-between.gif" hash="edb544a0de58547d4a39c526e06e3c82"/><file name="drop-no.gif" hash="67f83ea04a2eb1c50614a96faf625f25"/><file name="drop-over.gif" hash="d6b303cfa3de8784057d9d7e66cdaa86"/><file name="drop-under.gif" hash="55e5dbc9451cfa91423832260b0753aa"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/><file name="elbow-end-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-end-minus.gif" hash="a469f6a4394d797c2efeffc70409f6db"/><file name="elbow-end-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-end-plus.gif" hash="ec1482391363612d9e5f8c7087fddaba"/><file name="elbow-end.gif" hash="345551384aa325189ba28a1c20f3405e"/><file name="elbow-line.gif" hash="90e478158df476dc989a60daaafc87e6"/><file name="elbow-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-minus.gif" hash="71bb1bd44b1274c60d30dba1de472ed7"/><file name="elbow-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-plus.gif" hash="945572d06a74b5f952251a86c595f2da"/><file name="elbow.gif" hash="27679f3b1222ba95d9925885d7d82d02"/><file name="folder-open.gif" hash="c569141d6ae7c61d838ed8af26aa9380"/><file name="folder.gif" hash="b7209740bb4a825a06beb8698d92c2b1"/><file name="leaf.gif" hash="23757d6e353f343e3c7edfe28428f198"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/></dir><dir name="window"><file name="corners-sprite.gif" hash="b485d6e69678822a0fb77cc312487874"/><file name="left-right.gif" hash="3fe626d6ca2f71d36fc62c32cb1cc52a"/><file name="top-bottom.gif" hash="8a227016c401438e602c2f770a611d5b"/></dir></dir><dir name="magento"><dir name="basic-dialog"><file name="collapse-on.gif" hash="b60dfdc0d00cfb30a8a622e0c22eed84"/><file name="collapse.gif" hash="8525b9d2e93d31e0b071b1f9bf9550e5"/><file name="expand-on.gif" hash="0dfb4ac6d626cdcaa931c14dbb45848e"/><file name="expand.gif" hash="0eb5c03da8b8415e0568784c959e536a"/><file name="hd-sprite.gif" hash="035bf2296afd70af7020cf06b60bf3f6"/><file name="ns-collapse-on.gif" hash="88ed8b7578c803f68d9f1eb171454e00"/><file name="ns-collapse.gif" hash="44b91376c040f91672aaa98c1fcc062b"/><file name="ns-expand-on.gif" hash="587c2ce90066280e5e6cd731bb9d346c"/><file name="ns-expand.gif" hash="57b479b168f8a54200bd1770b5591630"/><file name="panel_close.gif" hash="686c6dfcf341de25487ab4d8ea5954ce"/><file name="pop_close.gif" hash="dd3605531f9959901eff6f089f084bdc"/><file name="pop_collapse.gif" hash="2b8007242ae1c9ae9f26c60a878a63f7"/></dir><dir name="grid"><file name="grid-body-bg.gif" hash="b5fe585c01f57b2171a2b723abcc4a38"/><file name="grid-split.gif" hash="32e210451e8dc4295b53cf7ca13bb4a6"/></dir><dir name="layout"><file name="checkered-bg.gif" hash="f0a0cd29a6120377c289fd39e2ee7e80"/><file name="icon-catalog.gif" hash="435ff2300ddefb9f8a4bad8ee806fb1a"/><file name="icon-category.gif" hash="ce2a146851bb5ec1e41670b68183b56a"/><file name="icon-my-tasks.gif" hash="0ecb888b160701845e25a7140d038af0"/><file name="icon-product.gif" hash="a0707878c5221052209e5ae6a4de0bd2"/></dir><file name="loading_bg.gif" hash="e202ef7e03d0ef3e9beac7480dae65bf"/><dir name="tabs"><file name="tab-sprite.gif" hash="049fb2f4186b6dc9de747ad96456b1ab"/></dir><dir name="toolbar"><file name="btn-arrow.gif" hash="938cffb6de5cc8b1febfd1851fd983c2"/><file name="header_bg.gif" hash="3696842a32740fa159484cabc3340d13"/><file name="toolbar-bg.gif" hash="8d1b465c2a75963407b536d9081f649f"/></dir><dir name="tree"><file name="elbow-end-minus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-minus.gif" hash="3dbdb88a9297fe5631e832f046b0350b"/><file name="elbow-end-plus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-plus.gif" hash="5470e5712a9742ba666c26cb429baaeb"/><file name="elbow-end.gif" hash="63fe879440e2784e0cc0d316ce017745"/><file name="elbow-line.gif" hash="b316a39455304e20e01dbc437f57fd32"/><file name="elbow-minus-nl.gif" hash="0e3129bff70475c8f7f297e0e59d1608"/><file name="elbow-minus.gif" hash="e7b18ff6800e65c6e171bbb2a911762e"/><file name="elbow-plus-nl.gif" hash="78a8f737941fa658f1e770258a3791cd"/><file name="elbow-plus.gif" hash="b02cb264df55aef2105b1b245d075e56"/><file name="elbow.gif" hash="b6bd0e0237e3cd413fa2dac27701c724"/><file name="folder-open.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="folder.gif" hash="03eb26c42137ac792609822862ef4d0f"/><file name="leaf.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="s.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/></dir></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Mage-1.9.4.0.xml b/var/package/Lib_Js_Mage-1.9.4.0.xml
deleted file mode 100644
index e75dfd1..0000000
--- a/var/package/Lib_Js_Mage-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Mage</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Javascript Libraries for Magento</summary>
-    <description>Javascript Libraries for Magento</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:00</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="lib"><file name="FABridge.js" hash="64244d8d58abd42bd71f0ee3309767ad"/><file name="boxover.js" hash="a5ade77452e8d5066cb84dcac3d34ed5"/><file name="ccard.js" hash="d3e849be0977d53de4af933b40293ff6"/><file name="dropdown.js" hash="4c2b33fe18424cdee8fc659216afd3a9"/><file name="ds-sleight.js" hash="85af457d444865d1587bfe4875bd4fc6"/><file name="flex.js" hash="f27867374b9cb7ff86aae31bb39f016f"/><dir name="jquery"><file name="jquery-1.10.2.js" hash="91515770ce8c55de23b306444d8ea998"/><file name="jquery-1.10.2.min.js" hash="841dc30647f93349b7d8ef61deebe411"/><file name="jquery-1.10.2.min.map" hash="6c3ccfc221d36777d383b6e04d0b8af9"/><file name="jquery-1.12.1.js" hash="62f69d29b6f01c8d477a547cedd922f2"/><file name="jquery-1.12.1.min.js" hash="1d244cb043be8157f0050ce9e45c9ef2"/><file name="jquery-1.12.1.min.map" hash="7761e30c5da1bf6d7cebc61bf612cd0e"/><file name="noconflict.js" hash="07849ea227cb2aee266dc14250cdcd72"/></dir><dir name="uploader"><file name="flow.min.js" hash="a82a557db407b53d5909fa4e1833a596"/><file name="fusty-flow-factory.js" hash="b3f49be0f28be74e8b8bb76496c52bc3"/><file name="fusty-flow.js" hash="302f440908837093fd4e9b6e76ec01e0"/></dir></dir><dir name="mage"><dir name="adminhtml"><file name="accordion.js" hash="c224339498e1a5304c073992a6d2cdeb"/><file name="backup.js" hash="4f53863337f627518eb0f57e7311a17a"/><file name="browser.js" hash="5bdae849d93e161a4c640735dfddef42"/><file name="events.js" hash="4d00fe8eeca479b3fd6997e681ec27e8"/><file name="flexuploader.js" hash="18328b7c8a81856a079d2994df59f902"/><file name="form.js" hash="8fa0d7ec3b03bb7ca41e5d4642888e94"/><file name="giftmessage.js" hash="2da5ed0ca29f3880e462cedbca8696b1"/><dir name="giftoptions"><file name="tooltip.js" hash="f5f4920568cb210aa7f8a0b2f9e0cb61"/></dir><file name="grid.js" hash="c33482101b7dd98763580acf1a5f2467"/><file name="hash.js" hash="261990e25a4586d43b1f5f4a02c31725"/><file name="image.js" hash="aa2f2fe381fb72a3446cf4d86badf1d8"/><file name="loader.js" hash="13835f1f7a1bd9066421e57b58e47298"/><file name="magento-all.js" hash="18e7474bb5aed97654e5bacd17076ef0"/><dir name="product"><dir name="composite"><file name="configure.js" hash="540ad14016cd4ab412dd2cd53e54cd27"/></dir></dir><file name="product.js" hash="5cf2b85a5c0ce65f6bf23f93ceafddd6"/><file name="rules.js" hash="31038635fcfae3918eabbfeb1048fcc1"/><dir name="sales"><file name="packaging.js" hash="cfb830d02a33c0e187660056a6e96277"/></dir><file name="sales.js" hash="3bef4871048d012d98e2389629501eec"/><file name="scrollbar.js" hash="ff79af2fa0ef8359319c7aec26f0d619"/><file name="tabs.js" hash="591ec7eb2d6ba32312ea7eeed145acb0"/><file name="tools.js" hash="4ecb7d1027caa06eda1166c2047e08a5"/><dir name="uploader"><file name="instance.js" hash="0e183b33955a1d1fb56dae0d2514f2d7"/></dir><file name="uploader.js" hash="e4da8c0e0261633c08dd89763cfdaa0c"/><file name="variables.js" hash="962b37dd6d893bfcc3f6553c2349df2a"/><dir name="wysiwyg"><dir name="tiny_mce"><dir name="plugins"><dir name="magentovariable"><file name="editor_plugin.js" hash="003b55ae437653b03963361b597ca7dd"/><dir name="img"><file name="icon.gif" hash="682b29a0e734f952cb2edabede6a25d1"/></dir></dir><dir name="magentowidget"><file name="editor_plugin.js" hash="c7fae499606d95f57f33300c0abf69f4"/><dir name="img"><file name="icon.gif" hash="532c141286373f098f1f4362e001c7f8"/></dir></dir></dir><file name="setup.js" hash="161bd02789945f1f0d24e0f028cbbd27"/><dir name="themes"><dir name="advanced"><dir name="skins"><dir name="default"><file name="content.css" hash="40e74d28dda4e3ed888ed9c389926ccc"/><file name="dialog.css" hash="e4ee65e17609668f49e60c78bf2ae674"/></dir></dir></dir></dir></dir><file name="widget.js" hash="8da09568baa72ae676f0e1e73be455e3"/></dir></dir><file name="captcha.js" hash="7be5c30bf178e3c1e2669db356a393f6"/><file name="centinel.js" hash="6e1b4524431eefa50d71be4441082083"/><file name="cookies.js" hash="67eadf7b9433d2cfc96546a85ebc5959"/><file name="directpost.js" hash="77a4f2f1017d6fc2d2c436b1c6840228"/><file name="translate.js" hash="5dae341ece021a8e9a9fdfcf89d94534"/><file name="translate_inline.css" hash="94ee55676a3ca446a403d21b7631dad4"/><file name="translate_inline.js" hash="3cfb6136a5756361cabc24773510c41f"/></dir><dir name="varien"><file name="accordion.js" hash="0b3016995870cd0b7050e05889b13098"/><file name="configurable.js" hash="4307b8038f4801db44a7728541a19674"/><file name="form.js" hash="ee2b2973a3595cc4048d6323c4df0dd5"/><file name="iehover-fix.js" hash="b28db3c01092190e221fee9903ac009c"/><file name="js.js" hash="d7d1e41851cfe1e49c65b754def9c082"/><file name="menu.js" hash="f2b0d57545ca03f598a2bb4a323c31ce"/><file name="payment.js" hash="2009cfa0cb7235a2e0b21a6f901cf67b"/><file name="product.js" hash="648b67b08c822cfedfcaea6d4a47f9d6"/><file name="product_options.js" hash="dbfe01736095f1efd73e05bf89624212"/><file name="telephone.js" hash="eb4c304fba714b84af5d7feed3fc239e"/><file name="weee.js" hash="22a837f9bb7d0f1ef95d71bb2533bbd9"/></dir><file name="blank.html" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="index.php" hash="702348421e0df944034bf0e4569f197d"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><dir name="flash"><file name="AC_RunActiveContent.js" hash="3e038cea960c1b650442b85cea237053"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Mage-1.9.4.1.xml b/var/package/Lib_Js_Mage-1.9.4.1.xml
new file mode 100644
index 0000000..1b7877a
--- /dev/null
+++ b/var/package/Lib_Js_Mage-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Mage</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Javascript Libraries for Magento</summary>
+    <description>Javascript Libraries for Magento</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="lib"><file name="FABridge.js" hash="64244d8d58abd42bd71f0ee3309767ad"/><file name="boxover.js" hash="a5ade77452e8d5066cb84dcac3d34ed5"/><file name="ccard.js" hash="d3e849be0977d53de4af933b40293ff6"/><file name="dropdown.js" hash="d74331fd65500cd64785163be3a434e6"/><file name="ds-sleight.js" hash="85af457d444865d1587bfe4875bd4fc6"/><file name="flex.js" hash="f9d88fdfef8a3bed86df58ed37cab345"/><dir name="jquery"><file name="jquery-1.10.2.js" hash="91515770ce8c55de23b306444d8ea998"/><file name="jquery-1.10.2.min.js" hash="841dc30647f93349b7d8ef61deebe411"/><file name="jquery-1.10.2.min.map" hash="6c3ccfc221d36777d383b6e04d0b8af9"/><file name="jquery-1.12.1.js" hash="62f69d29b6f01c8d477a547cedd922f2"/><file name="jquery-1.12.1.min.js" hash="1d244cb043be8157f0050ce9e45c9ef2"/><file name="jquery-1.12.1.min.map" hash="7761e30c5da1bf6d7cebc61bf612cd0e"/><file name="noconflict.js" hash="eafadf93ad691e381b31c79222507a83"/></dir><dir name="uploader"><file name="flow.min.js" hash="a82a557db407b53d5909fa4e1833a596"/><file name="fusty-flow-factory.js" hash="b3f49be0f28be74e8b8bb76496c52bc3"/><file name="fusty-flow.js" hash="302f440908837093fd4e9b6e76ec01e0"/></dir></dir><dir name="mage"><dir name="adminhtml"><file name="accordion.js" hash="3aa37f15fffadff036e88674fcbba336"/><file name="backup.js" hash="a5d9b6f5613c1407d6e4a7a7951ace80"/><file name="browser.js" hash="4d317c43a354cf614c155536e0ce6186"/><file name="events.js" hash="6cf24a04511896958fafb2f51f9f2ead"/><file name="flexuploader.js" hash="db54e1f8de2e441716b7ea3e1c8f3e55"/><file name="form.js" hash="be6975ed85d5ccedf447bd620a52ce36"/><file name="giftmessage.js" hash="68687e12c1e297b6b1e370102ad213ef"/><dir name="giftoptions"><file name="tooltip.js" hash="ed97a2001cbe2e09720d1a96883dcb61"/></dir><file name="grid.js" hash="b01c7305db7f6eba4236a836b5e0004c"/><file name="hash.js" hash="02bc7053edc147185e4e8de7f935ab12"/><file name="image.js" hash="79bbb61c8ed6ebfe8b576358d8db0104"/><file name="loader.js" hash="66f7a49300e1ee0b00afb53b1f7a22bb"/><file name="magento-all.js" hash="21ba6e3e754f0a45440178ce81dd2604"/><dir name="product"><dir name="composite"><file name="configure.js" hash="310f5314b8dc7faa0be8e35e80cff7f4"/></dir></dir><file name="product.js" hash="38ffa4aa21de646b4f1acfc657a4cc68"/><file name="rules.js" hash="9cb6236e99586a32a4797ddd5ff14d40"/><dir name="sales"><file name="packaging.js" hash="4039a5cb08d716e88af502617111eacc"/></dir><file name="sales.js" hash="36e169d95a25c454f989ac10a0759153"/><file name="scrollbar.js" hash="111c61f0618cd2c5fab7a2bff60b27e7"/><file name="tabs.js" hash="c5b880d653923fe89a7c890cc48073e9"/><file name="tools.js" hash="9fdc751d2cdd5f299d44f0bbd72ae3ff"/><dir name="uploader"><file name="instance.js" hash="2a248014ba11ad618c407150c802bae9"/></dir><file name="uploader.js" hash="072d5070944ee0f95687ce3838ab61f9"/><file name="variables.js" hash="d6941a240dd440594cb8ca4f944840ba"/><dir name="wysiwyg"><dir name="tiny_mce"><dir name="plugins"><dir name="magentovariable"><file name="editor_plugin.js" hash="eea3b1037886236f0f307e80fb162409"/><dir name="img"><file name="icon.gif" hash="682b29a0e734f952cb2edabede6a25d1"/></dir></dir><dir name="magentowidget"><file name="editor_plugin.js" hash="ce29610466ae0718054f9e3defaf5acb"/><dir name="img"><file name="icon.gif" hash="532c141286373f098f1f4362e001c7f8"/></dir></dir></dir><file name="setup.js" hash="d1325c4d9a5695cd5ad17594225fed5a"/><dir name="themes"><dir name="advanced"><dir name="skins"><dir name="default"><file name="content.css" hash="f573fb8565f8da1b9a2a29dd887ddbc5"/><file name="dialog.css" hash="2aa257d84ac0fd6b8809eee27a7f4193"/></dir></dir></dir></dir></dir><file name="widget.js" hash="b3a489bd327120724dae7c177c45fd69"/></dir></dir><file name="captcha.js" hash="997a04b22dc43ec11d7268417d206b51"/><file name="centinel.js" hash="d075a88fa4ba8495692a63f535f4cbba"/><file name="cookies.js" hash="b6bd01414e9cd58410aa11c0415a3884"/><file name="directpost.js" hash="588b9fcae7ad1f7288245c2a2ad2bbbb"/><file name="translate.js" hash="dce2b661d6b0675c7474a431f0f5185f"/><file name="translate_inline.css" hash="1df877f84ffcfff5529f8b5b02b0768f"/><file name="translate_inline.js" hash="1b6ab25d6dd80ed93e4dafd44b3bf2b7"/></dir><dir name="varien"><file name="accordion.js" hash="6823368dbc5179d26de71e30191f4edc"/><file name="configurable.js" hash="00da2ece9e4fc6337d9fc89d62e109c6"/><file name="form.js" hash="b4842ad91d7717ab5d40012b4e5fcf14"/><file name="iehover-fix.js" hash="33e74ae53e94f614f23dbdd65a3066e2"/><file name="js.js" hash="365504893b4d855adb8be98e1dac09e8"/><file name="menu.js" hash="7b74f8382494b73951d667d11826ccda"/><file name="payment.js" hash="57714c8b509a5279293cb609a4ee72b6"/><file name="product.js" hash="b42952fdef14b8f0ef6ae786ffbf19c1"/><file name="product_options.js" hash="5ce9e7c61822c56a8148e3b94d527fc7"/><file name="telephone.js" hash="927282682aed203d711b14766d5ddafd"/><file name="weee.js" hash="fb7dffa37b206729b224ea5508395a86"/></dir><file name="blank.html" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="index.php" hash="80ad8e3ab73bcb13af1e8490f9d1637b"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><dir name="flash"><file name="AC_RunActiveContent.js" hash="3e038cea960c1b650442b85cea237053"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Prototype-1.9.4.0.xml b/var/package/Lib_Js_Prototype-1.9.4.0.xml
deleted file mode 100644
index d2699ba..0000000
--- a/var/package/Lib_Js_Prototype-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Prototype</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Prototype and Scriptaculous Javascript Libraries for Magento</summary>
-    <description>Prototype and Scriptaculous Javascript Libraries for Magento</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:00</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="prototype"><file name="debug.js" hash="d5990eabf728ade1f34496737455c8ff"/><file name="effects.js" hash="91e1b7d8c6043dff4eadbe054a90e3a7"/><file name="extended_debug.js" hash="cc706bc76bb1c5a2610fc296cd85e053"/><file name="prototype.js" hash="3b4b13dad33b475e11feb26fd3468ecc"/><file name="tooltip.js" hash="8509b04b1594b7e6382d7cfdf4ee1236"/><file name="tooltip_manager.js" hash="6b9759cbad296fda3c18d7669d6b5af0"/><file name="validation.js" hash="a841158a1143694d447cc78e1099b3c8"/><file name="window.js" hash="1ad7aab8deee02a99403dba716492e97"/><file name="window_effects.js" hash="3c0b47a0f3cd41753a3992d01c118c3d"/><file name="window_ext.js" hash="d5163111a6dc50d05cc3f98360855336"/><file name="window_readme.txt" hash="97306d2a8c4be2ec65f66d2ec233289c"/><dir name="windows"><file name="MIT-LICENSE" hash="a839f717f1675b571481268a4e4a4ee2"/><file name="README" hash="75b8b2e714cbcb48337540a451655967"/><dir name="themes"><dir name="alert"><file name="bottom.gif" hash="e859e3bc00c4f10360fa81a659aa673f"/><file name="bottom_left.gif" hash="53585b1a0351d599e76a85ccc26f7980"/><file name="bottom_right.gif" hash="8170abe3fec71fd17612869a2f036cd6"/><file name="left.gif" hash="4f235c4e6afb0d386d220638c49e4545"/><file name="overlay.png" hash="f4ddcee6f819975bc9c5643b570de6dc"/><file name="progress.gif" hash="86b1ac6d1c485d54efa3a53643e91ceb"/><file name="right.gif" hash="838ade41815529e7a63f99c93b3a01f7"/><file name="top.gif" hash="8702ca9b81c19f6220ce81c4ea215878"/><file name="top_left.gif" hash="a8c097bcb67bddf640c2bd9161b79476"/><file name="top_right.gif" hash="05ef4e1a417a5a2c81fc816406a4842a"/></dir><file name="alert.css" hash="27df86baae5a6fa2e3556bdf1b85ccc6"/><file name="alert_lite.css" hash="fbeaff8f185cd3b302f1a8db5efa0110"/><dir name="alphacube"><file name="bottom-left-c.gif" hash="434cdfc5298f33efb108264cf3370e1c"/><file name="bottom-middle.gif" hash="3f882dd32d57a29a785f448bbba5ed26"/><file name="bottom-right-c.gif" hash="4c37ad7b94fc901a1cfaf54a1742d5fd"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="1bb1207b43425d214d4dc0da108f5449"/><file name="frame-right.gif" hash="8b9c36079881aa15c27a137666c56a38"/><file name="left-top.gif" hash="1ea936a090b4dfe8160fcb3a90ddb145"/><file name="right-top.gif" hash="e1b641feab640cb4207fa52160715e32"/><file name="top-middle.gif" hash="7f94c1018d023832c7c9e1fa468a9555"/></dir><file name="alphacube.css" hash="27c968911eaef53df158c55083ef0c84"/><file name="behavior.htc" hash="5588dff36ad5595f8353730e853044e5"/><dir name="darkX"><file name="button-close-focused.png" hash="5090b529a86a79679e0a26ccb0e1b0c6"/><file name="button-maximize-focused.png" hash="0f84bfcc9626d2cb1826291268b29f20"/><file name="button-minimize-focused.png" hash="630cd8cdd7124d412c6253e5c7cfc32a"/><file name="frame-bottom-left-focused.png" hash="8a34a3be2f349315dfd287ec15148332"/><file name="frame-bottom-mid-focused.png" hash="f1dbacdb64a19e00a485d426126f26db"/><file name="frame-bottom-right-focused.png" hash="17acb7874856dc68c3c017238d42054a"/><file name="frame-left-focused.png" hash="f30ab13888b2e48d0637991164a8f748"/><file name="frame-right-focused.png" hash="1115115c62507971b2f5eed3c2c5c2d0"/><file name="titlebar-left-focused.png" hash="491130dedbdbb3b2682f37424347b14c"/><file name="titlebar-mid-focused.png" hash="ae46975fc8a5e5a9f73f810d0c88809a"/><file name="titlebar-right-focused.png" hash="9560eb10dee94985f3ebe935833e2ae4"/></dir><file name="darkX.css" hash="16a964cfe57a2c979ad3d97831673b79"/><file name="debug.css" hash="63ee9aa7b7d80e0bb5e311407746ccd3"/><dir name="default"><file name="bottom_left.gif" hash="fb99ffa815a8648f95f42698fe5dfaa1"/><file name="bottom_mid.gif" hash="49b9ca7025562ea7f070a9111282364b"/><file name="bottom_right.gif" hash="e46768f632765cd86c5fe5d0166dcf2c"/><file name="bottom_right_resize.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="center_left.gif" hash="bd567580b4ee16a7a2734057cfbbe219"/><file name="center_right.gif" hash="eef184d5d89d1710313581a2ccf408e8"/><file name="clear.gif" hash="7af1206eeb0e7834a75e69d70676060d"/><file name="close.gif" hash="8a08f243c37a8e25a88d4ac135b2f07d"/><file name="inspect.gif" hash="aa2a0961067aad5c54b8634919af863b"/><file name="maximize.gif" hash="e73cd71c4979ebeadeb9e27d40a9e8fb"/><file name="minimize.gif" hash="2d2f4b1bd0506f342425f80ab76c49a3"/><file name="overlay.png" hash="536d40e87cda0c7ae7b11f1721aa52d0"/><file name="resize.gif" hash="320f534b5d444b39701e0b679529e779"/><file name="sizer.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="top_left.gif" hash="9c5e5920bfc189a45cc618099af93aa8"/><file name="top_mid.gif" hash="a12ff2b944025ad2d127d033dae5e9e1"/><file name="top_right.gif" hash="0cf1ec5b93f8ac8fcce0e2f72cf7f45e"/></dir><file name="default.css" hash="16014098f441d12d06c088135e2fde28"/><dir name="iefix"><file name="blank.gif" hash="56398e76be6355ad5999b262208a17c9"/><file name="iepngfix.css" hash="da3154c9a817850376f73a7976bfcb13"/><file name="iepngfix.htc" hash="b50c4e352a64254c5ceb6c63bcd0b176"/></dir><dir name="lighting"><file name="background_buttons.gif" hash="e66e67aaaf08a7b24f3cd1ba22584b42"/><file name="bottom-left-blue.png" hash="7c9e91d421945141315fc105d464a99f"/><file name="bottom-left-darkblue.png" hash="e88c2380acf403ee28597c6045988cc6"/><file name="bottom-left-green.png" hash="ee25ce8a12229b009fbfd91f7ba51e26"/><file name="bottom-left-grey.png" hash="5fdb3eae397ac7279aa5a7fdaad3dcc2"/><file name="bottom-middle-blue.png" hash="e93cc9d31d88f45c047a98a66be04354"/><file name="bottom-middle-darkblue.png" hash="763c88c424e0900e675042d3f0958bd4"/><file name="bottom-middle-green.png" hash="77e0a22afd2c55a83b5c7fa98a12ef25"/><file name="bottom-middle-grey.png" hash="3a2ebdeff74e2ff63c4471575568dd01"/><file name="bottom-right-blue.png" hash="0bc11a61047e8716451a283ebff897e5"/><file name="bottom-right-darkblue.png" hash="88e33ea702a304ae237edd57bc8447d6"/><file name="bottom-right-green.png" hash="7bce162df013eba43a659ae6e780ae4b"/><file name="bottom-right-grey.png" hash="86eb476492d911aac5688c9747fe7a1d"/><file name="button-close-blue.png" hash="42ae1a35caf8a9a275d6e748c27769fb"/><file name="button-close-darkblue.png" hash="50dbcd898dc519c1e6ac0d3a478978cd"/><file name="button-close-green.png" hash="b4273572fa91cba909a0a3e15b994d19"/><file name="button-close-grey.png" hash="124964b634ba67f2bb6dd08cf8cafd5a"/><file name="button-maximize-blue.png" hash="85b79237d85b09c205e09166dd8f4af0"/><file name="button-maximize-darkblue.png" hash="108d10619214e3365820aa4ab008aed5"/><file name="button-maximize-green.png" hash="90f5527705e4fd81997564e81c6ac2a3"/><file name="button-maximize-grey.png" hash="c46a8c014bd14be167f4c6a2f2dd52ed"/><file name="button-minimize-blue.png" hash="1fd738b99877a4dfa5656491cc3d8e6b"/><file name="button-minimize-darkblue.png" hash="b6d9da1cdf51ab54682fa75a6df2c40d"/><file name="button-minimize-green.png" hash="9e7d26298a0a49ffee3fbab6ea838e01"/><file name="button-minimize-grey.png" hash="0432701c2425cb3a5143d8a04bda0d87"/><file name="left-blue.png" hash="0a6acf0a863c04845a93b681769527cd"/><file name="left-darkblue.png" hash="44cdce8a75de4425d7eb7763092cc38d"/><file name="left-green.png" hash="d83116c49d62dc46bff0b7b4200b4ecf"/><file name="left-grey.png" hash="f3486d3293ae98b5edb8889c4b4082ef"/><file name="pngbehavior.htc" hash="b94c44e30423fd18a8b82bda5a139db3"/><file name="right-blue.png" hash="2c9b6b80d4a6b190b8e38a1c101e828c"/><file name="right-darkblue.png" hash="9b3267c5d36bb3f4588167cc3e78e569"/><file name="right-green.png" hash="4436968c2adbe6ed7c475c225631bc7c"/><file name="right-grey.png" hash="36b3de47bcbbd6b53e2f6e06843ee6e8"/><file name="spinner.gif" hash="c7b3cbb3ec8249a7121b722cdd76b870"/><file name="top-left-blue.png" hash="a5cb9eaa82f67df223d6784a52b26f1f"/><file name="top-left-darkblue.png" hash="e4a3af23d2cae7909331eb1995963c82"/><file name="top-left-green.png" hash="eb4cb604177c342998023d3dcd3aa5b0"/><file name="top-left-grey.png" hash="9f6f39abc4ae9539a0f54567a4a5d4f8"/><file name="top-middle-blue.png" hash="6d01df8637385bbe592b8df369294c8d"/><file name="top-middle-darkblue.png" hash="2c91ea6462e72a29cd07300d4102b88a"/><file name="top-middle-green.png" hash="e0f56311091bfb370fc6783fc7e71068"/><file name="top-middle-grey.png" hash="8c02881b730d602589fe9ed4bcaeb689"/><file name="top-right-blue.png" hash="4afefb06dc63c864211724a6348f25ad"/><file name="top-right-darkblue.png" hash="d8a9031987f648f170af67023179618d"/><file name="top-right-green.png" hash="b38813f9200440051273bdd622f5e545"/><file name="top-right-grey.png" hash="d7f7332ddf8686fb9810e4170767bf52"/></dir><file name="lighting.css" hash="d13de730c8ee7ef04167d361bdf8eebd"/><file name="mac_os_x.css" hash="65204ef34c1eeff0be29c53b0614076a"/><file name="mac_os_x_dialog.css" hash="0b7cd9d6a9e8f940f50bc4a080f54b1b"/><dir name="nuncio"><file name="bottom_left.png" hash="d9be5c7b432a342c6da5ef9b10148267"/><file name="bottom_mid.png" hash="facee2e7ee7c572a8f412750b0ce5387"/><file name="bottom_right.png" hash="6f3c124a066a11ff225897112de8e9d7"/><file name="center_left.png" hash="a11bee83f99addccc0d5eff3d2e82b8f"/><file name="center_right.png" hash="bf6b023ad1751d5f60f9820eea72ac28"/><file name="close.png" hash="46744062a7b54416c8767f8e0ccf1c41"/><file name="minimize.png" hash="bc911a3e90fc0640e0899856759a5e01"/><file name="overlay.png" hash="5ccd88855e923eb8a1bd9da1dec9d7fe"/><file name="top_left.png" hash="d3105aacc2c69954df11af953875a12e"/><file name="top_mid.png" hash="cb679a8c77e9b7485b5f0eca547eb103"/><file name="top_right.png" hash="e65d6fc6bf53891c487e414db16f1038"/></dir><file name="nuncio.css" hash="e30e31b94d96b0b27c80ad6d943d7010"/><dir name="spread"><file name="bottom-left-c.gif" hash="84641d08576f68a11f717103365dfb83"/><file name="bottom-middle.gif" hash="20ab265c67355c5b72cdcdc8739af555"/><file name="bottom-right-c.gif" hash="cb27b72623e997badc599e76024a6e44"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="63dc99b0c4ba0518688f7eca1f1628ca"/><file name="frame-right.gif" hash="a03585eec830f37898c7041d557dafc5"/><file name="left-top.gif" hash="7c78b8b59976d19191acf940cbfc04fb"/><file name="right-top.gif" hash="597530287fe1dc491278f855749f7e01"/><file name="top-middle.gif" hash="fa6fd6b90945c47f8d1718d9139d0a75"/><file name=".gif" hash="9dd39829e7cfdd06f3317a931bdc177e"/></dir><file name="spread.css" hash="a804413d7f1f9550c134477f6f9219ee"/></dir></dir></dir><dir name="scriptaculous"><file name="builder.js" hash="1174f6fc34ca5d54ba10b0c719386e7c"/><file name="controls.js" hash="8c414e1787c0ac9f10b16b252361c8b2"/><file name="dragdrop.js" hash="046759400db7a6096376e50110104edd"/><file name="effects.js" hash="d795089f95a22306cca9b337c439c65a"/><file name="scriptaculous.js" hash="d59eba4e0b14b672208b0862ae1c2196"/><file name="slider.js" hash="6043f96a71d2685fecd02e2ab99e84d9"/><file name="sound.js" hash="0f0fab23fa2cb1bc7717fd2bdf45402e"/><file name="unittest.js" hash="99969698b22272f77bdf4c64586862b3"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Prototype-1.9.4.1.xml b/var/package/Lib_Js_Prototype-1.9.4.1.xml
new file mode 100644
index 0000000..6237dc0
--- /dev/null
+++ b/var/package/Lib_Js_Prototype-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Prototype</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Prototype and Scriptaculous Javascript Libraries for Magento</summary>
+    <description>Prototype and Scriptaculous Javascript Libraries for Magento</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="prototype"><file name="debug.js" hash="d5990eabf728ade1f34496737455c8ff"/><file name="effects.js" hash="91e1b7d8c6043dff4eadbe054a90e3a7"/><file name="extended_debug.js" hash="cc706bc76bb1c5a2610fc296cd85e053"/><file name="prototype.js" hash="3b4b13dad33b475e11feb26fd3468ecc"/><file name="tooltip.js" hash="8509b04b1594b7e6382d7cfdf4ee1236"/><file name="tooltip_manager.js" hash="6b9759cbad296fda3c18d7669d6b5af0"/><file name="validation.js" hash="a841158a1143694d447cc78e1099b3c8"/><file name="window.js" hash="1ad7aab8deee02a99403dba716492e97"/><file name="window_effects.js" hash="3c0b47a0f3cd41753a3992d01c118c3d"/><file name="window_ext.js" hash="d5163111a6dc50d05cc3f98360855336"/><file name="window_readme.txt" hash="97306d2a8c4be2ec65f66d2ec233289c"/><dir name="windows"><file name="MIT-LICENSE" hash="a839f717f1675b571481268a4e4a4ee2"/><file name="README" hash="75b8b2e714cbcb48337540a451655967"/><dir name="themes"><dir name="alert"><file name="bottom.gif" hash="e859e3bc00c4f10360fa81a659aa673f"/><file name="bottom_left.gif" hash="53585b1a0351d599e76a85ccc26f7980"/><file name="bottom_right.gif" hash="8170abe3fec71fd17612869a2f036cd6"/><file name="left.gif" hash="4f235c4e6afb0d386d220638c49e4545"/><file name="overlay.png" hash="f4ddcee6f819975bc9c5643b570de6dc"/><file name="progress.gif" hash="86b1ac6d1c485d54efa3a53643e91ceb"/><file name="right.gif" hash="838ade41815529e7a63f99c93b3a01f7"/><file name="top.gif" hash="8702ca9b81c19f6220ce81c4ea215878"/><file name="top_left.gif" hash="a8c097bcb67bddf640c2bd9161b79476"/><file name="top_right.gif" hash="05ef4e1a417a5a2c81fc816406a4842a"/></dir><file name="alert.css" hash="27df86baae5a6fa2e3556bdf1b85ccc6"/><file name="alert_lite.css" hash="fbeaff8f185cd3b302f1a8db5efa0110"/><dir name="alphacube"><file name="bottom-left-c.gif" hash="434cdfc5298f33efb108264cf3370e1c"/><file name="bottom-middle.gif" hash="3f882dd32d57a29a785f448bbba5ed26"/><file name="bottom-right-c.gif" hash="4c37ad7b94fc901a1cfaf54a1742d5fd"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="1bb1207b43425d214d4dc0da108f5449"/><file name="frame-right.gif" hash="8b9c36079881aa15c27a137666c56a38"/><file name="left-top.gif" hash="1ea936a090b4dfe8160fcb3a90ddb145"/><file name="right-top.gif" hash="e1b641feab640cb4207fa52160715e32"/><file name="top-middle.gif" hash="7f94c1018d023832c7c9e1fa468a9555"/></dir><file name="alphacube.css" hash="27c968911eaef53df158c55083ef0c84"/><file name="behavior.htc" hash="5588dff36ad5595f8353730e853044e5"/><dir name="darkX"><file name="button-close-focused.png" hash="5090b529a86a79679e0a26ccb0e1b0c6"/><file name="button-maximize-focused.png" hash="0f84bfcc9626d2cb1826291268b29f20"/><file name="button-minimize-focused.png" hash="630cd8cdd7124d412c6253e5c7cfc32a"/><file name="frame-bottom-left-focused.png" hash="8a34a3be2f349315dfd287ec15148332"/><file name="frame-bottom-mid-focused.png" hash="f1dbacdb64a19e00a485d426126f26db"/><file name="frame-bottom-right-focused.png" hash="17acb7874856dc68c3c017238d42054a"/><file name="frame-left-focused.png" hash="f30ab13888b2e48d0637991164a8f748"/><file name="frame-right-focused.png" hash="1115115c62507971b2f5eed3c2c5c2d0"/><file name="titlebar-left-focused.png" hash="491130dedbdbb3b2682f37424347b14c"/><file name="titlebar-mid-focused.png" hash="ae46975fc8a5e5a9f73f810d0c88809a"/><file name="titlebar-right-focused.png" hash="9560eb10dee94985f3ebe935833e2ae4"/></dir><file name="darkX.css" hash="16a964cfe57a2c979ad3d97831673b79"/><file name="debug.css" hash="63ee9aa7b7d80e0bb5e311407746ccd3"/><dir name="default"><file name="bottom_left.gif" hash="fb99ffa815a8648f95f42698fe5dfaa1"/><file name="bottom_mid.gif" hash="49b9ca7025562ea7f070a9111282364b"/><file name="bottom_right.gif" hash="e46768f632765cd86c5fe5d0166dcf2c"/><file name="bottom_right_resize.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="center_left.gif" hash="bd567580b4ee16a7a2734057cfbbe219"/><file name="center_right.gif" hash="eef184d5d89d1710313581a2ccf408e8"/><file name="clear.gif" hash="7af1206eeb0e7834a75e69d70676060d"/><file name="close.gif" hash="8a08f243c37a8e25a88d4ac135b2f07d"/><file name="inspect.gif" hash="aa2a0961067aad5c54b8634919af863b"/><file name="maximize.gif" hash="e73cd71c4979ebeadeb9e27d40a9e8fb"/><file name="minimize.gif" hash="2d2f4b1bd0506f342425f80ab76c49a3"/><file name="overlay.png" hash="536d40e87cda0c7ae7b11f1721aa52d0"/><file name="resize.gif" hash="320f534b5d444b39701e0b679529e779"/><file name="sizer.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="top_left.gif" hash="9c5e5920bfc189a45cc618099af93aa8"/><file name="top_mid.gif" hash="a12ff2b944025ad2d127d033dae5e9e1"/><file name="top_right.gif" hash="0cf1ec5b93f8ac8fcce0e2f72cf7f45e"/></dir><file name="default.css" hash="16014098f441d12d06c088135e2fde28"/><dir name="iefix"><file name="blank.gif" hash="56398e76be6355ad5999b262208a17c9"/><file name="iepngfix.css" hash="da3154c9a817850376f73a7976bfcb13"/><file name="iepngfix.htc" hash="b50c4e352a64254c5ceb6c63bcd0b176"/></dir><dir name="lighting"><file name="background_buttons.gif" hash="e66e67aaaf08a7b24f3cd1ba22584b42"/><file name="bottom-left-blue.png" hash="7c9e91d421945141315fc105d464a99f"/><file name="bottom-left-darkblue.png" hash="e88c2380acf403ee28597c6045988cc6"/><file name="bottom-left-green.png" hash="ee25ce8a12229b009fbfd91f7ba51e26"/><file name="bottom-left-grey.png" hash="5fdb3eae397ac7279aa5a7fdaad3dcc2"/><file name="bottom-middle-blue.png" hash="e93cc9d31d88f45c047a98a66be04354"/><file name="bottom-middle-darkblue.png" hash="763c88c424e0900e675042d3f0958bd4"/><file name="bottom-middle-green.png" hash="77e0a22afd2c55a83b5c7fa98a12ef25"/><file name="bottom-middle-grey.png" hash="3a2ebdeff74e2ff63c4471575568dd01"/><file name="bottom-right-blue.png" hash="0bc11a61047e8716451a283ebff897e5"/><file name="bottom-right-darkblue.png" hash="88e33ea702a304ae237edd57bc8447d6"/><file name="bottom-right-green.png" hash="7bce162df013eba43a659ae6e780ae4b"/><file name="bottom-right-grey.png" hash="86eb476492d911aac5688c9747fe7a1d"/><file name="button-close-blue.png" hash="42ae1a35caf8a9a275d6e748c27769fb"/><file name="button-close-darkblue.png" hash="50dbcd898dc519c1e6ac0d3a478978cd"/><file name="button-close-green.png" hash="b4273572fa91cba909a0a3e15b994d19"/><file name="button-close-grey.png" hash="124964b634ba67f2bb6dd08cf8cafd5a"/><file name="button-maximize-blue.png" hash="85b79237d85b09c205e09166dd8f4af0"/><file name="button-maximize-darkblue.png" hash="108d10619214e3365820aa4ab008aed5"/><file name="button-maximize-green.png" hash="90f5527705e4fd81997564e81c6ac2a3"/><file name="button-maximize-grey.png" hash="c46a8c014bd14be167f4c6a2f2dd52ed"/><file name="button-minimize-blue.png" hash="1fd738b99877a4dfa5656491cc3d8e6b"/><file name="button-minimize-darkblue.png" hash="b6d9da1cdf51ab54682fa75a6df2c40d"/><file name="button-minimize-green.png" hash="9e7d26298a0a49ffee3fbab6ea838e01"/><file name="button-minimize-grey.png" hash="0432701c2425cb3a5143d8a04bda0d87"/><file name="left-blue.png" hash="0a6acf0a863c04845a93b681769527cd"/><file name="left-darkblue.png" hash="44cdce8a75de4425d7eb7763092cc38d"/><file name="left-green.png" hash="d83116c49d62dc46bff0b7b4200b4ecf"/><file name="left-grey.png" hash="f3486d3293ae98b5edb8889c4b4082ef"/><file name="pngbehavior.htc" hash="b94c44e30423fd18a8b82bda5a139db3"/><file name="right-blue.png" hash="2c9b6b80d4a6b190b8e38a1c101e828c"/><file name="right-darkblue.png" hash="9b3267c5d36bb3f4588167cc3e78e569"/><file name="right-green.png" hash="4436968c2adbe6ed7c475c225631bc7c"/><file name="right-grey.png" hash="36b3de47bcbbd6b53e2f6e06843ee6e8"/><file name="spinner.gif" hash="c7b3cbb3ec8249a7121b722cdd76b870"/><file name="top-left-blue.png" hash="a5cb9eaa82f67df223d6784a52b26f1f"/><file name="top-left-darkblue.png" hash="e4a3af23d2cae7909331eb1995963c82"/><file name="top-left-green.png" hash="eb4cb604177c342998023d3dcd3aa5b0"/><file name="top-left-grey.png" hash="9f6f39abc4ae9539a0f54567a4a5d4f8"/><file name="top-middle-blue.png" hash="6d01df8637385bbe592b8df369294c8d"/><file name="top-middle-darkblue.png" hash="2c91ea6462e72a29cd07300d4102b88a"/><file name="top-middle-green.png" hash="e0f56311091bfb370fc6783fc7e71068"/><file name="top-middle-grey.png" hash="8c02881b730d602589fe9ed4bcaeb689"/><file name="top-right-blue.png" hash="4afefb06dc63c864211724a6348f25ad"/><file name="top-right-darkblue.png" hash="d8a9031987f648f170af67023179618d"/><file name="top-right-green.png" hash="b38813f9200440051273bdd622f5e545"/><file name="top-right-grey.png" hash="d7f7332ddf8686fb9810e4170767bf52"/></dir><file name="lighting.css" hash="d13de730c8ee7ef04167d361bdf8eebd"/><file name="mac_os_x.css" hash="65204ef34c1eeff0be29c53b0614076a"/><file name="mac_os_x_dialog.css" hash="0b7cd9d6a9e8f940f50bc4a080f54b1b"/><dir name="nuncio"><file name="bottom_left.png" hash="d9be5c7b432a342c6da5ef9b10148267"/><file name="bottom_mid.png" hash="facee2e7ee7c572a8f412750b0ce5387"/><file name="bottom_right.png" hash="6f3c124a066a11ff225897112de8e9d7"/><file name="center_left.png" hash="a11bee83f99addccc0d5eff3d2e82b8f"/><file name="center_right.png" hash="bf6b023ad1751d5f60f9820eea72ac28"/><file name="close.png" hash="46744062a7b54416c8767f8e0ccf1c41"/><file name="minimize.png" hash="bc911a3e90fc0640e0899856759a5e01"/><file name="overlay.png" hash="5ccd88855e923eb8a1bd9da1dec9d7fe"/><file name="top_left.png" hash="d3105aacc2c69954df11af953875a12e"/><file name="top_mid.png" hash="cb679a8c77e9b7485b5f0eca547eb103"/><file name="top_right.png" hash="e65d6fc6bf53891c487e414db16f1038"/></dir><file name="nuncio.css" hash="e30e31b94d96b0b27c80ad6d943d7010"/><dir name="spread"><file name="bottom-left-c.gif" hash="84641d08576f68a11f717103365dfb83"/><file name="bottom-middle.gif" hash="20ab265c67355c5b72cdcdc8739af555"/><file name="bottom-right-c.gif" hash="cb27b72623e997badc599e76024a6e44"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="63dc99b0c4ba0518688f7eca1f1628ca"/><file name="frame-right.gif" hash="a03585eec830f37898c7041d557dafc5"/><file name="left-top.gif" hash="7c78b8b59976d19191acf940cbfc04fb"/><file name="right-top.gif" hash="597530287fe1dc491278f855749f7e01"/><file name="top-middle.gif" hash="fa6fd6b90945c47f8d1718d9139d0a75"/><file name=".gif" hash="9dd39829e7cfdd06f3317a931bdc177e"/></dir><file name="spread.css" hash="a804413d7f1f9550c134477f6f9219ee"/></dir></dir></dir><dir name="scriptaculous"><file name="builder.js" hash="1174f6fc34ca5d54ba10b0c719386e7c"/><file name="controls.js" hash="8c414e1787c0ac9f10b16b252361c8b2"/><file name="dragdrop.js" hash="046759400db7a6096376e50110104edd"/><file name="effects.js" hash="d795089f95a22306cca9b337c439c65a"/><file name="scriptaculous.js" hash="d59eba4e0b14b672208b0862ae1c2196"/><file name="slider.js" hash="6043f96a71d2685fecd02e2ab99e84d9"/><file name="sound.js" hash="0f0fab23fa2cb1bc7717fd2bdf45402e"/><file name="unittest.js" hash="99969698b22272f77bdf4c64586862b3"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_TinyMCE-3.5.11.16.xml b/var/package/Lib_Js_TinyMCE-3.5.11.16.xml
deleted file mode 100644
index e8db77f..0000000
--- a/var/package/Lib_Js_TinyMCE-3.5.11.16.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_TinyMCE</name>
-    <version>3.5.11.16</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>TinyMCE Javascript Libraries for Magento</summary>
-    <description>TinyMCE Javascript Libraries for Magento</description>
-    <notes>3.5.11.16</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:00</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="tiny_mce"><dir name="classes"><file name="AddOnManager.js" hash="394e98bc019eb5c08c657fe4f8a48546"/><file name="ControlManager.js" hash="26cedc474b183b1a9905cdb3d10254dc"/><file name="Editor.Events.js" hash="07af3e1a08aead0078eb0cd6b030b864"/><file name="Editor.js" hash="e921b224172fbe2bd134eaab1974f2e8"/><file name="EditorCommands.js" hash="18b0d752aafddca09cf59fa7cc4d45c2"/><file name="EditorManager.js" hash="68b7a4a6252ab8b326fa5c8ee52d8016"/><file name="EnterKey.js" hash="ecc48ccb75c80dca2bd6bd7023fc906e"/><file name="ForceBlocks.js" hash="186ad2042e7b9416d2c4f9ec5f519893"/><file name="Formatter.js" hash="413f6c83f256d864a01e05718fbe7ce6"/><file name="LegacyInput.js" hash="a14c5e4099e2e4cbc6339eb54d3ec8f9"/><file name="Popup.js" hash="b6775a0e19bd839625b4dfb6b92a9688"/><file name="UndoManager.js" hash="276955286b65fba55ee60833ca2d6671"/><file name="WindowManager.js" hash="794c3d88226e8b62eac09eeeef283c3b"/><dir name="adapter"><dir name="jquery"><file name="adapter.js" hash="a5eea8e2826d7b0929291aa7a927ec29"/><file name="jquery.tinymce.js" hash="f2f319f369a84757b8976c2d66872933"/></dir><dir name="prototype"><file name="adapter.js" hash="37d84615944f028635f68d05b889c5c2"/></dir></dir><dir name="dom"><file name="DOMUtils.js" hash="bb9a7c2b19ad2433c85984cb8511e085"/><file name="Element.js" hash="1208e71eb2bc8e578b5a9cb4ec3b1365"/><file name="EventUtils.js" hash="652351eaf41de2659cfc7e380b694c02"/><file name="Range.js" hash="05c8ac178fa799217f60ebb650b41e0f"/><file name="RangeUtils.js" hash="9948e6204548089899b1e325370355f1"/><file name="ScriptLoader.js" hash="742ce02734095db354ad54ab8399a0ee"/><file name="Selection.js" hash="3332b2293dfc2a93fdb6a67ce5329642"/><file name="Serializer.js" hash="8762f4920ed6d4a57203bfbb8bc8490c"/><file name="Sizzle.js" hash="7930b22f632c7b0240237df1393e5023"/><file name="TreeWalker.js" hash="55425ece6675a529525bad45c6acbd94"/><file name="TridentSelection.js" hash="1fd402d1bb8144fa8549031b5f061733"/></dir><dir name="firebug"><file name="FIREBUG.LICENSE" hash="3b402ea96cec202bac23ea7144653cfa"/><file name="firebug-lite.js" hash="1c9c10926be94a61564ad0541a50624f"/></dir><dir name="html"><file name="DomParser.js" hash="25a47241e40445f2870bc94ce6a10b3c"/><file name="Entities.js" hash="7292e9f893096fb66d3232920be3c3d9"/><file name="Node.js" hash="ea0a5b87b71760018a753eb41a4e0f48"/><file name="SaxParser.js" hash="6dbb27c6762a5f27a9e6e844391393f4"/><file name="Schema.js" hash="e4d6e60fbca99911660f272717b9c08b"/><file name="Serializer.js" hash="ab74a79798a6f20f4267e3f1da17f2da"/><file name="Styles.js" hash="72317437bb3c7f0a05302658ea19dfce"/><file name="Writer.js" hash="3a2e8b824b749c19c5f27f8c830f95a5"/></dir><file name="tinymce.js" hash="546ec1f2bbfbf1ee04b4a33dcc05bc52"/><dir name="ui"><file name="Button.js" hash="82e9cd9d322a714652b0bc8e40e7e503"/><file name="ColorSplitButton.js" hash="06760a696b922b56a482f5889407714e"/><file name="Container.js" hash="7929a5d6aef46380197061e49e4f9dfb"/><file name="Control.js" hash="460a997aaad3b1b24f684bfdbefd3d9c"/><file name="DropMenu.js" hash="3359b973c857ca38105eeb276119b99f"/><file name="KeyboardNavigation.js" hash="f446fdfbadd728e8b009dc4adfc0b0d2"/><file name="ListBox.js" hash="2cd7287ec70ac87cb3903ecf0a2ccfdc"/><file name="Menu.js" hash="02762fee614d37aaea7eaf14f07dece1"/><file name="MenuButton.js" hash="fb0251eb52a5b3779d76ed2c2f8ec77e"/><file name="MenuItem.js" hash="55d400a161aa44d9dd5334d6f58ed956"/><file name="NativeListBox.js" hash="964785fd8a23be00b6db650f96e9ebf7"/><file name="Separator.js" hash="d4c5d779114617360ea78a2c0d523c81"/><file name="SplitButton.js" hash="e78e53578280cce9d97f936a82eca6de"/><file name="Toolbar.js" hash="b742f894f63122c4ee635fa59958167d"/><file name="ToolbarGroup.js" hash="db7b059b984e114ea22b1dc558d3d1f2"/></dir><dir name="util"><file name="Cookie.js" hash="14bc612b28c3c75549138a1699d5c238"/><file name="Dispatcher.js" hash="bf9bd51bbabca1823634833b3b16097c"/><file name="JSON.js" hash="b9b5964dbcd4cff962264dd72d8e4df5"/><file name="JSONP.js" hash="0a39d9e1b8427ab8b6dbdd00177c8c48"/><file name="JSONRequest.js" hash="dd12f1ac5c78ec4ba7459fb825ff9e5e"/><file name="Quirks.js" hash="927b518cc3aa663a41921590d0d3b4ac"/><file name="URI.js" hash="7069a8a2dfa4b0315719778b8c744139"/><file name="VK.js" hash="78114029ce46d5a4a441b01c44f23b4f"/><file name="XHR.js" hash="b00450d636335e7be50d46d2c31cc5a0"/></dir><dir name="xml"><file name="Parser.js" hash="c6d6862014ef2ab23a5a16adaee1af6d"/></dir></dir><file name="jquery.tinymce.js" hash="751418d46d453e7c6b1a7fbd4e60fefa"/><dir name="langs"><file name="en.js" hash="eff36a9433bccea2f3243b1465fe6fe3"/></dir><file name="license.txt" hash="b238d032089de4c340f6e0119210ce3a"/><dir name="plugins"><dir name="advhr"><dir name="css"><file name="advhr.css" hash="15df80b2137bcc04d5455ffa3a51e0c5"/></dir><file name="editor_plugin.js" hash="d0a03059205455e5c19cf3a845a0ebde"/><file name="editor_plugin_src.js" hash="a7fda2e674f15a33baf53cea2e23ec66"/><dir name="js"><file name="rule.js" hash="ef46d7c850c8bcc869ea84ed7ac00c49"/></dir><dir name="langs"><file name="en_dlg.js" hash="af62ab3f1b7a27190f8e001c8aefdfa6"/></dir><file name="rule.htm" hash="492ebbdc24d46061e928d911873d5fc8"/></dir><dir name="advimage"><dir name="css"><file name="advimage.css" hash="1ccd374d5f1e89cc16e1649558a9bb33"/></dir><file name="editor_plugin.js" hash="8af1f904909820d132bc0cbeb6469130"/><file name="editor_plugin_src.js" hash="958a409150fba5532d27e862d52015e9"/><file name="image.htm" hash="0d204c8f7651c3080ab542fb36957881"/><dir name="img"><file name="sample.gif" hash="b9c7057c46716340e8967340ad11766e"/></dir><dir name="js"><file name="image.js" hash="d071360a06b4f8590b4b18a7eca039aa"/></dir><dir name="langs"><file name="en_dlg.js" hash="6f80f834e2209e6a95957403bb4842f0"/></dir></dir><dir name="advlink"><dir name="css"><file name="advlink.css" hash="aaf226732a7b4ae80ee680700f488a1e"/></dir><file name="editor_plugin.js" hash="5e440c6bcb7fd94e7fd597f8a183e16f"/><file name="editor_plugin_src.js" hash="4104cd66aea546becf5d8fca66cf7951"/><dir name="js"><file name="advlink.js" hash="80dd2f99418025b6f9fd757adfdb1a71"/></dir><dir name="langs"><file name="en_dlg.js" hash="8da3a95d6886837c0bca18670f57ae1c"/></dir><file name="link.htm" hash="206ef7aba261ac4bc14e7c6fdbdcc8c5"/></dir><dir name="advlist"><file name="editor_plugin.js" hash="5f1c8625c04a6b0f4567c1c8d5e28ff9"/><file name="editor_plugin_src.js" hash="d451908bf1e060ecd49356787f33fc7c"/></dir><dir name="autolink"><file name="editor_plugin.js" hash="5091233229ffe517f075b787c5f388a6"/><file name="editor_plugin_src.js" hash="f03a8ec9ad17bd53f897a525e3cc30f7"/></dir><dir name="autoresize"><file name="editor_plugin.js" hash="adf5cbe96119e3ed9ab4a86ba26405e7"/><file name="editor_plugin_src.js" hash="4d1cdbe307f73b4d36d1bf9b3bc2d0a9"/></dir><dir name="autosave"><file name="editor_plugin.js" hash="ae4c2aba85a22da66e3655f55d1c89fd"/><file name="editor_plugin_src.js" hash="6177147324865c00736c242b8ccb2de6"/><dir name="langs"><file name="en.js" hash="a33b0322c949a6d74bde7fa164396984"/></dir></dir><dir name="bbcode"><file name="editor_plugin.js" hash="31748a6cc57a13da54a0243c3301f3e6"/><file name="editor_plugin_src.js" hash="842450703b915245adb53df7d478ea5a"/></dir><dir name="contextmenu"><file name="editor_plugin.js" hash="5a0fc9ce2ba71bf2b6f54eb94838619f"/><file name="editor_plugin_src.js" hash="b923e4315f2d98703bbe9699465f84f0"/></dir><dir name="directionality"><file name="editor_plugin.js" hash="e2d925fe1e778dbcade06d55164fc276"/><file name="editor_plugin_src.js" hash="14b7a5b69fdc4f235b654436e4fe3081"/></dir><dir name="emotions"><file name="editor_plugin.js" hash="98cba02e33fc108024f3e993be0b0b62"/><file name="editor_plugin_src.js" hash="4cbc6e9b083a810ab0d3768af8f8f864"/><file name="emotions.htm" hash="9378bfd04b56a828318f7798f5696f67"/><dir name="img"><file name="smiley-cool.gif" hash="e26e97a318f82ec144b0818e5a8f8edb"/><file name="smiley-cry.gif" hash="e72bf995ceca9230273ed9909c5db9c8"/><file name="smiley-embarassed.gif" hash="d59171236e6b0b96091eeda1f7b57ce3"/><file name="smiley-foot-in-mouth.gif" hash="c12d9db6a14ad0b52f66f1e2cf2a38e7"/><file name="smiley-frown.gif" hash="59930208822fe755f651a67ef4b70530"/><file name="smiley-innocent.gif" hash="ec0477c8a206ff250782e40f9bae4b4c"/><file name="smiley-kiss.gif" hash="4ae8945f3960751b5d294f18242e144d"/><file name="smiley-laughing.gif" hash="c37f405db4e13cbebf24e745534687bf"/><file name="smiley-money-mouth.gif" hash="11c14bd1496afd0e21df115d25b68e96"/><file name="smiley-sealed.gif" hash="bb828cb46b377d1589927a02f8fd1762"/><file name="smiley-smile.gif" hash="2968a664098d9580079c66d628dad1a8"/><file name="smiley-surprised.gif" hash="2e136ebd637bf3e6c9fc6bdc20cbe73e"/><file name="smiley-tongue-out.gif" hash="5ec3bb4781c8e43a51d3a1a948b98fc0"/><file name="smiley-undecided.gif" hash="3c0c011d16b1a2331385ed97e160a42a"/><file name="smiley-wink.gif" hash="897275ac7d07032b4d93fb83a0d2a41b"/><file name="smiley-yell.gif" hash="19bb8ebfe3c2f5ef3ffb9aa4a027900d"/></dir><dir name="js"><file name="emotions.js" hash="85efe828d29037950412fec963b6f950"/></dir><dir name="langs"><file name="en_dlg.js" hash="62c052504a77e4f4cec6d90ece0d76c4"/></dir></dir><dir name="example"><file name="dialog.htm" hash="e6170a190a4d44ea5e6af089d2728d7e"/><file name="editor_plugin.js" hash="e0a175dca3d5e437657ccd5d548ff409"/><file name="editor_plugin_src.js" hash="b98bec73743c249187e0fa8f8311e3a3"/><dir name="img"><file name="example.gif" hash="6036655a01df362267183a8b23fead10"/></dir><dir name="js"><file name="dialog.js" hash="83245e76c97e24d466cf5df2308f9bf4"/></dir><dir name="langs"><file name="en.js" hash="78c88182b5fb900fc956845f75885b3a"/><file name="en_dlg.js" hash="7aec7a3b9d4642fbf7bb3ef1ed8a7570"/></dir></dir><dir name="example_dependency"><file name="editor_plugin.js" hash="405d190ae03384a9acb00533568b2cfd"/><file name="editor_plugin_src.js" hash="473878118b45efe326d335f992ff9943"/></dir><dir name="fullpage"><dir name="css"><file name="fullpage.css" hash="2ac64c98369f8b4f7cbf6fa70e25bfca"/></dir><file name="editor_plugin.js" hash="5dfbe0a82c87eb0fb65b11dcd39406d0"/><file name="editor_plugin_src.js" hash="636afe66f3de447eb92611bdcfb7f2b3"/><file name="fullpage.htm" hash="8c58825b698712e7297f95da51a9c03c"/><dir name="js"><file name="fullpage.js" hash="a7913b6b1a1ae634a509c3db9faf381a"/></dir><dir name="langs"><file name="en_dlg.js" hash="963f370d56f19c2f94de09b10a306187"/></dir></dir><dir name="fullscreen"><file name="editor_plugin.js" hash="15134339e36472281b8a1626233f747d"/><file name="editor_plugin_src.js" hash="a28a8a8bf569d6ee5e6dccbc988490ce"/><file name="fullscreen.htm" hash="b6d76297c2f679b9110ec7119d091900"/></dir><dir name="iespell"><file name="editor_plugin.js" hash="22526393cacb6447a0e3bfff2fb47773"/><file name="editor_plugin_src.js" hash="311e13bcc85c06da43decc37dc1b4f83"/></dir><dir name="inlinepopups"><file name="editor_plugin.js" hash="db32751b98f40ca6eee24efc848d6cbb"/><file name="editor_plugin_src.js" hash="d1c1de414c13fef3593ffd14503d37c0"/><dir name="skins"><dir name="clearlooks2"><dir name="img"><file name="alert.gif" hash="568d4cf84413656fb72fe39d1dd60f8d"/><file name="button.gif" hash="19f864cb81177840dcd534df4d537ea3"/><file name="buttons.gif" hash="1743ac9f7f2267a6edafefc536a2265d"/><file name="confirm.gif" hash="1bc337a20c319e531cda6ced531827d0"/><file name="corners.gif" hash="55298b5baaecb7e06a251db9f0a4b14c"/><file name="horizontal.gif" hash="0365e75dd4a9ad61dc98dcb641207c21"/><file name="vertical.gif" hash="0261136fac58ce77bdbd96aa0194947e"/></dir><file name="window.css" hash="f715affab9da63bc26f8c6362a989395"/></dir></dir><file name="template.htm" hash="3d7e3ae05511a9f64c5da924b9e971ba"/></dir><dir name="insertdatetime"><file name="editor_plugin.js" hash="d99072498466cdb2f53ed7c02da85982"/><file name="editor_plugin_src.js" hash="32a2afa1cd3ff8c9b966f8724ba3e0b3"/></dir><dir name="layer"><file name="editor_plugin.js" hash="4e5fc1b467c19d79dcf6246ba3a63cd8"/><file name="editor_plugin_src.js" hash="3754eb57b08539e459509caa74acecc6"/></dir><dir name="legacyoutput"><file name="editor_plugin.js" hash="b732a86187723cd9cc32853d67730061"/><file name="editor_plugin_src.js" hash="8a0a69cbe8d447d722aaef7d4ed7dcc1"/></dir><dir name="lists"><file name="editor_plugin.js" hash="46ba57884d8fe05d92cd9d98d3bb00af"/><file name="editor_plugin_src.js" hash="04e1f245c19d6dc9454dae57faec9b6f"/></dir><dir name="media"><dir name="css"><file name="media.css" hash="f211293a697a2c83da00effd67f535a2"/></dir><file name="editor_plugin.js" hash="5ad7db86c5008f98ec135595db4a4973"/><file name="editor_plugin_src.js" hash="1d03ec1ec36745041db26132b07b0491"/><dir name="img"><file name="flash.gif" hash="6c69b02015d09280332ff8b07e4ea2f3"/><file name="quicktime.gif" hash="9a6a9fdead205b125c07ea37e71ed4f1"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="baa643b587565755157618032dc93e3c"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/><file name="media.js" hash="4f35c0283a30f3556e023e76c34368b2"/></dir><dir name="langs"><file name="en_dlg.js" hash="9523fc123c577642000fd409bd862c3f"/></dir><file name="media.htm" hash="be58b1edf9a4a4dbf3a1993e3d897e1a"/><file name="moxieplayer.swf" hash="9217cea72c76c361fa5033526712284e"/><file name=".htaccess" hash="9f2e3ee0d6e50d80819eb8c0300a0913"/></dir><dir name="nonbreaking"><file name="editor_plugin.js" hash="232f23a586f10bd8ddabf38d767113d4"/><file name="editor_plugin_src.js" hash="fefbda5243d10652038ccf40801b8893"/></dir><dir name="noneditable"><file name="editor_plugin.js" hash="b332a5f8767506024a0f50aa4204b1fe"/><file name="editor_plugin_src.js" hash="273d35e2221889e75f33fd545f77d44e"/></dir><dir name="pagebreak"><dir name="css"><file name="content.css" hash="d9664762a610f2b5f7b10b5781f3299a"/></dir><file name="editor_plugin.js" hash="8be3376740c886fa2842d2f4eb282bbc"/><file name="editor_plugin_src.js" hash="c2d432a5914f0095a859ff443700a5e9"/><dir name="img"><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/></dir></dir><dir name="paste"><file name="editor_plugin.js" hash="1b68c59eb95a28ccc2aff2cfb85a8829"/><file name="editor_plugin_src.js" hash="40eef37ac300b571da5383bc0bddf73f"/><dir name="js"><file name="pastetext.js" hash="d6e4b39f19b89118b34b0d21491494b7"/><file name="pasteword.js" hash="112504d12e971e4d32f17a59c5616c36"/></dir><dir name="langs"><file name="en_dlg.js" hash="6ea2189562f65287be8e5e3185c405b7"/></dir><file name="pastetext.htm" hash="8f217769e59a5dd67843c7c17c842f41"/><file name="pasteword.htm" hash="8b9459b98f9a70ed684832326bf1cdf6"/></dir><dir name="preview"><file name="editor_plugin.js" hash="925216b63aabd5adc67d642ca2d04b4a"/><file name="editor_plugin_src.js" hash="6f9c3234dfdc0f62b713e8771f4ca5dc"/><file name="example.html" hash="9b9290408ae10fa29ec29db60682be91"/><dir name="jscripts"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/></dir><file name="preview.html" hash="bb02414f4cdd28c4a66e7fb5ed820f2d"/></dir><dir name="print"><file name="editor_plugin.js" hash="53eb1da78f727ee8337671fb86354c17"/><file name="editor_plugin_src.js" hash="f11547aa114df69b35df319003105e11"/></dir><dir name="save"><file name="editor_plugin.js" hash="307a0743c68c4e4aff005f13027f296f"/><file name="editor_plugin_src.js" hash="4dcbdaab64f06550a2db2b650f99d411"/></dir><dir name="searchreplace"><dir name="css"><file name="searchreplace.css" hash="ad0addca1bd5727432f39ec9b7fdac1e"/></dir><file name="editor_plugin.js" hash="ed4f1fa6e12844b533c86258647a298f"/><file name="editor_plugin_src.js" hash="7292198991a0fda1b9c7b28c921c6521"/><dir name="js"><file name="searchreplace.js" hash="0eeedb83f5bf1240348e1c6e77be2c47"/></dir><dir name="langs"><file name="en_dlg.js" hash="fbd47078679d87b541479000589ef4c9"/></dir><file name="searchreplace.htm" hash="4d01ee3be4045a600778fca1e11cee61"/></dir><dir name="spellchecker"><dir name="css"><file name="content.css" hash="ac0c7dbbbe44022d29d63b7b05123e3d"/></dir><file name="editor_plugin.js" hash="629a571ee7686ace6ee7ad1181be916b"/><file name="editor_plugin_src.js" hash="bae03899e91abca8b4b77c8ea886b561"/><dir name="img"><file name="wline.gif" hash="c136c9f8e00718a98947a21d8adbcc56"/></dir></dir><dir name="style"><dir name="css"><file name="props.css" hash="c2d2adc78609ea65760dae2dab058395"/></dir><file name="editor_plugin.js" hash="f9bcd692d63dfef1fe5c586d27ecd91b"/><file name="editor_plugin_src.js" hash="2ec50d9d37ce1e732380a746fabceefc"/><dir name="js"><file name="props.js" hash="f3614bf040f29057162e423822b89e11"/></dir><dir name="langs"><file name="en_dlg.js" hash="62a82106cfd480a6da4442b4763a2f2d"/></dir><file name="props.htm" hash="32f3f16194be9170386419c9dcc5b99a"/><file name="readme.txt" hash="ced5c8e014184a33da5507dbcd96b91f"/></dir><dir name="tabfocus"><file name="editor_plugin.js" hash="d3e5ef7a1a203516af0d8fdf94952fd2"/><file name="editor_plugin_src.js" hash="12889ccf8caf1d466859ba949f52fbca"/></dir><dir name="table"><file name="cell.htm" hash="f427b778a4924154a5e2317ddfd0f567"/><dir name="css"><file name="cell.css" hash="56394e6cdb267d97e23a07a98820e84b"/><file name="row.css" hash="81a75523c1e83be93e524c8bb901a089"/><file name="table.css" hash="f5e651f5a32284f1c4e0faa1d7cd5ff4"/></dir><file name="editor_plugin.js" hash="c12f0891c5bf0a7a6dd43ef0bd44dd82"/><file name="editor_plugin_src.js" hash="8228b4ab83fe4dfe2e377850dc2cf97e"/><dir name="js"><file name="cell.js" hash="8b0d4a7fe48c2f92c8b9b79dbb12cca1"/><file name="merge_cells.js" hash="3650484c93d6c9a197d03a5c3c3d2e80"/><file name="row.js" hash="d1cf0ab3d974f0b528e467d4b5c5c89f"/><file name="table.js" hash="f894721e5f5a6c2efa1a232c4b4a85b6"/></dir><dir name="langs"><file name="en_dlg.js" hash="ee3484503050cdae74d2cafa7d2e9999"/></dir><file name="merge_cells.htm" hash="f939ddd56826c0ec3c9e6e9a478346bf"/><file name="row.htm" hash="7ad9e68624759b28be626ac4b53c8907"/><file name="table.htm" hash="88fb36057ec1cb1681fed2dcb0b44693"/></dir><dir name="template"><file name="blank.htm" hash="9553e76581d74579d23bea5c7ea8a807"/><dir name="css"><file name="template.css" hash="5b2c159120cbef004c9b0804c292820b"/></dir><file name="editor_plugin.js" hash="70cb20c4e287110ae8aeed999893c532"/><file name="editor_plugin_src.js" hash="336af7b2ec3e0f7c83a7d05bf16cd018"/><dir name="js"><file name="template.js" hash="75abfd82a90ae648fb18c5517dfd925b"/></dir><dir name="langs"><file name="en_dlg.js" hash="1ce03c0fcf0f1aa74c132459abe30f39"/></dir><file name="template.htm" hash="b55e174e239e5c4b3a52d6ad60eb991d"/></dir><dir name="visualblocks"><dir name="css"><file name="visualblocks.css" hash="1fe4f62cc93864784b9b2d6b11b050b7"/></dir><file name="editor_plugin.js" hash="592e70a44aeb7c974eb9c5ff05c107a7"/><file name="editor_plugin_src.js" hash="6d1a4ea64bfedf8797260792e33f4c17"/></dir><dir name="visualchars"><file name="editor_plugin.js" hash="e494d07c71e24040a407b20017ca63e3"/><file name="editor_plugin_src.js" hash="f285c8f2ffac745325e86687b8cf0fb5"/></dir><dir name="wordcount"><file name="editor_plugin.js" hash="fb71ed139697b519f0054179d28ec782"/><file name="editor_plugin_src.js" hash="a034fddb393e4b6e7d25fc3761bea529"/></dir><dir name="xhtmlxtras"><file name="abbr.htm" hash="e514d143e00e4b121cab8fe8dfae48d2"/><file name="acronym.htm" hash="ec632b3d4b6afb189c055afa234e6291"/><file name="attributes.htm" hash="cf540b962f752babf53faa7a47bde108"/><file name="cite.htm" hash="1468438313b9cb1de0e53e50d75c92fa"/><dir name="css"><file name="attributes.css" hash="abc1b941c6eef8e1ea76915984e8a03e"/><file name="popup.css" hash="ed53e7b6ab799f6a249c3d403047dcfc"/></dir><file name="del.htm" hash="81bbcce0d19d78698fad760ee90b6948"/><file name="editor_plugin.js" hash="c9f91af5f1b8a1ba7a1e4ccf53fc7790"/><file name="editor_plugin_src.js" hash="b8b8236893ef2347a46cb131fc1a8c69"/><file name="ins.htm" hash="47e7db25678cee383fe6532ebb9e3fcb"/><dir name="js"><file name="abbr.js" hash="d91ae7d986336de4ecb977d19dcfab19"/><file name="acronym.js" hash="0a19f79bdc9222d3273712fe37a8051c"/><file name="attributes.js" hash="e75f23fae888b9febb57a29f2eb5a86c"/><file name="cite.js" hash="ba39487ce6a625538b838c21502bbaa7"/><file name="del.js" hash="be96fef888076d27384dd3546e8b6b6f"/><file name="element_common.js" hash="b817f5e2d514147d72765c92c1f60f3d"/><file name="ins.js" hash="6148dd4151e58dcda9112933908b97b1"/></dir><dir name="langs"><file name="en_dlg.js" hash="45db1586e7debc385f63092a13a9f43c"/></dir></dir></dir><dir name="themes"><dir name="advanced"><file name="about.htm" hash="ff135857e9b930d4d4658f92077e051c"/><file name="anchor.htm" hash="79d46a2b007b5cb08a3920e922a5da7f"/><file name="charmap.htm" hash="be712e4cf08670a1212e9eed2f452693"/><file name="color_picker.htm" hash="8db4d59dec910525149039f006a2bb9e"/><file name="editor_template.js" hash="a2b3085f0ab3c323dd28187b739139ec"/><file name="editor_template_src.js" hash="1fa308a86046cee68c5227ca58013bba"/><file name="image.htm" hash="2cb986c0cad7efd0592a4d8c35e41f0a"/><dir name="img"><file name="colorpicker.jpg" hash="9bcc36292defe94bca5a013a1736c7d7"/><file name="flash.gif" hash="33adee48d32bbbba3e6412cc54ecf335"/><file name="icons.gif" hash="75ad72872bc6280c32609e12fc3b610a"/><file name="iframe.gif" hash="a1af02e9ba370f64297087b46e80591e"/><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="quicktime.gif" hash="61da1ff8729ca5016344c4e8eb173369"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="1ce7d48784981aac9d4375cf2effdc4d"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="video.gif" hash="f85c56813ea016a75e496bba50d66ab4"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="about.js" hash="606c16492a17240ebded6e9fce75a555"/><file name="anchor.js" hash="da6a28397899bec3570216b2d2106684"/><file name="charmap.js" hash="02f40a38033ef8a0abeac870e5f4eda8"/><file name="color_picker.js" hash="cfc0f59a846661e748cae1c0adca77dc"/><file name="image.js" hash="75df8142a91f0245367e4121a2da7065"/><file name="link.js" hash="71949506dce04e923bbbc2ecc8ab5f1f"/><file name="source_editor.js" hash="4cbdfdf929a0949070f4d7ab4818b0f2"/></dir><dir name="langs"><file name="en.js" hash="58c814313230f1dec07fe45ad5f304e5"/><file name="en_dlg.js" hash="3a2c8aed5b7579ae45be6bd2b34ef06b"/></dir><file name="link.htm" hash="65c56f5a6d714fdbdc47c68ec9422976"/><file name="shortcuts.htm" hash="2bae05c8667b54b9ec019b529e743327"/><dir name="skins"><dir name="default"><file name="content.css" hash="1779499935490440d7a2423157756bc5"/><file name="dialog.css" hash="ab94126c11ff9c79445cc4ad537b2823"/><dir name="img"><file name="buttons.png" hash="33b2f2e08cc3ade5254fec64c4183558"/><file name="items.gif" hash="d201498a710fc8aac6e117820b9814b7"/><file name="menu_arrow.gif" hash="e21752451a9d80e276fef7b602bdbdba"/><file name="menu_check.gif" hash="c7d003885737f94768eecae49dcbca63"/><file name="progress.gif" hash="50c5e3e79b276c92df6cc52caeb464f0"/><file name="tabs.gif" hash="6473bbcd0a011e9fcdd9f777ef437410"/></dir><file name="ui.css" hash="823d750bb9c2bde55084d322f44b17c1"/></dir><dir name="highcontrast"><file name="content.css" hash="8294a1222d0ab5fa7520879cc9073e85"/><file name="dialog.css" hash="f6e95a7450471eb7473f8dbc3e6b6581"/><file name="ui.css" hash="1bdbee2f94594ca00c65b4d6a930bbf6"/></dir><dir name="o2k7"><file name="content.css" hash="c696812903368f41cd65616574c81484"/><file name="dialog.css" hash="661f54aa4a283b67c0acd25f91f2f213"/><dir name="img"><file name="button_bg.png" hash="36fd9fbd748860f515df259443367163"/><file name="button_bg_black.png" hash="9645f90b37102a3618a52be18b74b02b"/><file name="button_bg_silver.png" hash="15fbf2b4a20dbaa86205af6764f4fee4"/></dir><file name="ui.css" hash="a108668128c143e61bc44990dff89fe6"/><file name="ui_black.css" hash="ba8d82d9bff6e2854b29b1f97ead05fe"/><file name="ui_silver.css" hash="b42c7d51247d02ddca437a1661e748e5"/></dir></dir><file name="source_editor.htm" hash="42f3a13b55ffcf7c2d3ab768012abfcc"/></dir><dir name="simple"><file name="editor_template.js" hash="3ac3fd3129ee9605052b8470f8d58538"/><file name="editor_template_src.js" hash="409e0cce50eb6c62463d6dd9c6120859"/><dir name="img"><file name="icons.gif" hash="273dad62be4d114c5d52210b50a5838f"/></dir><dir name="langs"><file name="en.js" hash="50dce0602a45ba9fac56f12f76a63ec3"/></dir><dir name="skins"><dir name="default"><file name="content.css" hash="0f70f3ca9624e252d1c41ea064fc65e7"/><file name="ui.css" hash="c46c68283c617bb61dada1cd2494dd9f"/></dir><dir name="o2k7"><file name="content.css" hash="eb7a087c67578b6e3b5e0987caa4ba64"/><dir name="img"><file name="button_bg.png" hash="405ca3d63b48667ef485553192507f59"/></dir><file name="ui.css" hash="f0ec0273462e01b81e1dfd292f64451e"/></dir></dir></dir></dir><file name="tiny_mce.js" hash="199630688fff7a8bb0a549cd80187cbd"/><file name="tiny_mce_dev.js" hash="3a3819b032736635cc608076a02b3dbe"/><file name="tiny_mce_jquery.js" hash="87ee7a1967b86d56f5cdb1ba985ef4ce"/><file name="tiny_mce_jquery_src.js" hash="212727559aacdd03ea9ae6f5c6ede65a"/><file name="tiny_mce_popup.js" hash="5a318277fedf491a0301e177a9ef10b3"/><file name="tiny_mce_prototype.js" hash="0c65808fab93d86cf8552976f691b9c8"/><file name="tiny_mce_prototype_src.js" hash="3629c32a57bcf63cb52f455f18709223"/><file name="tiny_mce_src.js" hash="98575c8e6816a36f73145c2d97b0846a"/><dir name="utils"><file name="editable_selects.js" hash="e760eb21f60892a1ef2298da7df313e5"/><file name="form_utils.js" hash="579b2803ffca7953c50f53dcbef5df7e"/><file name="mctabs.js" hash="51b9bfe349fe76204ac5b65254bbef6f"/><file name="validate.js" hash="bfbaf5dc8058ff772afe2d87f4e82fbf"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_TinyMCE-3.5.11.17.xml b/var/package/Lib_Js_TinyMCE-3.5.11.17.xml
new file mode 100644
index 0000000..57e52ee
--- /dev/null
+++ b/var/package/Lib_Js_TinyMCE-3.5.11.17.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_TinyMCE</name>
+    <version>3.5.11.17</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>TinyMCE Javascript Libraries for Magento</summary>
+    <description>TinyMCE Javascript Libraries for Magento</description>
+    <notes>3.5.11.17</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:42</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="tiny_mce"><dir name="classes"><file name="AddOnManager.js" hash="394e98bc019eb5c08c657fe4f8a48546"/><file name="ControlManager.js" hash="26cedc474b183b1a9905cdb3d10254dc"/><file name="Editor.Events.js" hash="07af3e1a08aead0078eb0cd6b030b864"/><file name="Editor.js" hash="e921b224172fbe2bd134eaab1974f2e8"/><file name="EditorCommands.js" hash="18b0d752aafddca09cf59fa7cc4d45c2"/><file name="EditorManager.js" hash="68b7a4a6252ab8b326fa5c8ee52d8016"/><file name="EnterKey.js" hash="ecc48ccb75c80dca2bd6bd7023fc906e"/><file name="ForceBlocks.js" hash="186ad2042e7b9416d2c4f9ec5f519893"/><file name="Formatter.js" hash="413f6c83f256d864a01e05718fbe7ce6"/><file name="LegacyInput.js" hash="a14c5e4099e2e4cbc6339eb54d3ec8f9"/><file name="Popup.js" hash="b6775a0e19bd839625b4dfb6b92a9688"/><file name="UndoManager.js" hash="276955286b65fba55ee60833ca2d6671"/><file name="WindowManager.js" hash="794c3d88226e8b62eac09eeeef283c3b"/><dir name="adapter"><dir name="jquery"><file name="adapter.js" hash="a5eea8e2826d7b0929291aa7a927ec29"/><file name="jquery.tinymce.js" hash="f2f319f369a84757b8976c2d66872933"/></dir><dir name="prototype"><file name="adapter.js" hash="37d84615944f028635f68d05b889c5c2"/></dir></dir><dir name="dom"><file name="DOMUtils.js" hash="bb9a7c2b19ad2433c85984cb8511e085"/><file name="Element.js" hash="1208e71eb2bc8e578b5a9cb4ec3b1365"/><file name="EventUtils.js" hash="652351eaf41de2659cfc7e380b694c02"/><file name="Range.js" hash="05c8ac178fa799217f60ebb650b41e0f"/><file name="RangeUtils.js" hash="9948e6204548089899b1e325370355f1"/><file name="ScriptLoader.js" hash="742ce02734095db354ad54ab8399a0ee"/><file name="Selection.js" hash="3332b2293dfc2a93fdb6a67ce5329642"/><file name="Serializer.js" hash="8762f4920ed6d4a57203bfbb8bc8490c"/><file name="Sizzle.js" hash="7930b22f632c7b0240237df1393e5023"/><file name="TreeWalker.js" hash="55425ece6675a529525bad45c6acbd94"/><file name="TridentSelection.js" hash="1fd402d1bb8144fa8549031b5f061733"/></dir><dir name="firebug"><file name="FIREBUG.LICENSE" hash="3b402ea96cec202bac23ea7144653cfa"/><file name="firebug-lite.js" hash="1c9c10926be94a61564ad0541a50624f"/></dir><dir name="html"><file name="DomParser.js" hash="25a47241e40445f2870bc94ce6a10b3c"/><file name="Entities.js" hash="7292e9f893096fb66d3232920be3c3d9"/><file name="Node.js" hash="ea0a5b87b71760018a753eb41a4e0f48"/><file name="SaxParser.js" hash="6dbb27c6762a5f27a9e6e844391393f4"/><file name="Schema.js" hash="e4d6e60fbca99911660f272717b9c08b"/><file name="Serializer.js" hash="ab74a79798a6f20f4267e3f1da17f2da"/><file name="Styles.js" hash="72317437bb3c7f0a05302658ea19dfce"/><file name="Writer.js" hash="3a2e8b824b749c19c5f27f8c830f95a5"/></dir><file name="tinymce.js" hash="546ec1f2bbfbf1ee04b4a33dcc05bc52"/><dir name="ui"><file name="Button.js" hash="82e9cd9d322a714652b0bc8e40e7e503"/><file name="ColorSplitButton.js" hash="06760a696b922b56a482f5889407714e"/><file name="Container.js" hash="7929a5d6aef46380197061e49e4f9dfb"/><file name="Control.js" hash="460a997aaad3b1b24f684bfdbefd3d9c"/><file name="DropMenu.js" hash="3359b973c857ca38105eeb276119b99f"/><file name="KeyboardNavigation.js" hash="f446fdfbadd728e8b009dc4adfc0b0d2"/><file name="ListBox.js" hash="2cd7287ec70ac87cb3903ecf0a2ccfdc"/><file name="Menu.js" hash="02762fee614d37aaea7eaf14f07dece1"/><file name="MenuButton.js" hash="fb0251eb52a5b3779d76ed2c2f8ec77e"/><file name="MenuItem.js" hash="55d400a161aa44d9dd5334d6f58ed956"/><file name="NativeListBox.js" hash="964785fd8a23be00b6db650f96e9ebf7"/><file name="Separator.js" hash="d4c5d779114617360ea78a2c0d523c81"/><file name="SplitButton.js" hash="e78e53578280cce9d97f936a82eca6de"/><file name="Toolbar.js" hash="b742f894f63122c4ee635fa59958167d"/><file name="ToolbarGroup.js" hash="db7b059b984e114ea22b1dc558d3d1f2"/></dir><dir name="util"><file name="Cookie.js" hash="14bc612b28c3c75549138a1699d5c238"/><file name="Dispatcher.js" hash="bf9bd51bbabca1823634833b3b16097c"/><file name="JSON.js" hash="b9b5964dbcd4cff962264dd72d8e4df5"/><file name="JSONP.js" hash="0a39d9e1b8427ab8b6dbdd00177c8c48"/><file name="JSONRequest.js" hash="dd12f1ac5c78ec4ba7459fb825ff9e5e"/><file name="Quirks.js" hash="927b518cc3aa663a41921590d0d3b4ac"/><file name="URI.js" hash="7069a8a2dfa4b0315719778b8c744139"/><file name="VK.js" hash="78114029ce46d5a4a441b01c44f23b4f"/><file name="XHR.js" hash="b00450d636335e7be50d46d2c31cc5a0"/></dir><dir name="xml"><file name="Parser.js" hash="c6d6862014ef2ab23a5a16adaee1af6d"/></dir></dir><file name="jquery.tinymce.js" hash="751418d46d453e7c6b1a7fbd4e60fefa"/><dir name="langs"><file name="en.js" hash="eff36a9433bccea2f3243b1465fe6fe3"/></dir><file name="license.txt" hash="b238d032089de4c340f6e0119210ce3a"/><dir name="plugins"><dir name="advhr"><dir name="css"><file name="advhr.css" hash="15df80b2137bcc04d5455ffa3a51e0c5"/></dir><file name="editor_plugin.js" hash="d0a03059205455e5c19cf3a845a0ebde"/><file name="editor_plugin_src.js" hash="a7fda2e674f15a33baf53cea2e23ec66"/><dir name="js"><file name="rule.js" hash="ef46d7c850c8bcc869ea84ed7ac00c49"/></dir><dir name="langs"><file name="en_dlg.js" hash="af62ab3f1b7a27190f8e001c8aefdfa6"/></dir><file name="rule.htm" hash="492ebbdc24d46061e928d911873d5fc8"/></dir><dir name="advimage"><dir name="css"><file name="advimage.css" hash="1ccd374d5f1e89cc16e1649558a9bb33"/></dir><file name="editor_plugin.js" hash="8af1f904909820d132bc0cbeb6469130"/><file name="editor_plugin_src.js" hash="958a409150fba5532d27e862d52015e9"/><file name="image.htm" hash="0d204c8f7651c3080ab542fb36957881"/><dir name="img"><file name="sample.gif" hash="b9c7057c46716340e8967340ad11766e"/></dir><dir name="js"><file name="image.js" hash="d071360a06b4f8590b4b18a7eca039aa"/></dir><dir name="langs"><file name="en_dlg.js" hash="6f80f834e2209e6a95957403bb4842f0"/></dir></dir><dir name="advlink"><dir name="css"><file name="advlink.css" hash="aaf226732a7b4ae80ee680700f488a1e"/></dir><file name="editor_plugin.js" hash="5e440c6bcb7fd94e7fd597f8a183e16f"/><file name="editor_plugin_src.js" hash="4104cd66aea546becf5d8fca66cf7951"/><dir name="js"><file name="advlink.js" hash="80dd2f99418025b6f9fd757adfdb1a71"/></dir><dir name="langs"><file name="en_dlg.js" hash="8da3a95d6886837c0bca18670f57ae1c"/></dir><file name="link.htm" hash="206ef7aba261ac4bc14e7c6fdbdcc8c5"/></dir><dir name="advlist"><file name="editor_plugin.js" hash="5f1c8625c04a6b0f4567c1c8d5e28ff9"/><file name="editor_plugin_src.js" hash="d451908bf1e060ecd49356787f33fc7c"/></dir><dir name="autolink"><file name="editor_plugin.js" hash="5091233229ffe517f075b787c5f388a6"/><file name="editor_plugin_src.js" hash="f03a8ec9ad17bd53f897a525e3cc30f7"/></dir><dir name="autoresize"><file name="editor_plugin.js" hash="adf5cbe96119e3ed9ab4a86ba26405e7"/><file name="editor_plugin_src.js" hash="4d1cdbe307f73b4d36d1bf9b3bc2d0a9"/></dir><dir name="autosave"><file name="editor_plugin.js" hash="ae4c2aba85a22da66e3655f55d1c89fd"/><file name="editor_plugin_src.js" hash="6177147324865c00736c242b8ccb2de6"/><dir name="langs"><file name="en.js" hash="a33b0322c949a6d74bde7fa164396984"/></dir></dir><dir name="bbcode"><file name="editor_plugin.js" hash="31748a6cc57a13da54a0243c3301f3e6"/><file name="editor_plugin_src.js" hash="842450703b915245adb53df7d478ea5a"/></dir><dir name="contextmenu"><file name="editor_plugin.js" hash="5a0fc9ce2ba71bf2b6f54eb94838619f"/><file name="editor_plugin_src.js" hash="b923e4315f2d98703bbe9699465f84f0"/></dir><dir name="directionality"><file name="editor_plugin.js" hash="e2d925fe1e778dbcade06d55164fc276"/><file name="editor_plugin_src.js" hash="14b7a5b69fdc4f235b654436e4fe3081"/></dir><dir name="emotions"><file name="editor_plugin.js" hash="98cba02e33fc108024f3e993be0b0b62"/><file name="editor_plugin_src.js" hash="4cbc6e9b083a810ab0d3768af8f8f864"/><file name="emotions.htm" hash="9378bfd04b56a828318f7798f5696f67"/><dir name="img"><file name="smiley-cool.gif" hash="e26e97a318f82ec144b0818e5a8f8edb"/><file name="smiley-cry.gif" hash="e72bf995ceca9230273ed9909c5db9c8"/><file name="smiley-embarassed.gif" hash="d59171236e6b0b96091eeda1f7b57ce3"/><file name="smiley-foot-in-mouth.gif" hash="c12d9db6a14ad0b52f66f1e2cf2a38e7"/><file name="smiley-frown.gif" hash="59930208822fe755f651a67ef4b70530"/><file name="smiley-innocent.gif" hash="ec0477c8a206ff250782e40f9bae4b4c"/><file name="smiley-kiss.gif" hash="4ae8945f3960751b5d294f18242e144d"/><file name="smiley-laughing.gif" hash="c37f405db4e13cbebf24e745534687bf"/><file name="smiley-money-mouth.gif" hash="11c14bd1496afd0e21df115d25b68e96"/><file name="smiley-sealed.gif" hash="bb828cb46b377d1589927a02f8fd1762"/><file name="smiley-smile.gif" hash="2968a664098d9580079c66d628dad1a8"/><file name="smiley-surprised.gif" hash="2e136ebd637bf3e6c9fc6bdc20cbe73e"/><file name="smiley-tongue-out.gif" hash="5ec3bb4781c8e43a51d3a1a948b98fc0"/><file name="smiley-undecided.gif" hash="3c0c011d16b1a2331385ed97e160a42a"/><file name="smiley-wink.gif" hash="897275ac7d07032b4d93fb83a0d2a41b"/><file name="smiley-yell.gif" hash="19bb8ebfe3c2f5ef3ffb9aa4a027900d"/></dir><dir name="js"><file name="emotions.js" hash="85efe828d29037950412fec963b6f950"/></dir><dir name="langs"><file name="en_dlg.js" hash="62c052504a77e4f4cec6d90ece0d76c4"/></dir></dir><dir name="example"><file name="dialog.htm" hash="e6170a190a4d44ea5e6af089d2728d7e"/><file name="editor_plugin.js" hash="e0a175dca3d5e437657ccd5d548ff409"/><file name="editor_plugin_src.js" hash="b98bec73743c249187e0fa8f8311e3a3"/><dir name="img"><file name="example.gif" hash="6036655a01df362267183a8b23fead10"/></dir><dir name="js"><file name="dialog.js" hash="83245e76c97e24d466cf5df2308f9bf4"/></dir><dir name="langs"><file name="en.js" hash="78c88182b5fb900fc956845f75885b3a"/><file name="en_dlg.js" hash="7aec7a3b9d4642fbf7bb3ef1ed8a7570"/></dir></dir><dir name="example_dependency"><file name="editor_plugin.js" hash="405d190ae03384a9acb00533568b2cfd"/><file name="editor_plugin_src.js" hash="473878118b45efe326d335f992ff9943"/></dir><dir name="fullpage"><dir name="css"><file name="fullpage.css" hash="2ac64c98369f8b4f7cbf6fa70e25bfca"/></dir><file name="editor_plugin.js" hash="5dfbe0a82c87eb0fb65b11dcd39406d0"/><file name="editor_plugin_src.js" hash="636afe66f3de447eb92611bdcfb7f2b3"/><file name="fullpage.htm" hash="8c58825b698712e7297f95da51a9c03c"/><dir name="js"><file name="fullpage.js" hash="a7913b6b1a1ae634a509c3db9faf381a"/></dir><dir name="langs"><file name="en_dlg.js" hash="963f370d56f19c2f94de09b10a306187"/></dir></dir><dir name="fullscreen"><file name="editor_plugin.js" hash="15134339e36472281b8a1626233f747d"/><file name="editor_plugin_src.js" hash="a28a8a8bf569d6ee5e6dccbc988490ce"/><file name="fullscreen.htm" hash="b6d76297c2f679b9110ec7119d091900"/></dir><dir name="iespell"><file name="editor_plugin.js" hash="22526393cacb6447a0e3bfff2fb47773"/><file name="editor_plugin_src.js" hash="311e13bcc85c06da43decc37dc1b4f83"/></dir><dir name="inlinepopups"><file name="editor_plugin.js" hash="db32751b98f40ca6eee24efc848d6cbb"/><file name="editor_plugin_src.js" hash="d1c1de414c13fef3593ffd14503d37c0"/><dir name="skins"><dir name="clearlooks2"><dir name="img"><file name="alert.gif" hash="568d4cf84413656fb72fe39d1dd60f8d"/><file name="button.gif" hash="19f864cb81177840dcd534df4d537ea3"/><file name="buttons.gif" hash="1743ac9f7f2267a6edafefc536a2265d"/><file name="confirm.gif" hash="1bc337a20c319e531cda6ced531827d0"/><file name="corners.gif" hash="55298b5baaecb7e06a251db9f0a4b14c"/><file name="horizontal.gif" hash="0365e75dd4a9ad61dc98dcb641207c21"/><file name="vertical.gif" hash="0261136fac58ce77bdbd96aa0194947e"/></dir><file name="window.css" hash="f715affab9da63bc26f8c6362a989395"/></dir></dir><file name="template.htm" hash="3d7e3ae05511a9f64c5da924b9e971ba"/></dir><dir name="insertdatetime"><file name="editor_plugin.js" hash="d99072498466cdb2f53ed7c02da85982"/><file name="editor_plugin_src.js" hash="32a2afa1cd3ff8c9b966f8724ba3e0b3"/></dir><dir name="layer"><file name="editor_plugin.js" hash="4e5fc1b467c19d79dcf6246ba3a63cd8"/><file name="editor_plugin_src.js" hash="3754eb57b08539e459509caa74acecc6"/></dir><dir name="legacyoutput"><file name="editor_plugin.js" hash="b732a86187723cd9cc32853d67730061"/><file name="editor_plugin_src.js" hash="8a0a69cbe8d447d722aaef7d4ed7dcc1"/></dir><dir name="lists"><file name="editor_plugin.js" hash="46ba57884d8fe05d92cd9d98d3bb00af"/><file name="editor_plugin_src.js" hash="04e1f245c19d6dc9454dae57faec9b6f"/></dir><dir name="media"><dir name="css"><file name="media.css" hash="f211293a697a2c83da00effd67f535a2"/></dir><file name="editor_plugin.js" hash="5ad7db86c5008f98ec135595db4a4973"/><file name="editor_plugin_src.js" hash="1d03ec1ec36745041db26132b07b0491"/><dir name="img"><file name="flash.gif" hash="6c69b02015d09280332ff8b07e4ea2f3"/><file name="quicktime.gif" hash="9a6a9fdead205b125c07ea37e71ed4f1"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="baa643b587565755157618032dc93e3c"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/><file name="media.js" hash="4f35c0283a30f3556e023e76c34368b2"/></dir><dir name="langs"><file name="en_dlg.js" hash="9523fc123c577642000fd409bd862c3f"/></dir><file name="media.htm" hash="be58b1edf9a4a4dbf3a1993e3d897e1a"/><file name="moxieplayer.swf" hash="9217cea72c76c361fa5033526712284e"/><file name=".htaccess" hash="9f2e3ee0d6e50d80819eb8c0300a0913"/></dir><dir name="nonbreaking"><file name="editor_plugin.js" hash="232f23a586f10bd8ddabf38d767113d4"/><file name="editor_plugin_src.js" hash="fefbda5243d10652038ccf40801b8893"/></dir><dir name="noneditable"><file name="editor_plugin.js" hash="b332a5f8767506024a0f50aa4204b1fe"/><file name="editor_plugin_src.js" hash="273d35e2221889e75f33fd545f77d44e"/></dir><dir name="pagebreak"><dir name="css"><file name="content.css" hash="d9664762a610f2b5f7b10b5781f3299a"/></dir><file name="editor_plugin.js" hash="8be3376740c886fa2842d2f4eb282bbc"/><file name="editor_plugin_src.js" hash="c2d432a5914f0095a859ff443700a5e9"/><dir name="img"><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/></dir></dir><dir name="paste"><file name="editor_plugin.js" hash="1b68c59eb95a28ccc2aff2cfb85a8829"/><file name="editor_plugin_src.js" hash="40eef37ac300b571da5383bc0bddf73f"/><dir name="js"><file name="pastetext.js" hash="d6e4b39f19b89118b34b0d21491494b7"/><file name="pasteword.js" hash="112504d12e971e4d32f17a59c5616c36"/></dir><dir name="langs"><file name="en_dlg.js" hash="6ea2189562f65287be8e5e3185c405b7"/></dir><file name="pastetext.htm" hash="8f217769e59a5dd67843c7c17c842f41"/><file name="pasteword.htm" hash="8b9459b98f9a70ed684832326bf1cdf6"/></dir><dir name="preview"><file name="editor_plugin.js" hash="925216b63aabd5adc67d642ca2d04b4a"/><file name="editor_plugin_src.js" hash="6f9c3234dfdc0f62b713e8771f4ca5dc"/><file name="example.html" hash="9b9290408ae10fa29ec29db60682be91"/><dir name="jscripts"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/></dir><file name="preview.html" hash="bb02414f4cdd28c4a66e7fb5ed820f2d"/></dir><dir name="print"><file name="editor_plugin.js" hash="53eb1da78f727ee8337671fb86354c17"/><file name="editor_plugin_src.js" hash="f11547aa114df69b35df319003105e11"/></dir><dir name="save"><file name="editor_plugin.js" hash="307a0743c68c4e4aff005f13027f296f"/><file name="editor_plugin_src.js" hash="4dcbdaab64f06550a2db2b650f99d411"/></dir><dir name="searchreplace"><dir name="css"><file name="searchreplace.css" hash="ad0addca1bd5727432f39ec9b7fdac1e"/></dir><file name="editor_plugin.js" hash="ed4f1fa6e12844b533c86258647a298f"/><file name="editor_plugin_src.js" hash="7292198991a0fda1b9c7b28c921c6521"/><dir name="js"><file name="searchreplace.js" hash="0eeedb83f5bf1240348e1c6e77be2c47"/></dir><dir name="langs"><file name="en_dlg.js" hash="fbd47078679d87b541479000589ef4c9"/></dir><file name="searchreplace.htm" hash="4d01ee3be4045a600778fca1e11cee61"/></dir><dir name="spellchecker"><dir name="css"><file name="content.css" hash="ac0c7dbbbe44022d29d63b7b05123e3d"/></dir><file name="editor_plugin.js" hash="629a571ee7686ace6ee7ad1181be916b"/><file name="editor_plugin_src.js" hash="bae03899e91abca8b4b77c8ea886b561"/><dir name="img"><file name="wline.gif" hash="c136c9f8e00718a98947a21d8adbcc56"/></dir></dir><dir name="style"><dir name="css"><file name="props.css" hash="c2d2adc78609ea65760dae2dab058395"/></dir><file name="editor_plugin.js" hash="f9bcd692d63dfef1fe5c586d27ecd91b"/><file name="editor_plugin_src.js" hash="2ec50d9d37ce1e732380a746fabceefc"/><dir name="js"><file name="props.js" hash="f3614bf040f29057162e423822b89e11"/></dir><dir name="langs"><file name="en_dlg.js" hash="62a82106cfd480a6da4442b4763a2f2d"/></dir><file name="props.htm" hash="32f3f16194be9170386419c9dcc5b99a"/><file name="readme.txt" hash="ced5c8e014184a33da5507dbcd96b91f"/></dir><dir name="tabfocus"><file name="editor_plugin.js" hash="d3e5ef7a1a203516af0d8fdf94952fd2"/><file name="editor_plugin_src.js" hash="12889ccf8caf1d466859ba949f52fbca"/></dir><dir name="table"><file name="cell.htm" hash="f427b778a4924154a5e2317ddfd0f567"/><dir name="css"><file name="cell.css" hash="56394e6cdb267d97e23a07a98820e84b"/><file name="row.css" hash="81a75523c1e83be93e524c8bb901a089"/><file name="table.css" hash="f5e651f5a32284f1c4e0faa1d7cd5ff4"/></dir><file name="editor_plugin.js" hash="c12f0891c5bf0a7a6dd43ef0bd44dd82"/><file name="editor_plugin_src.js" hash="8228b4ab83fe4dfe2e377850dc2cf97e"/><dir name="js"><file name="cell.js" hash="8b0d4a7fe48c2f92c8b9b79dbb12cca1"/><file name="merge_cells.js" hash="3650484c93d6c9a197d03a5c3c3d2e80"/><file name="row.js" hash="d1cf0ab3d974f0b528e467d4b5c5c89f"/><file name="table.js" hash="f894721e5f5a6c2efa1a232c4b4a85b6"/></dir><dir name="langs"><file name="en_dlg.js" hash="ee3484503050cdae74d2cafa7d2e9999"/></dir><file name="merge_cells.htm" hash="f939ddd56826c0ec3c9e6e9a478346bf"/><file name="row.htm" hash="7ad9e68624759b28be626ac4b53c8907"/><file name="table.htm" hash="88fb36057ec1cb1681fed2dcb0b44693"/></dir><dir name="template"><file name="blank.htm" hash="9553e76581d74579d23bea5c7ea8a807"/><dir name="css"><file name="template.css" hash="5b2c159120cbef004c9b0804c292820b"/></dir><file name="editor_plugin.js" hash="70cb20c4e287110ae8aeed999893c532"/><file name="editor_plugin_src.js" hash="336af7b2ec3e0f7c83a7d05bf16cd018"/><dir name="js"><file name="template.js" hash="75abfd82a90ae648fb18c5517dfd925b"/></dir><dir name="langs"><file name="en_dlg.js" hash="1ce03c0fcf0f1aa74c132459abe30f39"/></dir><file name="template.htm" hash="b55e174e239e5c4b3a52d6ad60eb991d"/></dir><dir name="visualblocks"><dir name="css"><file name="visualblocks.css" hash="1fe4f62cc93864784b9b2d6b11b050b7"/></dir><file name="editor_plugin.js" hash="592e70a44aeb7c974eb9c5ff05c107a7"/><file name="editor_plugin_src.js" hash="6d1a4ea64bfedf8797260792e33f4c17"/></dir><dir name="visualchars"><file name="editor_plugin.js" hash="e494d07c71e24040a407b20017ca63e3"/><file name="editor_plugin_src.js" hash="f285c8f2ffac745325e86687b8cf0fb5"/></dir><dir name="wordcount"><file name="editor_plugin.js" hash="fb71ed139697b519f0054179d28ec782"/><file name="editor_plugin_src.js" hash="a034fddb393e4b6e7d25fc3761bea529"/></dir><dir name="xhtmlxtras"><file name="abbr.htm" hash="e514d143e00e4b121cab8fe8dfae48d2"/><file name="acronym.htm" hash="ec632b3d4b6afb189c055afa234e6291"/><file name="attributes.htm" hash="cf540b962f752babf53faa7a47bde108"/><file name="cite.htm" hash="1468438313b9cb1de0e53e50d75c92fa"/><dir name="css"><file name="attributes.css" hash="abc1b941c6eef8e1ea76915984e8a03e"/><file name="popup.css" hash="ed53e7b6ab799f6a249c3d403047dcfc"/></dir><file name="del.htm" hash="81bbcce0d19d78698fad760ee90b6948"/><file name="editor_plugin.js" hash="c9f91af5f1b8a1ba7a1e4ccf53fc7790"/><file name="editor_plugin_src.js" hash="b8b8236893ef2347a46cb131fc1a8c69"/><file name="ins.htm" hash="47e7db25678cee383fe6532ebb9e3fcb"/><dir name="js"><file name="abbr.js" hash="d91ae7d986336de4ecb977d19dcfab19"/><file name="acronym.js" hash="0a19f79bdc9222d3273712fe37a8051c"/><file name="attributes.js" hash="e75f23fae888b9febb57a29f2eb5a86c"/><file name="cite.js" hash="ba39487ce6a625538b838c21502bbaa7"/><file name="del.js" hash="be96fef888076d27384dd3546e8b6b6f"/><file name="element_common.js" hash="b817f5e2d514147d72765c92c1f60f3d"/><file name="ins.js" hash="6148dd4151e58dcda9112933908b97b1"/></dir><dir name="langs"><file name="en_dlg.js" hash="45db1586e7debc385f63092a13a9f43c"/></dir></dir></dir><dir name="themes"><dir name="advanced"><file name="about.htm" hash="ff135857e9b930d4d4658f92077e051c"/><file name="anchor.htm" hash="79d46a2b007b5cb08a3920e922a5da7f"/><file name="charmap.htm" hash="be712e4cf08670a1212e9eed2f452693"/><file name="color_picker.htm" hash="8db4d59dec910525149039f006a2bb9e"/><file name="editor_template.js" hash="a2b3085f0ab3c323dd28187b739139ec"/><file name="editor_template_src.js" hash="1fa308a86046cee68c5227ca58013bba"/><file name="image.htm" hash="2cb986c0cad7efd0592a4d8c35e41f0a"/><dir name="img"><file name="colorpicker.jpg" hash="9bcc36292defe94bca5a013a1736c7d7"/><file name="flash.gif" hash="33adee48d32bbbba3e6412cc54ecf335"/><file name="icons.gif" hash="75ad72872bc6280c32609e12fc3b610a"/><file name="iframe.gif" hash="a1af02e9ba370f64297087b46e80591e"/><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="quicktime.gif" hash="61da1ff8729ca5016344c4e8eb173369"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="1ce7d48784981aac9d4375cf2effdc4d"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="video.gif" hash="f85c56813ea016a75e496bba50d66ab4"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="about.js" hash="606c16492a17240ebded6e9fce75a555"/><file name="anchor.js" hash="da6a28397899bec3570216b2d2106684"/><file name="charmap.js" hash="02f40a38033ef8a0abeac870e5f4eda8"/><file name="color_picker.js" hash="cfc0f59a846661e748cae1c0adca77dc"/><file name="image.js" hash="75df8142a91f0245367e4121a2da7065"/><file name="link.js" hash="71949506dce04e923bbbc2ecc8ab5f1f"/><file name="source_editor.js" hash="4cbdfdf929a0949070f4d7ab4818b0f2"/></dir><dir name="langs"><file name="en.js" hash="58c814313230f1dec07fe45ad5f304e5"/><file name="en_dlg.js" hash="3a2c8aed5b7579ae45be6bd2b34ef06b"/></dir><file name="link.htm" hash="65c56f5a6d714fdbdc47c68ec9422976"/><file name="shortcuts.htm" hash="2bae05c8667b54b9ec019b529e743327"/><dir name="skins"><dir name="default"><file name="content.css" hash="1779499935490440d7a2423157756bc5"/><file name="dialog.css" hash="ab94126c11ff9c79445cc4ad537b2823"/><dir name="img"><file name="buttons.png" hash="33b2f2e08cc3ade5254fec64c4183558"/><file name="items.gif" hash="d201498a710fc8aac6e117820b9814b7"/><file name="menu_arrow.gif" hash="e21752451a9d80e276fef7b602bdbdba"/><file name="menu_check.gif" hash="c7d003885737f94768eecae49dcbca63"/><file name="progress.gif" hash="50c5e3e79b276c92df6cc52caeb464f0"/><file name="tabs.gif" hash="6473bbcd0a011e9fcdd9f777ef437410"/></dir><file name="ui.css" hash="823d750bb9c2bde55084d322f44b17c1"/></dir><dir name="highcontrast"><file name="content.css" hash="8294a1222d0ab5fa7520879cc9073e85"/><file name="dialog.css" hash="f6e95a7450471eb7473f8dbc3e6b6581"/><file name="ui.css" hash="1bdbee2f94594ca00c65b4d6a930bbf6"/></dir><dir name="o2k7"><file name="content.css" hash="c696812903368f41cd65616574c81484"/><file name="dialog.css" hash="661f54aa4a283b67c0acd25f91f2f213"/><dir name="img"><file name="button_bg.png" hash="36fd9fbd748860f515df259443367163"/><file name="button_bg_black.png" hash="9645f90b37102a3618a52be18b74b02b"/><file name="button_bg_silver.png" hash="15fbf2b4a20dbaa86205af6764f4fee4"/></dir><file name="ui.css" hash="a108668128c143e61bc44990dff89fe6"/><file name="ui_black.css" hash="ba8d82d9bff6e2854b29b1f97ead05fe"/><file name="ui_silver.css" hash="b42c7d51247d02ddca437a1661e748e5"/></dir></dir><file name="source_editor.htm" hash="42f3a13b55ffcf7c2d3ab768012abfcc"/></dir><dir name="simple"><file name="editor_template.js" hash="3ac3fd3129ee9605052b8470f8d58538"/><file name="editor_template_src.js" hash="409e0cce50eb6c62463d6dd9c6120859"/><dir name="img"><file name="icons.gif" hash="273dad62be4d114c5d52210b50a5838f"/></dir><dir name="langs"><file name="en.js" hash="50dce0602a45ba9fac56f12f76a63ec3"/></dir><dir name="skins"><dir name="default"><file name="content.css" hash="0f70f3ca9624e252d1c41ea064fc65e7"/><file name="ui.css" hash="c46c68283c617bb61dada1cd2494dd9f"/></dir><dir name="o2k7"><file name="content.css" hash="eb7a087c67578b6e3b5e0987caa4ba64"/><dir name="img"><file name="button_bg.png" hash="405ca3d63b48667ef485553192507f59"/></dir><file name="ui.css" hash="f0ec0273462e01b81e1dfd292f64451e"/></dir></dir></dir></dir><file name="tiny_mce.js" hash="199630688fff7a8bb0a549cd80187cbd"/><file name="tiny_mce_dev.js" hash="3a3819b032736635cc608076a02b3dbe"/><file name="tiny_mce_jquery.js" hash="87ee7a1967b86d56f5cdb1ba985ef4ce"/><file name="tiny_mce_jquery_src.js" hash="212727559aacdd03ea9ae6f5c6ede65a"/><file name="tiny_mce_popup.js" hash="5a318277fedf491a0301e177a9ef10b3"/><file name="tiny_mce_prototype.js" hash="0c65808fab93d86cf8552976f691b9c8"/><file name="tiny_mce_prototype_src.js" hash="3629c32a57bcf63cb52f455f18709223"/><file name="tiny_mce_src.js" hash="98575c8e6816a36f73145c2d97b0846a"/><dir name="utils"><file name="editable_selects.js" hash="e760eb21f60892a1ef2298da7df313e5"/><file name="form_utils.js" hash="579b2803ffca7953c50f53dcbef5df7e"/><file name="mctabs.js" hash="51b9bfe349fe76204ac5b65254bbef6f"/><file name="validate.js" hash="bfbaf5dc8058ff772afe2d87f4e82fbf"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_LinLibertineFont-2.8.14.17.xml b/var/package/Lib_LinLibertineFont-2.8.14.17.xml
deleted file mode 100644
index c2ffc1c..0000000
--- a/var/package/Lib_LinLibertineFont-2.8.14.17.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_LinLibertineFont</name>
-    <version>2.8.14.17</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/gpl.html">GPL</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Libertine Open Fonts Project fonts for PDF print-outs</summary>
-    <description>Libertine Open Fonts Project fonts for PDF print-outs</description>
-    <notes>2.8.14.17</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="LinLibertineFont"><file name="Bugs" hash="9ecefd5b5d739618917f6ff1a496af4d"/><file name="ChangeLog.txt" hash="c4a43af51dc70f4acbd09eeda8a1f95d"/><file name="GPL.txt" hash="ae32e069c670f1247694f4313efcc977"/><file name="LICENCE.txt" hash="9752e08000ee88048cb953607250dd7b"/><file name="LinLibertineC_Re-2.8.0.ttf" hash="7c98097ee899568bc86c28a8eafd77a3"/><file name="LinLibertine_Bd-2.8.1.ttf" hash="81c9c61a6c91fc6ccb93f1e6ec6ed06a"/><file name="LinLibertine_It-2.8.2.ttf" hash="5d334990c5d59bd428ae684ce8490c5c"/><file name="LinLibertine_Re-4.4.1.ttf" hash="de5bccf92a5145f4532b126f9506c28d"/><file name="OFL.txt" hash="6237e6976dcefd3d9fc3f1264b3c3bb9"/><file name="Readme" hash="9bbff4f7c21eb0a037527720e4b8473d"/><file name="Readme-TEX.txt" hash="14cb95ee0acecf6c3ef563f1b906443b"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_LinLibertineFont-2.8.14.18.xml b/var/package/Lib_LinLibertineFont-2.8.14.18.xml
new file mode 100644
index 0000000..5453196
--- /dev/null
+++ b/var/package/Lib_LinLibertineFont-2.8.14.18.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_LinLibertineFont</name>
+    <version>2.8.14.18</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/gpl.html">GPL</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Libertine Open Fonts Project fonts for PDF print-outs</summary>
+    <description>Libertine Open Fonts Project fonts for PDF print-outs</description>
+    <notes>2.8.14.18</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:43</time>
+    <contents><target name="magelib"><dir name="LinLibertineFont"><file name="Bugs" hash="9ecefd5b5d739618917f6ff1a496af4d"/><file name="ChangeLog.txt" hash="c4a43af51dc70f4acbd09eeda8a1f95d"/><file name="GPL.txt" hash="ae32e069c670f1247694f4313efcc977"/><file name="LICENCE.txt" hash="9752e08000ee88048cb953607250dd7b"/><file name="LinLibertineC_Re-2.8.0.ttf" hash="7c98097ee899568bc86c28a8eafd77a3"/><file name="LinLibertine_Bd-2.8.1.ttf" hash="81c9c61a6c91fc6ccb93f1e6ec6ed06a"/><file name="LinLibertine_It-2.8.2.ttf" hash="5d334990c5d59bd428ae684ce8490c5c"/><file name="LinLibertine_Re-4.4.1.ttf" hash="de5bccf92a5145f4532b126f9506c28d"/><file name="OFL.txt" hash="6237e6976dcefd3d9fc3f1264b3c3bb9"/><file name="Readme" hash="9bbff4f7c21eb0a037527720e4b8473d"/><file name="Readme-TEX.txt" hash="14cb95ee0acecf6c3ef563f1b906443b"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Mage-1.9.4.0.xml b/var/package/Lib_Mage-1.9.4.0.xml
deleted file mode 100644
index 0901bf9..0000000
--- a/var/package/Lib_Mage-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Mage</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Mage Library</summary>
-    <description>Mage Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="7219e31d44a1ad2263795f24f80fd557"/><file name="Bz.php" hash="ddda0a3dfbb7b81ce9a6e69c6b44e540"/><file name="Gz.php" hash="385b2740aacefcd317273448ed95ef83"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="0611e0df836dafa206aeac06ab609724"/><file name="Gz.php" hash="13c15537156d0293cc86588cca629267"/></dir><file name="File.php" hash="314284e414f094c7e7ea81ffe8f6a9ee"/></dir><file name="Interface.php" hash="212679c1c16ad7e35eff39e55c2ec510"/><file name="Tar.php" hash="93dce1abf2d3b717778aff701ce35d40"/></dir><file name="Archive.php" hash="736c17d5666816627fba72fe7d4f6140"/><dir name="Autoload"><file name="Simple.php" hash="aacee169c0bdcd87e470269641473631"/></dir><dir name="Backup"><file name="Abstract.php" hash="c3de48d5961070832d1ed0f7177ee4a2"/><dir name="Archive"><file name="Tar.php" hash="8bd53f96d6ba93d5887b0e7aa72f9269"/></dir><file name="Db.php" hash="89f62bd52b21db1dd708a02ae4347248"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="4f53c1142257ab85784198a402d2f425"/><file name="FtpConnectionFailed.php" hash="5fefd3d3b8be727781a6f5fdb138852f"/><file name="FtpValidationFailed.php" hash="cec68f36cf698a50e41471d46722d57c"/><file name="NotEnoughFreeSpace.php" hash="ccdd5e27479a58a1b3866c64533822c1"/><file name="NotEnoughPermissions.php" hash="3afd5fa76513cc11b55082bab2ebeb26"/></dir><file name="Exception.php" hash="d75dc453d7950a04329ba6309da002a9"/><dir name="Filesystem"><file name="Helper.php" hash="dc10bc252a7a55258278f52c5165f172"/><dir name="Iterator"><file name="File.php" hash="c85c788b168fc0a4645a4cdaf10caa80"/><file name="Filter.php" hash="174deec59e7fe57014725a3a623b074c"/></dir><dir name="Rollback"><file name="Abstract.php" hash="271c9e6032f86e8d71e660b9778e71a9"/><file name="Fs.php" hash="c6ca689d7bfd4c0fe4101ccb74a96c97"/><file name="Ftp.php" hash="c6f3318d266f386a52be726b3ed28c20"/></dir></dir><file name="Filesystem.php" hash="a2ac0ad741f06e862da5cc2a8d0c3a36"/><file name="Interface.php" hash="2550d86498a20a3d5d83672415ae7f91"/><file name="Media.php" hash="dd1f7d5304b53206c6d770ae668d254b"/><file name="Nomedia.php" hash="1d7f11e8507fbba3893be459d331891b"/><file name="Snapshot.php" hash="d3b7c974ed49905937cde4b69075ab4e"/></dir><file name="Backup.php" hash="951e7982ed239d7799e7722ac67435eb"/><dir name="Cache"><dir name="Backend"><file name="File.php" hash="458b0c266c9bc8a191335442522a645b"/><file name="Redis.php" hash="c398f19df4b0aef55450a14747f3c61b"/></dir></dir><dir name="Connect"><dir name="Channel"><file name="Generator.php" hash="b3dbdf1fdd1d5a462a522c68627d2bba"/><file name="Parser.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="VO.php" hash="38e61a3a3b877639cdeb427f8746ced1"/></dir><dir name="Command"><file name="Channels.php" hash="c13a8190309ee8b816eb044422d02dc4"/><file name="Channels_Header.php" hash="ef497284ed4c24aa7234dbfe48d238dc"/><file name="Config.php" hash="33bff8743fd8a86cb292f3e94edbdf50"/><file name="Config_Header.php" hash="11b772152974cbd6be72b76335a91896"/><file name="Install.php" hash="19de11c9f04c7b1a161a23fa843f5a1e"/><file name="Install_Header.php" hash="5bd1465e62f45dc30cb8f249c399a65e"/><file name="Package.php" hash="79fd89514981e32d13de63a6d8cf164a"/><file name="Package_Header.php" hash="f30cba27b0e6233f39bf5dcd06af3ba5"/><file name="Registry.php" hash="e88277d0fdeffae71097cc4d4cbe8441"/><file name="Registry_Header.php" hash="9fa6bff3f86a4e7a87d9ca50000ef999"/><file name="Remote.php" hash="1291065611ca8320c6948d1f1e458857"/><file name="Remote_Header.php" hash="27419e6e322ce60848994cc45bc71bcd"/></dir><file name="Command.php" hash="bc170c01333fc3867a6cd537219a4c10"/><file name="Config.php" hash="56b877abd4a1604e1989bea18473418d"/><file name="Converter.php" hash="fea5425f9074136c9fc10d6d7b15a4f8"/><dir name="Frontend"><file name="CLI.php" hash="abb0ea49598d20bb2c4b91a507e6e2a0"/></dir><file name="Frontend.php" hash="39e10184f8d83572b5edbea240642cfa"/><file name="Ftp.php" hash="ecc1ee16683875cc8779ff22168508fb"/><dir name="Loader"><file name="Ftp.php" hash="b59ab0750f9ad9f8462ec43583eb8d3e"/></dir><file name="Loader.php" hash="355ed95e925fa98bdec382f37cfeeb39"/><dir name="Package"><file name="Extension.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Hotfix.php" hash="31f281c8485a8c010230eebc64d2fdc9"/><file name="Maintainer.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Reader.php" hash="94dd06082e803182e7d54a9b6a3a9117"/><file name="Target.php" hash="3769c486343cee9e9c20ab0a7d211288"/><file name="VO.php" hash="bfbe38745c9f36fe9b79aa1c0bf3c106"/><file name="Writer.php" hash="19ea81f6f2dc4d2828ebecf7ba84ca44"/></dir><file name="Package.php" hash="1b3f2d9c00d37cd66edae1068ae7ace4"/><file name="Packager.php" hash="002b9d6df3513b2e6622d5a92888d976"/><dir name="Repository"><file name="Abstract.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><dir name="Channel"><file name="Abstract.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Commercial.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Community.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Core.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/></dir><file name="Channel.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Local.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/></dir><file name="Repository.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Rest.php" hash="62b4562a1ec60a923bd9360e4395ae1e"/><file name="Singleconfig.php" hash="03d046a07f52a29e27da2a184e61c5cd"/><dir name="Structures"><file name="Graph.php" hash="907ec31e395ed931d3468bab30c8a865"/><file name="Node.php" hash="bfa5cc71b8e0787ddf41917faaa8d859"/></dir><file name="Validator.php" hash="ea9b801aff843b3bda84200b9f612e76"/></dir><dir name="DB"><file name="Exception.php" hash="1651c02af32d13cb09f18e55fe41a454"/><file name="Mysqli.php" hash="1afea21a74a5c95afb3aa0fac88dd8f1"/></dir><file name="Exception.php" hash="b2841a64f422bb6de9ca9deb16483199"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="9fc530e406f64aadb1d18a8af8c22f9d"/><file name="Socket.php" hash="2403f0c937a01759262eca2bd838b13a"/></dir><file name="Client.php" hash="6de915c729f44d8700147a4929de5a08"/><file name="IClient.php" hash="1bb87d5c7b0027db0288a58d2691c1f8"/></dir><dir name="System"><file name="Args.php" hash="c95ce3451a31af33ed0a0987fc007a80"/><file name="Dirs.php" hash="557f6440351c8c0f5a34b30340ac2601"/><file name="Ftp.php" hash="d5d2052fd9d8799b4aaa26fc6bb2d05c"/></dir><dir name="Xml"><file name="Generator.php" hash="dbbf15cac6bef48830f921ece90b4382"/><file name="Parser.php" hash="4dab68fb16c447bf58897b57a9e7f589"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Mage-1.9.4.1.xml b/var/package/Lib_Mage-1.9.4.1.xml
new file mode 100644
index 0000000..37c6d9b
--- /dev/null
+++ b/var/package/Lib_Mage-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Mage</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Mage Library</summary>
+    <description>Mage Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:43</time>
+    <contents><target name="magelib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="885d30e2585116c9c5c3b35c579eb8cc"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="a4aeeebc126d4120438e0d28a35e043e"/></dir><file name="Archive.php" hash="e2fc609c9a68b600ee3d004ea47e11a4"/><dir name="Autoload"><file name="Simple.php" hash="0c93e10e43467dc314329567e4f1017a"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="3ca2f9e886689a5a177b1926af96270b"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="54069ee402c8aff0674969c649080647"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Cache"><dir name="Backend"><file name="File.php" hash="6cb7c7a675a38a8572367d2057760c5b"/><file name="Redis.php" hash="cfbc64fae1141401527d564e50b19975"/></dir></dir><dir name="Connect"><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="9392eea3bf03eeededfdb77189a77ed1"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="aeb7f173a74e88b126f24a5c423d238d"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="3f9fa5724199094218b7a423fc2188f1"/><file name="Package_Header.php" hash="99644d4f466ac78c1443a340c8ae73ef"/><file name="Registry.php" hash="3380f750bb96583b8e15024fe215b6da"/><file name="Registry_Header.php" hash="0f6571d92254cb88f697cc87300a8153"/><file name="Remote.php" hash="058b14285950694cd3abf2e82991fa59"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="7377f6955be0ef8df32ceea23bd43a05"/><file name="Config.php" hash="4fbfe162550121cdcc11573f5c8a3eef"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="f1b095d29a7e1441006c6ac8e07e5687"/></dir><file name="Frontend.php" hash="d2f246e8f0e5ada260676a12b4e79188"/><file name="Ftp.php" hash="72efa691308535fead42e7220a0ec853"/><dir name="Loader"><file name="Ftp.php" hash="a835c7fe4b0d2069c74134f152b78847"/></dir><file name="Loader.php" hash="5c6b2b24c4d5bf2343a61101156878a3"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="8f8c4f28da356e4a5893ac0523673a85"/></dir><file name="Package.php" hash="fe4dc41cbd8468e99a0b45072eb1fd66"/><file name="Packager.php" hash="7888f316b4d504708bde21844c05818f"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Rest.php" hash="bf1dd62f5ffe4c908b74d34e8361da05"/><file name="Singleconfig.php" hash="ca24a1a23c2a0d5033d8679cf3b33b00"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="616706e0605b61a63ea209174ee8f68c"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="e524751d0497a6142c2aaf2b8d94d310"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="01b98ec808157fe1ee18bdad2912e545"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="9ecc29ecd17c7a58063053bb5b44c6f9"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="f8800d0e16431a6d51869b8109912d8e"/><file name="Ftp.php" hash="191e30aa3d5917e3df81388e0914c35d"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Magento-1.9.4.0.xml b/var/package/Lib_Magento-1.9.4.0.xml
deleted file mode 100644
index 4aa9bbe..0000000
--- a/var/package/Lib_Magento-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Magento</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Magento"><dir name="Autoload"><file name="ClassMap.php" hash="0c278d60e2c12dbe4ed34aa05816099f"/><file name="IncludePath.php" hash="7ed33a977845bacf0ac132978a6bfd92"/><file name="Simple.php" hash="76230e87f5557fa5d804f9c41c3141aa"/></dir><file name="Crypt.php" hash="a00c241177a5e666d5dab59bb538c283"/><dir name="Db"><dir name="Adapter"><dir name="Pdo"><file name="Mysql.php" hash="8c0fb38753426719991081ec22ae2f08"/></dir></dir><dir name="Object"><file name="Interface.php" hash="24ddf513994dde357f8934bcdbc9a182"/><file name="Table.php" hash="aeeac7ef5d85e6f6513962c1afe5f143"/><file name="Trigger.php" hash="2c46164f6fb21c35e6b92ae0429f67be"/><file name="View.php" hash="75bb64fdd6ba76332d1da56025c334ae"/></dir><file name="Object.php" hash="0857207e7e7b27575912512ba71d1401"/><dir name="Sql"><file name="Select.php" hash="433372e6bd00f43ee5f0ced15c30745e"/><file name="Trigger.php" hash="e961171ab02c054c0f9994c8d627db75"/></dir></dir><file name="Exception.php" hash="dd1ff8f6b66ad294b3998647f9727912"/><dir name="Profiler"><dir name="Output"><file name="Csvfile.php" hash="46187439941f8a93cd8ecd0a1873d2c5"/><file name="Firebug.php" hash="37d7aae1a60fb5d6318132bc82755605"/><file name="Html.php" hash="4b624ab12401c750eb199319dd3ce085"/></dir><file name="OutputAbstract.php" hash="6df96db27d29ca1a85f0ac4c2f078332"/></dir><file name="Profiler.php" hash="1f53ea480dcd53042d3794519c9b9f2a"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Magento-1.9.4.1.xml b/var/package/Lib_Magento-1.9.4.1.xml
new file mode 100644
index 0000000..a8952a1
--- /dev/null
+++ b/var/package/Lib_Magento-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Magento</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:44</time>
+    <contents><target name="magelib"><dir name="Magento"><dir name="Autoload"><file name="ClassMap.php" hash="d7d379df650db4eb4fc37168151c947c"/><file name="IncludePath.php" hash="c7917ae3d56f3a4b49f9b2ec79a135c4"/><file name="Simple.php" hash="a63a70fd7e06f77e2827a518de094961"/></dir><file name="Crypt.php" hash="4ef70800c1fa7c02d201c1fccf55d1a8"/><dir name="Db"><dir name="Adapter"><dir name="Pdo"><file name="Mysql.php" hash="55046e3803f80607287ae1d73e8ae14e"/></dir></dir><dir name="Object"><file name="Interface.php" hash="d54abcd0881635c5ac599af581d854bd"/><file name="Table.php" hash="58e1917b843b5523671cff24b632f4aa"/><file name="Trigger.php" hash="76c9abc78a55542112d2f0b963d286f7"/><file name="View.php" hash="cdc398ea71b49718dc07ca4644675058"/></dir><file name="Object.php" hash="7a511bb00c4e496ba81e943bd2e09855"/><dir name="Sql"><file name="Select.php" hash="898d4b91dbce179d1ccac6c9b64bebb4"/><file name="Trigger.php" hash="80bbbd22a7564c622ef07e648cd3da7a"/></dir></dir><file name="Exception.php" hash="794834095fb24ea0f5577069f7d336e7"/><dir name="Profiler"><dir name="Output"><file name="Csvfile.php" hash="b4aea3fd851994613172d0b27f8f0d6c"/><file name="Firebug.php" hash="d1665ccdde2353e4fc35c7b0254f8161"/><file name="Html.php" hash="704b989bf1009b94b55be3cf8b5d40c8"/></dir><file name="OutputAbstract.php" hash="531e71bf6953ea65a449a8ba417c1500"/></dir><file name="Profiler.php" hash="7c94820b4c445ee99fd7ad1d61431cd6"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Mcryptcompat-1.9.4.0.xml b/var/package/Lib_Mcryptcompat-1.9.4.0.xml
deleted file mode 100644
index b2c892b..0000000
--- a/var/package/Lib_Mcryptcompat-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Mcryptcompat</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://www.opensource.org/licenses/mit-license.html">MIT</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Mcrypt Library</summary>
-    <description>PHP 7.1 removed the mcrypt extension. This provides a compatibility layer for legacy applications.</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Jim Wigginton</name><user>core</user><email>terrafrost@php.net</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="mcryptcompat"><file name="mcrypt.php" hash="bf8efc3ef65399aba6c1f08e9b3adbe0"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Mcryptcompat-1.9.4.1.xml b/var/package/Lib_Mcryptcompat-1.9.4.1.xml
new file mode 100644
index 0000000..2f71d89
--- /dev/null
+++ b/var/package/Lib_Mcryptcompat-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Mcryptcompat</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://www.opensource.org/licenses/mit-license.html">MIT</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Mcrypt Library</summary>
+    <description>PHP 7.1 removed the mcrypt extension. This provides a compatibility layer for legacy applications.</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Jim Wigginton</name><user>core</user><email>terrafrost@php.net</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:44</time>
+    <contents><target name="magelib"><dir name="mcryptcompat"><file name="mcrypt.php" hash="bf8efc3ef65399aba6c1f08e9b3adbe0"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Pelago-1.9.4.0.xml b/var/package/Lib_Pelago-1.9.4.0.xml
deleted file mode 100644
index 6145361..0000000
--- a/var/package/Lib_Pelago-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Pelago</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Pelago Library</summary>
-    <description>Pelago Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Pelago"><file name="Emogrifier.php" hash="de3919d36c718834d9755dd1cb68df87"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Pelago-1.9.4.1.xml b/var/package/Lib_Pelago-1.9.4.1.xml
new file mode 100644
index 0000000..743fef2
--- /dev/null
+++ b/var/package/Lib_Pelago-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Pelago</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Pelago Library</summary>
+    <description>Pelago Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:44</time>
+    <contents><target name="magelib"><dir name="Pelago"><file name="Emogrifier.php" hash="de3919d36c718834d9755dd1cb68df87"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Phpseclib-1.9.4.0.xml b/var/package/Lib_Phpseclib-1.9.4.0.xml
deleted file mode 100644
index 299b108..0000000
--- a/var/package/Lib_Phpseclib-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Phpseclib</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/lgpl.txt">LGPL v.3</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Phpseclib Library</summary>
-    <description>Phpseclib Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="phpseclib"><dir name="Crypt"><file name="AES.php" hash="22d0024134a5291b96ba1e04ff5706cc"/><file name="Base.php" hash="30f53da6745acd05de335bbf8a81c171"/><file name="Blowfish.php" hash="af6bf1aa8864cba2be2cd01059504f8c"/><file name="DES.php" hash="dd4ec1b7a4b4a67d0b41fc45a3d9a060"/><file name="Hash.php" hash="eb18f40942a4431ef8704b7e3a8013fd"/><file name="RC2.php" hash="e26943cba9cf24f4231fc9fa52002eca"/><file name="RC4.php" hash="de8b1dcc1a3e0a18b4d0b27f9f56c063"/><file name="RSA.php" hash="450260568ddca20f50130fb54f3907a7"/><file name="Random.php" hash="93193a666526c63ba95629cd71504aef"/><file name="Rijndael.php" hash="e695ed56c5178ac7ee1f438e728f1f24"/><file name="TripleDES.php" hash="3c282665b77ed6a970f2f34ec0305953"/><file name="Twofish.php" hash="5eb765fe5f99cee6236198ef6b0ce273"/></dir><dir name="File"><file name="ANSI.php" hash="0bbcc6b7de2830e94d8653123441eabe"/><dir name="ASN1"><file name="Element.php" hash="c94013bbb82d49d0c467a5e48fc318bd"/></dir><file name="ASN1.php" hash="f08c586b9ae2d22439620659410e0d8f"/><file name="X509.php" hash="b1c6ed7a19714520d227eb9d951c0963"/></dir><dir name="Math"><file name="BigInteger.php" hash="ac5a5a2c4575e74393c3137cc76e0919"/></dir><dir name="Net"><file name="SCP.php" hash="6f04a3784d5b677391fac09b152d2c86"/><dir name="SFTP"><file name="Stream.php" hash="819f66e981bbd02ad8237413c8cb13a2"/></dir><file name="SFTP.php" hash="81b700bba41e7578744b87f0daf5da6d"/><file name="SSH1.php" hash="aa19523d08b5db590d8413795f7d9f41"/><file name="SSH2.php" hash="97b204231f064dd38b0751aaf7617e48"/></dir><dir name="PHP"><dir name="Compat"><dir name="Function"><file name="array_fill.php" hash="2c0a4268deed10ced9491155e2284a82"/><file name="bcpowmod.php" hash="37fc1de34085874a930eaa76888f0cb1"/><file name="str_split.php" hash="889ab2b0d90b0962ded2ee65f1bfbc37"/></dir></dir></dir><dir name="System"><dir name="SSH"><dir name="Agent"><file name="Identity.php" hash="0592ff991d07c93a2bcbb2dfcbd85e5b"/></dir><file name="Agent.php" hash="4d1554ca5700f3359c827a8cb9c9ca07"/></dir></dir><file name="bootstrap.php" hash="1fd3efc24ca047574642e5fe830e6194"/><file name="openssl.cnf" hash="b4409823562c617107907cd04d67c8fa"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Phpseclib-1.9.4.1.xml b/var/package/Lib_Phpseclib-1.9.4.1.xml
new file mode 100644
index 0000000..35befb1
--- /dev/null
+++ b/var/package/Lib_Phpseclib-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Phpseclib</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/lgpl.txt">LGPL v.3</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Phpseclib Library</summary>
+    <description>Phpseclib Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:44</time>
+    <contents><target name="magelib"><dir name="phpseclib"><dir name="Crypt"><file name="AES.php" hash="22d0024134a5291b96ba1e04ff5706cc"/><file name="Base.php" hash="30f53da6745acd05de335bbf8a81c171"/><file name="Blowfish.php" hash="af6bf1aa8864cba2be2cd01059504f8c"/><file name="DES.php" hash="dd4ec1b7a4b4a67d0b41fc45a3d9a060"/><file name="Hash.php" hash="eb18f40942a4431ef8704b7e3a8013fd"/><file name="RC2.php" hash="e26943cba9cf24f4231fc9fa52002eca"/><file name="RC4.php" hash="de8b1dcc1a3e0a18b4d0b27f9f56c063"/><file name="RSA.php" hash="450260568ddca20f50130fb54f3907a7"/><file name="Random.php" hash="93193a666526c63ba95629cd71504aef"/><file name="Rijndael.php" hash="e695ed56c5178ac7ee1f438e728f1f24"/><file name="TripleDES.php" hash="3c282665b77ed6a970f2f34ec0305953"/><file name="Twofish.php" hash="5eb765fe5f99cee6236198ef6b0ce273"/></dir><dir name="File"><file name="ANSI.php" hash="0bbcc6b7de2830e94d8653123441eabe"/><dir name="ASN1"><file name="Element.php" hash="c94013bbb82d49d0c467a5e48fc318bd"/></dir><file name="ASN1.php" hash="f08c586b9ae2d22439620659410e0d8f"/><file name="X509.php" hash="b1c6ed7a19714520d227eb9d951c0963"/></dir><dir name="Math"><file name="BigInteger.php" hash="ac5a5a2c4575e74393c3137cc76e0919"/></dir><dir name="Net"><file name="SCP.php" hash="6f04a3784d5b677391fac09b152d2c86"/><dir name="SFTP"><file name="Stream.php" hash="819f66e981bbd02ad8237413c8cb13a2"/></dir><file name="SFTP.php" hash="81b700bba41e7578744b87f0daf5da6d"/><file name="SSH1.php" hash="aa19523d08b5db590d8413795f7d9f41"/><file name="SSH2.php" hash="97b204231f064dd38b0751aaf7617e48"/></dir><dir name="PHP"><dir name="Compat"><dir name="Function"><file name="array_fill.php" hash="2c0a4268deed10ced9491155e2284a82"/><file name="bcpowmod.php" hash="37fc1de34085874a930eaa76888f0cb1"/><file name="str_split.php" hash="889ab2b0d90b0962ded2ee65f1bfbc37"/></dir></dir></dir><dir name="System"><dir name="SSH"><dir name="Agent"><file name="Identity.php" hash="0592ff991d07c93a2bcbb2dfcbd85e5b"/></dir><file name="Agent.php" hash="4d1554ca5700f3359c827a8cb9c9ca07"/></dir></dir><file name="bootstrap.php" hash="1fd3efc24ca047574642e5fe830e6194"/><file name="openssl.cnf" hash="b4409823562c617107907cd04d67c8fa"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Unserialize-1.9.4.0.xml b/var/package/Lib_Unserialize-1.9.4.0.xml
deleted file mode 100644
index a74ad54..0000000
--- a/var/package/Lib_Unserialize-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Unserialize</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">Magento Core Edition</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Unserialize"><file name="Parser.php" hash="a6ed4dfff7ea3c5a9a25faabd3c4b8ce"/><dir name="Reader"><file name="Arr.php" hash="c64df9e432b8d27ab17f5eb76cace94a"/><file name="ArrKey.php" hash="120e34968eed7cae3bcabc6c3b47806e"/><file name="ArrValue.php" hash="61f5b23442dd9a098f381316fd239441"/><file name="Bool.php" hash="a644633ffe141e995ae17ec5cd381c85"/><file name="Dbl.php" hash="d1272d69b5672c9120fc8d39e55f92ff"/><file name="Int.php" hash="fa568e8f975fbff5efc38c6545b161dd"/><file name="Null.php" hash="980301f21c3ed844e58d204beb0d808e"/><file name="Str.php" hash="65cac13641db41bb55853576499e781d"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Unserialize-1.9.4.1.xml b/var/package/Lib_Unserialize-1.9.4.1.xml
new file mode 100644
index 0000000..15fc695
--- /dev/null
+++ b/var/package/Lib_Unserialize-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Unserialize</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">Magento Core Edition</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:45</time>
+    <contents><target name="magelib"><dir name="Unserialize"><file name="Parser.php" hash="2e8c12e6185b0479fbbc97c192e3506c"/><dir name="Reader"><file name="Arr.php" hash="28e3bbd54c4b71c6ff67ab4cc980e01e"/><file name="ArrKey.php" hash="69d3bd343bf5724e36f038c14983facf"/><file name="ArrValue.php" hash="3f7052850f22d567970d26405cac1aca"/><file name="Bool.php" hash="9eb2785c62cc29ae17aaccf563db303b"/><file name="Dbl.php" hash="f5140de1c3b69adeb94e245699b670e7"/><file name="Int.php" hash="fae6a1cc12c0f49e03862fefbfca9744"/><file name="Null.php" hash="01cbebcb0c7a8cc4959debf5f9197abe"/><file name="Str.php" hash="ad1fb0146566ac112708848f46ca997c"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Varien-1.9.4.0.xml b/var/package/Lib_Varien-1.9.4.0.xml
deleted file mode 100644
index 6fc0373..0000000
--- a/var/package/Lib_Varien-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Varien</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Varien Library</summary>
-    <description>Varien Library</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Varien"><file name="Autoload.php" hash="1afe7d1796e64e4bba412384442de930"/><dir name="Cache"><dir name="Backend"><file name="Database.php" hash="f10f11b0cd11baed0cb2306a9443a6cd"/><file name="Eaccelerator.php" hash="cc97685065562865dba40b108edf32b6"/><file name="Memcached.php" hash="7a5c748a9f2eeec61cc07d9de9472387"/></dir><file name="Core.php" hash="c5b5ad380e58fbc08318131523156b99"/></dir><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="f08cdad50faa8fccbc92e1de32241e64"/><file name="Interface.php" hash="f98e70c7da35df8e10fd94d60e2ff449"/></dir><file name="Action.php" hash="3b97e7c79ff9eb71e3f0526e876896c0"/><dir name="Adapter"><file name="Abstract.php" hash="9e95ba1f0a96c078834b7ccaebc09e62"/><dir name="Db"><file name="Table.php" hash="54727e849fe22ff68ab63492d503010f"/></dir><dir name="Http"><file name="Curl.php" hash="5955504a3ccbc61715d40c14bb4a7f62"/></dir><file name="Http.php" hash="7e12f3e9e1b2a182889f474c07a6a975"/><file name="Interface.php" hash="4ecd613e941abf46798154cac25bbe5c"/><file name="Io.php" hash="44fa563ae5aa2121f174146f93d25972"/><file name="Soap.php" hash="e925540ce1d250606ce93e6799d25722"/><file name="Std.php" hash="2c0b95e5b951aa2d7295c0ca0e96302d"/><dir name="Zend"><file name="Cache.php" hash="ab00f6b0e4765ab05635dc028d849829"/><file name="Db.php" hash="9b8a7aa60eb6d48b05bcf7346ac49bff"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="e405297bed690cb85db8b3ba128064f9"/><file name="Collection.php" hash="9479ab2fd8053670c9bca6a3a29f9771"/><file name="Generic.php" hash="4d1af502665cc2358cdd42a36da2965f"/><file name="Interface.php" hash="312ab40a2a6060f4bf6849d4ecc5af2b"/></dir><file name="Exception.php" hash="c198c87ac4077346323921516318f55d"/><dir name="Mapper"><file name="Abstract.php" hash="4fc92ece94b10c34ad7652ae65a73b67"/><file name="Column.php" hash="6e4608ee0bc9b90a8cd6d384e63c2e2d"/><file name="Interface.php" hash="09efdacbea50e9238229dfa74d401f07"/></dir><dir name="Parser"><file name="Abstract.php" hash="382e8b73bbd42ac0a016eab4e025c033"/><file name="Csv.php" hash="792baac6606d380c8992f337506797ad"/><file name="Interface.php" hash="06a65a77e00f63e75d4c8471ba5fee53"/><file name="Serialize.php" hash="66712f86ef3c72475b5f2437232533cd"/><dir name="Xml"><file name="Excel.php" hash="bd3fccae662ee6f9a457277a1b61d4b4"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="eb43c2ef32390fbc68cbbab9a635fbe2"/><file name="Collection.php" hash="1a8f9975c44e6ee9ab0e5ed417ebb69c"/></dir><file name="Profile.php" hash="0370c1e24bcc52c50c3ec010464068d6"/><dir name="Validator"><file name="Abstract.php" hash="c30d6ea61664e526b80693747fab8dca"/><file name="Column.php" hash="cf76fe39fa11750d6d5ecf7d49704f62"/><file name="Dryrun.php" hash="6fb6fa70b9e50086da18c6f410d129c7"/><file name="Interface.php" hash="0c3882b052cca2e3288aedee02989830"/></dir></dir><file name="Convert.php" hash="46a7e86a8ace0c13b521b7fea63e12e6"/><dir name="Crypt"><file name="Abstract.php" hash="eb1cafa758bddb5e4b16d82a6c58c53b"/><file name="Mcrypt.php" hash="029c1701f5d850bf9b636b2ab0e8aa25"/></dir><file name="Crypt.php" hash="2961fc8be8f2a01c697ef0c80fdd5f05"/><dir name="Data"><dir name="Collection"><file name="Db.php" hash="360d280e1e465aa4798ec000c143d8ed"/><file name="Filesystem.php" hash="edf7736ae0592e7b037a8055956ca038"/></dir><file name="Collection.php" hash="a6a58e45c273c3e80482692801eca87d"/><dir name="Form"><file name="Abstract.php" hash="68e6d626779b575961957f0ba5764662"/><dir name="Element"><file name="Abstract.php" hash="fa28645308fa7afe0553ec4b9fc5a2eb"/><file name="Button.php" hash="14053ef464963479967e5d92b8f7f2e1"/><file name="Checkbox.php" hash="71be65c99441f9ebc266e52d5f0c3ce9"/><file name="Checkboxes.php" hash="7cfaa815ccfbfe7797140a305393ac0c"/><file name="Collection.php" hash="9cb710827d7833c3c163280db0a0f8ce"/><file name="Column.php" hash="981c5cc0eca4a5dc77cfebf88a30cf33"/><file name="Date.php" hash="206e89d0dc4ab59bc57ff84690b9b068"/><file name="Datetime.php" hash="c1f342fe6639eaf9ebe7b4cce7a86295"/><file name="Editor.php" hash="53ba59a7010fdb301c035cac8f0c3760"/><file name="Fieldset.php" hash="45f2e0e602644fd44758b3be880629fc"/><file name="File.php" hash="cbe609ce2ce4c791f9249d06e3be6c7c"/><file name="Gallery.php" hash="87a3207d14500cd65725a66918fae2a8"/><file name="Hidden.php" hash="e8b46511eea3a5233071a137fcefe406"/><file name="Image.php" hash="a27af0545a6795b543e4a74baeca06c0"/><file name="Imagefile.php" hash="c665eaae499b8a031b73a0dc7f785840"/><file name="Label.php" hash="28bf2d22964397d9299dd07470dcc3e3"/><file name="Link.php" hash="6528d397238cedd1377a8d5622d62291"/><file name="Multiline.php" hash="4d963a66cea1fc47a80007ac28c96a30"/><file name="Multiselect.php" hash="10593b01d8206c385366510ab7c7fa87"/><file name="Note.php" hash="40716d10385639bc3d02107682b81927"/><file name="Obscure.php" hash="36f7a3338959855a43c9e515b8d1fa6a"/><file name="Password.php" hash="7a2b4bb659b5de8636c1be54c72acd32"/><file name="Radio.php" hash="2d79fcc287e7ce2e270e80f835dba8a3"/><file name="Radios.php" hash="b49934be42ee2fabe8674b17986a8f2d"/><dir name="Renderer"><file name="Interface.php" hash="f29db3bc3a621fd234eb9002d01b5774"/></dir><file name="Reset.php" hash="37a93fe24e647569da0dc5e3ea6f6b9a"/><file name="Select.php" hash="10236470a728b841ade5e198ed649c6c"/><file name="Submit.php" hash="165d17de52334eb7d8e34e03d5f6fb7e"/><file name="Text.php" hash="c5ea165f4a51705857dca24390be50aa"/><file name="Textarea.php" hash="df882762f2c1d59a96f130b615453a23"/><file name="Time.php" hash="1135575de5522b7288b1cf47333af428"/></dir><dir name="Filter"><file name="Date.php" hash="3a824ffe28a4256bb565124900d3a4be"/><file name="Datetime.php" hash="746f36a2e7694a07c4055a9a0d8ea435"/><file name="Escapehtml.php" hash="5d1f6b46bcf48732a00431a1bc19aef8"/><file name="Interface.php" hash="d04e2fec8e5ac11670d7f55ddbd773bd"/><file name="Striptags.php" hash="17155dec034f60136dff596884f9e222"/></dir></dir><file name="Form.php" hash="21310a418407c727298db35a0daf1f3d"/><dir name="Tree"><file name="Db.php" hash="df3ea304d0cfb8cbd25c9d28c87703bd"/><file name="Dbp.php" hash="9c0d64b0f6ec2d09bac5a9a0092dc433"/><dir name="Node"><file name="Collection.php" hash="b70bd872ad6fdc73ecd7f0633952a381"/></dir><file name="Node.php" hash="607ff14056b49b7c51d31af235c33d41"/></dir><file name="Tree.php" hash="2bf738a89219853173d373acc9a640fb"/></dir><file name="Date.php" hash="fee00689f607a7ecf069e00c4187d5ee"/><dir name="Db"><dir name="Adapter"><file name="Interface.php" hash="c13a55c43bbaa8b566d6e2353944b890"/><file name="Mysqli.php" hash="b6c036d18132ca0ca80d26700751dd89"/><dir name="Pdo"><file name="Mysql.php" hash="6d9d8d7c48d5afac49fa92ef90c48611"/></dir></dir><dir name="Ddl"><file name="Table.php" hash="20a1563e2610e6161317b17e3f81d1c0"/></dir><file name="Exception.php" hash="c099346a2e4c0c9034a6e7630778f7e8"/><file name="Helper.php" hash="73eedcb369100f90eefaa80a766c64c4"/><file name="Select.php" hash="f0b8f7a95449c9d8b0317e779e9ede68"/><dir name="Statement"><file name="Parameter.php" hash="eb73496668b9d0112e6697c1216a5346"/><dir name="Pdo"><file name="Mysql.php" hash="fd1e46ceb0b9ac253b33371317375e8f"/></dir></dir><dir name="Tree"><file name="Exception.php" hash="19dbeee477e639b088ee807e4bd84dc2"/><dir name="Node"><file name="Exception.php" hash="b18689e161efa37981ea924e70d87738"/></dir><file name="Node.php" hash="fd4896d033af1c9fa7762ab4d88be3b3"/><dir name="NodeSet"><file name="Exception.php" hash="142dfe2d6b0fd295b513f62a5870b4d3"/></dir><file name="NodeSet.php" hash="ae772ac03fba4ff292fa6fa08d51ad3d"/></dir><file name="Tree.php" hash="4081f9dde4cc5fc216b2eb36b5bf62e8"/></dir><file name="Debug.php" hash="f28e98293553fa1a2552a4ef444eef75"/><dir name="Directory"><file name="Collection.php" hash="e5f1c5052a3a749ebcdea94694a3aaa2"/><file name="Factory.php" hash="f1fd7212a10c6a9cb7ebe9ab21e91d77"/><file name="IFactory.php" hash="0d117aa06ac87f6e3c5f09766b38e13a"/><file name="a.txt" hash="026e450c46ac92ea375302955a4f42fb"/></dir><dir name="Event"><file name="Collection.php" hash="9d99e1a5b2d678c8009f7b672cbae4c6"/><dir name="Observer"><file name="Collection.php" hash="200b88fec0363e745e83dbc789173af0"/><file name="Cron.php" hash="c05f829caafdcb21ae6b4902f660f95d"/><file name="Regex.php" hash="e988f035c549b6b15c0e244a1bb11367"/></dir><file name="Observer.php" hash="66c279124f63bc73c24ce63a86d97ed6"/></dir><file name="Event.php" hash="4ce1363eee411291fc83db4c0669e619"/><file name="Exception.php" hash="f942caba0b856d4c84c9c23857323ca6"/><dir name="File"><file name="Csv.php" hash="78ad2ad633e37aad62178af9d479aaee"/><file name="CsvMulty.php" hash="cc7c533d96bb9b633462604d9493e4fe"/><file name="Object.php" hash="3b4e18159835d64b27fc2b09cdb21aa2"/><dir name="Transfer"><dir name="Adapter"><file name="Http.php" hash="f51917fa3176f40947213242b104b467"/></dir></dir><dir name="Uploader"><file name="Image.php" hash="c69ac6f559f7e35e987a19cf792d162a"/></dir><file name="Uploader.php" hash="83a7ff76dc32bb7af4ef7de883be27ad"/></dir><dir name="Filter"><dir name="Array"><file name="Grid.php" hash="f717b1ef6e91b580f1ac491691f9edaf"/></dir><file name="Array.php" hash="fd5dabce1a8280ebab4ff47505005619"/><file name="Email.php" hash="d9f891cf1c048108cbfc0247990e8fb3"/><file name="FormElementName.php" hash="1726a40e399ca9418aa2c9a6730dbb8c"/><file name="Money.php" hash="63d238c3555094ade8a14eb6d42010af"/><dir name="Object"><file name="Grid.php" hash="850263994ebc6ad5edeb483f317db179"/></dir><file name="Object.php" hash="b315a6ae1f95f31787474cf694d6bbc8"/><file name="Sprintf.php" hash="2fffd1470053951886d7a574f3671497"/><dir name="Template"><file name="Simple.php" hash="a23d47096582716a01f55d25e6f267e0"/><dir name="Tokenizer"><file name="Abstract.php" hash="78735e5cc10d138e57913a465086de5f"/><file name="Parameter.php" hash="dcaa7d54f6f9bbc7cc46580c468e82cb"/><file name="Variable.php" hash="176437ed02703970392956e3ebe1a635"/></dir></dir><file name="Template.php" hash="f68942ca438fd163b3e7d61c14d708c5"/></dir><dir name="Http"><dir name="Adapter"><file name="Curl.php" hash="5cd76ff6c6abee1bb9d68761af446ca9"/></dir><file name="Client.php" hash="f10044719a133419d9f262507f75c75f"/></dir><dir name="Image"><dir name="Adapter"><file name="Abstract.php" hash="0812e524a0467377ca8a7f7a8e3fd0af"/><file name="Gd2.php" hash="c6b0d8ae75d76f82d347ff84e1f27f74"/></dir><file name="Adapter.php" hash="971f7941dec2fa4d542fea26e092a9ce"/></dir><file name="Image.php" hash="f3ceb270d95ad7447a22b3b7b2207eae"/><dir name="Io"><file name="Abstract.php" hash="a0013ae157c383c79396cca3a3f95104"/><file name="Exception.php" hash="a7785c16c28846d4d269634b0577b75d"/><file name="File.php" hash="3cb64844e4235f3bacdd27e3dbc40b1d"/><file name="Ftp.php" hash="26f51613ff21c56401d7a6e619e6d128"/><file name="Interface.php" hash="5cfdbec1a6c94d0c47ceb84ca06c1252"/><file name="Sftp.php" hash="c0133c7ea78f445df46a2651270a5649"/></dir><dir name="Object"><file name="Cache.php" hash="185457f3c1b369d8bc44c2550ebb7790"/><file name="Mapper.php" hash="6ba50bea44b2a5d7d8174f6caca95838"/></dir><file name="Object.php" hash="73b091578424f92b65725403f083cd63"/><dir name="Pear"><file name="Frontend.php" hash="83313301512d529f71a8c3bdbd39a5ff"/><file name="Package.php" hash="3084b59014bbd3fad2466fcf8072c04c"/><file name="Registry.php" hash="31ec6e3fd934f097bd0c1d308d6d4b8d"/></dir><file name="Pear.php" hash="960057984b3515d6a337be700abbd257"/><file name="Profiler.php" hash="98121aa7a444c9bdf2064354a0797996"/><dir name="Simplexml"><dir name="Config"><dir name="Cache"><file name="Abstract.php" hash="63b77872096068ff5b122258272516d3"/><file name="File.php" hash="7f6d2894e22a668cbec7218421afec24"/></dir></dir><file name="Config.php" hash="88f772f3d981ff18100336957aa75183"/><file name="Element.php" hash="a55c460c2002e788cc7b28e0d49bd5d9"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF</name><channel>community</channel><min>1.12.10.16</min><max>1.12.10.16</max></package><extension><name>PDO</name><min/><max/></extension><extension><name>SPL</name><min/><max/></extension><extension><name>curl</name><min/><max/></extension><extension><name>SimpleXML</name><min/><max/></extension><extension><name>dom</name><min/><max/></extension><extension><name>gd</name><min/><max/></extension><extension><name>iconv</name><min/><max/></extension><extension><name>pdo_mysql</name><min/><max/></extension><extension><name>mcrypt</name><min/><max/></extension><extension><name>pcre</name><min/><max/></extension><extension><name>Reflection</name><min/><max/></extension><extension><name>session</name><min/><max/></extension></required></dependencies>
-</package>
diff --git a/var/package/Lib_Varien-1.9.4.1.xml b/var/package/Lib_Varien-1.9.4.1.xml
new file mode 100644
index 0000000..e59b462
--- /dev/null
+++ b/var/package/Lib_Varien-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Varien</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Varien Library</summary>
+    <description>Varien Library</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:45</time>
+    <contents><target name="magelib"><dir name="Varien"><file name="Autoload.php" hash="83df31b32908601ff8accdd77b3a6570"/><dir name="Cache"><dir name="Backend"><file name="Database.php" hash="4558bc9ea129984dff92225e5c906093"/><file name="Eaccelerator.php" hash="fdd6c0506169a715e59a7832d6713206"/><file name="Memcached.php" hash="d7352ab7c11f72bdda6d47734a20d2a4"/></dir><file name="Core.php" hash="8cbff322c428d6878a57733dee251db2"/></dir><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="aa07c8969ac7c8fca3d5884e3642bcb3"/><file name="Interface.php" hash="fc98355673ada6d3e0c83c274c19d11f"/></dir><file name="Action.php" hash="54f84922e0586b6c8d553b714553d483"/><dir name="Adapter"><file name="Abstract.php" hash="802883b133a2a24c49aee649a71f1825"/><dir name="Db"><file name="Table.php" hash="1c500fca0433926194d95b59be5da50a"/></dir><dir name="Http"><file name="Curl.php" hash="cb020fbec631754244c91b3b207ae2d9"/></dir><file name="Http.php" hash="b781730ed9e32ac995bff79b624cd986"/><file name="Interface.php" hash="376a5b2839eabbea5278147ce90abb4b"/><file name="Io.php" hash="4deae02038f64dbfc96d4954225d44d7"/><file name="Soap.php" hash="fe1eab70e9a8b079e14c49a770a64297"/><file name="Std.php" hash="6fc7283d42c4ac649e6cbef19c72f9a0"/><dir name="Zend"><file name="Cache.php" hash="382dc52125350b0f42d8f848add2e97a"/><file name="Db.php" hash="ee44aae9549aad006b398c72237b7bce"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="aa0e7b0922d141d7852f45c04acaf0d1"/><file name="Collection.php" hash="76c3b2d4d61ceb5c03c55374063d8c84"/><file name="Generic.php" hash="11d8b3f6a501ac3650aa5541376eea1b"/><file name="Interface.php" hash="38ffd9337b2463e7c65c80ed334f3af3"/></dir><file name="Exception.php" hash="16b20354f42fec8bdda1fd65f5e0ee18"/><dir name="Mapper"><file name="Abstract.php" hash="e895d317b69731452eae05e27fc63861"/><file name="Column.php" hash="ed7b17ba976591bd417b04103c032d99"/><file name="Interface.php" hash="32bf96e77d133ce506b84140cae8788e"/></dir><dir name="Parser"><file name="Abstract.php" hash="547315ff4562e1df05399927c12bd9d5"/><file name="Csv.php" hash="83c6df8fe7e94bb3b308714f1078b552"/><file name="Interface.php" hash="5b3ebb007ec8c128fb0291d266f0570f"/><file name="Serialize.php" hash="bb9ac58f4f49e66ec2a9fc15c8aea70b"/><dir name="Xml"><file name="Excel.php" hash="4421faf73c3dac535ea0f24bf4ca81c1"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="1623035ede75f21e0297236166a215e4"/><file name="Collection.php" hash="1f333c4138cf744e0bf7869f21e73b9e"/></dir><file name="Profile.php" hash="03bfbba826814962f3c42bfe3564e182"/><dir name="Validator"><file name="Abstract.php" hash="fb95584b2c52839d1ccd44d54e2eaa01"/><file name="Column.php" hash="2b636ba1a0a02ec4435fe53a61eefe0d"/><file name="Dryrun.php" hash="6c92bf4eea4b7dd52bd15ce538aad37f"/><file name="Interface.php" hash="bfca360c34a9c522b0e0ef82cf981dd3"/></dir></dir><file name="Convert.php" hash="1c68406f2e0c3a73f6d2387104b1a3dc"/><dir name="Crypt"><file name="Abstract.php" hash="011df9e3225b279c4b6560e8bb8e0428"/><file name="Mcrypt.php" hash="fc9ea287df54f9852e24bfed5d9d3ce5"/></dir><file name="Crypt.php" hash="bcb35e50d720bf63860d6efc63fbabdb"/><dir name="Data"><dir name="Collection"><file name="Db.php" hash="0368acf6151bede860ad5c55544063f7"/><file name="Filesystem.php" hash="0e6286ddcf1897a30a61e2b18cd09b8d"/></dir><file name="Collection.php" hash="2df83d72dada45878e2f6769805b2a96"/><dir name="Form"><file name="Abstract.php" hash="26cab9dd0a0d1206cd52e7ff18921611"/><dir name="Element"><file name="Abstract.php" hash="5ff02044990476d5b1e551ff26504567"/><file name="Button.php" hash="4fca414994ee5802820d2685bbd42f52"/><file name="Checkbox.php" hash="695e3a8cf4fcff4c9748c19a59e1912e"/><file name="Checkboxes.php" hash="af8b4f2a834ae33b1c88e55d5b0ebb00"/><file name="Collection.php" hash="77da6fbe771af0fd0ac21a1abad5375c"/><file name="Column.php" hash="1fc996bbd070e76884010bdbf3911e95"/><file name="Date.php" hash="0f048edb364a4bd244b53c975618aec6"/><file name="Datetime.php" hash="0a41fb17cbb707ecb73bbd18f263c399"/><file name="Editor.php" hash="4d1c28f25474e5939753f80c8832a054"/><file name="Fieldset.php" hash="3762ae485be0672cd360e22d3d6dabff"/><file name="File.php" hash="0fd2adca3bf64fb7bafd2f2ee6256657"/><file name="Gallery.php" hash="17de4da040848ee231feb958e6fd376d"/><file name="Hidden.php" hash="aafa27aef7c8627690c615c7a931d09d"/><file name="Image.php" hash="8b0818947fae070af5e15cba7c8ab88f"/><file name="Imagefile.php" hash="9cbaba642ad82387ffee20e897411126"/><file name="Label.php" hash="3fd825f28e4950915a41ba892d79fcba"/><file name="Link.php" hash="3dccac5b75d83a9be6baa3fcfbeec68d"/><file name="Multiline.php" hash="f7cc823504866ca65ac44e0104e491bd"/><file name="Multiselect.php" hash="26c9b48c08542b7ee72de706e492f138"/><file name="Note.php" hash="50063c006a00212caddedb38a87a056d"/><file name="Obscure.php" hash="a115890f5039f23a7adc9e16dfbe70cd"/><file name="Password.php" hash="0efb7743673f16499c03a5010a7b77e0"/><file name="Radio.php" hash="12c91f9d706aa95f9f5403afc8a64c23"/><file name="Radios.php" hash="3de26d652e0f38bc8bc87bc494d49566"/><dir name="Renderer"><file name="Interface.php" hash="37007cfe3e3c72ef25b11f0cf6ecca83"/></dir><file name="Reset.php" hash="13016bb7b85371cfcdd0971724960bd8"/><file name="Select.php" hash="7b6f4201e6f9d67d071e56304137a83a"/><file name="Submit.php" hash="8028d2ced5195be2e2ec48d6837437c8"/><file name="Text.php" hash="97fbb6865f668d3a728c97767bd132e9"/><file name="Textarea.php" hash="87c9ba8bad825a4b79686ae2598f6184"/><file name="Time.php" hash="7cc613f3ae502d6848890e08f03dcaec"/></dir><dir name="Filter"><file name="Date.php" hash="db74b10371cd790b816092c0396c9a93"/><file name="Datetime.php" hash="cc217bad27dd64f00321365807c7558f"/><file name="Escapehtml.php" hash="18170646fab195203459896e9e60ae48"/><file name="Interface.php" hash="59df343d05f57d3bf9ad7ddd0947a77f"/><file name="Striptags.php" hash="640c9f50c64dd95ee27cfe313f173e2f"/></dir></dir><file name="Form.php" hash="ab131826b74ed3a10d31d9f62b6b259c"/><dir name="Tree"><file name="Db.php" hash="ec1181ad3895fb284a96382128a20f61"/><file name="Dbp.php" hash="469b6348043d25fb898437856841cc79"/><dir name="Node"><file name="Collection.php" hash="894b62ae263c0134ffad85991ac3dee9"/></dir><file name="Node.php" hash="182d394ee942f1b43e74e09a3e03e38a"/></dir><file name="Tree.php" hash="55648442ae71e7178ed613c5a5f62148"/></dir><file name="Date.php" hash="e5633ee80d29f2c4d37a727539a3f4b2"/><dir name="Db"><dir name="Adapter"><file name="Interface.php" hash="45b43500799e07a4dee06c7fa0c5476c"/><file name="Mysqli.php" hash="60d034a0e9f7101f816b3c28399c56a8"/><dir name="Pdo"><file name="Mysql.php" hash="b751a77a9c214dd73ab0c1163ba72e02"/></dir></dir><dir name="Ddl"><file name="Table.php" hash="ee2db3d640dbc6894c24412c769268df"/></dir><file name="Exception.php" hash="0d4789e6f30f7a7ef4dfb4ccd0c170f4"/><file name="Helper.php" hash="5cf99fb372f50ba340d5aead53cd4208"/><file name="Select.php" hash="990f82d2e9c2f857a82bcd1767dd7684"/><dir name="Statement"><file name="Parameter.php" hash="5ad28b7d637943572958352ac94b4f9a"/><dir name="Pdo"><file name="Mysql.php" hash="d89336de4c80f6389564330efdd3de36"/></dir></dir><dir name="Tree"><file name="Exception.php" hash="1e0bb5144a0ddeb8e0fc9d131027b0d7"/><dir name="Node"><file name="Exception.php" hash="e25dc938220e7bf4a4ebb9a108b5d2cc"/></dir><file name="Node.php" hash="21620e7483feac19ff2586e8c95725ae"/><dir name="NodeSet"><file name="Exception.php" hash="1397d3b273ae824f13fa8427147a97a6"/></dir><file name="NodeSet.php" hash="96c7dc66089e12bdade0d2e857ff149d"/></dir><file name="Tree.php" hash="d755be61028aa1b24f9d8b1347f622ed"/></dir><file name="Debug.php" hash="d8189861656b0da46cb37c9b3766f5d3"/><dir name="Directory"><file name="Collection.php" hash="f7b5a07b0b4f2df3b36ea0cc0a5bcad6"/><file name="Factory.php" hash="c5d91520dcec96b71cb7ec98faa17057"/><file name="IFactory.php" hash="cfa6810941e34e3c3ef6eba359d66814"/><file name="a.txt" hash="026e450c46ac92ea375302955a4f42fb"/></dir><dir name="Event"><file name="Collection.php" hash="471c3c72741cb35d07ac91c9a85a498b"/><dir name="Observer"><file name="Collection.php" hash="bc756715513f1f6a7ae10ac799f345c7"/><file name="Cron.php" hash="2a9d3e29d0d6b1c24176dd0c32856555"/><file name="Regex.php" hash="63cfe9d637d0c0de8350e1080b49bfa4"/></dir><file name="Observer.php" hash="3c97ff427cfe0a08de3132ed21daaae6"/></dir><file name="Event.php" hash="91150d8313ab2fd9993013bcbacc72b3"/><file name="Exception.php" hash="aa0d83d218f712f916c03f7a79190389"/><dir name="File"><file name="Csv.php" hash="be3bfde4744a8b5d3fbf9ab542454c26"/><file name="CsvMulty.php" hash="f94c12c3aaf73780dcd31f967f7e466a"/><file name="Object.php" hash="b61957e11dee3356f2f115c6b52ca69a"/><dir name="Transfer"><dir name="Adapter"><file name="Http.php" hash="8daeb55bb020d8bcf28feee86d66a718"/></dir></dir><dir name="Uploader"><file name="Image.php" hash="422dac7a6347c032f83e14f1fc86e07b"/></dir><file name="Uploader.php" hash="ec947e50f553f9830a1ad4d2d7659085"/></dir><dir name="Filter"><dir name="Array"><file name="Grid.php" hash="65505e4fd2e926d4e85d991886831f7c"/></dir><file name="Array.php" hash="22eb10bd9b3677837298364270af7f84"/><file name="Email.php" hash="ae58e662d03948a1a3027fb0db032c75"/><file name="FormElementName.php" hash="20f765343435adeb2b5b25f0b297ae20"/><file name="Money.php" hash="5143d8a013808cd125789297bd393b4b"/><dir name="Object"><file name="Grid.php" hash="ffe87e23b82aa39bbed05c72ea349275"/></dir><file name="Object.php" hash="e8fa3670dd3c2abf1e2ea207da15ee3e"/><file name="Sprintf.php" hash="3651ab095c5a80fa66269078c7e088c7"/><dir name="Template"><file name="Simple.php" hash="f8d5fc519df002eec91320bf2c5d1b65"/><dir name="Tokenizer"><file name="Abstract.php" hash="b2ea9c4923890d7117a4f3a590bbe2b7"/><file name="Parameter.php" hash="38d46e28f4aeae6926f14e9b6e397c7a"/><file name="Variable.php" hash="d7c7081594072b2868361aae7865e83c"/></dir></dir><file name="Template.php" hash="7275f80bde808fe75c13150cf5245572"/></dir><dir name="Http"><dir name="Adapter"><file name="Curl.php" hash="930d5fe90e800319bcdfce8fe5b265f1"/></dir><file name="Client.php" hash="5e80a6051da1050e78742921a8d51dc1"/></dir><dir name="Image"><dir name="Adapter"><file name="Abstract.php" hash="98a297efcd312b3080f66ef7433be7cf"/><file name="Gd2.php" hash="129ec92e8529d535efef7ee3c8893d4c"/></dir><file name="Adapter.php" hash="85f0fbd720486910a30a23fdac001545"/></dir><file name="Image.php" hash="362c46214e9a5fecc72af8e948fe4f9b"/><dir name="Io"><file name="Abstract.php" hash="bb956b8f692477dd51d58d3945db6d85"/><file name="Exception.php" hash="b346d28ea3165f8026600124c7615564"/><file name="File.php" hash="48eaf08b241c41283d9520aa5d2a47fd"/><file name="Ftp.php" hash="c754d9a23a6d715f1b355d110208f128"/><file name="Interface.php" hash="a88c19f93828f4a2187ab5921c5a18e6"/><file name="Sftp.php" hash="55f977b370029afd3bee62e489d5d7d1"/></dir><dir name="Object"><file name="Cache.php" hash="7e9edfcc8fedea2059184ef237f28b37"/><file name="Mapper.php" hash="0ba64566287bda680391b996b38c19a2"/></dir><file name="Object.php" hash="a65322d769c9e40a53926f4ad5cd192d"/><dir name="Pear"><file name="Frontend.php" hash="253e0208f7b488167e825f22bdb8b1db"/><file name="Package.php" hash="351364f80d012550c0a78a73e99ede65"/><file name="Registry.php" hash="d9ab146f9555953d418023859a46ea78"/></dir><file name="Pear.php" hash="c4e8719324d78665db52674d2c898847"/><file name="Profiler.php" hash="88cd98aad2d9b3adec60f5e32fb159ea"/><dir name="Simplexml"><dir name="Config"><dir name="Cache"><file name="Abstract.php" hash="07de624696215a35278a490ad7ff98b8"/><file name="File.php" hash="4170f2792397ff9e6c179a8de4cb50bb"/></dir></dir><file name="Config.php" hash="7c49d3d0937856ec23a4b34e6b7995e1"/><file name="Element.php" hash="737cc893da6cd0ead13a4cee79de96a5"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF</name><channel>community</channel><min>1.12.10.17</min><max>1.12.10.17</max></package><extension><name>PDO</name><min/><max/></extension><extension><name>SPL</name><min/><max/></extension><extension><name>curl</name><min/><max/></extension><extension><name>SimpleXML</name><min/><max/></extension><extension><name>dom</name><min/><max/></extension><extension><name>gd</name><min/><max/></extension><extension><name>iconv</name><min/><max/></extension><extension><name>pdo_mysql</name><min/><max/></extension><extension><name>mcrypt</name><min/><max/></extension><extension><name>pcre</name><min/><max/></extension><extension><name>Reflection</name><min/><max/></extension><extension><name>session</name><min/><max/></extension></required></dependencies>
+</package>
diff --git a/var/package/Lib_ZF-1.12.10.16.xml b/var/package/Lib_ZF-1.12.10.16.xml
deleted file mode 100644
index 2f30980..0000000
--- a/var/package/Lib_ZF-1.12.10.16.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_ZF</name>
-    <version>1.12.10.16</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Zend Framework</summary>
-    <description>Zend Framework</description>
-    <notes>1.12.10.16</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:01</time>
-    <contents><target name="magelib"><dir name="Zend"><dir name="Acl"><dir name="Assert"><file name="Interface.php" hash="753f4c058211502ad047851c4550a121"/></dir><file name="Exception.php" hash="833945ed22a5631224398ec5d1a51736"/><dir name="Resource"><file name="Interface.php" hash="ec27f75c67a2ddb21ede3e8f5cf2188c"/></dir><file name="Resource.php" hash="1eac5e2cda19d6f595ce678ee9b27065"/><dir name="Role"><file name="Interface.php" hash="e61127c46f87a10799582eb5d58673ca"/><dir name="Registry"><file name="Exception.php" hash="1ab8aea40c56fb9754ea4d76cf022893"/></dir><file name="Registry.php" hash="b13b4d4f96691f26328aba33d2a725f6"/></dir><file name="Role.php" hash="4ffca60ba53123c02874b9f412a1d5a0"/></dir><file name="Acl.php" hash="9362ea321157987e2d667ce6ba6640c4"/><dir name="Amf"><dir name="Adobe"><file name="Auth.php" hash="5f1b8fa4bc0646bfc7e1a0248af99e4d"/><file name="DbInspector.php" hash="c945730a861cc8dfb79affc681d935cd"/><file name="Introspector.php" hash="1faa52d4a734963e2114f0244b4eb0fc"/></dir><dir name="Auth"><file name="Abstract.php" hash="eb1eebcde25e987e8cfd64b097a64438"/></dir><file name="Constants.php" hash="27f591080a8aa87a7603079496b03f31"/><file name="Exception.php" hash="c37e40e651b342f39763d2651a86e907"/><dir name="Parse"><dir name="Amf0"><file name="Deserializer.php" hash="91d9e217cf20c9012993d945e3f7e744"/><file name="Serializer.php" hash="fc6f4e7a3adcee15df87e6f5e918891d"/></dir><dir name="Amf3"><file name="Deserializer.php" hash="63f1c82ab2bf8029208347a5d6188cf9"/><file name="Serializer.php" hash="94893d06b63c1c7b89958790051a96b8"/></dir><file name="Deserializer.php" hash="6bf0ed466d51a8ed7d47842ae56b0c2e"/><file name="InputStream.php" hash="8825ad088d82c7b0e1eec7f1fc2a977f"/><file name="OutputStream.php" hash="f6954a735a7abc530b3d08c3a66a1610"/><dir name="Resource"><file name="MysqlResult.php" hash="f93006c3cf636f4426559266c7254301"/><file name="MysqliResult.php" hash="3ff39905a315dc50438612cdfd044003"/><file name="Stream.php" hash="9fac77c33d3b8a5932618b7140eb480e"/></dir><file name="Serializer.php" hash="89f6dade3493238bcebd57f7aec7c441"/><file name="TypeLoader.php" hash="2eb3de6c0c76a88c84e52d053db1b3c3"/></dir><dir name="Request"><file name="Http.php" hash="3ceb2e9419c58b42b8a91dfa518bdbe6"/></dir><file name="Request.php" hash="210fafeb570fabde64f45367aa2b818f"/><dir name="Response"><file name="Http.php" hash="9165da2b40ea937760d21e82d14fccfd"/></dir><file name="Response.php" hash="df120c6bdcd3624007e264387c3ea49d"/><dir name="Server"><file name="Exception.php" hash="b49d17bc0487b1f94e263edc3cd63b80"/></dir><file name="Server.php" hash="a382bc11323a9e000c8b903609842a60"/><dir name="Util"><file name="BinaryStream.php" hash="2be5bd9b9c7daf56a578bb98c79c4393"/></dir><dir name="Value"><file name="ByteArray.php" hash="3501ce99e15b597c7159a47a166585b3"/><file name="MessageBody.php" hash="8b61f8ee1c39105e5c19ee0c3df1eedf"/><file name="MessageHeader.php" hash="3719e3197128d0db242a664278740de3"/><dir name="Messaging"><file name="AbstractMessage.php" hash="3091614466f82c843414c7f780e2713f"/><file name="AcknowledgeMessage.php" hash="0102f33c15054d697d29ab872d587e75"/><file name="ArrayCollection.php" hash="5070cc263f4b56b4aa6a62110c563ae7"/><file name="AsyncMessage.php" hash="ad0d187dc1179ce2cad255fe5fbd00a6"/><file name="CommandMessage.php" hash="46b117af57383509740a975f1d35a801"/><file name="ErrorMessage.php" hash="cd980b1cc29739aa685d714e3645f5bd"/><file name="RemotingMessage.php" hash="acaa5c29b712d4d24168bb384d512bd8"/></dir><file name="TraitsInfo.php" hash="91da9ed050e8e44979a229eadf433bf4"/></dir></dir><dir name="Application"><dir name="Bootstrap"><file name="Bootstrap.php" hash="a54f574a13568e3b0d79f9792b58a77b"/><file name="BootstrapAbstract.php" hash="85403088f5775085724427f2db4e3f41"/><file name="Bootstrapper.php" hash="f6ffc93f65f911d74273c97480019ebc"/><file name="Exception.php" hash="592efcd13a2430fb8a8051c77af2bdbf"/><file name="ResourceBootstrapper.php" hash="b5697b89f0bee36d64f1323ae0e6fad7"/></dir><file name="Exception.php" hash="33b45075f371aa758ab73043d9bb345b"/><dir name="Module"><file name="Autoloader.php" hash="561bbbddfd1d5d66e9950b1c5435e822"/><file name="Bootstrap.php" hash="a982af99ca3f8583e7e06754c932bee6"/></dir><dir name="Resource"><file name="Cachemanager.php" hash="aed3b8889084e6b3b46b9e1ad2482309"/><file name="Db.php" hash="a5bc7745dd9416c3cee07ca45701672d"/><file name="Dojo.php" hash="ed17a22f02f2b4b52219cb1a8f5f283f"/><file name="Exception.php" hash="e7cc6162f923bea3163ab3c72a9144c2"/><file name="Frontcontroller.php" hash="4096de73ec4a62565475ade369fa2f10"/><file name="Layout.php" hash="cc29553ce7af25e5497433b38cb33d96"/><file name="Locale.php" hash="d9ddba5ce3e52cf74e06bcaa28e9f701"/><file name="Log.php" hash="6425ed565c8ffa8d6a2061b4bed90c77"/><file name="Mail.php" hash="43d891a5921b267f2298392f5de16f2e"/><file name="Modules.php" hash="de2fead30f02effe859de66503972e1a"/><file name="Multidb.php" hash="f958bb43354951af50a592a27c1de9c0"/><file name="Navigation.php" hash="fa7ac38efd17722bb2fd0181131af18d"/><file name="Resource.php" hash="fea870fdc0a7fe568ff6f7d1d10ab523"/><file name="ResourceAbstract.php" hash="5808f3f8a2c6a349aa21e4de678fef40"/><file name="Router.php" hash="54f15d496ef84d800897d8571523e5b5"/><file name="Session.php" hash="714544fe025fa8e5db47686b58fd410b"/><file name="Translate.php" hash="9b75da2a9e3f571a90f30f14bbe72582"/><file name="Useragent.php" hash="17a0a2deba744c0fd4091fb48958b782"/><file name="View.php" hash="18803d667bd908ccfc04edc3e39d209b"/></dir></dir><file name="Application.php" hash="a0c9ea8a48289b2bd9bafd2dfe76765c"/><dir name="Auth"><dir name="Adapter"><file name="DbTable.php" hash="c8b79405b8855b67ffd8d6f82e6a4045"/><file name="Digest.php" hash="bbc1edafb9a244774ca986a2790e5661"/><file name="Exception.php" hash="194d445ab6929d8c5a6faefe604c64a0"/><dir name="Http"><dir name="Resolver"><file name="Exception.php" hash="cf95d8463e66b8dcc7eb679aaa0127cb"/><file name="File.php" hash="56c75079c07a8f3081841dff74f4f8b5"/><file name="Interface.php" hash="136ff303d6f17f676641db12415a679e"/></dir></dir><file name="Http.php" hash="0cfb159e07de35d89ab6754c9e409b1e"/><file name="Interface.php" hash="9baba8292deab88415d58155627009ea"/><file name="Ldap.php" hash="5bec476c61237745110b07a6981f0ba7"/><file name="OpenId.php" hash="9b87324993b0882e8add83140b24799b"/></dir><file name="Exception.php" hash="0cbee6397372cb825d4d2330f1e01cbf"/><file name="Result.php" hash="011bad9ebfb3e12cde52dc199c1b9b0c"/><dir name="Storage"><file name="Exception.php" hash="7c0657994ccacd29c396728dd3e40ead"/><file name="Interface.php" hash="336438156ed6a7db4183fbb365ec24e0"/><file name="NonPersistent.php" hash="88366aa8fd16a4c565e7a6cf467c9d45"/><file name="Session.php" hash="128255a8d51a1d9fa137e137f17b773f"/></dir></dir><file name="Auth.php" hash="6ec79877089d5629bf32dc9cfca8a5ed"/><dir name="Barcode"><file name="Exception.php" hash="5cf74c43e0bb3bda36dab4cdcf435a7c"/><dir name="Object"><file name="Code128.php" hash="989d2bf6723d392c704a9d793a0870c6"/><file name="Code25.php" hash="945a62bd63cefd4bc548aca2175a798e"/><file name="Code25interleaved.php" hash="163795899dd207d6777ed489b3652783"/><file name="Code39.php" hash="6a9d919307643317d2670d0b5a0cfc75"/><file name="Ean13.php" hash="d073b0b3b0d548aa553128e61a8f739e"/><file name="Ean2.php" hash="244bfc6ef32a4d56629c045c929138f1"/><file name="Ean5.php" hash="198f60f22d8bb1d165bff02c5820a20b"/><file name="Ean8.php" hash="8cea912422779ab67e11d8a169063216"/><file name="Error.php" hash="20edaea0778ac6253009722af4bc1ba8"/><file name="Exception.php" hash="4222bc4babead0b78ff6cd53aa72e359"/><file name="Identcode.php" hash="8a1ac5c7c3b04d3e62aa8265c4e1c2f7"/><file name="Itf14.php" hash="9384e00165c9961a203d1f135a3eaa5d"/><file name="Leitcode.php" hash="3c805e7d37dfb51e8de1f35d16ed5da5"/><file name="ObjectAbstract.php" hash="017bd4e5560bfddab60971b889d9f0a0"/><file name="Planet.php" hash="e1c10362fbc9baa5aabede9041060d79"/><file name="Postnet.php" hash="5f6845e59e609f8991fa580bbdc5eefc"/><file name="Royalmail.php" hash="8cc2c93b813ed89f4b0f6cd60df29f77"/><file name="Upca.php" hash="1485da9e266c49e993a00f9d287b4019"/><file name="Upce.php" hash="7cbde278294ce55ff3cb0857f5c014c5"/></dir><dir name="Renderer"><file name="Exception.php" hash="8579d580dcc35ccd16c82590ff39c1b9"/><file name="Image.php" hash="dba737459af451c5c51bad867b77a0a6"/><file name="Pdf.php" hash="1e2d590fe769d9ebf74d901a34635aa7"/><file name="RendererAbstract.php" hash="359cbfacb66cc0fb5ae362845b3fbf58"/><file name="Svg.php" hash="93544d770411772a4dc2c995cced685e"/></dir></dir><file name="Barcode.php" hash="0586994cdf9871ebabd7aa8079566258"/><dir name="Cache"><dir name="Backend"><file name="Apc.php" hash="0770aacd96ff057d06978bcc7a22035e"/><file name="BlackHole.php" hash="f51e1f122876be7d7ba667e39c540901"/><file name="ExtendedInterface.php" hash="fb6c1f28d7049d8ebb5b367586a386b4"/><file name="File.php" hash="292986e780e4b420968b5dfa15267a01"/><file name="Interface.php" hash="9e9a235e4aa33de40ff9fbc97efa468d"/><file name="Libmemcached.php" hash="2f9d3d284be576c031ff2195afaabc20"/><file name="Memcached.php" hash="cbee447e2af7453a2a37ddee2206f971"/><file name="Sqlite.php" hash="8c2ffff28dbe7e5c27a2bfb6fa1a4759"/><file name="Static.php" hash="8b4e8ac2f3e416316d447266e1a6f8dd"/><file name="Test.php" hash="6bcaf9deb1e13215d9fada844fa0bb25"/><file name="TwoLevels.php" hash="1d48225fde0e61fc38401841b28740da"/><file name="WinCache.php" hash="57da7293a57294e3cc2878d872230aea"/><file name="Xcache.php" hash="364f350bb7e58a221a9dda26dfd940d3"/><file name="ZendPlatform.php" hash="dd2264172835c8ac2b1cd0eba670d1ee"/><dir name="ZendServer"><file name="Disk.php" hash="092b29cf8ea2e0391e156ca38a9c8dbd"/><file name="ShMem.php" hash="94d219bd689df1b0ce1f5fe48c0fda7e"/></dir><file name="ZendServer.php" hash="6397a63f6ceba054b9c4c774451109a6"/></dir><file name="Backend.php" hash="046904b4b5c7661bbdcb6c3ec7969af3"/><file name="Core.php" hash="26e9ed27936fe7c894f36a1241b6aa35"/><file name="Exception.php" hash="64896658ade26dbd6b15851aee788379"/><dir name="Frontend"><file name="Capture.php" hash="5e7254e902e587587a9f7c1749787690"/><file name="Class.php" hash="e0fba9da74e040fc5fcbfeede03147d2"/><file name="File.php" hash="291450665f2b240c3a1d0b8f81d9e505"/><file name="Function.php" hash="80926f9d0d94953c8534f381b3e9e92b"/><file name="Output.php" hash="b3902a3f0ddf1b4608b84f6172a317e6"/><file name="Page.php" hash="d447d1e18b8c9ccfe95f5cbd4f8ad0aa"/></dir><file name="Manager.php" hash="bba8e1dfc892616eccc5f033d3849aec"/></dir><file name="Cache.php" hash="dd6b3426e3682f832f5e73a5a5e7bbe4"/><dir name="Captcha"><file name="Adapter.php" hash="c80da3e14f86386865a1a11f386509f0"/><file name="Base.php" hash="f3f587f183c8dbb0f71b588a99f56728"/><file name="Dumb.php" hash="42cf7479a157ab4f6d92f4ea2edd402f"/><file name="Exception.php" hash="a1ea444d80d4629ae987f5120d7b6ab4"/><file name="Figlet.php" hash="9434c31c17fa4558d823f72863bda27e"/><file name="Image.php" hash="8f1bb1448407f673d986cc387846bf3f"/><file name="ReCaptcha.php" hash="7213da2f0082b6a209bf5659d5279036"/><file name="Word.php" hash="2b20aa38f1132306e259f4032ad1de6e"/></dir><dir name="Cloud"><file name="AbstractFactory.php" hash="0360f699d631c5eb6f1f5e117a2a6524"/><dir name="DocumentService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="3679fe7eef0b73516d98565b35e90366"/><dir name="SimpleDb"><file name="Query.php" hash="163f21a702cb5aa76d58682d29559bd2"/></dir><file name="SimpleDb.php" hash="78628ea1029ec6f267c83c302611b6e8"/><dir name="WindowsAzure"><file name="Query.php" hash="657934a415bd7d731906ebb3fa42187d"/></dir><file name="WindowsAzure.php" hash="9a48103bc6327e24a98f27307641c397"/></dir><file name="Adapter.php" hash="22799d67b8935e871e9fcb5403617a9d"/><file name="Document.php" hash="e76315e7e307aa99dae6d634b51c2ece"/><file name="DocumentSet.php" hash="53cabe8e2d6454beab6b476953fb9a58"/><file name="Exception.php" hash="e69eb63ef3ac0476422e553c0f9d0b7c"/><file name="Factory.php" hash="d11189e3ba364466584a8461e9bea29b"/><file name="Query.php" hash="dcf377f4d08e1adc178dcef42a7e21d4"/><file name="QueryAdapter.php" hash="b683d5360841a57b8b58f0ac937b4991"/></dir><file name="Exception.php" hash="baa1da441578d83ef668c947bc26993a"/><dir name="Infrastructure"><dir name="Adapter"><file name="AbstractAdapter.php" hash="1a0c85424e055522ed27fd848641adb9"/><file name="Ec2.php" hash="f702d42320cb2a843124faeff6308673"/><file name="Rackspace.php" hash="12ca011eaa260a98e5f0b021497d6d9f"/></dir><file name="Adapter.php" hash="8fd0db5ff41dd87d2730981cf6a651e6"/><file name="Exception.php" hash="dd74945bd044a9b569715d8b8f33d6c6"/><file name="Factory.php" hash="e35fedab839a9897bd494b4525c70d74"/><file name="Image.php" hash="d0b5a851095a8a6d00cc758e66de65d0"/><file name="ImageList.php" hash="330f4330efa43095c73963860719d8dc"/><file name="Instance.php" hash="aa600d04524311d6da4bfac324aae00f"/><file name="InstanceList.php" hash="9f5c27c450518e4090aa5200261e0804"/></dir><file name="OperationNotAvailableException.php" hash="cb15f6dfb2c6caf15bf3d3c7192a2859"/><dir name="QueueService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="6aafd9d7c44e76e68dd7b8ea83aea6fe"/><file name="Sqs.php" hash="03b431d971a7679aa43dba8d235fd9bb"/><file name="WindowsAzure.php" hash="b4762cebc1460850e73552d5a617ea6d"/><file name="ZendQueue.php" hash="d8aaa2f4ec3302693fcaee2833339bac"/></dir><file name="Adapter.php" hash="c950feca6fdab3f115ba62146e9c4061"/><file name="Exception.php" hash="0406a9d40baf106b1e7c7a52c58622ce"/><file name="Factory.php" hash="1489be14015fdbc7364317e2e6fdb4dc"/><file name="Message.php" hash="48907828e50d23674d1500834ac33d96"/><file name="MessageSet.php" hash="f4371e5f68036dbea532b7899c59679c"/></dir><dir name="StorageService"><dir name="Adapter"><file name="FileSystem.php" hash="c2066ccb70e97bfccf1dc6eca5beabed"/><file name="Rackspace.php" hash="d5b49d598b7a2ca875599df0c07d17e2"/><file name="S3.php" hash="36d663a296803282ec6ffbb4d1f6ecf7"/><file name="WindowsAzure.php" hash="1c266330be81f9034e491cdc5c0becee"/></dir><file name="Adapter.php" hash="4bf256cad4b27a0b4ccd0ea0d2e5df44"/><file name="Exception.php" hash="b1938d4a1d75a132c7896c9d1d49c316"/><file name="Factory.php" hash="e60551fd66495592c25f2143683c0eae"/></dir></dir><dir name="CodeGenerator"><file name="Abstract.php" hash="8bb5c3fb76b0953dad77b8aefd240552"/><file name="Exception.php" hash="2f35c31886c1506cbce95bd48ceb8302"/><dir name="Php"><file name="Abstract.php" hash="7ffc414197119b98d09c089d38b745cf"/><file name="Body.php" hash="4354cf77549e88c8ef742f74df428824"/><file name="Class.php" hash="e96e076b5e9a7a41b9dff5d65d65cbf8"/><dir name="Docblock"><dir name="Tag"><file name="License.php" hash="fa6989bdda9dcc8eed58dfcd5cd11d3e"/><file name="Param.php" hash="c5402463f594b0ada366547e2140c087"/><file name="Return.php" hash="d36a1b1dbd2383043b9703449212218e"/></dir><file name="Tag.php" hash="94c4d5bf7254f1122a9140578562cf4a"/></dir><file name="Docblock.php" hash="3630eee3a36264ed70bb414b1b6659d2"/><file name="Exception.php" hash="4d0d644d274ba0d93c86edabe96a937a"/><file name="File.php" hash="16190c6965142355870ea2d86065c2f3"/><dir name="Member"><file name="Abstract.php" hash="a07d1b1c01755725fd9c670b83e14c6e"/><file name="Container.php" hash="52c0f2936e0dd96e3efaca239e97a537"/></dir><file name="Method.php" hash="facb978030d8ed1148d3fd9b27647a5c"/><dir name="Parameter"><file name="DefaultValue.php" hash="402dc7efb5a973be4b3695d97df9d5e6"/></dir><file name="Parameter.php" hash="f963e92d375973d82c64e9aeeb99aa68"/><dir name="Property"><file name="DefaultValue.php" hash="23583ff2c6b01162f217d3f18e17f5bb"/></dir><file name="Property.php" hash="5d85c620c090d866edd2cc4af3bb0737"/></dir></dir><dir name="Config"><file name="Exception.php" hash="825b93db4d92fc10ff2334d0701ac39a"/><file name="Ini.php" hash="bc377745cc51608820d81f08bb5e622c"/><file name="Json.php" hash="191c7eb21cbb2042491e5548a59087a4"/><dir name="Writer"><file name="Array.php" hash="fa6b3a9d9f68cc5973db7309b93454eb"/><file name="FileAbstract.php" hash="14f344ccee37bac7224aa203e5be6bf5"/><file name="Ini.php" hash="c658c697e401b7fab66edac3e5ab5edf"/><file name="Json.php" hash="675cff174476aab6e44540ce20b9ef6f"/><file name="Xml.php" hash="0ff4954d3f6be816d2911cc236d588de"/><file name="Yaml.php" hash="0a6d7e361af7f4f5cff8a9eb81264318"/></dir><file name="Writer.php" hash="7bca990f32b4a7bf64b6d7bcd6a8b144"/><file name="Xml.php" hash="24d64c4d3269a55f1577d40717069b3f"/><file name="Yaml.php" hash="d559550b7de8c77f03a6d8c5ab1af715"/></dir><file name="Config.php" hash="0ec674c135a25bb65bf7f2f536496373"/><dir name="Console"><dir name="Getopt"><file name="Exception.php" hash="ba4d96e50ff729964f51d3ff320a695b"/></dir><file name="Getopt.php" hash="a8165d6a04ff959844c118bd1517d4af"/></dir><dir name="Controller"><dir name="Action"><file name="Exception.php" hash="5c5bfb99e09c49bfd42afc92cca046a3"/><dir name="Helper"><file name="Abstract.php" hash="2db15ec4775320a42a86fc96ded791f6"/><file name="ActionStack.php" hash="72d618b0c01345a39b86362d00b519e5"/><file name="AjaxContext.php" hash="d25cd19237deee404b1d78c3babc51e6"/><dir name="AutoComplete"><file name="Abstract.php" hash="8265a4c01db3fc5ef8359855b5bc7de7"/></dir><file name="AutoCompleteDojo.php" hash="bc727565a422d34c4ee642604bca989f"/><file name="AutoCompleteScriptaculous.php" hash="423035f705a0ead78f0b508915f9f11d"/><file name="Cache.php" hash="5e1ee2f20930ce3ce6c9ff95c7986fd5"/><file name="ContextSwitch.php" hash="bbde32302aea3a45df7525ee558ba61b"/><file name="FlashMessenger.php" hash="6f60de563b5b400d75b630f359ce09be"/><file name="Json.php" hash="46f702a70e0d5e4ecff66439b34502aa"/><file name="Redirector.php" hash="246b26f4b71cdab25a5992577986b119"/><file name="Url.php" hash="16c5a98afe9f6f14bee59bbb0ee58583"/><file name="ViewRenderer.php" hash="6eac5b3e0152d2c000145c6a4076456a"/></dir><dir name="HelperBroker"><file name="PriorityStack.php" hash="9919f1af00251ac5d7a362dba0a280c8"/></dir><file name="HelperBroker.php" hash="aa9cf211934ac5b4fc9e4220ad26d7ca"/><file name="Interface.php" hash="0cb0ece63ce5a245010b9c79927149fe"/></dir><file name="Action.php" hash="1eff5915284945de72327a06cb10c10a"/><dir name="Dispatcher"><file name="Abstract.php" hash="3a481b8b2beb61d223f1c90757339a6d"/><file name="Exception.php" hash="21e0c2b4a1f642448f391e0601bf8327"/><file name="Interface.php" hash="323c3bfe932dca40b3f0f18ebaa39bf4"/><file name="Standard.php" hash="ccbde33f1d7616c2c35ee556039b12a0"/></dir><file name="Exception.php" hash="75ef40958ca34b2ce0007a6a9bd11b62"/><file name="Front.php" hash="a0cd827d65e2d2cc1d51d96009d61032"/><dir name="Plugin"><file name="Abstract.php" hash="4f9c2a5fcb32f0f02d01559c2900e2ff"/><file name="ActionStack.php" hash="dc0f223ebf96304711e62b0ff066cbe6"/><file name="Broker.php" hash="4558d24e01418e1a7a4a45f8a0419b05"/><file name="ErrorHandler.php" hash="1b86cb0d967cb3a80091271532e5f29f"/><file name="PutHandler.php" hash="5b65c0f667538e81cd5152060b1fc50e"/></dir><dir name="Request"><file name="Abstract.php" hash="479150985f9f5b1ad60da1c627ba5422"/><file name="Apache404.php" hash="6e4073adcf927bc08c36267350259110"/><file name="Exception.php" hash="401a6bfe6ee4f2eef739d5622d457235"/><file name="Http.php" hash="4866762dc4e2d7f2f70ebcf3ec3f3174"/><file name="HttpTestCase.php" hash="fee8b0ea3da866bae3125716977e609a"/><file name="Simple.php" hash="4debb461f0bf9c865b3ef7e9a2f9eec1"/></dir><dir name="Response"><file name="Abstract.php" hash="41812ba5c1950b91ca6db21c36a65022"/><file name="Cli.php" hash="1be9de58bd3af4e70797422c5936b9f0"/><file name="Exception.php" hash="daf74bb0fb6ffed9c50a414b78947388"/><file name="Http.php" hash="1b97675e6f09aca759dd04cadc2ada31"/><file name="HttpTestCase.php" hash="b8e25dbcd9245fce7f9e985aedb53ab2"/></dir><dir name="Router"><file name="Abstract.php" hash="7c3976721fbba2c462793f6152a7952a"/><file name="Exception.php" hash="10f91dd02d28dfb9c5de84d778f5e451"/><file name="Interface.php" hash="3f0e4586ac18e02e172ff65e1228a197"/><file name="Rewrite.php" hash="333634b9f184476914d985f68d06b12a"/><dir name="Route"><file name="Abstract.php" hash="c0437b622e03a117783fc6d8c2a581da"/><file name="Chain.php" hash="eb747ff18f4f5549888a7964b8f16f2e"/><file name="Hostname.php" hash="b54e6b9f68ffa63f9c493f82606ab2ac"/><file name="Interface.php" hash="80dd1da3a1fe916fcf173891716985cc"/><file name="Module.php" hash="dca7ac356221ebd066c5b17a72557551"/><file name="Regex.php" hash="4bcd3642f6ee8d66b9ec9cf591cfa121"/><file name="Static.php" hash="2bc26cb37610470e8fbb0e9302e76175"/></dir><file name="Route.php" hash="9be953ae63b6074535656826c99f88dd"/></dir></dir><dir name="Crypt"><dir name="DiffieHellman"><file name="Exception.php" hash="27066062da23c7b0b5c8ea405d63424f"/></dir><file name="DiffieHellman.php" hash="b146591071090ba7dc2d120c8d7cfcb1"/><file name="Exception.php" hash="98d264f8b46a12e8e1fa644b37488636"/><dir name="Hmac"><file name="Exception.php" hash="3b8bf2fed9087ce573c7d9e461211d01"/></dir><file name="Hmac.php" hash="7beea2bae905ad98fc8212a5a2ba906c"/><dir name="Math"><dir name="BigInteger"><file name="Bcmath.php" hash="7ad0514366aa1cfbbacf9a841d17209d"/><file name="Exception.php" hash="c7047b1ec96c2c5bf9d2ec8fd516c232"/><file name="Gmp.php" hash="1e136ad9748ff4e120be567de7195084"/><file name="Interface.php" hash="a1a15aadc0d1232e19e3660778e25a4e"/></dir><file name="BigInteger.php" hash="5941fbc6fa7558f254212a5c704de46f"/><file name="Exception.php" hash="0a2a9e2cdf2619549bb1891d31565cb4"/></dir><file name="Math.php" hash="0e54c36e33bb980ba251c42719e72e48"/><dir name="Rsa"><file name="Exception.php" hash="9af79ec754f6202584671b395e9898cb"/><dir name="Key"><file name="Private.php" hash="6b8486eba224159d7c05dea23039ec8e"/><file name="Public.php" hash="8cd4ac9225b58e1a2990659f4a97a45d"/></dir><file name="Key.php" hash="a0c0daf511c3a74d1e754faeaace0f83"/></dir><file name="Rsa.php" hash="e46289dffb56184f7c15faa3b24a0a68"/></dir><file name="Crypt.php" hash="ae1d981cb224263c8625604621d0ffc9"/><dir name="Currency"><file name="CurrencyInterface.php" hash="c52c23140b8d66185e2792cb10c65b40"/><file name="Exception.php" hash="f04c4fcb9b9b4117ab0c91e688904a06"/></dir><file name="Currency.php" hash="e380eca83740d28bb55435c3489204cf"/><dir name="Date"><file name="Cities.php" hash="4698b47f264db687c97ea7fa5ccd717e"/><file name="DateObject.php" hash="05ef22746ef2b1925cce51d42a5670b9"/><file name="Exception.php" hash="b91a2d166cf91afa1325a07747bafe57"/></dir><file name="Date.php" hash="6d17472f661d6b599477f215dda67f82"/><dir name="Db"><dir name="Adapter"><file name="Abstract.php" hash="7d5a1b64e9f292c018fec8fca159311b"/><dir name="Db2"><file name="Exception.php" hash="b64143620db1d7e5cd7b90312aeaf7bf"/></dir><file name="Db2.php" hash="d27757593a5be92da47326b25af8b4a4"/><file name="Exception.php" hash="461a43822f24e3e79bf8a844541235a3"/><dir name="Mysqli"><file name="Exception.php" hash="71ae5837eee0e261ba7639dff878845c"/></dir><file name="Mysqli.php" hash="c997a7381205b413a03efba602f2debd"/><dir name="Oracle"><file name="Exception.php" hash="8a08377363d09d1711c31ed0e2b4f220"/></dir><file name="Oracle.php" hash="2c539f9ac5ce7e656f3432c9aa00daae"/><dir name="Pdo"><file name="Abstract.php" hash="1f71eaf0415b750ee0573a80374e61cb"/><dir name="Ibm"><file name="Db2.php" hash="b947c61e9abf1f277adb40dc1aaf6319"/><file name="Ids.php" hash="a2d4fcf42c7b9435515399862224d74c"/></dir><file name="Ibm.php" hash="1042d1f01417241dc09679e1edb3a248"/><file name="Mssql.php" hash="139b7b3957b4e2b347d220b9dc8e959d"/><file name="Mysql.php" hash="0ca1bc627085e101ce51e02328b16347"/><file name="Oci.php" hash="819a1b3d31d7f65ba3f9de49ceecdf30"/><file name="Pgsql.php" hash="1b7fde0593b3799e4afa1f74b63499d7"/><file name="Sqlite.php" hash="efb68039f3e1b9e34a81c3dc9d0e8f20"/></dir><dir name="Sqlsrv"><file name="Exception.php" hash="097530f562d1993a992d6f62aadea809"/></dir><file name="Sqlsrv.php" hash="0fb64191a2d9e688410094c736d5eda6"/></dir><file name="Exception.php" hash="aebb5d861915d6a2494c58fc343f2752"/><file name="Expr.php" hash="2dca05427df6b34d6da9fb872517f684"/><dir name="Profiler"><file name="Exception.php" hash="42d03d9fd63aada757d6dabacdb73cb0"/><file name="Firebug.php" hash="1f5b0198a97091bba6ec8a8f74f3cf1a"/><file name="Query.php" hash="fe0bfc38389c14cecc76d528e33bfe83"/></dir><file name="Profiler.php" hash="e7327368b94ae8e094c602e41f617609"/><dir name="Select"><file name="Exception.php" hash="f8b241a9791bc28c77ca8c14cf80ba84"/></dir><file name="Select.php" hash="0fb5975684da5ea68ed45e4437d759d6"/><dir name="Statement"><dir name="Db2"><file name="Exception.php" hash="05225962b3d3107841d87d0d6c4ca9de"/></dir><file name="Db2.php" hash="36c397903c5e07ebe5b82b5e76030c7a"/><file name="Exception.php" hash="d41110267373d38bb4af77e1785329ae"/><file name="Interface.php" hash="222f50673200f578767b1e0c43d5a6bd"/><dir name="Mysqli"><file name="Exception.php" hash="1932b0ae9232ab79ccacadd46a45f022"/></dir><file name="Mysqli.php" hash="64e3e41642115ec95cce487da79fe737"/><dir name="Oracle"><file name="Exception.php" hash="59588ef7feadf4b0a726d1e1410f10bd"/></dir><file name="Oracle.php" hash="3fd727a08bbb347495dd6a2fb044defb"/><dir name="Pdo"><file name="Ibm.php" hash="aadb46dbcc67223ab9e240c35301cb0d"/><file name="Oci.php" hash="75a7032f82e8e29f52a8994a847e9533"/></dir><file name="Pdo.php" hash="91da6eddeaa94a88bcea2c3c912480bb"/><dir name="Sqlsrv"><file name="Exception.php" hash="925701544428f06183ecbb6718047839"/></dir><file name="Sqlsrv.php" hash="4d49d2edc91902768b1685768ac0421c"/></dir><file name="Statement.php" hash="48578c5307d13998d3b9dc73486bb666"/><dir name="Table"><file name="Abstract.php" hash="d1f0eb94b3a83abab809a132edec8d70"/><file name="Definition.php" hash="056d17187e24f48f42059889802ade8d"/><file name="Exception.php" hash="4ad0192e2759ce865081bfd65fba1537"/><dir name="Row"><file name="Abstract.php" hash="79e1dca4c87a158d36b171b11ec721a5"/><file name="Exception.php" hash="3182c2febc7a67988a02a2f4e3262c7c"/></dir><file name="Row.php" hash="adb2429446ad01b98bf74a1c79802009"/><dir name="Rowset"><file name="Abstract.php" hash="6474578f17e077f0d176de3d41bd43fa"/><file name="Exception.php" hash="c5e373d4e4d06e728572b3ca8c5d7d40"/></dir><file name="Rowset.php" hash="0534466fa3f58d60e28761013df1035d"/><dir name="Select"><file name="Exception.php" hash="c87230b6b7401370de518e6ad7218203"/></dir><file name="Select.php" hash="4a86cf29c8e383613e79caa5ef51ca36"/></dir><file name="Table.php" hash="bddf2a8c1ee791ef8a75fd81362a95b9"/></dir><file name="Db.php" hash="944811d3042ae76f201ce5ccee064693"/><file name="Debug.php" hash="e91277596844e74a3189f72b260d743f"/><dir name="Dojo"><file name="BuildLayer.php" hash="59fd3f007b9ddfe836308735a4fad349"/><file name="Data.php" hash="584f49393cc79deedcd43f36ff7cf68e"/><file name="Exception.php" hash="ce849ec1ac41925ce396495a4c0b5e5f"/><dir name="Form"><dir name="Decorator"><file name="AccordionContainer.php" hash="5ccfa22f987078a553c8334a1751a78e"/><file name="AccordionPane.php" hash="bfb6959fc54968e6e631a7b812f795cc"/><file name="BorderContainer.php" hash="3630699c89e4d611d463952ab7b616af"/><file name="ContentPane.php" hash="f5e7d589fc667a74c537f1c4a1d2f1ee"/><file name="DijitContainer.php" hash="6e30cb3a91ee447e6d9ae587a5b08fdc"/><file name="DijitElement.php" hash="63a591c8ae6f23a5fac3c4c4799849b6"/><file name="DijitForm.php" hash="3107c8e3a51efd7cd960a4d140fd2552"/><file name="SplitContainer.php" hash="32118776073ace34a7a6e6b775f7a41d"/><file name="StackContainer.php" hash="511f80fb7e777c7420df3a33e5d36df3"/><file name="TabContainer.php" hash="bfba332a70e20ac8e4bc1f9a7b488ffe"/></dir><file name="DisplayGroup.php" hash="4fc35365159beb7532119735b43ac5ae"/><dir name="Element"><file name="Button.php" hash="3ed66e9ab5b21731a355a35cc0bdadc5"/><file name="CheckBox.php" hash="cdf55f6261658dc12c508397228c86d5"/><file name="ComboBox.php" hash="ad263405d78671cb38f39a42f4153306"/><file name="CurrencyTextBox.php" hash="8a0101a9a7fdc7504fe882222df91d8b"/><file name="DateTextBox.php" hash="b1a766b9190c2c124d34d59d8c742f04"/><file name="Dijit.php" hash="8389aeca66aecb8a39d9341f81ded916"/><file name="DijitMulti.php" hash="bd0fe55261b57bcd2c92ea196eceaf08"/><file name="Editor.php" hash="bb3636533a931bc1f9a5782ac4c66565"/><file name="FilteringSelect.php" hash="d330a4330b410089733f8c1eeb1839e2"/><file name="HorizontalSlider.php" hash="b23bd0da212335080121f31e318f743d"/><file name="NumberSpinner.php" hash="9ae185b60accc9edb7baed24b93ca540"/><file name="NumberTextBox.php" hash="cc340c040ab7c8eaa02bf401a9a91bc3"/><file name="PasswordTextBox.php" hash="48b304d5bbfb2417adf1724362e032b6"/><file name="RadioButton.php" hash="80e8b86eaf8258626084f54272a7a576"/><file name="SimpleTextarea.php" hash="69791b92fb7d656676266fe53592b6b0"/><file name="Slider.php" hash="21f9f99bb495bcf2997a022f6a43c276"/><file name="SubmitButton.php" hash="52c7e25fd90d33b9501150746b046e14"/><file name="TextBox.php" hash="874413d9bf8c39f9a7a73d7175842cf5"/><file name="Textarea.php" hash="1fab8c9619163b0fd1cdeaf4bf4113c7"/><file name="TimeTextBox.php" hash="6ab9be9f6555bdc14ba9a02fb18c3157"/><file name="ValidationTextBox.php" hash="dd456a154f47bc74e05834800490ad53"/><file name="VerticalSlider.php" hash="c99c979911b12b2907b9ce727d595f42"/></dir><file name="SubForm.php" hash="46b28da42e2447cdf7f23ce8635a6243"/></dir><file name="Form.php" hash="5dc7b152deef6e0fedf0c0caa73f7c68"/><dir name="View"><file name="Exception.php" hash="fed5a27397fd8fb08841c1db38364df7"/><dir name="Helper"><file name="AccordionContainer.php" hash="3b2eaa765a22ea9a2d3d2e507da446b8"/><file name="AccordionPane.php" hash="94b8d5edb317926ca8aee3539c33ce8a"/><file name="BorderContainer.php" hash="f8b3939b919a3f961c8da6196b2166be"/><file name="Button.php" hash="e1e816f2362a2f973acceadb1414de98"/><file name="CheckBox.php" hash="43f1a6ad27883f62cda4bc1b560c9f89"/><file name="ComboBox.php" hash="d2811e390eb44a4f3e953c241949db0e"/><file name="ContentPane.php" hash="041084c11934376f3f759154a1835abf"/><file name="CurrencyTextBox.php" hash="56f2046e985a0d1cd81ba0d045f91a7a"/><file name="CustomDijit.php" hash="34bfe4e1501f8dc1227adcc9b7e2b20b"/><file name="DateTextBox.php" hash="81bdffce0b2acb693a7c2cbd3941f156"/><file name="Dijit.php" hash="7a1eb3742998cbbabac1b2338a590566"/><file name="DijitContainer.php" hash="3091a920fbfb48215a59f73be1988eaa"/><dir name="Dojo"><file name="Container.php" hash="e40d8395af2e395a2e81d593e8f4602c"/></dir><file name="Dojo.php" hash="6303c9d4ede5b67cc828ead89c4016a6"/><file name="Editor.php" hash="f251624a2b798b53eea465d9938ac276"/><file name="FilteringSelect.php" hash="60bbdd84239febff9241199104b4cf1a"/><file name="Form.php" hash="105f502558eb241c81c39be0e5d85a72"/><file name="HorizontalSlider.php" hash="7b3c19156aee3db41dbaee18abe2ded7"/><file name="NumberSpinner.php" hash="cf27c892acfeb8ba60027bba29d8715a"/><file name="NumberTextBox.php" hash="9674fa01666c5622896d4513da69ce8d"/><file name="PasswordTextBox.php" hash="0ba727cff497c3b580bffaf04eecc75b"/><file name="RadioButton.php" hash="ddd9733fd29a47cf20f224115895d2cb"/><file name="SimpleTextarea.php" hash="8162db2b947a8b380099ee4266bd2edb"/><file name="Slider.php" hash="b09cd129a4885cb799978b234e8ef496"/><file name="SplitContainer.php" hash="8fa96d45ff63d2b0f24250856afea806"/><file name="StackContainer.php" hash="f3f24abf9640124f26274b9663eccd5d"/><file name="SubmitButton.php" hash="9083d4797eb4be0a879951a88be9a6f3"/><file name="TabContainer.php" hash="8b6865aa0b8015b220896d3487ec0966"/><file name="TextBox.php" hash="75b65da85221b840ff6f3bd4d38890e2"/><file name="Textarea.php" hash="58421d644f61edc039bdaf8b2d13af7d"/><file name="TimeTextBox.php" hash="7865f42c62fd06ead74987324d2310d0"/><file name="ValidationTextBox.php" hash="59bc7469004e22811c038791462d67a7"/><file name="VerticalSlider.php" hash="9c113d757c1b99048d09ba8949452034"/></dir></dir></dir><file name="Dojo.php" hash="3d5a5b6120bb16fbde6a24fc082bb2e7"/><dir name="Dom"><file name="Exception.php" hash="764e44b0e7b8346387c4b677e725d6bf"/><dir name="Query"><file name="Css2Xpath.php" hash="84d8020779e37ed005fa2ca53052731c"/><file name="Result.php" hash="2c8f3fdb6f945804d2a2b5881b5c0567"/></dir><file name="Query.php" hash="ac0c71f2c7a030485756a780c2ca5904"/></dir><dir name="EventManager"><file name="Event.php" hash="73a22bba4a1536ad0bedb311992ed841"/><file name="EventCollection.php" hash="6846535fe1c08a148593082878839b2b"/><file name="EventDescription.php" hash="6cb5b7a743c322cc486c09de9e2466c1"/><file name="EventManager.php" hash="775973335393a6aab98b63fd7e580f6f"/><file name="EventManagerAware.php" hash="616ae31ca46f1f0206e28851f408e777"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4651b42388b3cc0f6a8c77b8c92a988f"/></dir><file name="Exception.php" hash="a7a76fcb8615694bebfd1b7a6c63cc2e"/><dir name="Filter"><file name="FilterIterator.php" hash="479bdbab563e57ade8718744d6a9eaed"/></dir><file name="Filter.php" hash="a6705be98a15d9abb250329a18bc5f44"/><file name="FilterChain.php" hash="0bbe4e22e4bd7731c91b0d8849e24dd4"/><file name="GlobalEventManager.php" hash="2448f17e7235ad32e0986dccaaf6f21f"/><file name="ListenerAggregate.php" hash="e0bf702bb54b9ba2d54828a2d66d2954"/><file name="ResponseCollection.php" hash="14500f355513b35b17a7dd7e947f5301"/><file name="SharedEventCollection.php" hash="0504cdf3c7168fa6e6a1d164705617c7"/><file name="SharedEventCollectionAware.php" hash="c53dea67b8742191c78911a87cf4c1c5"/><file name="SharedEventManager.php" hash="973daf2597a36f485ec43ae91f53fbef"/><file name="StaticEventManager.php" hash="47bc3c834d44e64eab6ea0b0c0a83eba"/></dir><file name="Exception.php" hash="fdca55eece8acc76af7ec98eca620311"/><dir name="Feed"><file name="Abstract.php" hash="66b85329fd8524fc66b93c16397cc49d"/><file name="Atom.php" hash="24d80774c71e1932b8be5054793d4fd6"/><dir name="Builder"><file name="Entry.php" hash="4871eb1a5d2084552d48b346fb9424ae"/><file name="Exception.php" hash="f8d2074819dd7157b4de4428579958c9"/><dir name="Header"><file name="Itunes.php" hash="da87e20a7e6b587316644377c8cc3c55"/></dir><file name="Header.php" hash="7e1b1053ef90762e3b6d9933cab4964b"/><file name="Interface.php" hash="407dbfd89e522c6e033214974954ad9c"/></dir><file name="Builder.php" hash="9453c5958f2cc22bd37a1e8e8de22ff7"/><file name="Element.php" hash="04f6a067ec047936af106f5a3ee9f0ee"/><dir name="Entry"><file name="Abstract.php" hash="44340d16439984b02edd6f26d7a1885e"/><file name="Atom.php" hash="a2642776469712e0e2dfcc0912e98aa3"/><file name="Rss.php" hash="93e478df77e9c9c43c55334ce2165a8d"/></dir><file name="Exception.php" hash="3ce015184369dd3392923dba02ccb4ab"/><dir name="Pubsubhubbub"><file name="CallbackAbstract.php" hash="5fc3da695c59069c88f54206485038c9"/><file name="CallbackInterface.php" hash="3b8478bc6bac3d9309c0fe7ba6f89dd0"/><file name="Exception.php" hash="028e2d741379246df90e62b96393ffe9"/><file name="HttpResponse.php" hash="6a929e3ac877b89fd0b8664b9894f953"/><dir name="Model"><file name="ModelAbstract.php" hash="ce0a0b0b03f77348b066a947e4d4a087"/><file name="Subscription.php" hash="99c0b396f4e21b0fe2bc3c068220958e"/><file name="SubscriptionInterface.php" hash="63f95bde2e9254d0e3c31b905fea78bc"/></dir><file name="Publisher.php" hash="44d781a089ad5ac1ee949b74badad6ca"/><dir name="Subscriber"><file name="Callback.php" hash="c50e22f4bec18ed4365b7a7fd472db69"/></dir><file name="Subscriber.php" hash="3a06e76251527da315017fd545595ee2"/></dir><file name="Pubsubhubbub.php" hash="9187f4accebd9b1b23010e141485f2c8"/><dir name="Reader"><dir name="Collection"><file name="Author.php" hash="bd0aee1688a6905cfa60ad3df2876d42"/><file name="Category.php" hash="0ac74f5a4ea9492998e7f76e6e959283"/><file name="CollectionAbstract.php" hash="a0d023979ca9ca7c2fdf93e0acb36745"/></dir><file name="Collection.php" hash="6a92b8355578f92468d24f03c33f6e7b"/><dir name="Entry"><file name="Atom.php" hash="c4f9ba356c97d5ad4ad6a5a210fa5d31"/><file name="Rss.php" hash="01b9d9b750ec9c730bc3fa624629deeb"/></dir><file name="EntryAbstract.php" hash="b9e05d05ad657e24bca3947764bf4aba"/><file name="EntryInterface.php" hash="3e33c60c08158ac0398bb9f05ec2090b"/><dir name="Extension"><dir name="Atom"><file name="Entry.php" hash="6baacc2e3ddc23ad3cfa9e190fd54157"/><file name="Feed.php" hash="16e84c49d96b759d10b1fe86982cca2f"/></dir><dir name="Content"><file name="Entry.php" hash="4a01e7b785bc08518739d03825f8c7af"/></dir><dir name="CreativeCommons"><file name="Entry.php" hash="4c7cc6a5ddcb6971e2a7d30c701151b7"/><file name="Feed.php" hash="40b8c9f5146271c2fe7433f7daff07ac"/></dir><dir name="DublinCore"><file name="Entry.php" hash="3ff54fc3fe5df35c8ba4075ed42dabeb"/><file name="Feed.php" hash="56f06a3e2739c70c66da54e7608c9496"/></dir><file name="EntryAbstract.php" hash="fb62ce68f7a440fac11ec666e9e4bc22"/><file name="FeedAbstract.php" hash="c1283a62809662e762cd0a7875b0b913"/><dir name="Podcast"><file name="Entry.php" hash="738c47a9b19c44bedbce6a6e901ee173"/><file name="Feed.php" hash="23c593352bc891c6bbce22e98da18f6e"/></dir><dir name="Slash"><file name="Entry.php" hash="29d24797987342ea6a580a48af0accb5"/></dir><dir name="Syndication"><file name="Feed.php" hash="67ec064681ba8a77b4f6d44a35d4d8f7"/></dir><dir name="Thread"><file name="Entry.php" hash="202da1cb171c55d435b125cfb264d874"/></dir><dir name="WellFormedWeb"><file name="Entry.php" hash="88c3ee8f88632712522d206426a2927c"/></dir></dir><dir name="Feed"><dir name="Atom"><file name="Source.php" hash="71d4bceda67dd3a4acbc45bbee33853a"/></dir><file name="Atom.php" hash="042c93075ae2e933e5241750c101d3de"/><file name="Rss.php" hash="e354bd24fbf48a5bab9d518e3912bd93"/></dir><file name="FeedAbstract.php" hash="e577cfdd039f4025877f12d2d08dcce6"/><file name="FeedInterface.php" hash="7eaed63ef055848aa1b299bc98d8cc11"/><file name="FeedSet.php" hash="5ba5f156ac7607b73929dac85826c659"/></dir><file name="Reader.php" hash="d9bc6e5b898eb8be4fa72e313e89bccb"/><file name="Rss.php" hash="e14ca674ad56d9ce18df5d9728c770bc"/><dir name="Writer"><file name="Deleted.php" hash="35aad5db793b86ca638a81d052c6ae14"/><file name="Entry.php" hash="87c1a1d4b637d4918f5fabe8b56c1a9a"/><dir name="Exception"><file name="InvalidMethodException.php" hash="02419d36ca4d923b7ae46f8cf5e9808b"/></dir><dir name="Extension"><dir name="Atom"><dir name="Renderer"><file name="Feed.php" hash="e1c642e0775de8ace9639daff1a932aa"/></dir></dir><dir name="Content"><dir name="Renderer"><file name="Entry.php" hash="f86cd399902d04ab6652aa952c81916f"/></dir></dir><dir name="DublinCore"><dir name="Renderer"><file name="Entry.php" hash="6f79082f7b75e1d7b73930169ff6d5e0"/><file name="Feed.php" hash="8b6825b40579ce795e0018eac48a0fa6"/></dir></dir><dir name="ITunes"><file name="Entry.php" hash="e23d802f1cc74b432a3c5362be650c55"/><file name="Feed.php" hash="ffa388bb1b1c868a92978ee85f3c8d50"/><dir name="Renderer"><file name="Entry.php" hash="184f5e6f780c987cb55374c6b899dee2"/><file name="Feed.php" hash="c5df3307f99f2349024d3a31612d67a5"/></dir></dir><file name="RendererAbstract.php" hash="427c8bd29a3f0aec64f2034405b8fa89"/><file name="RendererInterface.php" hash="2cbb9d13b450a08098921fe99f5084bf"/><dir name="Slash"><dir name="Renderer"><file name="Entry.php" hash="95b4d946971ccd12e852d36125e241ad"/></dir></dir><dir name="Threading"><dir name="Renderer"><file name="Entry.php" hash="81fa4f73e25ce35482f8ea2d01ceac48"/></dir></dir><dir name="WellFormedWeb"><dir name="Renderer"><file name="Entry.php" hash="45c4795ca01add23d35af6ca1961a27b"/></dir></dir></dir><dir name="Feed"><file name="FeedAbstract.php" hash="65fa012f95547e0e63deb8715038c9c0"/></dir><file name="Feed.php" hash="699463ea19aa24d3cf48d9ddf37d63d4"/><dir name="Renderer"><dir name="Entry"><dir name="Atom"><file name="Deleted.php" hash="65126201b8fb20b29f945956c3c7aa14"/></dir><file name="Atom.php" hash="fd98f2be04963b4a660c49cd0bb9db5e"/><file name="Rss.php" hash="f0e70e6a183416e6c04a1aa58d91b128"/></dir><dir name="Feed"><dir name="Atom"><file name="AtomAbstract.php" hash="2762eb27cc4182026d7cb5d4a2d8e7d0"/><file name="Source.php" hash="b4432fc84152c9922c2a0318043431e2"/></dir><file name="Atom.php" hash="a4e0a7056233cc18c1abcbcf45895b3a"/><file name="Rss.php" hash="b01a32487ec79c8e29848e56d12f4fef"/></dir><file name="RendererAbstract.php" hash="e818b72ef7cccb7e411218194c4a90c2"/><file name="RendererInterface.php" hash="b9d0002ea9fd72117b6438231ca2db9e"/></dir><file name="Source.php" hash="3cce4bf24782f65948e0078eee3af8b8"/></dir><file name="Writer.php" hash="31915fe86b889b38f29cd365dfa2eef8"/></dir><file name="Feed.php" hash="90930372cd8489f1be5480df69e492a3"/><dir name="File"><file name="ClassFileLocator.php" hash="a763041253fb82e55d99e50078f9e791"/><file name="PhpClassFile.php" hash="95812fdfe2ea77215eaf98220970d2bc"/><dir name="Transfer"><dir name="Adapter"><file name="Abstract.php" hash="9f8caf0965ee20c3e394cc9abd39dc64"/><file name="Http.php" hash="98db3d564539a149becd025db2996089"/></dir><file name="Exception.php" hash="825fcee61f10cdfe37140f8053177a3f"/></dir><file name="Transfer.php" hash="3b238f59905a999aa851bd4e7b641d64"/></dir><dir name="Filter"><file name="Alnum.php" hash="4ca46f20de00a3ae2c141f1ceff56bad"/><file name="Alpha.php" hash="5b07ed4ed80ac52058355dc25eab7f17"/><file name="BaseName.php" hash="625ce144adaded5d1a792f2cdff08ddb"/><file name="Boolean.php" hash="8a4ccc8b5fe35cc6371f2a876c1687c4"/><file name="Callback.php" hash="877df95b6818f3919ff98ef2b792beab"/><dir name="Compress"><file name="Bz2.php" hash="85a13672065e12d52a4a53c7d57b5956"/><file name="CompressAbstract.php" hash="e31d6c9f72772def373f5f947ebb4857"/><file name="CompressInterface.php" hash="fea3425ce29a7262ac9aa37ca15e7ccd"/><file name="Gz.php" hash="e1a5c9d4301ba780b0fc2a2ab69b9cef"/><file name="Lzf.php" hash="238dbeb23d34fab2ce1fd53c5728c981"/><file name="Rar.php" hash="ee424491867ca2fce1556bdcf01e0a7f"/><file name="Tar.php" hash="e9fc01174f800ebf4e87294361714fe8"/><file name="Zip.php" hash="1adcddd63511b526c388dbbfb2693ca5"/></dir><file name="Compress.php" hash="17af88fb4588855a0fa2ad0c747e567c"/><file name="Decompress.php" hash="9900b029a91c9c1620903061b15d8b5d"/><file name="Decrypt.php" hash="ea36fb417859a47bc8090908f91c79b0"/><file name="Digits.php" hash="988e652d047ccb2b3f51368702b39932"/><file name="Dir.php" hash="ded6da050ac44e21c8729c4fd74559f0"/><dir name="Encrypt"><file name="Interface.php" hash="02481da5488767e23939a73b434d6728"/><file name="Mcrypt.php" hash="2320868b4e3235e934023f6339edb9ee"/><file name="Openssl.php" hash="37f02c9e5fd864557aca070ca8525e36"/></dir><file name="Encrypt.php" hash="41b1fa4536947b9ce5e4dcadb3bf80b7"/><file name="Exception.php" hash="ee7fa3aa3daed6b376e4fe3ff0533a65"/><dir name="File"><file name="Decrypt.php" hash="f82c770a201d0016ed0054874f39c90f"/><file name="Encrypt.php" hash="63c6232b0c216381bee8c18df751ab59"/><file name="LowerCase.php" hash="664f911dfcba8fb26ad86605eda4ad93"/><file name="Rename.php" hash="d854b8b98abd89db4d4b0eca30a2b496"/><file name="UpperCase.php" hash="9aad43cc07b024188734fe231ec7a80e"/></dir><file name="HtmlEntities.php" hash="6ce1c0425b0b5f48c21649c15ffe1d26"/><file name="Inflector.php" hash="b6b671c8956fe8c359af7739c56867a8"/><file name="Input.php" hash="fc8cc25c2f9da1b1da7b2839eb914c99"/><file name="Int.php" hash="41724f5b9f96f08b6b01281891bc3eab"/><file name="Interface.php" hash="0f810dcab23fc1f455c960af3f317a04"/><file name="LocalizedToNormalized.php" hash="6b98acca5dc278027620e0d5361a316e"/><file name="NormalizedToLocalized.php" hash="27f9795714f46c3d4a143330e77219ce"/><file name="Null.php" hash="fe5c2ff3f08d7ef9ffc140ad251dd6da"/><file name="PregReplace.php" hash="7b0c18825dcc9016d0cc2a0fea8fee53"/><file name="RealPath.php" hash="133f0776eaa042a0712e2d8e7db3ed7c"/><file name="StringToLower.php" hash="9a7352bfa73b4ac825bc2af9fef3c286"/><file name="StringToUpper.php" hash="ec2165f772585dcf346b589bbf9bc716"/><file name="StringTrim.php" hash="ca76b8743fd9ec88290ef11a24d48a03"/><file name="StripNewlines.php" hash="fe69c99129f9bd2b69ea16c0bbfc61c1"/><file name="StripTags.php" hash="78d7393075f2327644e873d4e9196082"/><dir name="Word"><file name="CamelCaseToDash.php" hash="3793e4ef36c6778b9e5df032dfc15b67"/><file name="CamelCaseToSeparator.php" hash="cd445e16f5d3ef145c4b0f35a10b1dcd"/><file name="CamelCaseToUnderscore.php" hash="932bcf0ead2bda7d9ba9544458fe2de8"/><file name="DashToCamelCase.php" hash="705245ae67e4a9eede0bb3c0bf0e6ac4"/><file name="DashToSeparator.php" hash="6edcb2382b8fc7acc8448679d6fb46b4"/><file name="DashToUnderscore.php" hash="1075b2edc67d246d7f300c336a00a745"/><dir name="Separator"><file name="Abstract.php" hash="7c13a127a26229fc8d5e0678e8efcb5f"/></dir><file name="SeparatorToCamelCase.php" hash="87f3c3a2ab24e2146db100710050d873"/><file name="SeparatorToDash.php" hash="d13f2d966ffd8cfb05114fbb9f3906b1"/><file name="SeparatorToSeparator.php" hash="3f70eae82b1616c098cd9aec7be41f9c"/><file name="UnderscoreToCamelCase.php" hash="5f19c37337b901edd5fe5080a8353116"/><file name="UnderscoreToDash.php" hash="2f25783e6e165b827fc113f046f30f44"/><file name="UnderscoreToSeparator.php" hash="b0e92b24b679b3dcbee459cd752a2478"/></dir></dir><file name="Filter.php" hash="383fca34ab08e0a803adb2c7766fad95"/><dir name="Form"><dir name="Decorator"><file name="Abstract.php" hash="8522e625655a35646b477ad4ff99dfe5"/><file name="Callback.php" hash="190782b871a222c75dfc8444b863da11"/><dir name="Captcha"><file name="ReCaptcha.php" hash="39b4156e05bfd86a8bc607c94f437e32"/><file name="Word.php" hash="880894024cfbed08b5f1078076512a25"/></dir><file name="Captcha.php" hash="1d07f76a5ba267e35b801bbfa6437b1f"/><file name="Description.php" hash="4c386b676076f9d5839eea503b633567"/><file name="DtDdWrapper.php" hash="124076232159f0fa26fc9fe67685830f"/><file name="Errors.php" hash="e10d634460b6dae52065a83cd5c3b3a2"/><file name="Exception.php" hash="7540f704e53237cd3a6715d1e480c3b9"/><file name="Fieldset.php" hash="6bd5c5b9ff8e9e489e5a7c560aff175a"/><file name="File.php" hash="c06f2200db61e4ebffa266d99260c726"/><file name="Form.php" hash="c0117ea6a352a32b780baae652d717b9"/><file name="FormElements.php" hash="8cb9c8f03fb877b45696b534c1b39b14"/><file name="FormErrors.php" hash="723036887204776c398e63c715b762fa"/><file name="HtmlTag.php" hash="2b90f769619b1e6624e14922dc2c32ec"/><file name="Image.php" hash="2a1a7dd1624ee71cfc13b7c96b4796e9"/><file name="Interface.php" hash="60d51f6f15d396b5a16519ba5eeec204"/><file name="Label.php" hash="277f64b41efc25890d78eba58db9b780"/><dir name="Marker"><dir name="File"><file name="Interface.php" hash="30667e6ff2ccced89c3b62cf0e13f931"/></dir></dir><file name="PrepareElements.php" hash="0ff6fb16d6c5a748c9c3d3e48037755d"/><file name="Tooltip.php" hash="bb7394628ade765908544c69c6790844"/><file name="ViewHelper.php" hash="c5cc8db2e0cec01b77be69fa2e1b9299"/><file name="ViewScript.php" hash="23ef6fc6fdac5fd8c9105738c5cd3ccf"/></dir><file name="DisplayGroup.php" hash="ee080ba86203eeb41ac17d38877651f5"/><dir name="Element"><file name="Button.php" hash="730df0b76e3957882f877197447d5f1d"/><file name="Captcha.php" hash="0752ad99fb0f43536c91367c70a494df"/><file name="Checkbox.php" hash="e39255d645c7c1b2ac042cc64c2e7cc9"/><file name="Exception.php" hash="c1a78bc6fbcad9d8544ef102ee578bd7"/><file name="File.php" hash="8a78cdb33c6d598fee1f22fe008e7479"/><file name="Hash.php" hash="98a63f7085dc662488f510b8341a450a"/><file name="Hidden.php" hash="4f1b7d49e10c937cbe9bc1f481a24e9e"/><file name="Image.php" hash="050990ff646853c7def62d5912a3a57e"/><file name="Multi.php" hash="546108cee3f938abc94159392b279638"/><file name="MultiCheckbox.php" hash="8da3e1c8f63673889aa82c8a477bc19e"/><file name="Multiselect.php" hash="70685894797a172bfbfeed0b3ca0c8c9"/><file name="Note.php" hash="db0386ab8c66da2df8c912e37b11110f"/><file name="Password.php" hash="4cee94cd5c56812e101f9cae256d79cf"/><file name="Radio.php" hash="088e0a26f8b959fd252edc7080cbe3c6"/><file name="Reset.php" hash="782f1aa0cbe1a792a0d05a51d58d8beb"/><file name="Select.php" hash="ee8919ec27665b02cc44cc0083609878"/><file name="Submit.php" hash="0a97601d86f82bd50d3ea6777937254c"/><file name="Text.php" hash="781ee2e638e37fc613ad760bbd2d30bb"/><file name="Textarea.php" hash="85a7119e8e0fa3377b0576b16aa05c51"/><file name="Xhtml.php" hash="4c20761fbbb7ca24ea9b49ac3cd41e58"/></dir><file name="Element.php" hash="f03fcc6dcd7b3e0da5a36046d36d727f"/><file name="Exception.php" hash="d33a48b9d1ec7e213210383b1f7bca68"/><file name="SubForm.php" hash="ba968be3402ccdf8b4185f4d53234120"/></dir><file name="Form.php" hash="4001592cf753a1170ba2cf1c178c17ce"/><dir name="Gdata"><dir name="Analytics"><file name="AccountEntry.php" hash="e12468f4c63d78e8edecbc473933aa4a"/><file name="AccountFeed.php" hash="a2f9b14dbdc470693a82907f57c4d258"/><file name="AccountQuery.php" hash="8f5b153ae38c2c0598dcdd0f4ca851a4"/><file name="DataEntry.php" hash="e45ec9042ba8356cdf29505e1e9e2d0b"/><file name="DataFeed.php" hash="5db9ffeb61cefb3659e9be8400ed20e8"/><file name="DataQuery.php" hash="f42425d8f43dada50bb8f128d8f975f6"/><dir name="Extension"><file name="Dimension.php" hash="38282ab7af5abb515f4aa658f820fc34"/><file name="Goal.php" hash="2c46c1d7db9b5f507a47e4bb121e2b4c"/><file name="Metric.php" hash="8560747659930f23b28cc94bd837440b"/><file name="Property.php" hash="d1ba271f052e44a1152eed24533824b0"/><file name="TableId.php" hash="60e5a4486c861d393b6f3183c2485267"/></dir></dir><file name="Analytics.php" hash="a97cd7d0faa0f65351e65f55c28fcc60"/><dir name="App"><file name="AuthException.php" hash="6f8d23065cd17d239b2cec093015ad8e"/><file name="BadMethodCallException.php" hash="86fe8ce683680f512145d94a22ab21d5"/><file name="Base.php" hash="109e590e151826d3347d1f2f58dcab56"/><file name="BaseMediaSource.php" hash="d1ec6648e8c89711225d42a07e4738d7"/><file name="CaptchaRequiredException.php" hash="7a3e3893b6f8a9c282d920acb9928e21"/><file name="Entry.php" hash="06786f3fe9e30b60c79888be9c70c067"/><file name="Exception.php" hash="82c41ada4e9863867adb2795fe7b1ca0"/><dir name="Extension"><file name="Author.php" hash="2df6f04ec34d35d1d79bbd189a9c53a8"/><file name="Category.php" hash="273bbd08b463d8394b8528294f2f43ef"/><file name="Content.php" hash="ba2ae463fc480db7c017c495c47f8380"/><file name="Contributor.php" hash="b06a5ee82e874422c7053e9bc4efa7a7"/><file name="Control.php" hash="2215659703162befaa49e7a18ad7abe1"/><file name="Draft.php" hash="45da888e1837d3002d099e483cc4e117"/><file name="Edited.php" hash="94503a1886214c959eb189dc1331a1e3"/><file name="Element.php" hash="1ff84c0f8b8e3e9be1edf28774125044"/><file name="Email.php" hash="f3733ecc80e481cd3e35b93df18a216d"/><file name="Generator.php" hash="aef1362208e44f2be51e4094089b4795"/><file name="Icon.php" hash="36d027f0cf96a2deb42b6c1aab0468ef"/><file name="Id.php" hash="9609dfb9218d0b8263086504e6b0d63c"/><file name="Link.php" hash="de21b9578b8592c5b3e3fcfb84419671"/><file name="Logo.php" hash="23c88a04e6897da7a7606733d5880094"/><file name="Name.php" hash="bcefb468fb70012b66b7322b1b9c618f"/><file name="Person.php" hash="5190427185a73d6cd253d4ad37d3130e"/><file name="Published.php" hash="f5b6d374545f8fea7382644413c786ee"/><file name="Rights.php" hash="add154a43b16eea075f70fef1dc0c614"/><file name="Source.php" hash="9b5c51a557d100b8d32f04c2e631d51e"/><file name="Subtitle.php" hash="87ccbc9582dabb57b4e5254c3cdb5419"/><file name="Summary.php" hash="308fcbd2860bac275a68bbaa455d75e5"/><file name="Text.php" hash="bcb0f1d994917499bb98c2045839cf78"/><file name="Title.php" hash="37736e9d970dbfb6508fe95c8b1d4c4a"/><file name="Updated.php" hash="3a00f1cac5e73b47fe960a4568d753a2"/><file name="Uri.php" hash="c8a0fd8b1e0ef4620dcb4f8d3bdf2f02"/></dir><file name="Extension.php" hash="e8d500cede8625e9a513241cb9340b8b"/><file name="Feed.php" hash="2a9b8a370e645cac248df5cec9752bf4"/><file name="FeedEntryParent.php" hash="03a2448db19430ce9d63af5a794c49ee"/><file name="FeedSourceParent.php" hash="ad513f8bba194a7c597d62332e1b748d"/><file name="HttpException.php" hash="e235854ac6db814217beb8e0f4432bda"/><file name="IOException.php" hash="4fe86dbdc8efd68b4f4e91eb720476fe"/><file name="InvalidArgumentException.php" hash="bb79aa3b093b89f2d1740e3de29c591b"/><file name="LoggingHttpClientAdapterSocket.php" hash="6c6fcbec1d914d2f0f1b4c9f9f9d6ded"/><file name="MediaEntry.php" hash="665829aa3a0b00efad9d39516ac20296"/><file name="MediaFileSource.php" hash="33e29faf6b09ad55399f8c4605de560b"/><file name="MediaSource.php" hash="956d976c017eb2969ec6980ba6a10227"/><file name="Util.php" hash="a978ace39e376ebb7a77168bb980e500"/><file name="VersionException.php" hash="46a96dcdf49d163f2b558f6af76770f8"/></dir><file name="App.php" hash="0611ada3705cf91a416144719aa34f4d"/><file name="AuthSub.php" hash="7d6c8fa90f00569465838f7485e6f8c9"/><dir name="Books"><file name="CollectionEntry.php" hash="e9400464091b197c1406c31904c89f46"/><file name="CollectionFeed.php" hash="50eb4262a08af25008fc23dc8ce38261"/><dir name="Extension"><file name="AnnotationLink.php" hash="229515a8187537875bec1df18a216e70"/><file name="BooksCategory.php" hash="94043b4e41582b92bd585a2f6ca55401"/><file name="BooksLink.php" hash="d4d4d737a079e5a06f9ec239156acc3b"/><file name="Embeddability.php" hash="02ea13af1b4c9e4bdf019cf85bd2e1e3"/><file name="InfoLink.php" hash="e901bc048235143eca51ac93750e148f"/><file name="PreviewLink.php" hash="96cc9f7155d4a8420b59dfab337df144"/><file name="Review.php" hash="8263c22752814fc5b8ed79f5b8fb0c64"/><file name="ThumbnailLink.php" hash="d39c8c46fdcd113b6e78b0a291e3fb7e"/><file name="Viewability.php" hash="00ab00c410d09d756c1f4eac2617dd85"/></dir><file name="VolumeEntry.php" hash="c792cd0a1600d1f82b359e4488ca96d6"/><file name="VolumeFeed.php" hash="df63b570832f03352f8fd9caf5dd0ad9"/><file name="VolumeQuery.php" hash="7c4eafbfe2dffe63d19da553d7116784"/></dir><file name="Books.php" hash="2b24e8b1f35eeb6c045c82aaea8ff279"/><dir name="Calendar"><file name="EventEntry.php" hash="3a8929e9b816b58b948bb27c5f5b7b11"/><file name="EventFeed.php" hash="cb77e63f75b7b00e3ad977160bf1df3b"/><file name="EventQuery.php" hash="c87b0d6fb40e7b41509bbf0c72c35563"/><dir name="Extension"><file name="AccessLevel.php" hash="0c08117546cfc5687e831e7c1c911386"/><file name="Color.php" hash="173b3b7765f71816d9474b4d662fa78b"/><file name="Hidden.php" hash="e013d7fa1de0281467fd342b68d82e47"/><file name="Link.php" hash="9024ffbc848c26dc7142791d334ed4c6"/><file name="QuickAdd.php" hash="b27ef7921a5f849c6d3670e80205a826"/><file name="Selected.php" hash="af19756358007c35c1e97b25d3c40f98"/><file name="SendEventNotifications.php" hash="ad25cf943facb4ca07b5eea08b29d6c0"/><file name="Timezone.php" hash="f42b5243c11888a5ba4075b0e9663d64"/><file name="WebContent.php" hash="b7097ddc1f180e4a85097a414b96bba9"/></dir><file name="ListEntry.php" hash="0579d1450de838b1b893f9720a7dacc1"/><file name="ListFeed.php" hash="e21a404f7d250f78fdac64f729d2b377"/></dir><file name="Calendar.php" hash="507e33fa6d185c57b0c2c351c0fbc060"/><file name="ClientLogin.php" hash="d5025122f58267716ea25d7546da7d62"/><dir name="Docs"><file name="DocumentListEntry.php" hash="08219506950f07c0cb16e1196dc4e09c"/><file name="DocumentListFeed.php" hash="dd7d591781ad9cf3293f73bc94e64e78"/><file name="Query.php" hash="e6c962a8f8cfe02d3ca0701b932dd5c9"/></dir><file name="Docs.php" hash="f29d7a621a95734e8b83a4afa5a6fe42"/><dir name="DublinCore"><dir name="Extension"><file name="Creator.php" hash="c56d34f65d24a0ad25e60a4e913fd54a"/><file name="Date.php" hash="54b46f21e08d7ca7d230c6b7e83e7210"/><file name="Description.php" hash="6f4bb927deae9cb5b501b37e4cbdeca7"/><file name="Format.php" hash="a2eb4fd88c1197f1b122adfcca64e4c5"/><file name="Identifier.php" hash="7900202e14b61bf0323069f736521521"/><file name="Language.php" hash="b47e4dafd3fcebd4d11b4ac0806cea70"/><file name="Publisher.php" hash="1660d7ee8e0fa26d24376ed8414849e3"/><file name="Rights.php" hash="1cddf53544c56ad8a29f012f1501501e"/><file name="Subject.php" hash="a287af1b176e22b3f7001e4a8d69129f"/><file name="Title.php" hash="77bbd2f9afb01b6337b03b12c19cd0ba"/></dir></dir><file name="DublinCore.php" hash="6fa896e35490d67182eb013b08ef6d75"/><file name="Entry.php" hash="b2f85f13672d64d288bbcf9824058488"/><dir name="Exif"><file name="Entry.php" hash="cba9027e69ca0d3431f5fa8e84519d22"/><dir name="Extension"><file name="Distance.php" hash="69d8d71b3c8f02fd85e22e72453f5e7c"/><file name="Exposure.php" hash="5b4f1e1c91ada58e661412e391c9167c"/><file name="FStop.php" hash="78c90acf5134d6a8cd7debc8dfff3942"/><file name="Flash.php" hash="bc1c363115d8ee05fc043ae829ca9398"/><file name="FocalLength.php" hash="ba8dba20995e7ad0dc5fbe056a13a431"/><file name="ImageUniqueId.php" hash="3007c391ed138e7db78cca05ad964cb5"/><file name="Iso.php" hash="9b7340beb6cd2f991d0b590da9929207"/><file name="Make.php" hash="b96528e1c95904dcf7a32b6d2b855c4a"/><file name="Model.php" hash="de354ebd3ac53b26c7ba7d07b7eaf74e"/><file name="Tags.php" hash="0b6dca99d61d601cd89ddfe6d9af5990"/><file name="Time.php" hash="880ab5825cab35d85036460d54b18148"/></dir><file name="Feed.php" hash="d102e026496f926fa8dbf0024e75ea22"/></dir><file name="Exif.php" hash="31c98117fa58af3fbc8a9504aed7f05d"/><dir name="Extension"><file name="AttendeeStatus.php" hash="dac3c0490bccbf09f924948ad44232cd"/><file name="AttendeeType.php" hash="3b42bd943b0536d5bde7e735fd8615d4"/><file name="Comments.php" hash="9afbcf4a4ce1d7dd52706e0e8928a8ee"/><file name="EntryLink.php" hash="5a280e630417eb616c257813c3ead727"/><file name="EventStatus.php" hash="61f988f2bfafa564543cabe4e7f86f29"/><file name="ExtendedProperty.php" hash="2d80f08e6e2e79da98134e959b58fbbd"/><file name="FeedLink.php" hash="679a6f5c9ebed486b6b41bac1522fba3"/><file name="OpenSearchItemsPerPage.php" hash="8430c39b6ce1bfb8deb8d2ff4070edf6"/><file name="OpenSearchStartIndex.php" hash="118645c4f8d38b135ebdd9792ba30234"/><file name="OpenSearchTotalResults.php" hash="8e7bbe094d00d023b1ac76184bbc871c"/><file name="OriginalEvent.php" hash="799806cbff3654b92028550a96d3f418"/><file name="Rating.php" hash="96f79437551070a76a0ffc8cf0ce3f93"/><file name="Recurrence.php" hash="da2e478f7368e9fae3e91aa4975769b9"/><file name="RecurrenceException.php" hash="1565fac963250d130a9a18d0e87a9462"/><file name="Reminder.php" hash="84525523e8827d09cda261f02f4c4214"/><file name="Transparency.php" hash="2c99f3896ceaa90632f565d3910eba43"/><file name="Visibility.php" hash="df49298225481498f3a082cc88092ed6"/><file name="When.php" hash="4a02d7db9ade6210d5d01fd401938732"/><file name="Where.php" hash="5d1d9557f1a8a24be5c6076464f35cda"/><file name="Who.php" hash="8d3c827558b62b6fbbdb1786bc6dc8f0"/></dir><file name="Extension.php" hash="3dbf28598313aea3fbcb6ae0a9218373"/><file name="Feed.php" hash="8ae61588a220ed9e612bd0d306ed7be9"/><dir name="Gapps"><file name="EmailListEntry.php" hash="beeaa4d8624538255fd4fa414bf2aa2b"/><file name="EmailListFeed.php" hash="dae8f9390c01ce354aacf7a03b56faa3"/><file name="EmailListQuery.php" hash="38e4255133125d1c3cd461769ff2bbf6"/><file name="EmailListRecipientEntry.php" hash="5042400a2ccf63b598d11098c08a02a8"/><file name="EmailListRecipientFeed.php" hash="e67f7530086c3c3de9bf49ce731ba816"/><file name="EmailListRecipientQuery.php" hash="6b48a9d58feb39241c63a1c448259894"/><file name="Error.php" hash="2739432a885e3aa64112124acf85666a"/><dir name="Extension"><file name="EmailList.php" hash="d83a001f6b79d69a55a534c352df4518"/><file name="Login.php" hash="068572b0a7d975d816564d334aa6cf07"/><file name="Name.php" hash="b895fe7b562ab015bc391c82be75d63e"/><file name="Nickname.php" hash="12ce7eb02489b501861272c13acec59d"/><file name="Property.php" hash="4517466631d6a91e771e3eba6c4d028e"/><file name="Quota.php" hash="18a9c44fdf6146c74b51d123c00bd7d4"/></dir><file name="GroupEntry.php" hash="5c36b2030c5394629693de197c909286"/><file name="GroupFeed.php" hash="13b68ebe7768fabe2f408b5a317bb088"/><file name="GroupQuery.php" hash="fc3f172f6fda1a3b50c6c8c2f3beebd6"/><file name="MemberEntry.php" hash="987fddd8e68938e62d4fb4c80a0b7586"/><file name="MemberFeed.php" hash="aaec820fc096293a6e6f4e5dc9a213a7"/><file name="MemberQuery.php" hash="1fe4b7f18ca161de836a9bf2b18cf123"/><file name="NicknameEntry.php" hash="f0fbcba505a6cac9d64328acf86c168a"/><file name="NicknameFeed.php" hash="80df6633ccad4aea2f1b0ff1fc56fedc"/><file name="NicknameQuery.php" hash="b3fc90f01854679f692ca2d34f1ef867"/><file name="OwnerEntry.php" hash="a66d48e8d46fddf2a9e3ea0330bcea45"/><file name="OwnerFeed.php" hash="98123454cb3cc6dc134d9ad827d297b2"/><file name="OwnerQuery.php" hash="5c829232390b828f06565012b2af3ce6"/><file name="Query.php" hash="a893bb0bebd43c558fac8f7b58477577"/><file name="ServiceException.php" hash="e62bc29c1a67ab44455ebc10fb033887"/><file name="UserEntry.php" hash="327e60ce8bad4fad8aa9d785902a0488"/><file name="UserFeed.php" hash="12a6e44ebb6b809f1ab17884c957d034"/><file name="UserQuery.php" hash="36d9b6e3c53812f1a0b3ba58b8348d1f"/></dir><file name="Gapps.php" hash="006b69cd2b4bb52efbc481cba3ded85d"/><dir name="Gbase"><file name="Entry.php" hash="d1c0594bd7f509ee8b71a0d4c6e93cef"/><dir name="Extension"><file name="BaseAttribute.php" hash="9860f259d07b1d7c48953ac145e91173"/></dir><file name="Feed.php" hash="a3a9a55b4dafc0c71da475d0b8ab4ed3"/><file name="ItemEntry.php" hash="4ad3d155cdb9fce8010cb9ff27d3ff54"/><file name="ItemFeed.php" hash="44ffbf3810fe7d602fa50a219f4d0c6b"/><file name="ItemQuery.php" hash="d85aa16b033dfc7478cbfa9cd38cbd69"/><file name="Query.php" hash="feaa71301ffc82297a5c768b267ff5b2"/><file name="SnippetEntry.php" hash="023249497ffc22f6fbad8645c50dc78d"/><file name="SnippetFeed.php" hash="5197182ca6edcf33fa8452f809597510"/><file name="SnippetQuery.php" hash="17365d8dc24d1da93b8b730c6fe6d864"/></dir><file name="Gbase.php" hash="78c17b83a499c8c31d31762990d83d3b"/><dir name="Geo"><file name="Entry.php" hash="bf5d39448208c58aba61ec64d6a79ad8"/><dir name="Extension"><file name="GeoRssWhere.php" hash="914e0e1155c117f5908f07dadc6ee889"/><file name="GmlPoint.php" hash="a5bf5b02bdec49c06e1aa44763bba1a8"/><file name="GmlPos.php" hash="8ef27447e497a39031e475372a8cb08a"/></dir><file name="Feed.php" hash="c2adb51ac77e046f74ac15f7bcfb53d3"/></dir><file name="Geo.php" hash="2a5a5a2dfa2462e061234e4946fbc8f4"/><dir name="Health"><dir name="Extension"><file name="Ccr.php" hash="5f6686a6c63958e949db8bf5deb92f2b"/></dir><file name="ProfileEntry.php" hash="a2c0dd3747b54680f62089aa25ca26c0"/><file name="ProfileFeed.php" hash="1a41a46d2871e28239c45f23f0b50868"/><file name="ProfileListEntry.php" hash="ee7b66b18af7f3d7406c10c82dbe903a"/><file name="ProfileListFeed.php" hash="1d15e991cf6dc94a83b52ec64aed7a2a"/><file name="Query.php" hash="6dd89b579a5aa4d35de32e74c0df5502"/></dir><file name="Health.php" hash="6b0a156697fe84a09efbde31eea3f497"/><file name="HttpAdapterStreamingProxy.php" hash="6b2964e32bf7c0e110b8ab25445ed53f"/><file name="HttpAdapterStreamingSocket.php" hash="b5b74e5c1cb8206da4b163666a81fed4"/><file name="HttpClient.php" hash="9cee0a291d6c4b11f7358628923f925f"/><dir name="Kind"><file name="EventEntry.php" hash="1f1204191536089911a984770ce0cb47"/></dir><dir name="Media"><file name="Entry.php" hash="9cc1bd304119ff7d428225d3107c3a34"/><dir name="Extension"><file name="MediaCategory.php" hash="8f9345afe735f43c0936d2741556db13"/><file name="MediaContent.php" hash="947b1ca390fa6021690d0a67f81c0c28"/><file name="MediaCopyright.php" hash="947dadff8c8d2708ccb7af6aaa5d928e"/><file name="MediaCredit.php" hash="6d2b9d4be6e3c896fc9c9f9a9581ce9d"/><file name="MediaDescription.php" hash="eeaf98530facd9f42d2e3c46661db3f3"/><file name="MediaGroup.php" hash="9e6dcb6e453393b23d7efb8dde3fb4b0"/><file name="MediaHash.php" hash="2f84bf6db86d3302709347222ad1eba4"/><file name="MediaKeywords.php" hash="6a1a4c5eee620173c5c1995a8bc0aa25"/><file name="MediaPlayer.php" hash="c7d51126d6604718daec1674785e90af"/><file name="MediaRating.php" hash="915d64d3fa690969aa6697c945ef7b28"/><file name="MediaRestriction.php" hash="8921f3bd9d80f7a530b826ab009668c4"/><file name="MediaText.php" hash="557defecdbd618e8917ed5fcd6ccddbf"/><file name="MediaThumbnail.php" hash="e5e272a715318c877fae805dc78e3fee"/><file name="MediaTitle.php" hash="4134d9c00494d89ba462ae9500d1e2bc"/></dir><file name="Feed.php" hash="f67c9bb85cbfbf098fb53ae50a026044"/></dir><file name="Media.php" hash="752e78b67dca41a50ffb85dee3b3e483"/><file name="MediaMimeStream.php" hash="de9b3dd42e0f9f62341fa075bb900c6c"/><file name="MimeBodyString.php" hash="ea742b4f32d34ddac64454b990d4ef37"/><file name="MimeFile.php" hash="0afbad3bc750c1cc5d3f93c54c3c5019"/><dir name="Photos"><file name="AlbumEntry.php" hash="1ab5e6bdc070df30938e912d52eada85"/><file name="AlbumFeed.php" hash="07c42ecd6819d25e428b94f31882c1a0"/><file name="AlbumQuery.php" hash="5da3a372fe52f8c076e9d97a35f823e1"/><file name="CommentEntry.php" hash="f7822566e08ea7b3f74c955abf89a41f"/><dir name="Extension"><file name="Access.php" hash="8d4c3dfe21dbb25632e87659070125d1"/><file name="AlbumId.php" hash="45b3059567bf5e49a6f8edf6b8a16937"/><file name="BytesUsed.php" hash="fd2a43339909b5c7402208dccbdf68c0"/><file name="Checksum.php" hash="5ca31e3430e2e9b747d91c94c000de8a"/><file name="Client.php" hash="2a3276f0666bc92c7d7155bcfbc74f42"/><file name="CommentCount.php" hash="48176e51ea9b1c3c0de6edcf24e25d19"/><file name="CommentingEnabled.php" hash="5b460e8f02be0079867d34af9ab54bce"/><file name="Height.php" hash="d913feb4798b7f3c8ba645bc6ecd1d59"/><file name="Id.php" hash="c5c6fcef6647a1523b99463cfb0a6ebe"/><file name="Location.php" hash="b2b10096aeca032d37e138b09f4ce18e"/><file name="MaxPhotosPerAlbum.php" hash="d1b61411c47e1eb91cb0b80be60998a0"/><file name="Name.php" hash="7e6637d23584ef1ebc3834940fc2ad52"/><file name="Nickname.php" hash="c4345329b15d815de6527d0f8e0277e6"/><file name="NumPhotos.php" hash="160edc7a3b4837435a36befe5378e01e"/><file name="NumPhotosRemaining.php" hash="a3b358f036c2fbefdf93830c92a027fd"/><file name="PhotoId.php" hash="ff997a353b24d944f439702d4ece0966"/><file name="Position.php" hash="cf9f8b0c29c98c1680b2675ebf47e6b2"/><file name="QuotaCurrent.php" hash="a57ff86ba83287a1f145f272ca463756"/><file name="QuotaLimit.php" hash="00c6e94954fbe136a09d4b7ca8f7128c"/><file name="Rotation.php" hash="513a2712c12e10fb61dde21976824b7e"/><file name="Size.php" hash="ab29ba1766a003c1b3ad22db180d18cc"/><file name="Thumbnail.php" hash="6a59c5bebc192e34992e8058ccfd11c1"/><file name="Timestamp.php" hash="b52abdc854529af5cb545691692375ec"/><file name="User.php" hash="3a21cef935fd5fb42f97e308b1997583"/><file name="Version.php" hash="9625bc1c6aefcf580c5fbe0d2f045b4e"/><file name="Weight.php" hash="a8bc3ed41e626323f92adf87410af458"/><file name="Width.php" hash="06f910c1bb1e4e747c38c26ed409522b"/></dir><file name="PhotoEntry.php" hash="ada12abf9bb991fa672ca9a05cb979a5"/><file name="PhotoFeed.php" hash="3b29ec6d750456cdd799bcbaa751e89b"/><file name="PhotoQuery.php" hash="93b28eba3750d181f44fe41181e45663"/><file name="TagEntry.php" hash="8c088bb0af6e8a14eced2775aa3a291c"/><file name="UserEntry.php" hash="15e59c396a645fc30f03cb42d2efc351"/><file name="UserFeed.php" hash="e1498967cc3f5d361c96a0bcde82437d"/><file name="UserQuery.php" hash="26f3ef6227851523817358a97544ebd6"/></dir><file name="Photos.php" hash="c46ff72fca949809ff42f17b0079c069"/><file name="Query.php" hash="100dee31d0a572c4d2e990a96f7e9a0e"/><dir name="Spreadsheets"><file name="CellEntry.php" hash="93cc5079095d6daa6c2147b62131a890"/><file name="CellFeed.php" hash="ca07b9478e1b6ecae9147bc2105c8bd7"/><file name="CellQuery.php" hash="bc7fbfd4e84481e19df568357bc22e37"/><file name="DocumentQuery.php" hash="fd2935ddca76445d1bea58c4f6799ebc"/><dir name="Extension"><file name="Cell.php" hash="917abed62f74a5101511f4449c805140"/><file name="ColCount.php" hash="dba4f0796d79fe80ff15d4dc9bebcd24"/><file name="Custom.php" hash="8f805dee81206d515ab43097cecedb1b"/><file name="RowCount.php" hash="be76b9f5b367cb349576283ab9765d34"/></dir><file name="ListEntry.php" hash="7b8c759afeb6cee40fc5ce231dcf6f2e"/><file name="ListFeed.php" hash="688c2cd0aab8cffabce85d835e4fe077"/><file name="ListQuery.php" hash="2bd4f1eb97b6b3c92c8d2f52fcdbbccf"/><file name="SpreadsheetEntry.php" hash="e43a1862baadf19907770d4a61a56626"/><file name="SpreadsheetFeed.php" hash="2cd1cf91c61a54ea236e1aaf73877009"/><file name="WorksheetEntry.php" hash="7091ab92f732197dbf7e45dcc9c87bf3"/><file name="WorksheetFeed.php" hash="3a4c334028cc35e76255507be1efe061"/></dir><file name="Spreadsheets.php" hash="5706fa18d101c716c73b5f1f6869f33b"/><dir name="YouTube"><file name="ActivityEntry.php" hash="19c73663008cbcbb141c35e8717521aa"/><file name="ActivityFeed.php" hash="5e45cff4ae0df9e35683067769a26386"/><file name="CommentEntry.php" hash="8f17768b645f4165b9601e59fab4045a"/><file name="CommentFeed.php" hash="a391a8ea8c0b27904e365eace8b03458"/><file name="ContactEntry.php" hash="440d8c1c0196e59dd80c6c52e30b2459"/><file name="ContactFeed.php" hash="ae3698b6ccf9d339f7a30b4a5789f698"/><dir name="Extension"><file name="AboutMe.php" hash="8011ef3b524bea9fff089882ea4ed0ab"/><file name="Age.php" hash="e2a9893b2e911b3db507465320cbcf63"/><file name="Books.php" hash="89b35f4bc0027463f91824b5cd2e47cb"/><file name="Company.php" hash="549c355f976cc892cebc6811fe2580a1"/><file name="Control.php" hash="578a083eabf62931b62d095600b80003"/><file name="CountHint.php" hash="666969cd9d5d77e06c9a115fae9de6b8"/><file name="Description.php" hash="8a7dbf10f59ccd573eb0c90cc5971cf6"/><file name="Duration.php" hash="24f2181f720fe6db1cb22503ffee459c"/><file name="FirstName.php" hash="d28dd3cd580a2fa7c6bfb829e8711166"/><file name="Gender.php" hash="260b84dc18e9c01eac563404d0fa5f5d"/><file name="Hobbies.php" hash="2dd89e1c8199ef743d771702ecc95c8f"/><file name="Hometown.php" hash="fda3ebb42524b3ab8d54467887da61f5"/><file name="LastName.php" hash="f19b93c1d745cafe6ecf20c7bc8d0c3d"/><file name="Link.php" hash="d93c9801f25b8c8cb13d87ff3b3b460e"/><file name="Location.php" hash="20909b4d155c9fd517081322b835f306"/><file name="MediaContent.php" hash="1b53bccaa9f1de51c19378fc8c442868"/><file name="MediaCredit.php" hash="4571da70916493177e72f0aebeaa78ac"/><file name="MediaGroup.php" hash="36cca7fb741bb294f4dcb4142733d100"/><file name="MediaRating.php" hash="099d0984cdb2c9110ca259311047d0de"/><file name="Movies.php" hash="464957a1f90eb56899ec503c4ede6ef9"/><file name="Music.php" hash="947c3294f34d0f35ab88c7f7a9c4f4b3"/><file name="NoEmbed.php" hash="1e6e4a5995de606554e7145a0df0b6d4"/><file name="Occupation.php" hash="b33c3053639572a312fec678395d7436"/><file name="PlaylistId.php" hash="af87bcfda7115ae9c55bf3c1f2986754"/><file name="PlaylistTitle.php" hash="79b89ae7bdce993a758fd1bf45188252"/><file name="Position.php" hash="d92a78e714b2f7afdfabd8d09f73ff1d"/><file name="Private.php" hash="93bd6eeaf228e882ccceda591813228f"/><file name="QueryString.php" hash="5e5c57c2e219ef2e5ca3184997d87ccd"/><file name="Racy.php" hash="ad019d20c5c40d12da9cfc9df9daeaec"/><file name="Recorded.php" hash="7af195c7f3f045946f13504cc38522a0"/><file name="Relationship.php" hash="b42aac9538b504662222635a29149436"/><file name="ReleaseDate.php" hash="beb4a4d9830ff40a06816a341de8dd15"/><file name="School.php" hash="51a1ff928489cc7cd3aacc7a7aaf08a3"/><file name="State.php" hash="04cd3d54d4050aafc5ce27e719d234e9"/><file name="Statistics.php" hash="73270160b45c7ec91914467ccda850ef"/><file name="Status.php" hash="aadcb325d6f3b51cae180406d4caf9a4"/><file name="Token.php" hash="8686b59bd2a0048283389bc01acf77bb"/><file name="Uploaded.php" hash="9ee6ea6660e515f1440d92b2ef4d97dd"/><file name="Username.php" hash="c3782552a9accafea073e8f0081e43f3"/><file name="VideoId.php" hash="30fdd4c5cd5b212a1e4c17cd28fbb12b"/></dir><file name="InboxEntry.php" hash="24eb593b56341f919f0bc0446b4b71f8"/><file name="InboxFeed.php" hash="69487f9424ad1686f1b00e2b1f73ad29"/><file name="MediaEntry.php" hash="924fd5fcbfec4c44e965812618c08b6e"/><file name="PlaylistListEntry.php" hash="367ad32e10ea7203408d99bcfae836a2"/><file name="PlaylistListFeed.php" hash="6a2db1a031b1f749231326b4bd57d9bd"/><file name="PlaylistVideoEntry.php" hash="5453811dc274201e95b9ca6450180669"/><file name="PlaylistVideoFeed.php" hash="54be8eb4c90f3a5a4b6ce1ce578f7e56"/><file name="SubscriptionEntry.php" hash="f602292610ce553fb7493cda0bc25cb0"/><file name="SubscriptionFeed.php" hash="576b63779940d7e3576a1c505bff284f"/><file name="UserProfileEntry.php" hash="4eafc0f86b477f85405429572ba1ba62"/><file name="VideoEntry.php" hash="1ef39076a4e9cd95f91bf8d69bf4f52c"/><file name="VideoFeed.php" hash="aa4889f83dab3ed5524583b48a7a5a22"/><file name="VideoQuery.php" hash="a2a973590b187f7314e994d824a6a288"/></dir><file name="YouTube.php" hash="a8dc12d5116ec45b159b59dacddbf946"/></dir><file name="Gdata.php" hash="f1583b57defcf04cb1b35c2875a95ea1"/><dir name="Http"><dir name="Client"><dir name="Adapter"><file name="Curl.php" hash="a4300f6a2b52d63e0edd1e81c4fe2dd5"/><file name="Exception.php" hash="edeae8782f6926386f145d8a873d23bb"/><file name="Interface.php" hash="588b60a6607675c8698be8b3fd2d4e22"/><file name="Proxy.php" hash="6892b7d0c9de3a441adb25d4fbbd22ec"/><file name="Socket.php" hash="6078a103596ba3a8b2544563d252d505"/><file name="Stream.php" hash="14a0106f768a6388688690a54a3eef27"/><file name="Test.php" hash="35e3087f1d6baa3b6fa2cda8228febf9"/></dir><file name="Exception.php" hash="a5f986ab6d87cb83bed91a1caf56ac00"/></dir><file name="Client.php" hash="26f6df4ccf15f65b213ebd0f5538978a"/><file name="Cookie.php" hash="a56a600d64c9bae67c66ae784de2fe58"/><file name="CookieJar.php" hash="7d93690c2caf40108c35a66b10e25586"/><file name="Exception.php" hash="b345b84b1e9b8a1ae2478ff04f37fc2f"/><dir name="Header"><dir name="Exception"><file name="InvalidArgumentException.php" hash="02d00d00a945c0595a648ea418fe3673"/><file name="RuntimeException.php" hash="8c166ae41ab4e516abda9289f19e973c"/></dir><file name="HeaderValue.php" hash="c0e08b696c63818f37faa68a0f733d32"/><file name="SetCookie.php" hash="5f5620b08a9a298bd60cab553cc4f213"/></dir><dir name="Response"><file name="Stream.php" hash="8a41b22b489629a6766dfb3cb96e0ed2"/></dir><file name="Response.php" hash="a34c934977d3bbc1da1a2153692a5743"/><dir name="UserAgent"><file name="AbstractDevice.php" hash="e52f1ad149795aad5075c4bc6cf977f3"/><file name="Bot.php" hash="e5679a2e30d3f1ef581d508446c1f482"/><file name="Checker.php" hash="0b6bb9cb341b75ca7bfb749cb2c871bd"/><file name="Console.php" hash="93650b34bd1238887e88c238291853c0"/><file name="Desktop.php" hash="9829ee285a2cdc4388326a07644d042c"/><file name="Device.php" hash="72533d95dea2a7fe6366bd2145b5b938"/><file name="Email.php" hash="f0a3fab08e59378c0189073237611af7"/><file name="Exception.php" hash="beb38f75f587ac56cbb7a843f59a84ae"/><dir name="Features"><dir name="Adapter"><file name="Browscap.php" hash="a88ccf8fa0b5aca789f32a08f83c98e7"/><file name="DeviceAtlas.php" hash="725061814353e65cc2d89e2a67a00673"/><file name="TeraWurfl.php" hash="1f91bc3ded39c5b108d8232d18cd17f4"/></dir><file name="Adapter.php" hash="a4dcf44cd31de8969f3e941f9a14d0a5"/><file name="Exception.php" hash="a8fba4a7bf9a1a58225ab313b5fa4dd3"/></dir><file name="Feed.php" hash="716918e5334ac352997eac35ca5956dc"/><file name="Mobile.php" hash="00d3e607c4ac5e298492bd3d7762c555"/><file name="Offline.php" hash="6c1ce88c65a43a63416928292c5f9f5c"/><file name="Probe.php" hash="b4df007dbdeb6ef7c49f599d728eed49"/><file name="Spam.php" hash="a4402ccfc92bdf4c49ed1a27bb1905eb"/><dir name="Storage"><file name="Exception.php" hash="ab40f3958bb905a85cfa5cf14af640d4"/><file name="NonPersistent.php" hash="9c8d459eb114f70df099bd397a542a1f"/><file name="Session.php" hash="6b94c84a472e0a767d42be7e26aec3c7"/></dir><file name="Storage.php" hash="ec42c71aae122ea711cbf87ef261c4e4"/><file name="Text.php" hash="711458780f3c17ad437f3d56b5109321"/><file name="Validator.php" hash="69d6afb8a82293c61a642c791f5a16db"/></dir><file name="UserAgent.php" hash="460734f564ed89053481a1204db01c79"/></dir><dir name="Json"><file name="Decoder.php" hash="be80f4b8fe57afd69752fc51c349dcc8"/><file name="Encoder.php" hash="0282ee4cb81e78771c8829398f64082f"/><file name="Exception.php" hash="949bff931d3430258aa0d8688d70df18"/><file name="Expr.php" hash="5985e830701d7f8d5daeb230ce56b1a3"/><dir name="Server"><file name="Cache.php" hash="149b4bcdb085ccd0d535903aa463a0a6"/><file name="Error.php" hash="f3bec127c343a8e14a7a9b1339ab28aa"/><file name="Exception.php" hash="1b0ac33c450ec1bee800421995576fa7"/><dir name="Request"><file name="Http.php" hash="832d82cb88edefb954c4d4d730d0a95c"/></dir><file name="Request.php" hash="35999aec48306723cd44da4c5a62fe35"/><dir name="Response"><file name="Http.php" hash="a5f156d547e04bd224295be634e864da"/></dir><file name="Response.php" hash="a3c115766d7a5e6e57cb4a27887cad2a"/><dir name="Smd"><file name="Service.php" hash="9aef500f4cef8c72886b6103820397e5"/></dir><file name="Smd.php" hash="c8dce4255950f809a22ee60febb2bc2c"/></dir><file name="Server.php" hash="90dcadb42953db253627a783aafa0b80"/></dir><file name="Json.php" hash="9c8bd17cde28999638cd2f05fe470cbb"/><dir name="Layout"><dir name="Controller"><dir name="Action"><dir name="Helper"><file name="Layout.php" hash="c049699d9228b85c2823d7bfdba7d8de"/></dir></dir><dir name="Plugin"><file name="Layout.php" hash="2af276e070314489ccdd514b841d86ad"/></dir></dir><file name="Exception.php" hash="a479f33598f2c4e1cb228883ae6f22ac"/></dir><file name="Layout.php" hash="6d7b1d2ad0c1bf5d5d1ea058ca5a24f7"/><dir name="Ldap"><file name="Attribute.php" hash="a334347a968defb0fda698c3c54f46d7"/><dir name="Collection"><dir name="Iterator"><file name="Default.php" hash="8f8a4876cf258d6b1f71582a805df017"/></dir></dir><file name="Collection.php" hash="ac57de545867cf7cd1df3d6c113263ca"/><dir name="Converter"><file name="Exception.php" hash="4e029f2da6d5c7df7644bfd2c434c6d0"/></dir><file name="Converter.php" hash="8e09bff7ca34d3051cee4a873f5b58a1"/><file name="Dn.php" hash="b5653205b12da006a91e498ca7fc7dc4"/><file name="Exception.php" hash="e12baa19246087c376b7d5cbf0ab7eca"/><dir name="Filter"><file name="Abstract.php" hash="efc802cd50bc28c4181e5bbab247e725"/><file name="And.php" hash="662ca1c25383de02b569c76bc62a058f"/><file name="Exception.php" hash="4f8ae5e40c68e60f00550dd5ccd7aa34"/><file name="Logical.php" hash="06aad3c5c574bae76adc46927ae21474"/><file name="Mask.php" hash="904d6707c87b202d9b66e1e3532fbd94"/><file name="Not.php" hash="028697704f21551b33dcb7c160369691"/><file name="Or.php" hash="8dec15db06446ad375c61c7f46912d7c"/><file name="String.php" hash="b1cc0c074d1822be6124f6c48e351a86"/></dir><file name="Filter.php" hash="c50df357d992c35c217ac7803ce314b2"/><dir name="Ldif"><file name="Encoder.php" hash="d1116ef8bfa81ce18fd5cbae52942227"/></dir><dir name="Node"><file name="Abstract.php" hash="e84bbf67046f975a1f5775aa0d49348d"/><file name="ChildrenIterator.php" hash="8b0c6775e5111e80938ccc9cb60aed0c"/><file name="Collection.php" hash="11098b8c84df455895877fad99f30a20"/><dir name="RootDse"><file name="ActiveDirectory.php" hash="c5f5e80b8dd2cb1e31ac3e03fc279024"/><file name="OpenLdap.php" hash="dcd6e7ebc3775e6a5cba8485bd78c8d6"/><file name="eDirectory.php" hash="f946fccdb3015b015d3cff00829a6ea6"/></dir><file name="RootDse.php" hash="c247acc47a79441717304abade296309"/><dir name="Schema"><file name="ActiveDirectory.php" hash="85bc7915ab42dae47c2d4fb8e3dba51c"/><dir name="AttributeType"><file name="ActiveDirectory.php" hash="04a142f499e0848e9ae43a64786328d4"/><file name="Interface.php" hash="ae4ab45b50efa4e032e32912d9c6a776"/><file name="OpenLdap.php" hash="a823f4b81c597a3820e4fe67e5454e70"/></dir><file name="Item.php" hash="fe670cbd69aa5863f9f66efadfcd3dd2"/><dir name="ObjectClass"><file name="ActiveDirectory.php" hash="e678fbe8c0e965cf7db01e829adff67f"/><file name="Interface.php" hash="166b71e4032d84ecfc88365d89b1de11"/><file name="OpenLdap.php" hash="428b8707dc060e1f9e7854005c51d58e"/></dir><file name="OpenLdap.php" hash="2e52c69ae03823a1d0f42e83aff2f316"/></dir><file name="Schema.php" hash="2745fb40a9578d326a48718ee91cc5fa"/></dir><file name="Node.php" hash="648c759b832b68b000e8bf08af0339ce"/></dir><file name="Ldap.php" hash="da470d2a2a451bc59b2ed1ecb118ec5d"/><dir name="Loader"><dir name="Autoloader"><file name="Interface.php" hash="5a8847bbf702beb3c5d03d9b6620291a"/><file name="Resource.php" hash="b9e4409e67051a21f4e2ae855c1bd691"/></dir><file name="Autoloader.php" hash="4882de8624fe2953294bb4a2a2a6f8f6"/><file name="AutoloaderFactory.php" hash="3ec199fa5c2dec860143b37f17b5ce65"/><file name="ClassMapAutoloader.php" hash="2acb3037511952ac7eb2bab70501dcd9"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4286045d7c3bad36fa3e101f0beadfaa"/></dir><file name="Exception.php" hash="81dbec797bf5464d3dd93886de055be3"/><dir name="PluginLoader"><file name="Exception.php" hash="fba867bd38d0dbb235f86cc6899d834e"/><file name="Interface.php" hash="60638720a3d503c41b6679d1a12c9e59"/></dir><file name="PluginLoader.php" hash="6be3d7edad844778eb79c52494f04eb8"/><file name="SplAutoloader.php" hash="b35315f66536a170485d6a91cc962a4f"/><file name="StandardAutoloader.php" hash="181406bd273d500ef771e5f24b0bd909"/></dir><file name="Loader.php" hash="817eebfff3c19cf057a8bd92f0c9c679"/><dir name="Log"><file name="Exception.php" hash="b163db6d6600897c6d7d9675f5b2082a"/><file name="FactoryInterface.php" hash="950fce8f1016b9149a3afa78cb5d6bdd"/><dir name="Filter"><file name="Abstract.php" hash="588c7a33b8cc18516fb09f45b6e4df27"/><file name="Interface.php" hash="8e207e5fde37a093bc429eca471abdb5"/><file name="Message.php" hash="42c00aa794507e263369816ebd6ecfb9"/><file name="Priority.php" hash="3bc818826edb7d8d47778c71534968ca"/><file name="Suppress.php" hash="6198f609922c91844696ad749f8f988b"/></dir><dir name="Formatter"><file name="Abstract.php" hash="f6b6a3a2f08104b92f02916dfae10819"/><file name="Firebug.php" hash="18bf525dd98a338a0068adc7223004aa"/><file name="Interface.php" hash="f304a62a7dc3774938c9a4c0386e312a"/><file name="Simple.php" hash="e99de8b500f61444ef4ffd6bd44f8b28"/><file name="Xml.php" hash="dc3361c1aeaa94dca0dac28920c7ea8d"/></dir><dir name="Writer"><file name="Abstract.php" hash="79ccb8a60f0146adc3d1019487a99a69"/><file name="Db.php" hash="e9dd86777ca1735ccec177c7e385316e"/><file name="Firebug.php" hash="6227fe3e164c36db1829e4afd5fdddd2"/><file name="Mail.php" hash="3f76aaf2c1bfa288b7f126efd127c306"/><file name="Mock.php" hash="be44a2526cd397f294cb3350334479cc"/><file name="Null.php" hash="7dc63aa32e13ee72975d68873d87d85d"/><file name="Stream.php" hash="5a287635e4c1d74763215959ba19b70a"/><file name="Syslog.php" hash="06022b333a8ca4d896eaea75f92fe543"/><file name="ZendMonitor.php" hash="3e508d727439f6c10212e70617d68b20"/></dir></dir><file name="Log.php" hash="1c6f8b389780f0bb85202471def93ea7"/><dir name="Mail"><file name="Exception.php" hash="8d01b40eca451bee7c9401d2498ae65d"/><dir name="Header"><file name="HeaderName.php" hash="ecd8c8336e3619779a72d1e1f105675c"/><file name="HeaderValue.php" hash="d55840608558bb29022bca0c565ae55e"/></dir><dir name="Message"><file name="File.php" hash="7415d6300a134322e1f9b5723f456375"/><file name="Interface.php" hash="37f65eeadf5f7d8c46e5740810a91f31"/></dir><file name="Message.php" hash="eea17eeae16ed0696aef9794f947791b"/><dir name="Part"><file name="File.php" hash="2973a0c512d8a12ae250f0310e7ab715"/><file name="Interface.php" hash="5a08dd0d4abfeba0e2b6a3bcd0647cb0"/></dir><file name="Part.php" hash="b948eb534e24b93bb22d34d6dc78c494"/><dir name="Protocol"><file name="Abstract.php" hash="75f76eb34f20aef472da005983e4ade4"/><file name="Exception.php" hash="324b88f119661b2fb45e50e03fdbb797"/><file name="Imap.php" hash="4be011d91db7e932867a9ef04b9e3f1c"/><file name="Pop3.php" hash="a3f36e5260b3fdf15ff91afb4edd06c8"/><dir name="Smtp"><dir name="Auth"><file name="Crammd5.php" hash="989efed470312ec3d252f04f48b13f1f"/><file name="Login.php" hash="eeb279a39d84d0c34b5b3c57a0d8e1fb"/><file name="Plain.php" hash="4e4fb49d2c0a4c3cc6326b9362663812"/></dir></dir><file name="Smtp.php" hash="a99437c462526c3ab7c4a16e6dd73dd5"/></dir><dir name="Storage"><file name="Abstract.php" hash="c80a746bb73014c266f2785247770e77"/><file name="Exception.php" hash="8dfb9dc508a506017fa2aba591171706"/><dir name="Folder"><file name="Interface.php" hash="e46d56b2092b8e66b0de59f089f28dbc"/><file name="Maildir.php" hash="2ffec84ff5cebbc06f42a4bf4e8e49a0"/><file name="Mbox.php" hash="a6bc27702d0e9acbc52d83efdbb623c0"/></dir><file name="Folder.php" hash="710f0f79f55eb9c16523b59b3e46026d"/><file name="Imap.php" hash="63b4ec9c47e81d973c0cecb781a0e398"/><file name="Maildir.php" hash="c298cee3127aebf1d902bc6a263cd67f"/><file name="Mbox.php" hash="96e1d239b5d88772aacd245255d35cc5"/><file name="Pop3.php" hash="fe599c6260e22c23dcd3bfd698271b77"/><dir name="Writable"><file name="Interface.php" hash="a5a3487a8b0dcc8c1f957e10b9535c96"/><file name="Maildir.php" hash="f9dc51e0430fed3cb7fb06a6fc46b4c1"/></dir></dir><file name="Storage.php" hash="bf94dde2f63c2ea5933cff36fd0d96d2"/><dir name="Transport"><file name="Abstract.php" hash="b5e088f0f4a65356307e1e6048558c5a"/><file name="Exception.php" hash="2fc585f21c0c0bbfb8d9218788a99d91"/><file name="File.php" hash="976dec70144df18e87d527ff7e516758"/><file name="Sendmail.php" hash="0a64fedcc87ebe0c9c15695805201bef"/><file name="Smtp.php" hash="6f916608a1b6f93dc6d116e8d8f40b94"/></dir></dir><file name="Mail.php" hash="233f0679a2a5101183c73419cc14e184"/><dir name="Markup"><file name="Exception.php" hash="6acb9e012348c31a98e8016f689bd83b"/><dir name="Parser"><file name="Bbcode.php" hash="fe5258254d43407c8ebf45121d5d3443"/><file name="Exception.php" hash="96b47171a5e4994dcb75bfeb964a3261"/><file name="ParserInterface.php" hash="22f4cab8c966e18965cc16bf1ac58a2e"/></dir><dir name="Renderer"><file name="Exception.php" hash="c27375ebcd69a8eb56a5c3e3229ef88c"/><dir name="Html"><file name="Code.php" hash="c919be3dcefb797b425cd65153302f6e"/><file name="HtmlAbstract.php" hash="7dc1ee614c7d125582f34ded495bd5a3"/><file name="Img.php" hash="6a130ace451a6ed0a2d0a1f1ea3bff58"/><file name="List.php" hash="e8474711d02734026d531708832e1310"/><file name="Url.php" hash="6bb6f2015aa632299941bf9997e8110e"/></dir><file name="Html.php" hash="b607c5add3adcb046c58771b79ecdca5"/><file name="RendererAbstract.php" hash="bf2e4d797e26ef28885babcf2d9e2722"/><file name="TokenConverterInterface.php" hash="e5b38c0b3ba387f0df071a35c7fb1f3f"/></dir><file name="Token.php" hash="925b6878c35fd1e0855a73ecf684f25c"/><file name="TokenList.php" hash="590aa72556941d672184f1aca02ef30c"/></dir><file name="Markup.php" hash="70327a385551a40429dbf98def244565"/><dir name="Measure"><file name="Abstract.php" hash="a844b711aca6638ea933630264ab309f"/><file name="Acceleration.php" hash="f6b1c64dd6bacb4f38d91f72cd8db6d9"/><file name="Angle.php" hash="6c7ec7f864050be14c1735017d149b18"/><file name="Area.php" hash="88b0f14de44d235235da841062691dd1"/><file name="Binary.php" hash="5f9e527c1e8d01535d9bfea7105ac76c"/><file name="Capacitance.php" hash="8bff74324cadcd21836b5acc547a544e"/><dir name="Cooking"><file name="Volume.php" hash="334d3bd9a1023acfed66eb41bf307a15"/><file name="Weight.php" hash="d970ef6d6f08a37db72285917d30ccd6"/></dir><file name="Current.php" hash="1747ffe7532a5c7c060343e3271a27f2"/><file name="Density.php" hash="f4cb05733337475f59762b41a29ae3bc"/><file name="Energy.php" hash="2ed086e65b6f7a4ce1280d8ef9d0f1c3"/><file name="Exception.php" hash="d00039899c6aa43c6b250588bbc07e35"/><dir name="Flow"><file name="Mass.php" hash="2d322913557ff2bfc45afc2ab480babd"/><file name="Mole.php" hash="ff0fe19858605f8c65cbc6f1f377aba4"/><file name="Volume.php" hash="66df34980d0aa473755280393b0f0d7c"/></dir><file name="Force.php" hash="9525a6c47d1e4cbaded7b3477d3c4ba7"/><file name="Frequency.php" hash="80bf10cfe7eeebc3d281b7ed11b397ea"/><file name="Illumination.php" hash="98ee18ab173727ba4dc93a3ada6edd33"/><file name="Length.php" hash="7318f5740bfe039f8c6bda66f172251a"/><file name="Lightness.php" hash="ea419ded90ccd0f5c053262458cc80eb"/><file name="Number.php" hash="7a63c36bbf2089aef5e8ee3e7347e24c"/><file name="Power.php" hash="c896cc783192f260057584f2ba881f87"/><file name="Pressure.php" hash="49c451f9eacd6d162ba6bb629e9118e1"/><file name="Speed.php" hash="c601fe3564d6f3d1f8813a0a7013e335"/><file name="Temperature.php" hash="0d5d33464d00562675fd5d801eebe117"/><file name="Time.php" hash="1c8b825d84b6ccffd76906404d92173a"/><file name="Torque.php" hash="1f530a46616ba82d78541493fb321445"/><dir name="Viscosity"><file name="Dynamic.php" hash="5f002bc79a1c1138cacacec371db37ab"/><file name="Kinematic.php" hash="bd10456069dc6d35a3e1713bd4c6dd71"/></dir><file name="Volume.php" hash="0fbf0ca1290f4aa1af5b23982a6914c3"/><file name="Weight.php" hash="a821fffd5941ccd527cc1d0694336b00"/></dir><dir name="Memory"><file name="AccessController.php" hash="a70d4c42eea7b98f61113d798b55259a"/><dir name="Container"><file name="Interface.php" hash="6068d380217bf27b6453cf894edb8695"/><file name="Locked.php" hash="9bc2f25899430f7ad02853e88dfca0a9"/><file name="Movable.php" hash="4c3c042f5e2bcc2531715dde401171cf"/></dir><file name="Container.php" hash="8feed8c3f2b8f5f0e8d688f13c48c2aa"/><file name="Exception.php" hash="3329d69fccf497932b1a2c27e9919c18"/><file name="Manager.php" hash="1a5c0de427d4436a95fb9d2c0953f279"/><file name="Value.php" hash="697a03309f774813690845eac71d4702"/></dir><file name="Memory.php" hash="2e82b15d077661c5c4b8201ea5bab1fc"/><dir name="Mime"><file name="Decode.php" hash="0cd721f3b84a257348cbfcb73919759e"/><file name="Exception.php" hash="994fc2875e99f10a522cb82e4a54b2b7"/><file name="Message.php" hash="4e3dd5e95f8621955641c7e1b4de46c5"/><file name="Part.php" hash="a11ac478688ef12d8cd0ccecff33670c"/></dir><file name="Mime.php" hash="39042a59c2be063d736a04dac55e903f"/><dir name="Mobile"><file name="Exception.php" hash="519a024f65881a7a4237732573710059"/><dir name="Push"><file name="Abstract.php" hash="456f8a825509d342fcfef1439673f54c"/><file name="Apns.php" hash="d8429732ef082dd5db604fea4c8915b5"/><dir name="Exception"><file name="DeviceQuotaExceeded.php" hash="86b9ff4bc83a799a58f7dffea7382284"/><file name="InvalidAuthToken.php" hash="5ad87658c33a7d9cc6f917d0b5920253"/><file name="InvalidPayload.php" hash="25c5f5d11619d662e9274418d98ed4f8"/><file name="InvalidRegistration.php" hash="8658ffa721150d321de50135d2e5a807"/><file name="InvalidToken.php" hash="713a8d260276537743a4d04b4aa81c11"/><file name="InvalidTopic.php" hash="7c829b73a958a1a5b2727d2819061578"/><file name="QuotaExceeded.php" hash="be67af28f9904f0fc42004751daff33a"/><file name="ServerUnavailable.php" hash="ed4b06b1ef3e3c429b90731ae2920412"/></dir><file name="Exception.php" hash="f894173f4a187922ee49522cf8d3353a"/><file name="Gcm.php" hash="920c224bf5d2829b12e860785f1fcb02"/><file name="Interface.php" hash="8ac308916b40869193bfe9f4924c6d8d"/><dir name="Message"><file name="Abstract.php" hash="60010ad2c300cc7aaeef6e09bd1f0eb7"/><file name="Apns.php" hash="3aa335c6ee551991ad704c6ec1965399"/><file name="Exception.php" hash="14efc16a622ee08a4d66f6b966aa8afc"/><file name="Gcm.php" hash="8e5c08acd168e10c7e0b7be393683846"/><file name="Interface.php" hash="aa9b1e963e71262791a2e85f9d5e03d4"/><dir name="Mpns"><file name="Raw.php" hash="cd49049ab99df63e747b3cf21ce49056"/><file name="Tile.php" hash="eeb12c6d00f840c828e8f928ef28e747"/><file name="Toast.php" hash="6b7b461af1ebd47bc8278388762e186d"/></dir><file name="Mpns.php" hash="bfb031f22738438461df23e002feb93c"/></dir><file name="Mpns.php" hash="d027a3baf86b7808b8f5dd097dd748dc"/><dir name="Response"><file name="Gcm.php" hash="02cdfb00622182c505e7c4916fb51397"/></dir><dir name="Test"><file name="ApnsProxy.php" hash="ef5b18b7cac0826d10cca487ab851180"/></dir></dir></dir><dir name="Navigation"><file name="Container.php" hash="ae908f801587df5bbc7a44d94e290365"/><file name="Exception.php" hash="1f907b7d1a68ca8d29b29f8f9694ca3c"/><dir name="Page"><file name="Mvc.php" hash="bb408e6676cc27d470e41f21084d050f"/><file name="Uri.php" hash="45e78f322e869f7570a82cac147f9985"/></dir><file name="Page.php" hash="ecc7fc65c84c45b552ea81d280fc13d2"/></dir><file name="Navigation.php" hash="bee97615ae02af0c039d61863d0b1e00"/><dir name="Oauth"><file name="Client.php" hash="74d6c02debac4961c253da9d8cc2fe5e"/><dir name="Config"><file name="ConfigInterface.php" hash="1cabd35d6a7f0f92529457b4ea62e17a"/></dir><file name="Config.php" hash="a02e7f37acbb42bc34feebc920d49871"/><file name="Consumer.php" hash="3dc938414065746a37763d2b592e1ee5"/><file name="Exception.php" hash="570bf15ce9b8ccf76e4bcd949adeef50"/><dir name="Http"><file name="AccessToken.php" hash="986d7e25f96d5bed67914e08404bbb5f"/><file name="RequestToken.php" hash="f4f86a01a6e424aaa7e8edb99e518f59"/><file name="UserAuthorization.php" hash="758cc6c3df942ac5ac3b103527a99a10"/><file name="Utility.php" hash="9c69fe9d58add25eda7730460eeb4ae1"/></dir><file name="Http.php" hash="cef52b37622bcfb2efd2a9644babc94d"/><dir name="Signature"><file name="Hmac.php" hash="26331323b06095d36ea1b3d8de214c79"/><file name="Plaintext.php" hash="11266c5bf1d868c63fac84ff14c22061"/><file name="Rsa.php" hash="4ea7e936077c094ee6365ee33707c4fb"/><file name="SignatureAbstract.php" hash="09e632d7cfb30720b43cd8e33ca867f7"/></dir><dir name="Token"><file name="Access.php" hash="974b61753e392b577562e7090dec4102"/><file name="AuthorizedRequest.php" hash="2c5a7071f93bfc03e8098a367c1b95ad"/><file name="Request.php" hash="3253abe4f0340e7fa12d6c26c669e1cf"/></dir><file name="Token.php" hash="19cbcf77a287619c7043efc9cf4cc2fb"/></dir><file name="Oauth.php" hash="239174147ad1cac48ff43b86ca768b5d"/><dir name="OpenId"><dir name="Consumer"><dir name="Storage"><file name="File.php" hash="53a1aec62db8e0bf8153d2363b8afdcd"/></dir><file name="Storage.php" hash="96636f4707d5090dd777ca16ff5f9498"/></dir><file name="Consumer.php" hash="d4129677162161a383a8327a8a5f5cb4"/><file name="Exception.php" hash="9ae51477a152a9993db86a2b3e87a792"/><dir name="Extension"><file name="Sreg.php" hash="a46ab3f654e7718b74f256863398070d"/></dir><file name="Extension.php" hash="d0cbcdb2874105fad8d517731ee682dd"/><dir name="Provider"><dir name="Storage"><file name="File.php" hash="78e54dc83e5862422be8c086458815bb"/></dir><file name="Storage.php" hash="a111906ee39dd25c3e8f03edf73a3f0b"/><dir name="User"><file name="Session.php" hash="184de6934deff211975387b3d0eea0c7"/></dir><file name="User.php" hash="1130cc8407f1607fcc19e0e0e7048953"/></dir><file name="Provider.php" hash="e82af61658678702cf9b92879c70494d"/></dir><file name="OpenId.php" hash="3afe8be181b4ee86ebca1531a1bd8b0b"/><dir name="Paginator"><dir name="Adapter"><file name="Array.php" hash="b19b7013fca38d006a2b638b89312764"/><file name="DbSelect.php" hash="3bd5b7dc7a01b4dcb161f396be0b8670"/><file name="DbTableSelect.php" hash="cab2b30b8210b2979b0c6bed4b123fad"/><file name="Interface.php" hash="5762707d8b9db19faf2a773eb78edd76"/><file name="Iterator.php" hash="3a51f92d688197a2967eef55d802f56e"/><file name="Null.php" hash="2e58e92129e83d96b61e5ba5bf679157"/></dir><file name="AdapterAggregate.php" hash="b6ed68617efff6b9dd41ba5d27cde51f"/><file name="Exception.php" hash="bd8961847f8ea166c7e222e2344d586b"/><dir name="ScrollingStyle"><file name="All.php" hash="7a024155b60bcbb024b3ab8418ea1737"/><file name="Elastic.php" hash="a7d8784429dc1e520b3f98d14c5eac09"/><file name="Interface.php" hash="1d6adbef71c9c1966676ede68de7f977"/><file name="Jumping.php" hash="2e2e9f1633d9ec60e0e111a5794aed93"/><file name="Sliding.php" hash="9f768e8bcaf3bd6f12e0e939c00775d4"/></dir><file name="SerializableLimitIterator.php" hash="411f2359e449e170c5dadaa24803a54b"/></dir><file name="Paginator.php" hash="0d3667499c2f0c3a8c9e5907e812b7a5"/><dir name="Pdf"><dir name="Action"><file name="GoTo.php" hash="d1e30bb7d45aedbeaa31b5dc8b40e287"/><file name="GoTo3DView.php" hash="fcd5460403b8433315caeca12418a5cf"/><file name="GoToE.php" hash="599ebb6d2df80852cfca9a9cedb8d6b0"/><file name="GoToR.php" hash="474402a7102d563261bd914a721b36d2"/><file name="Hide.php" hash="8810efbd459a87d1ee9de7cd007d1644"/><file name="ImportData.php" hash="ecd6feef7d654d60b8efc24bf26d4662"/><file name="JavaScript.php" hash="9bdf7f5f8360300bc95e3e293431f425"/><file name="Launch.php" hash="3e3b49828aefff82b9b44b295084e413"/><file name="Movie.php" hash="b65daa361fc8e77f5ffc4ecedb3becff"/><file name="Named.php" hash="7a1ea555152631327d04a9eb263b4a5a"/><file name="Rendition.php" hash="363bd0314e6d20994934dabd3ad63684"/><file name="ResetForm.php" hash="f4637cd51199245ab14aa6021ffe71be"/><file name="SetOCGState.php" hash="301da63cac76237c91818aac076cbddc"/><file name="Sound.php" hash="ee1e489704abce5aa0dee9047bd8b456"/><file name="SubmitForm.php" hash="657a9f4bc9cd87ca3551370d195b7a35"/><file name="Thread.php" hash="ecee0d4d74deafefed77cd0f6798093a"/><file name="Trans.php" hash="d9f99fb44efc3651ca5e2c56fd7e96b6"/><file name="URI.php" hash="7e52db0fd92d4edb87ab4f4e789d45e3"/><file name="Unknown.php" hash="a8602a55e7a0792d6cd0615c9ac23c41"/></dir><file name="Action.php" hash="ec5a813b9a9a0caf8beb63b890c68450"/><dir name="Annotation"><file name="FileAttachment.php" hash="f3864019953d49d9cd83d322f9a54f4d"/><file name="Link.php" hash="bff1663cb2b899d96d2b5e539f516d63"/><file name="Markup.php" hash="ab0f2e3e12ec5c7e75b2daf9851c59d1"/><file name="Text.php" hash="7b507f12f45421db845a74e91a0c78fb"/></dir><file name="Annotation.php" hash="0d098c2160f4b3267e7fd7f367f30290"/><dir name="Canvas"><file name="Abstract.php" hash="364364cb99b19cdf0d622397424e155d"/><file name="Interface.php" hash="1795a31a88af11db1f8eaefae3751d65"/></dir><file name="Canvas.php" hash="00dcbc00ee5b0678292c40c62709bb37"/><dir name="Cmap"><dir name="ByteEncoding"><file name="Static.php" hash="bca21500f7be22a1c6349cce6b489afa"/></dir><file name="ByteEncoding.php" hash="84d9e9e1afe70befb0b7c193516a7ad6"/><file name="SegmentToDelta.php" hash="34570bbef3c618d344e056a65a86310e"/><file name="TrimmedTable.php" hash="1a8eaed30b4393a4ad1972ccfa586275"/></dir><file name="Cmap.php" hash="9d7432c932a1f5260c8752cd0eb09cb9"/><dir name="Color"><file name="Cmyk.php" hash="9024fe208254093dfedb355f1a56bfa3"/><file name="GrayScale.php" hash="ac29a955a5422d31e3c6342c9ba5df7f"/><file name="Html.php" hash="98c75da7b5c1e27d72029a612973c33b"/><file name="Rgb.php" hash="db12cfc9dfbb80831d4b1e5436ff8323"/></dir><file name="Color.php" hash="104cf49d07c358cc85220fc3122e800e"/><dir name="Destination"><file name="Explicit.php" hash="13bd68687766542d36847199a9dd478a"/><file name="Fit.php" hash="1aa3f00fde3170cae69b69bd17786c3b"/><file name="FitBoundingBox.php" hash="b59f2ed44504d9f3df4a8e05450c0f07"/><file name="FitBoundingBoxHorizontally.php" hash="1271088bf2557a2eb8c18f388e1853ee"/><file name="FitBoundingBoxVertically.php" hash="16948b893fe63488b34891f82d409d52"/><file name="FitHorizontally.php" hash="88e880e0528a4f7060d233e687e90667"/><file name="FitRectangle.php" hash="408a9be40986151fff98af1efabe8a28"/><file name="FitVertically.php" hash="136c71dd521fb51103f98a76734fb8c1"/><file name="Named.php" hash="a65c919e6fa48d4453a9581ebb908adb"/><file name="Unknown.php" hash="1a2e8b67ee995941dc43b43070a3971f"/><file name="Zoom.php" hash="c9325d991fc179afcca30c3636e72e1b"/></dir><file name="Destination.php" hash="b7605192c93386f3fd25520d180343dc"/><dir name="Element"><file name="Array.php" hash="b644069461389d8cffe6d3bd1cc49835"/><file name="Boolean.php" hash="d4a4de598d871b0ae391dd72ee4cbd2a"/><file name="Dictionary.php" hash="fa2156732ab46185f1412c3e22c54c92"/><file name="Name.php" hash="be8084d6e0fec7b6941bfcb2cbc93535"/><file name="Null.php" hash="a982c3b2f79e698e80cccc4cd794219a"/><file name="Numeric.php" hash="020e5a151377a7f95b0ab846f4cf5829"/><dir name="Object"><file name="Stream.php" hash="9a4d7197a43ba30df5e1871cf85a05f2"/></dir><file name="Object.php" hash="f0b69fb983587a2f68a1f40e3e417663"/><dir name="Reference"><file name="Context.php" hash="e15ad61d18c94f11179594e9a58cb6d3"/><file name="Table.php" hash="6a90fd67ff295547877255bf8bfbe2a1"/></dir><file name="Reference.php" hash="0725ddc6094e61656354a949986d4def"/><file name="Stream.php" hash="166a0bef11c118de4591b7436a9e999f"/><dir name="String"><file name="Binary.php" hash="f6a6e7ce998124ba104470dcb4734dec"/></dir><file name="String.php" hash="e776be7acc388a17af23bec80954de82"/></dir><file name="Element.php" hash="3595c5f91616d00f51af614feafda5f5"/><dir name="ElementFactory"><file name="Interface.php" hash="d1a6e36aaeee2b4a4a7f8b6111facbec"/><file name="Proxy.php" hash="a07e4d22cba4810f367ca6b7240fbc83"/></dir><file name="ElementFactory.php" hash="024f30704c4c693597c11f4b032dfedc"/><file name="Exception.php" hash="7b3b6c5890b43cd2fb05b68f6282f521"/><dir name="FileParser"><dir name="Font"><dir name="OpenType"><file name="TrueType.php" hash="b493bcd28a5c4006be3f5c0a1081b28c"/></dir><file name="OpenType.php" hash="a5d6ab27fa54d414b01532d4830ef090"/></dir><file name="Font.php" hash="56634e0dcb7ade369b564643c5a5d171"/><dir name="Image"><file name="Png.php" hash="15d071e3ce65f9eb9936ca4149910fb7"/></dir><file name="Image.php" hash="29748c74077a30e3b3d108c316ee1910"/></dir><file name="FileParser.php" hash="4d54f7155401a9fb7df70998a2da9a50"/><dir name="FileParserDataSource"><file name="File.php" hash="1e9148d68ab81b33f2d88c403d9495a5"/><file name="String.php" hash="e4cd122d052ef39e6da5c38ec452d161"/></dir><file name="FileParserDataSource.php" hash="eb883b69beb455a62c8931a878151085"/><dir name="Filter"><file name="Ascii85.php" hash="b65b7f97285f88f9f11265191cf20849"/><file name="AsciiHex.php" hash="ed846de8708cd7026f551d78de57782d"/><dir name="Compression"><file name="Flate.php" hash="faf5cfc2e9c94444e43d7e6944247988"/><file name="Lzw.php" hash="9c28f750f6600ce94877b78ad7c71324"/></dir><file name="Compression.php" hash="73050021440ac2c7b18bd20513157c3f"/><file name="Interface.php" hash="e90f59d18816fbaacd86b59b392686d4"/><file name="RunLength.php" hash="e80a6edbe6fa87c4702d09d65db1a2ea"/></dir><file name="Font.php" hash="51087d7787fad796537357c3ac69dc73"/><file name="Image.php" hash="7877b76dd9e150104b83037266258658"/><file name="NameTree.php" hash="da4cc3e1566938790d1c613174aa23eb"/><dir name="Outline"><file name="Created.php" hash="9d373dc681d5b2805d30b5685ef862c2"/><file name="Loaded.php" hash="d6d0bcbbbc7125de10670b4e6562b59d"/></dir><file name="Outline.php" hash="f26766891dc3d3bce49b037adcfef12e"/><file name="Page.php" hash="13f4483dfd5d93e7e94d273c662b46ac"/><file name="Parser.php" hash="ba36ebc92a1b6e525ed8c0408e251bef"/><file name="RecursivelyIteratableObjectsContainer.php" hash="715f93a595f54a38111141fd5968213d"/><dir name="Resource"><file name="ContentStream.php" hash="a1749fec0cba8e9cb72efb1304de2346"/><file name="Extractor.php" hash="bb8efb4919fa8775f711f61d183a4e12"/><dir name="Font"><dir name="CidFont"><file name="TrueType.php" hash="1290b18c2ed5643477c1e88b0c76987e"/></dir><file name="CidFont.php" hash="382f00c4a207bea2ffd82a5d77da6304"/><file name="Extracted.php" hash="bd8bedaf4a31c4ae1eddf944644ecce5"/><file name="FontDescriptor.php" hash="9fcedd31b44153c7ad83cae939397e42"/><dir name="Simple"><dir name="Parsed"><file name="TrueType.php" hash="e060a25bc471d15d43a51d580679326d"/></dir><file name="Parsed.php" hash="becce62602415adde90984b7590993ba"/><dir name="Standard"><file name="Courier.php" hash="1a8795c6738e56ecc9b223ed823c0e0a"/><file name="CourierBold.php" hash="271652240d7b89827820060a185aef0d"/><file name="CourierBoldOblique.php" hash="f8e6fa84ffdc7ffcb8069c67e813f09b"/><file name="CourierOblique.php" hash="7b4080d45eff2b8fd5d66db97512a8bd"/><file name="Helvetica.php" hash="fdf4947a20fbf3f694f4fe940cec5df2"/><file name="HelveticaBold.php" hash="1340145daef0b6ed9e4d15ede06a0530"/><file name="HelveticaBoldOblique.php" hash="ae26d6990824525b0cb3c99e87674000"/><file name="HelveticaOblique.php" hash="a05d94e11e3e1db842ac7f1795074373"/><file name="Symbol.php" hash="9443a7d26e4c2a752cf3f4ff883ffa05"/><file name="TimesBold.php" hash="b2619f7edcc8abab8ff28a4009123f84"/><file name="TimesBoldItalic.php" hash="433fcd37d348fa4458cf437ea2cdabad"/><file name="TimesItalic.php" hash="76ec1fbba59e77bb848f8696337aadf0"/><file name="TimesRoman.php" hash="953b76c5e03a7858bd8361872e412ded"/><file name="ZapfDingbats.php" hash="548d057f0040392a4828264f24e243cd"/></dir><file name="Standard.php" hash="f332565c96e87d79436790a096f46aef"/></dir><file name="Simple.php" hash="334a3b36ea5235902d79cdb31cd05d73"/><file name="Type0.php" hash="6c0a83ed854fdbb16bf525fcd219a4ca"/></dir><file name="Font.php" hash="6046881c1057ef05d0a420998a05c1a4"/><file name="GraphicsState.php" hash="b51172933cdb59ea271e7a9ae323fe29"/><dir name="Image"><file name="Jpeg.php" hash="0a1a368f9642c0b98d8ff24f0aae7c3e"/><file name="Png.php" hash="f77b42c714316c69714df0a2a94cfb7c"/><file name="Tiff.php" hash="06e9fd0b542ecc53649d868fbb59372b"/></dir><file name="Image.php" hash="dbec25fbc65e673b12f311785249ae4f"/><file name="ImageFactory.php" hash="45222c4b5170b11e9b1fc9f16700f1a2"/><file name="Unified.php" hash="710f5f418d4939a609144eab68a8b797"/></dir><file name="Resource.php" hash="b71cd04a74a88e040f06ea7663ea5e65"/><file name="StringParser.php" hash="5376c86288c13e706f2c76478ae474f5"/><file name="Style.php" hash="8aceb18b61204e8157a46c41bbcdd7e9"/><file name="Target.php" hash="1a2badb1e3ca52a2368a77b0646efef7"/><dir name="Trailer"><file name="Generator.php" hash="2c12f38db376c57935d09f8527fa786d"/><file name="Keeper.php" hash="df14918b0e392a71bd41817f0abfaf55"/></dir><file name="Trailer.php" hash="8069878c1e9320d2b8533cf1e144f4f5"/><file name="UpdateInfoContainer.php" hash="39f4700c55860bb9ec1b3f122258930f"/></dir><file name="Pdf.php" hash="7f96ca856c0dde6e6074711e0db2487b"/><dir name="ProgressBar"><dir name="Adapter"><file name="Console.php" hash="09f7268da0ecd77f2d174f4a8a3de869"/><file name="Exception.php" hash="6a2ed89846b42f86a235044d05555198"/><file name="JsPull.php" hash="582d2e3d4fe457d4c961701b014886d1"/><file name="JsPush.php" hash="229b568b05cf46950fbb3707ca150c01"/></dir><file name="Adapter.php" hash="8297cf770c0ee628158397e3b089c621"/><file name="Exception.php" hash="6fd9c59515c836a7e044c07b146c1e6d"/></dir><file name="ProgressBar.php" hash="581036cf36019829ad17b626f15344f8"/><dir name="Queue"><dir name="Adapter"><file name="Activemq.php" hash="b419df4c2da5f1188e2f9fc07fa17d6b"/><file name="AdapterAbstract.php" hash="77fdf9a85df53d3a3b2a2f5d22e80626"/><file name="AdapterInterface.php" hash="0dcaaa3d94f0c384a3c37e45c7529b3e"/><file name="Array.php" hash="b3227f915782241e3ebdce389d3f0a18"/><dir name="Db"><file name="Message.php" hash="017e049117119a01fd2acf00fac7c5c4"/><file name="Queue.php" hash="0036c67014f3b5787878ecb638088423"/><file name="mysql.sql" hash="487d5a36b9172382351a7cc39d20d221"/><file name="postgresql.sql" hash="42dfaf91f8a425170c9b4b2c9318c875"/><file name="queue_sqlite.sql" hash="b0e5a2e43dfc9a230a5ec397c351eaf1"/><file name="sqlsrv.sql" hash="646346084e937e9239d911485bc0296c"/></dir><file name="Db.php" hash="876370736f86a93dedc206bdaea8ac05"/><file name="Memcacheq.php" hash="f0a6604c99debe72daf655a2f97ddc03"/><file name="Null.php" hash="abbd08fab4a38429460cd70b6170c492"/><file name="PlatformJobQueue.php" hash="0e9187b14fcb15711fc18e6bf0dd1383"/></dir><file name="Exception.php" hash="279bbedb61b1778812827fb636c62bd2"/><dir name="Message"><file name="Iterator.php" hash="11ea9382769f547d17a66ac1a54d655b"/><file name="PlatformJob.php" hash="2988e7c33a68ff837ffd7dcbd835de3c"/></dir><file name="Message.php" hash="fb9762a45a532513ff209e2b4820f871"/><dir name="Stomp"><dir name="Client"><file name="Connection.php" hash="aff6c9c41035654ec0d4a4887b4dd218"/><file name="ConnectionInterface.php" hash="e4adc375b6e177fafbd45e47b93ad1b1"/></dir><file name="Client.php" hash="1d64509385a30e21abb7df5e31aa11ae"/><file name="Frame.php" hash="d909edb1b42697e4f557de5a68368932"/><file name="FrameInterface.php" hash="16c13ddfcf2b1bcc50b85c61dc546646"/></dir></dir><file name="Queue.php" hash="1c9e3ec5bc7508a98b7de1f77ee61ba2"/><dir name="Reflection"><file name="Class.php" hash="ba4973471396d116ba92824b47d313a8"/><dir name="Docblock"><dir name="Tag"><file name="Param.php" hash="2a51f3907ad2ee281175d3cdb28a2e6b"/><file name="Return.php" hash="b0200cc0b804828031ab3a8582dbdcad"/></dir><file name="Tag.php" hash="0eebe17d3442b754d9422f8c9721231f"/></dir><file name="Docblock.php" hash="d0856efe818bee5c5d39645662312ba6"/><file name="Exception.php" hash="c43315831b3596fc86aba74529571aad"/><file name="Extension.php" hash="f4dd6dbfb0d48aabdbf359fa6bfaee9b"/><file name="File.php" hash="47206736078efdd5eefc6527408bd922"/><file name="Function.php" hash="1713773cab56cf753f7f90a1108953c8"/><file name="Method.php" hash="25ecb48f4e4f7029ea6fd759fba663f9"/><file name="Parameter.php" hash="7a34d5982a0dec35c6323160114dcb62"/><file name="Property.php" hash="7ca9b4aca176f18bf89b711b5f0929d3"/></dir><file name="Registry.php" hash="3b697b3b783d2821e69137c4dc3851b2"/><dir name="Rest"><dir name="Client"><file name="Exception.php" hash="2e86578bbe604d335a622957c1b0ae26"/><dir name="Result"><file name="Exception.php" hash="49193abd246224f975676b9bdd41349a"/></dir><file name="Result.php" hash="ffc3f1ee709136ab403949d4274098e1"/></dir><file name="Client.php" hash="b76ff6282552bcd098403cebc7b08ed6"/><file name="Controller.php" hash="86e1b0b6bc3ad11653dfe9e17c7d075f"/><file name="Exception.php" hash="c62bd750b3b4cd33407d99869c600d14"/><file name="Route.php" hash="20875e10d835e380c294d2edfb56b08f"/><dir name="Server"><file name="Exception.php" hash="235457f9f3a4f7720ac2013b51ad4ee9"/></dir><file name="Server.php" hash="ceb61231f7fc67faa657837a9fb2c9a3"/></dir><dir name="Search"><file name="Exception.php" hash="915c3138aac999bdce9426a8acd40556"/><dir name="Lucene"><dir name="Analysis"><dir name="Analyzer"><dir name="Common"><dir name="Text"><file name="CaseInsensitive.php" hash="307dc051465ca81322c5e85e8ec022cc"/></dir><file name="Text.php" hash="758df150a1df6eba4b64004148a672a4"/><dir name="TextNum"><file name="CaseInsensitive.php" hash="e5940381671ed3f7c321b3fda9862881"/></dir><file name="TextNum.php" hash="36acd4b130e2f8b78e2de06ac9b4f942"/><dir name="Utf8"><file name="CaseInsensitive.php" hash="44697c595e22b385d0a7616e7af30ac6"/></dir><file name="Utf8.php" hash="1b7f394340ca0d04c8e6a19fe22d4d23"/><dir name="Utf8Num"><file name="CaseInsensitive.php" hash="9325aa4566ece4546b23c82d1aedb57d"/></dir><file name="Utf8Num.php" hash="76dfe3f7ab2e55f1e8190054dd788790"/></dir><file name="Common.php" hash="04cd47fabbd6c404aff39664da13df9a"/></dir><file name="Analyzer.php" hash="85a3a397e4d2c53d185523e25e7ae53a"/><file name="Token.php" hash="b7c5544e368acd06d81d7539983ed85b"/><dir name="TokenFilter"><file name="LowerCase.php" hash="d3be32b9f01fa4343a427721fc3b82b3"/><file name="LowerCaseUtf8.php" hash="9293ea00a25a3e7f129723c9f74b3b9a"/><file name="ShortWords.php" hash="1e296157ac5b8dc2f80a441811707202"/><file name="StopWords.php" hash="c935b1d071ab560816f3a591e3a662e9"/></dir><file name="TokenFilter.php" hash="7e7caefe49ee420c8b5c1561e84f012e"/></dir><dir name="Document"><file name="Docx.php" hash="e6730cac4ab560138c45c9db700d28f0"/><file name="Exception.php" hash="d1f92a2cc3ea06517d5626e96429a5af"/><file name="Html.php" hash="64e7ae4d564af7e71f44c01e48c8e03a"/><file name="OpenXml.php" hash="b21a3c28a95e7a0c9980db28bbc65842"/><file name="Pptx.php" hash="5a2b150c6c2a98b80e1e7765cec8297e"/><file name="Xlsx.php" hash="cae7aa77e2e49c47ecf8a89f169c629f"/></dir><file name="Document.php" hash="81e9c33cd2320e8344181ac5bf78819c"/><file name="Exception.php" hash="2d392bf05fe81a16cd8a3b10618bc6bd"/><file name="FSM.php" hash="5009e011f0b10421ef6e9c6b2c509753"/><file name="FSMAction.php" hash="54cc85832b139caef30d62a66a8008c5"/><file name="Field.php" hash="62d99dc9804e4f352bb55f69a61e5764"/><dir name="Index"><file name="DictionaryLoader.php" hash="dd18c7bb937d629cd0960ba4e8156307"/><file name="DocsFilter.php" hash="a464c3ab082438689658bd370ea21887"/><file name="FieldInfo.php" hash="49cdf39b3445b209adc9370a9970d834"/><file name="SegmentInfo.php" hash="3e9803053f230d7309cce21a643c9e76"/><file name="SegmentMerger.php" hash="335a52ca7e40a79dd6cb95f72cbaa140"/><dir name="SegmentWriter"><file name="DocumentWriter.php" hash="5061bbd3c4b375f3304813ff93a6401b"/><file name="StreamWriter.php" hash="0f6d8ea058813929a7448a4958a3c7c7"/></dir><file name="SegmentWriter.php" hash="13a8736ed2991f513e57f68e61926a76"/><file name="Term.php" hash="490ae3da5ccd138e9b060792766646bb"/><file name="TermInfo.php" hash="4930aa466ba2eb3b65dae3c02aa03221"/><file name="TermsPriorityQueue.php" hash="32663e0ebb7d0279bbcea377903c12df"/><dir name="TermsStream"><file name="Interface.php" hash="751e8ab0d56bb26f7b795d9530dd2494"/></dir><file name="Writer.php" hash="b7ef933d12a1b2f5376584b2420d7976"/></dir><dir name="Interface"><file name="MultiSearcher.php" hash="3f40f5b499a8ee03957fb21aada499da"/></dir><file name="Interface.php" hash="a78e2d90755e526ac9db7eb1c4185f3a"/><file name="LockManager.php" hash="5f61443ba5976b5fa021fb36bba30371"/><file name="MultiSearcher.php" hash="2fde43036355b990e0ac0227a00b6c8e"/><file name="PriorityQueue.php" hash="5c915507c33213ddb4b4ac613f1f68c9"/><file name="Proxy.php" hash="11944c7b4d9879615fd4f3a5d768aed3"/><dir name="Search"><file name="BooleanExpressionRecognizer.php" hash="3896532815243d89040fecb2fd65f606"/><dir name="Highlighter"><file name="Default.php" hash="b1dbdc2d70bb032a5d2b9f9e11273ea0"/><file name="Interface.php" hash="7dca815c9e9f444b9a2a9765fe349dd2"/></dir><dir name="Query"><file name="Boolean.php" hash="5be6706e75dd3e9ccdfaa0eb22f93ca4"/><file name="Empty.php" hash="2e16007df371f28191f785ab85d4d103"/><file name="Fuzzy.php" hash="e66032fc9f9cb06422cac6da95f7b8f6"/><file name="Insignificant.php" hash="1f61e2f1ef8ff38101f2a85c87b9529e"/><file name="MultiTerm.php" hash="ec939add6f7d0424029b12106385afd0"/><file name="Phrase.php" hash="424cc7d460f4bac0907d0170b60ba625"/><dir name="Preprocessing"><file name="Fuzzy.php" hash="cae1047630f98baf520483fa68af463a"/><file name="Phrase.php" hash="d8afc95f2e9da2a44d9495cbce775c98"/><file name="Term.php" hash="b099d749d723fbb53d3991e3f61458be"/></dir><file name="Preprocessing.php" hash="83dba0878c9ed171628b7a9ac70d26b3"/><file name="Range.php" hash="d8bda3ad418d24e0db7e59c446be13fc"/><file name="Term.php" hash="54e883c87d7368fa5be1e105723db357"/><file name="Wildcard.php" hash="9c1c8ebeca45a6332ede6fab8d5bee54"/></dir><file name="Query.php" hash="2a9f2ceda3cfacd24f892dd8bccd8d28"/><dir name="QueryEntry"><file name="Phrase.php" hash="407da910b0015ff8d95432cc193d608a"/><file name="Subquery.php" hash="a33d941498f632d859bec94a1cb9c10b"/><file name="Term.php" hash="808b02c1c1aeae4316fee3c9c466facf"/></dir><file name="QueryEntry.php" hash="9620d76904656a0727091f449603c662"/><file name="QueryHit.php" hash="6d1727ed01abc54503badc7176955882"/><file name="QueryLexer.php" hash="57a592ea29129b28d1144063e152c878"/><file name="QueryParser.php" hash="569f6439976128dbc471bd42fa9511d9"/><file name="QueryParserContext.php" hash="45c71a353821fc29101c1ae2f8eba02a"/><file name="QueryParserException.php" hash="358f89eaca92ac3175b26c419b317640"/><file name="QueryToken.php" hash="f85c3ac0ab04b5abff04d034cf127f43"/><dir name="Similarity"><file name="Default.php" hash="43f6f75cb50b7c7f344a5bac85ef172a"/></dir><file name="Similarity.php" hash="194c9c6c1c2815a8491952ece299ef9e"/><dir name="Weight"><file name="Boolean.php" hash="537c06e5f44c3d014d98a88a39c834f3"/><file name="Empty.php" hash="0bfe83149630af587846c7d5df63e72b"/><file name="MultiTerm.php" hash="c95f65634ed9d8c2896f5ba66a833f10"/><file name="Phrase.php" hash="51bc4912b1784bfa58841e4bf14fb177"/><file name="Term.php" hash="2e0f6fc3511928f1e94349d375dec8b8"/></dir><file name="Weight.php" hash="49ece1259ec183d66d2a1ccc8c319299"/></dir><dir name="Storage"><dir name="Directory"><file name="Filesystem.php" hash="7928063a85bf3c53e2afd754c111cc6b"/></dir><file name="Directory.php" hash="25a0d0c262a3c4fa7dbc3f1f11f0a4ab"/><dir name="File"><file name="Filesystem.php" hash="5c2819323a9878475d31eba6992e6abd"/><file name="Memory.php" hash="89bce18491ebcd885736c5c9a790eab6"/></dir><file name="File.php" hash="2b77f8354d79c7dd57330677651f8fc6"/></dir><file name="TermStreamsPriorityQueue.php" hash="a26104e3325d2533afffdfc66dd1ead0"/></dir><file name="Lucene.php" hash="fe6103d1d763df12d670dfe5103defb7"/></dir><dir name="Serializer"><dir name="Adapter"><file name="AdapterAbstract.php" hash="8bd5c797ff2230e804b916545a67694b"/><file name="AdapterInterface.php" hash="cb397638959459eef297b8114ebb0504"/><file name="Amf0.php" hash="734f3143371bffe28f65e144f1d4fde3"/><file name="Amf3.php" hash="05a939a59cad0622a7627572f931e909"/><file name="Igbinary.php" hash="dc0da7256a83c6f0a06582b21b160156"/><file name="Json.php" hash="e62019ed95f69a184f735f1d3d4d32c0"/><file name="PhpCode.php" hash="731fc343849f966c1b532284822060a6"/><file name="PhpSerialize.php" hash="d7bc5453b1c516a6895e62fee2f94ec7"/><file name="PythonPickle.php" hash="8eaa4d904fa3ac33cc3d405f6eeb92bf"/><file name="Wddx.php" hash="4321621736a7d3940a27357608c66c28"/></dir><file name="Exception.php" hash="dd736f6d29e3a1f8d688bdf6b24f8d30"/></dir><file name="Serializer.php" hash="47d6232a605b0fc1b0dfd5bc6738d4a4"/><dir name="Server"><file name="Abstract.php" hash="878b796b9b09bac46361e73e3b76943d"/><file name="Cache.php" hash="8851d8d1c35c11be49192fc875141632"/><file name="Definition.php" hash="c37f863e7395e761f9601a4f918f0fc9"/><file name="Exception.php" hash="1ad53d7cdaadfe1377fe30f61814ce33"/><file name="Interface.php" hash="ef219942e75a7dd72f757ae0fee1fe94"/><dir name="Method"><file name="Callback.php" hash="204c77c05f77dab719f7e8d4d9940990"/><file name="Definition.php" hash="6a7435cbdd3791b656f0f7945e68e724"/><file name="Parameter.php" hash="5bb143b2c5472570019deb5c8df7e13e"/><file name="Prototype.php" hash="e6926328f51c97152380eef1cb9503a1"/></dir><dir name="Reflection"><file name="Class.php" hash="7c3040f1cdaa12303fa3aa8a87bbee33"/><file name="Exception.php" hash="81a1918244112e6992e608c37a128f81"/><dir name="Function"><file name="Abstract.php" hash="baf97034eb2f6541a0b04448cdb0c8ee"/></dir><file name="Function.php" hash="b931e2381290e01a62197a41f7d4a43e"/><file name="Method.php" hash="2589efa5b95e88475509c07460869c1a"/><file name="Node.php" hash="a764c4cdbcfd48911882e73801f55c9f"/><file name="Parameter.php" hash="2cb12fe3fdca85cb9056909277002912"/><file name="Prototype.php" hash="c8f4e9fc01efed6ef3b5a10bab70ddc5"/><file name="ReturnValue.php" hash="bd7392e46dac77ad14597e24fbe9297a"/></dir><file name="Reflection.php" hash="7b01bebd0c5e02694d94946a7ff4cd2a"/></dir><dir name="Service"><file name="Abstract.php" hash="057d0faabba16e34faa0ed6d43ca61af"/><file name="Akismet.php" hash="c63f5c6b7b1be4b2bbedb84a7f026bf7"/><dir name="Amazon"><file name="Abstract.php" hash="16b70230ca4bf9fd43feaedc24416f7c"/><file name="Accessories.php" hash="c0f666b47ccd5ca407ca7ab3e62a28cd"/><dir name="Authentication"><file name="Exception.php" hash="f1ba0e03f16bf019c0246384f6797093"/><file name="S3.php" hash="35c859c9bf7221844df79260142e3e55"/><file name="V1.php" hash="a4f6e5db52a4ae4b8200ac26b1bc413b"/><file name="V2.php" hash="b91365a27a1019d793f3821d50cf0209"/></dir><file name="Authentication.php" hash="5e503da9b9bf0a83fd61326aabaa7bc2"/><file name="CustomerReview.php" hash="970806dbbd0244f317183a7d121dd23b"/><dir name="Ec2"><file name="Abstract.php" hash="add0a48733a5b51010fab03133fcf8a9"/><file name="Availabilityzones.php" hash="0df01ed765ce15c35a783a66d7f8ff44"/><file name="CloudWatch.php" hash="e601ca48308ac50dc3727f992f7e62dd"/><file name="Ebs.php" hash="1f82b128c7b5d35d37b3024b6c42f712"/><file name="Elasticip.php" hash="bfad9fcffa9bcd6ad7d7cff8cec45c64"/><file name="Exception.php" hash="b212f735d14f127feb9a33d220bf2261"/><file name="Image.php" hash="335cf797d7a3a3d49e029ef7ce991bca"/><dir name="Instance"><file name="Reserved.php" hash="6027f89632821d100f27363ffbf293f3"/><file name="Windows.php" hash="f823795a24808167f1b87d91ece5cd1a"/></dir><file name="Instance.php" hash="52e9fb6d557898648a7dd9c71bb9100a"/><file name="Keypair.php" hash="e035010eee1a949d1d2b5b1ddd43e5a6"/><file name="Region.php" hash="7283cb6f54f68c09949e4c0535ed8a3b"/><file name="Response.php" hash="ad34c2acb59516d6075d12294fcf6bd3"/><file name="Securitygroups.php" hash="68c70053d0e4284169a5e2c49cb2ef2e"/></dir><file name="Ec2.php" hash="4a39d1eb801af3fd096582c2428e1371"/><file name="EditorialReview.php" hash="edc54626cf681ff42bdbc3207063e50a"/><file name="Exception.php" hash="25e8e93c6e940a70c57e0d4b6b35271c"/><file name="Image.php" hash="8cb0ff1afc2b9f99b7e4db1c61c27e99"/><file name="Item.php" hash="49164d984e1888291b9a1b0b82df2204"/><file name="ListmaniaList.php" hash="d319a0d6c264c92c22196d6a9a84762e"/><file name="Offer.php" hash="a04c4d2faf859a590fe2e74ef0440429"/><file name="OfferSet.php" hash="cce61ade0766251d602204b65ad5f73e"/><file name="Query.php" hash="a8a6c152fa729f7047f352552bee7367"/><file name="ResultSet.php" hash="b15520c352dfb95481aa26509c84211e"/><dir name="S3"><file name="Exception.php" hash="2fa452933db70802a191be880cec481b"/><file name="Stream.php" hash="62544ad7a8d493023c4a62272a68d4f5"/></dir><file name="S3.php" hash="224a86bfc54f7c6df36b8d5eb3febbd0"/><file name="SimilarProduct.php" hash="abcd839cfcc6c194e0b2ee0461216e12"/><dir name="SimpleDb"><file name="Attribute.php" hash="329401b2dac2ad11141f5077093ce70a"/><file name="Exception.php" hash="72cd6853d02b6c4335292d38f310ea54"/><file name="Page.php" hash="4c6b5dda8a61a932584eaf332ba25ae4"/><file name="Response.php" hash="763d18b153c7296ae4a1acc9dd52fea6"/></dir><file name="SimpleDb.php" hash="26a2419a5c73550f8ef47ac2a7c161ce"/><dir name="Sqs"><file name="Exception.php" hash="4d8c014ecb492938b3234fb250dcc21b"/></dir><file name="Sqs.php" hash="e5a368178455cc62f0c1e6272876e31f"/></dir><file name="Amazon.php" hash="8bf9c8bd3d16372566cc6dda58d26f57"/><file name="Audioscrobbler.php" hash="0931bdaeda5594a4b367fd4901b5444e"/><dir name="Console"><dir name="Command"><dir name="ParameterSource"><file name="Argv.php" hash="6acc204436c9d0de0d1e5d2063dff1d3"/><file name="ConfigFile.php" hash="0ac0fcf2907eed649d9f720d9c98cfb1"/><file name="Env.php" hash="83579d583b977fb4a890933d5795588f"/><file name="ParameterSourceInterface.php" hash="c1161355277be3eefdadb4853d8ee1b2"/><file name="Prompt.php" hash="8a9b67aa3eaa61b7ff33aa0110b129fd"/><file name="StdIn.php" hash="fd5c89a584ce532ae64ce2e607e28e02"/></dir></dir><file name="Command.php" hash="c94204e49bc285a615c281253cb41641"/><file name="Exception.php" hash="e1a199ba28f3255efc3ad5f0c272d247"/></dir><dir name="Delicious"><file name="Exception.php" hash="8b4644f2ad354c3e8c668bf6f4d8757c"/><file name="Post.php" hash="00f3ca873d1da362fe1ed121b1d18c32"/><file name="PostList.php" hash="41dbf9ff7c15a8eaec5153cebc705bb2"/><file name="SimplePost.php" hash="9ae5bac1252734db8bda2c2cbceb901c"/></dir><file name="Delicious.php" hash="2f725816f82a4ba6ebeace7bcaf6e0ff"/><dir name="Ebay"><file name="Abstract.php" hash="2e334688b614c983b6a7ce3592e08899"/><file name="Exception.php" hash="83aa9409ac7d1e2bf9fd83e86c39a6c6"/><dir name="Finding"><file name="Abstract.php" hash="7238678f990b585b50271ceafe5058f3"/><dir name="Aspect"><dir name="Histogram"><file name="Container.php" hash="45aab272db8949fc7ef41c1f5b9a5d65"/><dir name="Value"><file name="Set.php" hash="6a00192243d8ab215f368459e932d145"/></dir><file name="Value.php" hash="ffd36e8de497a77bd42cccb63ce3235b"/></dir><file name="Set.php" hash="c39339e0e65827c882eac9fa8d4d4fff"/></dir><file name="Aspect.php" hash="df96cb57c1c2b88a8244384894f1b9dc"/><dir name="Category"><dir name="Histogram"><file name="Container.php" hash="e99d9fdf2028e7f627fa7692d6e5e5af"/><file name="Set.php" hash="d10aeaf449c591a7884a38a1b5f90399"/></dir><file name="Histogram.php" hash="5fda3e21a2a68bbca36838425d54c454"/></dir><file name="Category.php" hash="aef46c1abec0621af48a4398de94bca0"/><dir name="Error"><dir name="Data"><file name="Set.php" hash="51d6f2c75eb549150dbb4255a747e238"/></dir><file name="Data.php" hash="06579aec01d55e0e27e48b66b32814a5"/><file name="Message.php" hash="f0082bf2e41b9fa997891d55536d6c94"/></dir><file name="Exception.php" hash="0d04308f626b6d80255403034766b93f"/><file name="ListingInfo.php" hash="37689bb7f7f1312e0a8690b1ec55d17f"/><file name="PaginationOutput.php" hash="dbd144ea4155492ca485092140ed7342"/><dir name="Response"><file name="Abstract.php" hash="13c8ef07cd6c8b9e0b54b183099d3c2d"/><file name="Histograms.php" hash="7e67ea07bdf9e34cb277b87cdad8db8c"/><file name="Items.php" hash="87e78262a0463b3689f75ade1a97bf0d"/><file name="Keywords.php" hash="501b1eb2db688abcb8926a924b2467c4"/></dir><dir name="Search"><dir name="Item"><file name="Set.php" hash="72dc95aa03723a96c6ad4e16bb6c1f04"/></dir><file name="Item.php" hash="8cc709c5b81a662e1b42f6fdcfbcd057"/><file name="Result.php" hash="bde45f1eff1c6745093e1fb16a25fa21"/></dir><file name="SellerInfo.php" hash="0a3e7e31682c1b4139860b692e3a7a93"/><file name="SellingStatus.php" hash="40cc9f7feb5534c9b7ffd77cde164d8e"/><dir name="Set"><file name="Abstract.php" hash="d68b570966c8c13d07ecc8e1c093a3f8"/></dir><file name="ShippingInfo.php" hash="ef20bffb5c3917bd631a79f6520aaa47"/><file name="Storefront.php" hash="59e0796869417ef09b2fabf17a0f51a2"/></dir><file name="Finding.php" hash="38297aa7141bd29cb58f499a6f301958"/></dir><file name="Exception.php" hash="065ed88e73a47544f5432781b553b095"/><dir name="Flickr"><file name="Image.php" hash="c18c420085a325a88aa32c6e8940febe"/><file name="Result.php" hash="3dae64d1fed5642f400e5a3ed34001e0"/><file name="ResultSet.php" hash="1141813d476af74ac4482982352df257"/></dir><file name="Flickr.php" hash="80ee3a6a56f644931629923efaa74f58"/><dir name="LiveDocx"><file name="Exception.php" hash="b7c0f8f23822ab34863ae7c8ba65fca0"/><file name="MailMerge.php" hash="9c3df9f5097d2426f98f3e4afd5417b2"/></dir><file name="LiveDocx.php" hash="bb79b5d68e67e91aa7c6678cf9d33fe5"/><dir name="Rackspace"><file name="Abstract.php" hash="38c670e3ba06278b4fed19a7a20ffa09"/><file name="Exception.php" hash="0e02a57f8eb16972b101ec5b2d5ee5c8"/><dir name="Files"><file name="Container.php" hash="59b5965b06c12c8f32f191d6d81578ed"/><file name="ContainerList.php" hash="60cab750d4475f791b0f6ef9487b2b5f"/><file name="Exception.php" hash="ff4c1a6d5b3c15b0134eea798aaebb5a"/><file name="Object.php" hash="fa7d117f207e2a26dfa5db744a098cdf"/><file name="ObjectList.php" hash="d2eaf4ebe570b3ca456844b294cfc6f6"/></dir><file name="Files.php" hash="fba4bd666821a5eec5cf17f5f91dd15a"/><dir name="Servers"><file name="Exception.php" hash="90e7248491ba6728731b35821a6797b3"/><file name="Image.php" hash="6977cee9fc642f32c2a3dd9b99739ab6"/><file name="ImageList.php" hash="0bc789d18d41f62ae1db82159487edc0"/><file name="Server.php" hash="73f6c2a5e062bf36b3b89ed8d1041eaf"/><file name="ServerList.php" hash="f76bf22857872982ce35e7afa2ea49f1"/><file name="SharedIpGroup.php" hash="75bc0d1b089228114a5bdbbc764f6799"/><file name="SharedIpGroupList.php" hash="97feec662c70d87bf02c0dd689d59962"/></dir><file name="Servers.php" hash="d7c9cd6f524ef033e9c4836623171ad4"/></dir><dir name="ReCaptcha"><file name="Exception.php" hash="e49c53a3c431f49911028b571a76bc06"/><dir name="MailHide"><file name="Exception.php" hash="fc56e06dc9697c40498f1015c0e76c08"/></dir><file name="MailHide.php" hash="ff143c31b0aaac1c852ae438ccc57a4a"/><file name="Response.php" hash="10d73062279da9040e445fe8d1820c36"/></dir><file name="ReCaptcha.php" hash="518a917f321d64422010babcdc82921a"/><dir name="ShortUrl"><file name="AbstractShortener.php" hash="7e0fa90e0324b377677bd8847412ffa5"/><file name="BitLy.php" hash="3e07fa8e265d44e7225af2f11ac75607"/><file name="Exception.php" hash="fa58bd8ee297581ecafe8e15d9c41858"/><file name="IsGd.php" hash="5d18b0c134f1da253893391c720144e7"/><file name="JdemCz.php" hash="6892d0e3e81cc3aeca234d4fb5164ac5"/><file name="MetamarkNet.php" hash="747c5d10917401f1d0d11ba38b1af8e2"/><file name="Shortener.php" hash="64e2ceca93f66c375605e62d6431a628"/><file name="TinyUrlCom.php" hash="1b7f09510d1b029c117e6c59c5419714"/></dir><dir name="SlideShare"><file name="Exception.php" hash="67b547c02b4b9c9440f5c11e570171f1"/><file name="SlideShow.php" hash="9d01060ec6c7a7583a21c824a3e74e21"/></dir><file name="SlideShare.php" hash="1cdc74e57a3be59df8d702bc3d9f7362"/><dir name="SqlAzure"><file name="Exception.php" hash="24d9e2d3dfca7d6ce54137652027152c"/><dir name="Management"><file name="Client.php" hash="e46b9564db9ae2344357919b4760ac4f"/><file name="Exception.php" hash="731e875bfd4df360b37ca082877bc1c6"/><file name="FirewallRuleInstance.php" hash="f564f5454ee9cb2b1ffa97499124d0e7"/><file name="ServerInstance.php" hash="7f3198f120d54ca4b70b5f58399cf0ab"/><file name="ServiceEntityAbstract.php" hash="72ca3fc5ef5341bf549685beb08dad5f"/></dir></dir><dir name="StrikeIron"><file name="Base.php" hash="0b1451704136ab44598ac7204bde94a1"/><file name="Decorator.php" hash="68741c986d506462846a6aa007f94cef"/><file name="Exception.php" hash="e61ee74d3ae19b3e61c1894264d6530a"/><file name="SalesUseTaxBasic.php" hash="43823d20d58aaf73be598f5282e7f841"/><file name="USAddressVerification.php" hash="f5dd585a282a046ebfb95125c29ed866"/><file name="ZipCodeInfo.php" hash="76beb6125d1035ffd7e67101cbd9df44"/></dir><file name="StrikeIron.php" hash="7eca35cee7479ac035ec83f456ddb2ec"/><dir name="Twitter"><file name="Exception.php" hash="d5a3fb65437ac5663d5262b19c226483"/><file name="Response.php" hash="f78d457745cd7df85d83b33e9b43a01f"/></dir><file name="Twitter.php" hash="8b3dc7c575b35c1351a9a00afd1b57c5"/><dir name="WindowsAzure"><dir name="CommandLine"><file name="Certificate.php" hash="82f6c9535209f9d9800b1ec5227ea5a8"/><file name="Deployment.php" hash="d77fb324a62e1d5bbec2ce07dbcd6051"/><file name="GetAsynchronousOperation.php" hash="da2b5c820d693a4fdcdc5f53378a317c"/><file name="Package.php" hash="4ed8d218b529fa358b9bad365caeda1c"/><dir name="PackageScaffolder"><file name="PackageScaffolderAbstract.php" hash="077b5928c2f1ff061f447754e17051c9"/></dir><dir name="Scaffolders"><dir name="DefaultScaffolder"><file name="build.bat" hash="651c7fb8b72233f40f4f25ca8905573b"/><file name="index.php" hash="894c44229a940ea713205338f8e490f7"/><dir name="resources"><dir name="PhpOnAzure.Web"><file name="Web.config" hash="65f639e413e4ff122d92623a1c14b2ae"/><dir name="bin"><file name="add-environment-variables.cmd" hash="b0e00d591398ec40968189bc4e35c139"/><file name="add-environment-variables.ps1" hash="19a5afae543fd10d118ad21136fc4bec"/><file name="install-php.cmd" hash="8248bad7c6981ab8f8ad34cbb6e224c3"/></dir><file name="diagnostics.wadcfg" hash="5188e0200f5446cae89c1be78db568c2"/><dir name="resources"><dir name="WebPICmdLine"><file name="Microsoft.Web.Deployment.dll" hash="ce4bedba97839fb3b3991c9e76d9a5f8"/><file name="Microsoft.Web.PlatformInstaller.UI.dll" hash="c692c64ac1ff35a256b05b3d0389d77a"/><file name="Microsoft.Web.PlatformInstaller.dll" hash="b3c7917c493dc73aab9ad4f3b32d3722"/><file name="WebpiCmdLine.exe" hash="23ee0847ce84831042e2094f8bb946a7"/><file name="license.rtf" hash="e19c7c8161a0d2cf8cd2bfa815edd707"/></dir></dir></dir><file name="ServiceConfiguration.cscfg" hash="aef39d43590593be9d2fe5fe4a3b5c80"/><file name="ServiceDefinition.csdef" hash="cc148db5e38df6777513c343f0552408"/></dir></dir><file name="DefaultScaffolder.phar" hash="7213da0e7d624e8c2a4ba1f3b5ff05eb"/></dir><file name="Service.php" hash="ff88b79b64947f883986e77838d8cb24"/><file name="Storage.php" hash="8944ded3eb414aa4826b6f53040049d9"/></dir><dir name="Credentials"><file name="CredentialsAbstract.php" hash="d4f022ee969ebb28059bb4fe1dc15bbd"/><file name="Exception.php" hash="46253077f849f4d86ff19bcd5c4ffbb2"/><file name="SharedAccessSignature.php" hash="b812dfc04bcc4349faa4b684e3c17ffe"/><file name="SharedKey.php" hash="d09970fb25d6649fc3626d016e57a71a"/><file name="SharedKeyLite.php" hash="a7af3a465e3b62edddd79fcfb8b5bfd0"/></dir><dir name="Diagnostics"><file name="ConfigurationDataSources.php" hash="164e443f79bf6b018796cbe4ace8552e"/><file name="ConfigurationDiagnosticInfrastructureLogs.php" hash="5ed3b44951c19fe3899d77e57777ccca"/><file name="ConfigurationDirectories.php" hash="ac9628ef7d6d5291b4a9755ffa83c4bc"/><file name="ConfigurationInstance.php" hash="2ffcb3db9f9ecfe5764d497f08175c1c"/><file name="ConfigurationLogs.php" hash="79cb3324521884a79c422318e9df0996"/><file name="ConfigurationObjectBaseAbstract.php" hash="574ad31edf5de775857d4d9818e09515"/><file name="ConfigurationPerformanceCounters.php" hash="f518fc30a51d61ee73f44fd54304d115"/><file name="ConfigurationWindowsEventLog.php" hash="7b071634e38e532d5faf245310846396"/><file name="DirectoryConfigurationSubscription.php" hash="5c72f815ecb4a4b619a43b05e0767d3e"/><file name="Exception.php" hash="ecc6ffb64bcd2b7e219b9e57ae8261c4"/><file name="LogLevel.php" hash="b63f1b837619bd6475f30b5c2862354b"/><file name="Manager.php" hash="0d92a4ee3426b0a3fa98efabad20850e"/><file name="PerformanceCounterSubscription.php" hash="f3793033b70429e761b5715d26a9b052"/></dir><file name="Exception.php" hash="ae2961639357d61fd0edbb1f8b19e600"/><dir name="Log"><file name="Exception.php" hash="f293efa4c7d400034fdd32b61e398d75"/><dir name="Formatter"><file name="WindowsAzure.php" hash="d2803e471ad8f151337b9b06adf840e2"/></dir><dir name="Writer"><file name="WindowsAzure.php" hash="898cc3aab9ed4a1143ad98af4c82828f"/></dir></dir><dir name="Management"><file name="AffinityGroupInstance.php" hash="999fccb597ded5e9bb1a3a49d0461238"/><file name="CertificateInstance.php" hash="e38186727c337efeb26e1edb3395c3aa"/><file name="Client.php" hash="7ea9a8aeec1b66c29127ce846788caeb"/><file name="DeploymentInstance.php" hash="da71eb3b750c5accba7df6a02a936572"/><file name="Exception.php" hash="e38e9729e738a5c98b7a444377dc390f"/><file name="HostedServiceInstance.php" hash="52a7a4f5e90fcddbba2da67f6ec1a714"/><file name="LocationInstance.php" hash="d7fc5f02f835fbea9bd39e25a2953415"/><file name="OperatingSystemFamilyInstance.php" hash="5463dc6555a2894cf77c15dd015b2bbe"/><file name="OperatingSystemInstance.php" hash="8d8fc32400bbb73a3765f06ccaefc05f"/><file name="OperationStatusInstance.php" hash="acb817c0203ca17237b430c7d086b7b3"/><file name="ServiceEntityAbstract.php" hash="6013b8d4f6378d945e29013d54dc634f"/><file name="StorageServiceInstance.php" hash="6d89ea4e90ac780fce17efba7e38976a"/><file name="SubscriptionOperationInstance.php" hash="9fb50cd722cc80be2d660e78cd42d3de"/></dir><dir name="RetryPolicy"><file name="Exception.php" hash="b83b70d8c828de010cfa12f027a2da23"/><file name="NoRetry.php" hash="faa7ed56468ce39f77162aa1888f8480"/><file name="RetryN.php" hash="340d6ccaa8d41eba0f3cd943dbff201b"/><file name="RetryPolicyAbstract.php" hash="57b861c1f66f83295ce1ae8284b6870c"/></dir><file name="SessionHandler.php" hash="49abc2db2f8cd60249889013eeb6c28f"/><dir name="Storage"><file name="Batch.php" hash="54321d9853919241064631b7fd5e404a"/><file name="BatchStorageAbstract.php" hash="1911d06beacc5afdee2e0214fadb48f7"/><dir name="Blob"><file name="Stream.php" hash="fca729afd6bced397324a092598c4348"/></dir><file name="Blob.php" hash="ba54d4c7b42bfb8536df0ace27d68ac5"/><file name="BlobContainer.php" hash="3762000f605bc3b601d33508d11ba9cb"/><file name="BlobInstance.php" hash="3acc55cc558e3003164dde92463f0f74"/><file name="DynamicTableEntity.php" hash="c0f1e5b79b12857c233299a4445bb168"/><file name="LeaseInstance.php" hash="3d0fc9b5d6808aec75d9aa5bfb537e3d"/><file name="PageRegionInstance.php" hash="ad3d6fda6950c0f1fa6516507ca9662b"/><file name="Queue.php" hash="e0f744f5a2c30c4368babc77282987d1"/><file name="QueueInstance.php" hash="fc1d2fe33c92b9709174fdb78b014839"/><file name="QueueMessage.php" hash="1743f7a02f0d443c7a2f85d87dc43e0f"/><file name="SignedIdentifier.php" hash="cd0fa8a05e3acd402a1e337b1ca7eee0"/><file name="StorageEntityAbstract.php" hash="f3ef81a6dbd64aea38bc60b1f0c7bb8b"/><file name="Table.php" hash="3264067c6ef982f7bb216234451f5781"/><file name="TableEntity.php" hash="c9be1c41776a2ae5892d8f8d14b74fd6"/><file name="TableEntityQuery.php" hash="13880ce0f4c805205dcd10a5283c0539"/><file name="TableInstance.php" hash="54f43c27f93bee83a2c9ba42831d9c27"/></dir><file name="Storage.php" hash="cbac5a9bb9efb6e93a3d9871c8699035"/></dir><dir name="Yahoo"><file name="Image.php" hash="aa6abfa0f447d43f4828dc44c0fdf86f"/><file name="ImageResult.php" hash="7a64eac529ce21090e8b58997fc22041"/><file name="ImageResultSet.php" hash="7ad19487bce9a09855cf7d79707af347"/><file name="InlinkDataResult.php" hash="28305ce865dfb4011a285015a40a6a83"/><file name="InlinkDataResultSet.php" hash="fb09080f12f5348b37fdd5d62fc946fc"/><file name="LocalResult.php" hash="306431d361c2097b3b00cdbaba1bb372"/><file name="LocalResultSet.php" hash="68a4cb69982884c1bd7d6a7df86be90b"/><file name="NewsResult.php" hash="ea496bdeee3021d391df58a3be8636af"/><file name="NewsResultSet.php" hash="f80bcd0b1ac7632f3fb3020a7ff83255"/><file name="PageDataResult.php" hash="c8ea663819efe5ec5d374463f04a8f39"/><file name="PageDataResultSet.php" hash="69c99f8806a98868cb77e9db268eb8d8"/><file name="Result.php" hash="221286f5fbe491b570df8cec1fb7c91c"/><file name="ResultSet.php" hash="4477af82dcaac7fcd93ce9c29c68bdd5"/><file name="VideoResult.php" hash="6ba0d1ebb1c288b11b17ff6a9e434a4d"/><file name="VideoResultSet.php" hash="1a434e1b8bcf9b32e755a32e97e52838"/><file name="WebResult.php" hash="eacd11e6aace9570c6064c8fc1b47750"/><file name="WebResultSet.php" hash="bf5f6f43eb71f0469c961b0f5a6e4094"/></dir><file name="Yahoo.php" hash="27616706be89313b7b5be256be21e095"/></dir><dir name="Session"><file name="Abstract.php" hash="b43880e48ff9ee3040eca09d1458f7d5"/><file name="Exception.php" hash="ce01f1ceaa96bef8c71759f7e6c1e578"/><file name="Namespace.php" hash="b3e6effe8f53d5f9f407a4b5507df31c"/><dir name="SaveHandler"><file name="DbTable.php" hash="5b08339aa3e7f044b5602e725e6c65c0"/><file name="Exception.php" hash="06db90dee9421e4a8e09b946de252d41"/><file name="Interface.php" hash="617704bf38e31d51b79c636480447b91"/></dir><dir name="Validator"><file name="Abstract.php" hash="7bc8436592d308a702f37d64a8afbe72"/><file name="Exception.php" hash="c00d9dfbc04a9250f2359a5f31e726b8"/><file name="HttpUserAgent.php" hash="6a2a83e6baf37967b06cf993170ed03e"/><file name="Interface.php" hash="6e54358cefb41ccb7e591eaba391f74e"/></dir></dir><file name="Session.php" hash="da8c2bc8217bb09a7e86c573fa7a6553"/><dir name="Soap"><dir name="AutoDiscover"><file name="Exception.php" hash="3c71353889e5488f16cd0747a1337882"/></dir><file name="AutoDiscover.php" hash="abdfc4afb277a6e0c23216cb1d894dd1"/><dir name="Client"><file name="Common.php" hash="4c196fc850f65702741c044d12507769"/><file name="DotNet.php" hash="61bacfc1a99fabb15c58d5499c064c72"/><file name="Exception.php" hash="fe48793a358a7201ad7faee3a077a7db"/><file name="Local.php" hash="843caaab790dc3a322e570cae31dfda7"/></dir><file name="Client.php" hash="bb395c77d4e6ca127f48e15953c72f90"/><dir name="Server"><file name="Exception.php" hash="b5366c6128550c6904b5f0d83d9a4495"/><file name="Proxy.php" hash="4e3e39bf6b40e758bb8154900c0be4ae"/></dir><file name="Server.php" hash="2d3adb7e3b01a55889f4a9ccd1226758"/><dir name="Wsdl"><file name="Exception.php" hash="c30308763d2f85ccde3e48c399d977fa"/><dir name="Strategy"><file name="Abstract.php" hash="f09e005c0c35a51dbc906815f298a515"/><file name="AnyType.php" hash="7e0f81e8c1bde45bd858ae5c16b4cd11"/><file name="ArrayOfTypeComplex.php" hash="3b9998427588b55e16496ee51a1d7d5d"/><file name="ArrayOfTypeSequence.php" hash="8ea1226e6138e1d162b647b39daed36d"/><file name="Composite.php" hash="7ea40da650826369c79e7a17ff93da40"/><file name="DefaultComplexType.php" hash="9fefac807dbb4c843feec714a05ac521"/><file name="Interface.php" hash="d4f3ed1447d163ae1eedcfc886662719"/></dir></dir><file name="Wsdl.php" hash="8e4ad5d4d160d770740012ec920e30de"/></dir><dir name="Stdlib"><file name="CallbackHandler.php" hash="f33bb03784021305a529525bf125df09"/><dir name="Exception"><file name="InvalidCallbackException.php" hash="977bd070fc4de8c0bce940a2d0a0c530"/></dir><file name="Exception.php" hash="826ef583632fe8b71ce0916ce4c01030"/><file name="PriorityQueue.php" hash="886161c12418c95bda548c5e484db351"/><file name="SplPriorityQueue.php" hash="4ce44425f16b61d5cfa2b37a36c430b9"/></dir><dir name="Tag"><dir name="Cloud"><dir name="Decorator"><file name="Cloud.php" hash="c03f8a8a9acad9b124508cb5ec762ef6"/><file name="Exception.php" hash="da2286643dd90128c9bafdb55d4874d9"/><file name="HtmlCloud.php" hash="ac29df72f5738876b6c5c3220200aea5"/><file name="HtmlTag.php" hash="1c66e72d27e394b7a67e083a6a7e7635"/><file name="Tag.php" hash="38969d4df8dd12f7c75d5886a4309e2d"/></dir><file name="Exception.php" hash="f1f89e1176804f89966ffa1b6057aadc"/></dir><file name="Cloud.php" hash="b563d184a10c5780ac839964d05f5b70"/><file name="Exception.php" hash="bb95c48a0889e48b9621fc24ece1855d"/><file name="Item.php" hash="4d8899476ff7c0edc26227377437184a"/><file name="ItemList.php" hash="a37b92d4346128d6928c3ed75abe85e3"/><file name="Taggable.php" hash="754d26825a791b7b493479ab96de35ac"/></dir><dir name="Test"><file name="DbAdapter.php" hash="9f14c0c71238db11ce231ec608fa0748"/><file name="DbStatement.php" hash="ae071a2e217641e4431dbaffab4b475c"/><dir name="PHPUnit"><dir name="Constraint"><file name="DomQuery.php" hash="4a372f65097fddc842326acfb0873110"/><file name="DomQuery34.php" hash="4cfc2fccf97dcad8979afdeb5051d99d"/><file name="DomQuery37.php" hash="4918ef15cdbf82e30ee35bce62246f6a"/><file name="DomQuery41.php" hash="0e55e6f6ec4df95712cf6ae2592eaa4d"/><file name="Exception.php" hash="08a569be3229aa317e045e0bb5712aee"/><file name="Redirect.php" hash="bd29ebef3a5193019124cbe48e3b57a4"/><file name="Redirect34.php" hash="7fbaaf229a5e72fd9328b6b3355979e0"/><file name="Redirect37.php" hash="25ae9936724abf4f6c655e79a4b017a7"/><file name="Redirect41.php" hash="b15f5d011531a5f341691400758b7b94"/><file name="ResponseHeader.php" hash="d0c824d1d0825eaff50fbff17ad9fe68"/><file name="ResponseHeader34.php" hash="970159fe86220f6d79ae839787445e76"/><file name="ResponseHeader37.php" hash="b45fcfbc270c1dc1be8af6f967d74055"/><file name="ResponseHeader41.php" hash="d898287c0e3c5c5a29c8dfc23258c357"/></dir><file name="ControllerTestCase.php" hash="a1587e2519d6a108213338a8df626983"/><file name="DatabaseTestCase.php" hash="e660d4e0b896a1349b5b3a7b908abed9"/><dir name="Db"><file name="Connection.php" hash="a376a28b4f32640b77896ed71aa94103"/><dir name="DataSet"><file name="DbRowset.php" hash="619ddf7996bdbae5efe2667bf43f97fd"/><file name="DbTable.php" hash="c2f9df7d0a3cf0d37631d8f06c818bc8"/><file name="DbTableDataSet.php" hash="d4399f69a07e07e1cdf51ee779ed4d25"/><file name="QueryDataSet.php" hash="9923dfa4b4f6ec969e05af835f0c9578"/><file name="QueryTable.php" hash="49db01b854018eed9f97f9e87dd8ef99"/></dir><file name="Exception.php" hash="b4db1bec052e5f4326e4f69f8265b1f6"/><dir name="Metadata"><file name="Generic.php" hash="0d50fe34d4d444504a433c495a10f4c7"/></dir><dir name="Operation"><file name="DeleteAll.php" hash="ad2d32c7274f19ffd7ff00f6a9629831"/><file name="Insert.php" hash="76990ebfd7da444a380ef153fd4ec2c7"/><file name="Truncate.php" hash="aeb7cea4a23f9a4978838834184b827c"/></dir><file name="SimpleTester.php" hash="303a002e44573654515318426f06454c"/></dir></dir></dir><dir name="Text"><file name="Exception.php" hash="63dc12adf35209b68cb541fad9d13339"/><dir name="Figlet"><file name="Exception.php" hash="ce4743f212bc9dd406e7c5abd1499a8c"/><file name="zend-framework.flf" hash="e421545f78033d8a6a4324e54ccf0454"/></dir><file name="Figlet.php" hash="342b1851f3fddf6de881bfdcd6dbdc25"/><file name="MultiByte.php" hash="7beb126807547c59a29ff72918ce4cb6"/><dir name="Table"><file name="Column.php" hash="cb652d404e394051bb9463ef0f5e5fac"/><dir name="Decorator"><file name="Ascii.php" hash="642655dbd861110617fe242a5f5b2e49"/><file name="Interface.php" hash="b246cf5bf0cc2ccb3fd612987dda1ac6"/><file name="Unicode.php" hash="78c514875a100d295a884d52cbff6679"/></dir><file name="Exception.php" hash="a9ad309358591313a0b39a9dc6637ead"/><file name="Row.php" hash="2e1210709f13f36070015bf1e7c4bae8"/></dir><file name="Table.php" hash="fa040e017955cd19728968adc4d3263a"/></dir><dir name="TimeSync"><file name="Exception.php" hash="c5c88b4fa22c7aa853c99e80293d6b56"/><file name="Ntp.php" hash="670a72b056bc3ea5c6ca09fd51e5c0d1"/><file name="Protocol.php" hash="81ebccdcfad278c458e8f801743e8035"/><file name="Sntp.php" hash="f491dc0e0e4ad0a6909cc9518c443855"/></dir><file name="TimeSync.php" hash="e68ddd486d397ad8b8072df003f0dbe9"/><dir name="Tool"><dir name="Framework"><dir name="Action"><file name="Base.php" hash="ca10276b0b663e3946f30a7e85e2437a"/><file name="Exception.php" hash="033fe3dfcbe687a8fc14217124485646"/><file name="Interface.php" hash="4971f7cd01f81557e06c52442d1e10ec"/><file name="Repository.php" hash="763980637bc854efdabe4702cf90429a"/></dir><dir name="Client"><file name="Abstract.php" hash="c6aa9afeb508a90fac77fdd01490c917"/><file name="Config.php" hash="88d068ae943aaa028252208d2ffa9737"/><dir name="Console"><file name="ArgumentParser.php" hash="a7aca2e438a4ea02beea9efe4fc322e6"/><file name="HelpSystem.php" hash="c49dfb3e52bc4dbd0fb981d2d2db7ea0"/><file name="Manifest.php" hash="8ecaf5471c98b4adecf441fd0b239fd1"/><dir name="ResponseDecorator"><file name="AlignCenter.php" hash="aea5fb29315c501c879f1414ab30bdf1"/><file name="Blockize.php" hash="f6510cb7f02bdd000eff5b3cfc7c3f94"/><file name="Colorizer.php" hash="b4370450e0af8f8bc5b70bca3a3140e4"/><file name="Indention.php" hash="9d05c40f3bcf99606a4433c4f2f550c8"/></dir></dir><file name="Console.php" hash="70d696d68e6f889e25661568ae0cafef"/><file name="Exception.php" hash="9fc08df23e990977b31c58157458797f"/><dir name="Interactive"><file name="InputHandler.php" hash="d4a71d517cbdfca13bc442f915eadfa3"/><file name="InputInterface.php" hash="b76636ebb7563e128e1653de60a05e47"/><file name="InputRequest.php" hash="01746459e3c0d5114ba84376641ce516"/><file name="InputResponse.php" hash="fe6fb87211d75ac5d43a0afcd12b3438"/><file name="OutputInterface.php" hash="e6473dcec31887ba9fc189cf5ac4b5cb"/></dir><file name="Manifest.php" hash="a04f5f7452adbe2a7b9f572753c282e1"/><file name="Request.php" hash="337a50f6b8ca0346335666825a138400"/><dir name="Response"><dir name="ContentDecorator"><file name="Interface.php" hash="f5f2e4d82017c916a98e600c0ecf10fa"/><file name="Separator.php" hash="0bdedce341d3dc2456856bedb4e6fbfd"/></dir></dir><file name="Response.php" hash="047455ac32ab5c1f0913bd8be80408e2"/><dir name="Storage"><file name="AdapterInterface.php" hash="cbe1be24e10113b8355be82c17257d74"/><file name="Directory.php" hash="7f818fcabc4dd64292ec750d69a2cab2"/></dir><file name="Storage.php" hash="e1e34565e6f12ef7a6914bea4f21b495"/></dir><file name="Exception.php" hash="e8ab7ccbf5e2a5516a35ca4e887b1f5e"/><dir name="Loader"><file name="Abstract.php" hash="ac9b19649683e89c14f162643680d6d2"/><file name="BasicLoader.php" hash="eb441f57c872d051c8bf4ff334516776"/><dir name="IncludePathLoader"><file name="RecursiveFilterIterator.php" hash="e809fc3ffb30c42bd65defb0b841d5ea"/></dir><file name="IncludePathLoader.php" hash="ba1fdc0c41d1ac3ac9b86f7b295d62fe"/><file name="Interface.php" hash="5a982ccd517b7fa2c5d1e7a181f9a66d"/></dir><dir name="Manifest"><file name="ActionManifestable.php" hash="6b75a1363ec0989198f0577519f2a8d8"/><file name="ActionMetadata.php" hash="55c5c7fd4609c3a2c188c68f2b59996b"/><file name="Exception.php" hash="e4adb9a694c21dd46682009e1a25ba80"/><file name="Indexable.php" hash="f2fdb04e846a873a00178d44dfb7c134"/><file name="Interface.php" hash="65fb779fcdd624b743e1c70370ce1a2f"/><file name="Metadata.php" hash="79d13b52ad9aa5bffe103b61a404296e"/><file name="MetadataManifestable.php" hash="2974762fdea9eec82a74a6d3446f676a"/><file name="ProviderManifestable.php" hash="3d59e772c55a5a791844910d9acbb131"/><file name="ProviderMetadata.php" hash="b1fa45e3f1309e25c3e71e43e1a48263"/><file name="Repository.php" hash="b055ec6bcaa48d3536f376c7d196052b"/></dir><dir name="Metadata"><file name="Attributable.php" hash="3a1ae646ad3127bcd9d7f0b590b49d75"/><file name="Basic.php" hash="f8e243b4883d1f53ef6dd440c0d8b618"/><file name="Dynamic.php" hash="2ae310d375a9f1e29f0322c03350b718"/><file name="Interface.php" hash="dd418e0cfd979aa8caac73abbe8d65d7"/><file name="Tool.php" hash="d4cf6475ece71a871144a646c4653b88"/></dir><dir name="Provider"><file name="Abstract.php" hash="54efa5905a09985cfc5261116cdc808f"/><file name="DocblockManifestable.php" hash="0bb7be516c01ef1df2db65cac6782604"/><file name="Exception.php" hash="8340027bd3f883ce3bc60e5a4a779e1c"/><file name="Initializable.php" hash="21203810d42fc2c661b5a74a4db22afd"/><file name="Interactable.php" hash="1645bf6768d35a154b409e9fc8d23629"/><file name="Interface.php" hash="5acbcaa43439912bfc3f9be9aae48561"/><file name="Pretendable.php" hash="7320be8f080b47a7a3c7768ed5b82655"/><file name="Repository.php" hash="06ac616d5eca5d9769ad7d1d1a7ca9bc"/><file name="Signature.php" hash="5be099c081171cd11a6c5e6a80011f2c"/></dir><dir name="Registry"><file name="EnabledInterface.php" hash="87fe89d72c54ad50ec51bb2d683d2992"/><file name="Exception.php" hash="eccc229c4505a1ed3e85902496e1935e"/><file name="Interface.php" hash="85731cc24ee6598ac544956ba02a4847"/></dir><file name="Registry.php" hash="430ca6afc053d09a02faafa778f05ddc"/><dir name="System"><dir name="Action"><file name="Create.php" hash="ece59a9bf0b39f4c7731dd2c3c6a3687"/><file name="Delete.php" hash="93a02ef0a268f9a46140122e6b658831"/></dir><file name="Manifest.php" hash="2dc6db96a2eaec2f041f73eb9784426e"/><dir name="Provider"><file name="Config.php" hash="0f0ac44a62caaea96bdd741dc8d10fe1"/><file name="Manifest.php" hash="9834badd5250276130dd8f035fa3aa69"/><file name="Phpinfo.php" hash="a18c9de3ae3099a941d257fd8bb83286"/><file name="Version.php" hash="235916637c0ec94a08f86894dd211da4"/></dir></dir></dir><dir name="Project"><dir name="Context"><dir name="Content"><dir name="Engine"><file name="CodeGenerator.php" hash="28294bea1645211c3a55b04b03eb97e5"/><file name="Phtml.php" hash="b635fe45ef2a8b9de27be338ff80e0c8"/></dir><file name="Engine.php" hash="3edec5f50d35068768bd1ddb7cfcb242"/></dir><file name="Exception.php" hash="903019115f2291dac64e2d8316b069d0"/><dir name="Filesystem"><file name="Abstract.php" hash="7de036baa7d7a11fde54ba3d0d9e199c"/><file name="Directory.php" hash="346bbbf87ee7515d0b1ea6d468a23bbb"/><file name="File.php" hash="82a28fef9d3d33f3de763e2f4415ef66"/></dir><file name="Interface.php" hash="ec12cc9de36ab46a2afb96f61f3af90e"/><file name="Repository.php" hash="652c4bea315e3239fd99f22103c51140"/><dir name="System"><file name="Interface.php" hash="9011f3458a2b39fdf8867e639414a7bc"/><file name="NotOverwritable.php" hash="de0a563d5079199bf642b6811b7e5bac"/><file name="ProjectDirectory.php" hash="f5d33f4805cc35574112532f2f262579"/><file name="ProjectProfileFile.php" hash="48ff62386762440129ae4fb7337deb2f"/><file name="ProjectProvidersDirectory.php" hash="b5a9d7bba0ccd8554ca26f0149128acc"/><file name="TopLevelRestrictable.php" hash="2309be1ddaf737de9b7adafa6cb8632a"/></dir><dir name="Zf"><file name="AbstractClassFile.php" hash="22a8a9cc341edc796112df20983a43bc"/><file name="ActionMethod.php" hash="2f16d745e3a323f9ff416e2217358f54"/><file name="ApisDirectory.php" hash="0b39c81c051cc37f5492df965835eba1"/><file name="ApplicationConfigFile.php" hash="677abcc2fc67896b511af1f1181a8f81"/><file name="ApplicationDirectory.php" hash="42a08abbb3ecc267cd883a87f817981b"/><file name="BootstrapFile.php" hash="b76b4cf58705698399d06e8d4c9f6d67"/><file name="CacheDirectory.php" hash="5bb06a72dcd025a283c76c03a1ce9599"/><file name="ConfigFile.php" hash="2462d7d79f673c397d3a2f7284ccde66"/><file name="ConfigsDirectory.php" hash="b1cccd4669781cc33b9171a186236219"/><file name="ControllerFile.php" hash="090e5fe4d3b57933b9e7aed8eeef7cc5"/><file name="ControllersDirectory.php" hash="8543ca965e6d7a4cf78177ef0dcfc4eb"/><file name="DataDirectory.php" hash="5f8d27eca9e789c24dc039ea0f62748e"/><file name="DbTableDirectory.php" hash="92eda9ff83054cc8818bee744ed6e463"/><file name="DbTableFile.php" hash="b936fc7a4dd1e4726f0bb49f01ad931a"/><file name="DocsDirectory.php" hash="f58949c95502bd2ff8c31c59009c92b5"/><file name="FormFile.php" hash="b35ea0268fe07098b794eb24082ef53b"/><file name="FormsDirectory.php" hash="ffe9f7939c29068e7a1932dbc374bb7b"/><file name="HtaccessFile.php" hash="8e933afd24df22e6742aa972f8fc470d"/><file name="LayoutScriptFile.php" hash="8bd850a37a308efa3f4c83927fa5d8f5"/><file name="LayoutScriptsDirectory.php" hash="036f5cc0c38ead9183f7dd3f712848e6"/><file name="LayoutsDirectory.php" hash="c86cd320a91a46d439e4b419bd8ee428"/><file name="LibraryDirectory.php" hash="29a3c5283210c444e65284206b3da79c"/><file name="LocalesDirectory.php" hash="029c2897885aa476bd4103c48894ca87"/><file name="LogsDirectory.php" hash="3ee80aca0572bb9c5f6a44c6c021fcdc"/><file name="ModelFile.php" hash="958ed1603c25bd34ceb3f09ceeb6746f"/><file name="ModelsDirectory.php" hash="82dde848d95e686be57804162c11dc63"/><file name="ModuleDirectory.php" hash="7e219e82a6349ed878042cc17ee1faf5"/><file name="ModulesDirectory.php" hash="00182e9148959046c0a7d2d6e261e0b1"/><file name="ProjectProviderFile.php" hash="f3deaf3adf5c501237f22dc653430f91"/><file name="PublicDirectory.php" hash="e93bb7ed0ef00a864c097993ae1a2a94"/><file name="PublicImagesDirectory.php" hash="d769f00ec21961d66b41fffc8035277e"/><file name="PublicIndexFile.php" hash="4d3cf05ca9d35e24242dbf61d8189579"/><file name="PublicScriptsDirectory.php" hash="ff61ddca598a5ce42907b78140187614"/><file name="PublicStylesheetsDirectory.php" hash="8262d74f0f35523a912d95dd261fbc18"/><file name="SearchIndexesDirectory.php" hash="5ddf8701c47bcc6baf68cfdcc0ff7467"/><file name="ServicesDirectory.php" hash="825c4204f9f44f2280de370b0b156733"/><file name="SessionsDirectory.php" hash="af2fd72fa2bcf4d003c0a6368953cdb7"/><file name="TemporaryDirectory.php" hash="46790ecd95da8518c80dd8715fe7f8ad"/><file name="TestApplicationActionMethod.php" hash="4bbc3a869e69c2093bfa02068b6e057b"/><file name="TestApplicationBootstrapFile.php" hash="6f335bc4e4e047c948e77e8b0708f45e"/><file name="TestApplicationControllerDirectory.php" hash="1976699a04927fa3f5a1686934cdd08e"/><file name="TestApplicationControllerFile.php" hash="8f2956d50a3ba47f0b8c1fa96b361025"/><file name="TestApplicationDirectory.php" hash="09f0536bc206b5305862a21b65301016"/><file name="TestApplicationModuleDirectory.php" hash="da78a9b90b270578a9d36f8d62575a2f"/><file name="TestApplicationModulesDirectory.php" hash="4b54130f6c22e995308da7138d85330b"/><file name="TestLibraryBootstrapFile.php" hash="d78b732c8602c082ad1688c9bc6bf68d"/><file name="TestLibraryDirectory.php" hash="3626bc62a7c1c330369eb0001c4a9b16"/><file name="TestLibraryFile.php" hash="b45dc141518eab43f5c89e64b29aebfb"/><file name="TestLibraryNamespaceDirectory.php" hash="2e70388b581499815e6e2ba2c1cc0c81"/><file name="TestPHPUnitBootstrapFile.php" hash="40d55d88d6c84cd153adb2539ee323a9"/><file name="TestPHPUnitConfigFile.php" hash="1f136f46d817445285994244274f9276"/><file name="TestsDirectory.php" hash="0dec72680dea22074c8d370953effac0"/><file name="UploadsDirectory.php" hash="5d72a25ffd1ee7899fa182ddd7c9e028"/><file name="ViewControllerScriptsDirectory.php" hash="0ce107dd0b77183717845592b5be2550"/><file name="ViewFiltersDirectory.php" hash="59d3134c2b27c136adaa07177a72b28c"/><file name="ViewHelpersDirectory.php" hash="305d6bcc8066a02a658d82a69b73828f"/><file name="ViewScriptFile.php" hash="95b593cd475edcfd2a6ecea8f2668ffe"/><file name="ViewScriptsDirectory.php" hash="9aeac85b2f35bd6a666a4da29b465d45"/><file name="ViewsDirectory.php" hash="f36732d4b125b54a661356327d6850cf"/><file name="ZfStandardLibraryDirectory.php" hash="eea898b019c52dafd72f7de1aaa92d50"/></dir></dir><file name="Exception.php" hash="125c1606112c9ce2cfc8b697fb989d5f"/><dir name="Profile"><file name="Exception.php" hash="907a68043581559d3bf42ccc2c4b1322"/><dir name="FileParser"><file name="Interface.php" hash="325d41a29468a70dfe7476e1fcc8d20f"/><file name="Xml.php" hash="59f053468c48c4d9b881bc1b859ec28c"/></dir><dir name="Iterator"><file name="ContextFilter.php" hash="ff51879dcc3452e49ad8bf2d9e2c4910"/><file name="EnabledResourceFilter.php" hash="8d0d4add1f853aa9cfd89aaf138e2de3"/></dir><dir name="Resource"><file name="Container.php" hash="ab368c4da0867a25770b6f7970a782f4"/><file name="SearchConstraints.php" hash="9e4a7578e2879e6c9da8cfeb1fbfa9ba"/></dir><file name="Resource.php" hash="2a5467d1f6ff134cd8e35a2cb92eaedc"/></dir><file name="Profile.php" hash="db1e9708dc20fe27c3b39b9e6f57f1f5"/><dir name="Provider"><file name="Abstract.php" hash="8c55b9fe14b8d37beac8a5d1356c2cdd"/><file name="Action.php" hash="72581e6e7e4acd0a19f8ba9bbc0e73aa"/><file name="Application.php" hash="64fa6f041e1f5727a88bb9cbc7636f22"/><file name="Controller.php" hash="677b3b817a7fdb644cd150be124e9a96"/><file name="DbAdapter.php" hash="b831929398b67e053a395a548227695f"/><file name="DbTable.php" hash="6d922b240f64a010df894b03a44e0132"/><file name="Exception.php" hash="00d67294ec03f48a1e43fede57faee26"/><file name="Form.php" hash="95362baaf1eb17e9698573f6d7fbcb53"/><file name="Layout.php" hash="40528bb34ab9942db935b59b831ab909"/><file name="Manifest.php" hash="9d3a781e8c917a5cdb9e7dd10641cd35"/><file name="Model.php" hash="f561e3f60741f857d2a0a8d8d8509823"/><file name="Module.php" hash="f3cb636991bdb7fa9d69285ff5370a75"/><file name="Profile.php" hash="2bf881a5c9cf4e1032cb8de9d9297b16"/><file name="Project.php" hash="a7b3b98eeb5b8a38d7b003adde3a3c16"/><file name="ProjectProvider.php" hash="63455c931c8fa909d4a413ae91c99cdd"/><file name="Test.php" hash="ef752345daf66c4d3bfcdf94feea8602"/><file name="View.php" hash="1a8b7de4308dea33a847f1c590238d80"/></dir></dir></dir><dir name="Translate"><dir name="Adapter"><file name="Array.php" hash="539a98b29aa0bbcec264db5e29d810ff"/><file name="Csv.php" hash="698388dd2ac2843c3664586596e248f0"/><file name="Gettext.php" hash="321e228017b8049e94ea89f4e41f35b7"/><file name="Ini.php" hash="c03616b55e55e0c62363c4ee5e6b106f"/><file name="Qt.php" hash="19fd28ff1f5135d08c73c5faca961f96"/><file name="Tbx.php" hash="688c8d48dd29565f46d6f49d160e2f4a"/><file name="Tmx.php" hash="829f33d7444e30e4dc5053890fa22ccf"/><file name="Xliff.php" hash="0af804c51c85eea4b76941587aa673cb"/><file name="XmlTm.php" hash="39a37d7374fe3f0e3bf63a1e1f9ccb44"/></dir><file name="Adapter.php" hash="61940eb09da1bed1e6b8984370ad4088"/><file name="Exception.php" hash="469fbd261b8e8e1b91a8221fad6a79cb"/><file name="Plural.php" hash="4afe3e908bd63c3320fc7c899cd7b139"/></dir><file name="Translate.php" hash="0a7fda94b43cc10499fae10d9ec5d2e2"/><dir name="Uri"><file name="Exception.php" hash="0d12fb53167123e15aacbdddd8b11797"/><file name="Http.php" hash="55fae6ba863159381838ccc7bf8c651a"/></dir><file name="Uri.php" hash="f20bdab5c9c0694f64dd5b69f090e083"/><dir name="Validate"><file name="Abstract.php" hash="3382bfb0c407a0d3b490685a4f85678e"/><file name="Alnum.php" hash="2fe48d28207f9917e69f5edf99a392e1"/><file name="Alpha.php" hash="abeae56166032b791ae499883857d17d"/><dir name="Barcode"><file name="AdapterAbstract.php" hash="7bf5990b4b1dc34fe1fd7bcddd8f0348"/><file name="AdapterInterface.php" hash="c1b8934e5706e958f6e889e7c04a6931"/><file name="Code25.php" hash="f707195d53cd032ba5a9fbde32e75176"/><file name="Code25interleaved.php" hash="0c2ca046d04c43c4204e6cbb9d6dff7b"/><file name="Code39.php" hash="adff9a47dbf44dca5784dc8cdcc3ddc7"/><file name="Code39ext.php" hash="2e69f0103fbda86142024fc7466958be"/><file name="Code93.php" hash="2377845f1bee4dab114519c8f5dd4c5f"/><file name="Code93ext.php" hash="795aad78199cbc0668c70e12defcf9ec"/><file name="Ean12.php" hash="233d2f57fb2b36f1f2c7b3a36b0ead3b"/><file name="Ean13.php" hash="349560c5d4af7178e257a38c3a24735e"/><file name="Ean14.php" hash="30ab956febdabc3c13a7812f6e703bd1"/><file name="Ean18.php" hash="899007801fc5a8f97b577d711e2d692e"/><file name="Ean2.php" hash="0d73987f006070e0d15a573277a812e0"/><file name="Ean5.php" hash="806813312608a4ade42bbfab5d233711"/><file name="Ean8.php" hash="d0f3b4b0305e5dd0a7ba077fbb4978cd"/><file name="Gtin12.php" hash="da6df50e6751f4872604687602cc9695"/><file name="Gtin13.php" hash="dbd9c8a33ed3669917d10dee00a44a13"/><file name="Gtin14.php" hash="ae9c9fccedb5e71c87950c17bc5a3411"/><file name="Identcode.php" hash="9fed06deab51a31d97a66801fc68921e"/><file name="Intelligentmail.php" hash="9f4a16c7b78b3b1e5d9429569ea2aa11"/><file name="Issn.php" hash="e8de22a236a14b191225614ca730d343"/><file name="Itf14.php" hash="958a09981361b0cc8c83c0ae98831008"/><file name="Leitcode.php" hash="581e77d7ff774564ac3961077e40b27f"/><file name="Planet.php" hash="cda7f2f6910606728d4f6b375b17bbff"/><file name="Postnet.php" hash="9182081361daecfe6f0371fc4cabcd9e"/><file name="Royalmail.php" hash="e5bfd9d4ffd4935ca4b988f651270e4d"/><file name="Sscc.php" hash="eabc46811aff1a4a7f4468bd73a3f1e8"/><file name="Upca.php" hash="bb4f503adce344b6d3eb584843d7378a"/><file name="Upce.php" hash="368d3a61898baad1f968d2292a2692af"/></dir><file name="Barcode.php" hash="b3531dde74c28ed55c868d75615a9d3b"/><file name="Between.php" hash="5ccda5b2ac3d35bcc7faa8d8800108df"/><file name="Callback.php" hash="4e6874a0cb4bba53ef8edb9cde9eed18"/><file name="Ccnum.php" hash="1871fdfe01ac8f50e1b76f103297d7fb"/><file name="CreditCard.php" hash="2b68a89fbd9747e2a7308bc08aab9a12"/><file name="Date.php" hash="ac196efe9a75f1f5052881f0ad0fb7fc"/><dir name="Db"><file name="Abstract.php" hash="f32f786acb59d6936c87698c0ac868ad"/><file name="NoRecordExists.php" hash="de3eab3a488154fd14c3aeaad18c58b7"/><file name="RecordExists.php" hash="6203f6b21b338f28420fffd67f007dcf"/></dir><file name="Digits.php" hash="6536e4f93eea9d40663dc5b8308455c3"/><file name="EmailAddress.php" hash="f2fb48bbe83e3fb4288ee0f4825f485b"/><file name="Exception.php" hash="f05330fae73fa8a6fa5eb13b239492ae"/><dir name="File"><file name="Count.php" hash="fd4240625ed05056050c46051750d42a"/><file name="Crc32.php" hash="37be3ed367b5b7d13170fdc56c083488"/><file name="ExcludeExtension.php" hash="cffccfd1fcdae2be7676722ba8af7d9e"/><file name="ExcludeMimeType.php" hash="071a625f92fac84b76467a0eba3c467f"/><file name="Exists.php" hash="f5ab404939714ebf24c992bb3e4db124"/><file name="Extension.php" hash="21bf334b8b2ee214e82709c7bc1bf489"/><file name="FilesSize.php" hash="ab8dd66b1a133b1851d51927eabea61e"/><file name="Hash.php" hash="fd3f0e2888d1266d78da22e7d6647690"/><file name="ImageSize.php" hash="d277f5533a2aa61b2d5132babaf63c43"/><file name="IsCompressed.php" hash="1a0257de13523c8227a809b5673eb217"/><file name="IsImage.php" hash="7cd64b53b6e4a635e71b69e8ed5af7c4"/><file name="Md5.php" hash="4af983e349f6c2bc3a3fb6bc05d51e32"/><file name="MimeType.php" hash="c996e072363c49d15feba2a7ed35684c"/><file name="NotExists.php" hash="66d36bf5981467b276a1d97ae22ba5a9"/><file name="Sha1.php" hash="bf177eb68980e20cdf4a0db90bc32a08"/><file name="Size.php" hash="e6fe4f698bbe20ca0ccabe817462e0e7"/><file name="Upload.php" hash="a4099691c48b3427cdb144e3333b9145"/><file name="WordCount.php" hash="a2c3afef06b310c0b6a61867dfe25ab2"/></dir><file name="Float.php" hash="7d81882373a3c805ea6d890fd23d534d"/><file name="GreaterThan.php" hash="c8abc03e583058774db68388b71654ae"/><file name="Hex.php" hash="b491553d31f5894f2bd1303d685223f5"/><dir name="Hostname"><file name="Biz.php" hash="7696fce32b01be696c7a3f168ebd56de"/><file name="Cn.php" hash="fb00d241ff6f27a84d1c63758be2a14a"/><file name="Com.php" hash="5deccb0b547e92073687530b13870ce2"/><file name="Jp.php" hash="d22c9a1a27cfc135357a79c4608cbbd6"/></dir><file name="Hostname.php" hash="084ca6f450f36d3c76248663351f27dd"/><file name="Iban.php" hash="93312cb157edcb0735182b06a20d22dd"/><file name="Identical.php" hash="35b72f8c75851bb0dddfe4ac2126cef0"/><file name="InArray.php" hash="c75ec63d4745f66be627d1973bd76396"/><file name="Int.php" hash="222edd304fa91776951350e2659597fb"/><file name="Interface.php" hash="dbdfc01be0180334732bf0331fb19468"/><file name="Ip.php" hash="7abc354eed666e6b93c14c9187d2d0a3"/><file name="Isbn.php" hash="aedbe250623c9a9ef228d1863104b839"/><dir name="Ldap"><file name="Dn.php" hash="2716b9bc0c82519ab2fdbb52a0094eaf"/></dir><file name="LessThan.php" hash="e9fd4f35f101acb8fa94df0812ece205"/><file name="NotEmpty.php" hash="84a8e76bc9fd6fce9ce3d93f9e37b36f"/><file name="PostCode.php" hash="4513fb89c9215f1c987354ea552c0925"/><file name="Regex.php" hash="cd9c961f1bc2241a1beb61b8adc6325c"/><dir name="Sitemap"><file name="Changefreq.php" hash="02c174efb2eb92c1f99083d8d8a8201b"/><file name="Lastmod.php" hash="ecb2907a0827ca4f9a902b1842104f0c"/><file name="Loc.php" hash="43a32b211470fd207e614e122b373d5f"/><file name="Priority.php" hash="c4062b2af691dd790e88a80aa5f5400b"/></dir><file name="StringLength.php" hash="b57a08cb0418165feed0c8f3069830dc"/></dir><file name="Validate.php" hash="fdb819323b45ba50c37cefe43410afd6"/><file name="Version.php" hash="4050aa162960c6f935a49ffe910f81bd"/><dir name="View"><file name="Abstract.php" hash="1319cd055a57d8627ff0ed820f17daa9"/><file name="Exception.php" hash="7a4c976601978de749639c8b0914a03f"/><dir name="Helper"><file name="Abstract.php" hash="e1018e0e93049ac253c920888dc1133e"/><file name="Action.php" hash="786799b58e0fc8729abfde4de463e4df"/><file name="BaseUrl.php" hash="183857156a40c84f03eaea0ff24606bf"/><file name="Currency.php" hash="2ffa077bbe17cbda6974509421cd0582"/><file name="Cycle.php" hash="33bb85798e40541bc8e75cde27cf3499"/><file name="DeclareVars.php" hash="3cbcbf5083117f5f1dad9bac8df3b474"/><file name="Doctype.php" hash="b7e492a249f52859e00c287a8973edb9"/><file name="Fieldset.php" hash="4874b3f6f0658d8f9eae3bf750bf9793"/><file name="Form.php" hash="17d5d7e238c33e8e8cb0efbe043c01e0"/><file name="FormButton.php" hash="c62cf4a51db83501c7c7f1e2fad7cabe"/><file name="FormCheckbox.php" hash="3fefb8a82a8183e4cda683231bad496a"/><file name="FormElement.php" hash="9dc8f7fdd07eb031bc7cee049faa49e2"/><file name="FormErrors.php" hash="eb7e95a90d8a438d4b1043fd32a5f3ab"/><file name="FormFile.php" hash="cf7ec88f4ffd6c732a7df42737069d07"/><file name="FormHidden.php" hash="396bbe9d13da93ee84befb08a5c86f55"/><file name="FormImage.php" hash="3c9adc229035b5972678f634f690cd75"/><file name="FormLabel.php" hash="af00a20fba6e72eb035a605e72a814a7"/><file name="FormMultiCheckbox.php" hash="4033cf623ff32c24f0eaac26e96272d9"/><file name="FormNote.php" hash="94c3fe7ae9857d5d1c0f7e67bd817ee2"/><file name="FormPassword.php" hash="e743953bac753960ee4918c34372ede6"/><file name="FormRadio.php" hash="7df9c01b4e3bac15aca3394bd6bb20ae"/><file name="FormReset.php" hash="7463249d29ef3c895e6d73548c0d2250"/><file name="FormSelect.php" hash="b9076b91b3dd8880a74b9a1ff0f6fb2e"/><file name="FormSubmit.php" hash="abb3c753621b09e8251e88dd7d9cfb1b"/><file name="FormText.php" hash="c059e5863263faaa09d4e7fe99ef4fa1"/><file name="FormTextarea.php" hash="b5a12bd7577c3794b4f7536e1721254c"/><file name="Gravatar.php" hash="8b4c4ce3552c48ec148b81ebb4f843d7"/><file name="HeadLink.php" hash="c25bb4abcf60925394a915df38b006a5"/><file name="HeadMeta.php" hash="42d8fed1309297d58411bb7d487ebe28"/><file name="HeadScript.php" hash="c835c0d98daf0f2b89f2f486d22587a5"/><file name="HeadStyle.php" hash="2770400f4d12c2bf7b27c053aa1a6453"/><file name="HeadTitle.php" hash="329e23739809b5a55dc8d28c447dc91c"/><file name="HtmlElement.php" hash="e5e6b362d6001c20bbb805e31beb36e1"/><file name="HtmlFlash.php" hash="dff36a0bf66c600be3004bdd34cc8b08"/><file name="HtmlList.php" hash="f21ac692428d4c457dc2f3d2db5e7304"/><file name="HtmlObject.php" hash="dda5c4a84c32c4cdd73112a33c322c87"/><file name="HtmlPage.php" hash="d49d3e056e0aab1a8179bd2b3f1917e2"/><file name="HtmlQuicktime.php" hash="4455adb547e6d3a1d3fb52d6746df770"/><file name="InlineScript.php" hash="aabae2682812b3ee88a5bfafaa3d00dd"/><file name="Interface.php" hash="52fa974c83ce1fff7c9d56a994b1fbbc"/><file name="Json.php" hash="78621362d2c630ad5b8b7f7ef2cf2124"/><file name="Layout.php" hash="9e98d798baba317de41bc0cdf75cdf60"/><dir name="Navigation"><file name="Breadcrumbs.php" hash="6482ca2aa2565f318b49ce0458072ae4"/><file name="Helper.php" hash="673a27dfb10aa4442dfa2951e0ef0c4a"/><file name="HelperAbstract.php" hash="6bae63e5c54e21b87ebaf8d2622ac1b9"/><file name="Links.php" hash="b2b7b2403670be61982c1a73851ed2eb"/><file name="Menu.php" hash="8f5c5c42c0b10ac7a68c69b4503ecaa2"/><file name="Sitemap.php" hash="960d3bd171fbe2ca66ba073afd33140a"/></dir><file name="Navigation.php" hash="98f3a4adbd4c69df20c127f90e09156c"/><file name="PaginationControl.php" hash="b18eee7e9c52256b27384a982a75f0eb"/><dir name="Partial"><file name="Exception.php" hash="047c658de482d2ae0eb5d21ac0cd0a55"/></dir><file name="Partial.php" hash="abe72103b776eeee4a96ccbca003cabe"/><file name="PartialLoop.php" hash="637e144d4c2d369a35848d681b4b6464"/><dir name="Placeholder"><dir name="Container"><file name="Abstract.php" hash="8d885989d99888fc2798a85f07c9f17a"/><file name="Exception.php" hash="326371b5ef3489904fee8e387e7feb46"/><file name="Standalone.php" hash="637e4d2b742d9902ae6de414c0475237"/></dir><file name="Container.php" hash="16d8237399260e817a542e68a4828d4c"/><dir name="Registry"><file name="Exception.php" hash="b9a3969a1431cf44f4cd03764dd92e32"/></dir><file name="Registry.php" hash="ee6d81b2c630c83baac77a0d619ba7d1"/></dir><file name="Placeholder.php" hash="2fced270eb2e3474b4bd538cd73f517a"/><file name="RenderToPlaceholder.php" hash="5ad5803d78bad07455af8f5d3c876977"/><file name="ServerUrl.php" hash="c6a222f4e795320f6f07c6bb8f80d7f3"/><file name="Translate.php" hash="d341ce0f8809b691728672fe506736e6"/><file name="Url.php" hash="71f6c3948d28f8190bfc27b3586d3f93"/><file name="UserAgent.php" hash="dbee4e1b78fad667479a85e8e2d0cbd1"/></dir><file name="Interface.php" hash="eec709b1a8ebb0256a9f752db1a8ad75"/><file name="Stream.php" hash="6f4c3f620f6e2d2f92cd371db18d3a90"/></dir><file name="View.php" hash="604cd51ea9ba98756064b418d6785a5d"/><dir name="Wildfire"><dir name="Channel"><file name="HttpHeaders.php" hash="62dffc43581615ca6cb052efcb2a43f9"/><file name="Interface.php" hash="0bed6c7ae3ee56a17f5c5187eef3ce10"/></dir><file name="Exception.php" hash="a225536440492a4ef3d37702aea1cb40"/><dir name="Plugin"><dir name="FirePhp"><file name="Message.php" hash="f481d929bbb00bf2bac8dfb008ae37d8"/><file name="TableMessage.php" hash="074faf9136be2ea86add5cdf2b459dd8"/></dir><file name="FirePhp.php" hash="e23b81012ace71de3018a37deb708885"/><file name="Interface.php" hash="c3cb69d35db9a385f7caa140b9634dab"/></dir><dir name="Protocol"><file name="JsonStream.php" hash="38a7d96f9d4ec70f68492f1bcf4022f2"/></dir></dir><dir name="Xml"><file name="Exception.php" hash="2dfb5785f12ed3858b16ab075570d577"/><file name="Security.php" hash="b7b7a240b24574b06f73a59dd8a4e6f0"/></dir><dir name="XmlRpc"><dir name="Client"><file name="Exception.php" hash="8e96419287c2faeeb4412ed9e832d975"/><file name="FaultException.php" hash="28c34f9ec27f280c44d215ee38bd41c3"/><file name="HttpException.php" hash="8c2eac4d043926123b3691562ad47310"/><file name="IntrospectException.php" hash="39d33b723e4fb1d5ce2af5cfd1f41589"/><file name="ServerIntrospection.php" hash="e52c06c394a8c8ac91b5313e5c575024"/><file name="ServerProxy.php" hash="43f25d1783bc1f11462d21ab5a134976"/></dir><file name="Client.php" hash="ea8c5a084405ca13e4f43340e37fe866"/><file name="Exception.php" hash="a04feed37237658eb7c174518a4d9383"/><file name="Fault.php" hash="18685e9a87f2f7750fa968d86ab89625"/><dir name="Generator"><file name="DomDocument.php" hash="5fc0be6304c7a00e58ac39f033d0dd22"/><file name="GeneratorAbstract.php" hash="493eda4b0b32cb59a133c06d63fbef90"/><file name="XmlWriter.php" hash="45013d6c2e24f7ee77439df64a958172"/></dir><dir name="Request"><file name="Http.php" hash="70fcc3ae21a466a9295f42ebae0c2a93"/><file name="Stdin.php" hash="23583af65a719e197a70fcd4c5500ac0"/></dir><file name="Request.php" hash="6945ae9bdf8d76308651611848870e09"/><dir name="Response"><file name="Http.php" hash="50e6859ca7391fd453d7137697f57dc5"/></dir><file name="Response.php" hash="cc7fe267b740ab5c556b7b2d19b6d600"/><dir name="Server"><file name="Cache.php" hash="1cd78db98fe5499e4a64379e97689f77"/><file name="Exception.php" hash="6294a6b1a7d4da4b7a15e7ee489eb119"/><file name="Fault.php" hash="69b89d7568a910f82109b6f3cb0410de"/><file name="System.php" hash="d7b0d17c91367f44eb993da66672dbac"/></dir><file name="Server.php" hash="1087be94c4995db9c38a5335323e922e"/><dir name="Value"><file name="Array.php" hash="b7011fc480c395bfcbc67d68ead94cd7"/><file name="Base64.php" hash="91ea9215e1d57716c0cd79bb1906134e"/><file name="BigInteger.php" hash="10222f3f5cd5eeaaa9813d8ed9f2494c"/><file name="Boolean.php" hash="770874cea876566818fb9135f31e69c5"/><file name="Collection.php" hash="0708fe32732db76ebe9d7e89396b89e0"/><file name="DateTime.php" hash="1a9f56c65375240ee0385ed912731b84"/><file name="Double.php" hash="ee71a5a9eeb026f1eb75387b8158706e"/><file name="Exception.php" hash="b7adf50526128e43c344331e7250b935"/><file name="Integer.php" hash="66c8d75e059a4cf328ff108d15db5c5e"/><file name="Nil.php" hash="ad51cdbcfb5eff5e06d7fc2c6d4661e9"/><file name="Scalar.php" hash="e61890f60aff885a3bed37b093f36e6d"/><file name="String.php" hash="a9d992c1910d76c4ed5330e704a1d438"/><file name="Struct.php" hash="028b64a94eeca406537505ecd52788d1"/></dir><file name="Value.php" hash="7d09b0ce98deeb7a07c01ad1bc94aa0f"/></dir><file name="replace_recursive.php" hash="e886103ea1f75208cc11780718aa3094"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF_Locale</name><channel>community</channel><min>1.12.10.16</min><max>1.12.10.16</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_ZF-1.12.10.17.xml b/var/package/Lib_ZF-1.12.10.17.xml
new file mode 100644
index 0000000..8c29b90
--- /dev/null
+++ b/var/package/Lib_ZF-1.12.10.17.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_ZF</name>
+    <version>1.12.10.17</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Zend Framework</summary>
+    <description>Zend Framework</description>
+    <notes>1.12.10.17</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:45</time>
+    <contents><target name="magelib"><dir name="Zend"><dir name="Acl"><dir name="Assert"><file name="Interface.php" hash="753f4c058211502ad047851c4550a121"/></dir><file name="Exception.php" hash="833945ed22a5631224398ec5d1a51736"/><dir name="Resource"><file name="Interface.php" hash="ec27f75c67a2ddb21ede3e8f5cf2188c"/></dir><file name="Resource.php" hash="1eac5e2cda19d6f595ce678ee9b27065"/><dir name="Role"><file name="Interface.php" hash="e61127c46f87a10799582eb5d58673ca"/><dir name="Registry"><file name="Exception.php" hash="1ab8aea40c56fb9754ea4d76cf022893"/></dir><file name="Registry.php" hash="b13b4d4f96691f26328aba33d2a725f6"/></dir><file name="Role.php" hash="4ffca60ba53123c02874b9f412a1d5a0"/></dir><file name="Acl.php" hash="9362ea321157987e2d667ce6ba6640c4"/><dir name="Amf"><dir name="Adobe"><file name="Auth.php" hash="5f1b8fa4bc0646bfc7e1a0248af99e4d"/><file name="DbInspector.php" hash="c945730a861cc8dfb79affc681d935cd"/><file name="Introspector.php" hash="1faa52d4a734963e2114f0244b4eb0fc"/></dir><dir name="Auth"><file name="Abstract.php" hash="eb1eebcde25e987e8cfd64b097a64438"/></dir><file name="Constants.php" hash="27f591080a8aa87a7603079496b03f31"/><file name="Exception.php" hash="c37e40e651b342f39763d2651a86e907"/><dir name="Parse"><dir name="Amf0"><file name="Deserializer.php" hash="91d9e217cf20c9012993d945e3f7e744"/><file name="Serializer.php" hash="fc6f4e7a3adcee15df87e6f5e918891d"/></dir><dir name="Amf3"><file name="Deserializer.php" hash="63f1c82ab2bf8029208347a5d6188cf9"/><file name="Serializer.php" hash="94893d06b63c1c7b89958790051a96b8"/></dir><file name="Deserializer.php" hash="6bf0ed466d51a8ed7d47842ae56b0c2e"/><file name="InputStream.php" hash="8825ad088d82c7b0e1eec7f1fc2a977f"/><file name="OutputStream.php" hash="f6954a735a7abc530b3d08c3a66a1610"/><dir name="Resource"><file name="MysqlResult.php" hash="f93006c3cf636f4426559266c7254301"/><file name="MysqliResult.php" hash="3ff39905a315dc50438612cdfd044003"/><file name="Stream.php" hash="9fac77c33d3b8a5932618b7140eb480e"/></dir><file name="Serializer.php" hash="89f6dade3493238bcebd57f7aec7c441"/><file name="TypeLoader.php" hash="2eb3de6c0c76a88c84e52d053db1b3c3"/></dir><dir name="Request"><file name="Http.php" hash="3ceb2e9419c58b42b8a91dfa518bdbe6"/></dir><file name="Request.php" hash="210fafeb570fabde64f45367aa2b818f"/><dir name="Response"><file name="Http.php" hash="9165da2b40ea937760d21e82d14fccfd"/></dir><file name="Response.php" hash="df120c6bdcd3624007e264387c3ea49d"/><dir name="Server"><file name="Exception.php" hash="b49d17bc0487b1f94e263edc3cd63b80"/></dir><file name="Server.php" hash="a382bc11323a9e000c8b903609842a60"/><dir name="Util"><file name="BinaryStream.php" hash="2be5bd9b9c7daf56a578bb98c79c4393"/></dir><dir name="Value"><file name="ByteArray.php" hash="3501ce99e15b597c7159a47a166585b3"/><file name="MessageBody.php" hash="8b61f8ee1c39105e5c19ee0c3df1eedf"/><file name="MessageHeader.php" hash="3719e3197128d0db242a664278740de3"/><dir name="Messaging"><file name="AbstractMessage.php" hash="3091614466f82c843414c7f780e2713f"/><file name="AcknowledgeMessage.php" hash="0102f33c15054d697d29ab872d587e75"/><file name="ArrayCollection.php" hash="5070cc263f4b56b4aa6a62110c563ae7"/><file name="AsyncMessage.php" hash="ad0d187dc1179ce2cad255fe5fbd00a6"/><file name="CommandMessage.php" hash="46b117af57383509740a975f1d35a801"/><file name="ErrorMessage.php" hash="cd980b1cc29739aa685d714e3645f5bd"/><file name="RemotingMessage.php" hash="acaa5c29b712d4d24168bb384d512bd8"/></dir><file name="TraitsInfo.php" hash="91da9ed050e8e44979a229eadf433bf4"/></dir></dir><dir name="Application"><dir name="Bootstrap"><file name="Bootstrap.php" hash="a54f574a13568e3b0d79f9792b58a77b"/><file name="BootstrapAbstract.php" hash="85403088f5775085724427f2db4e3f41"/><file name="Bootstrapper.php" hash="f6ffc93f65f911d74273c97480019ebc"/><file name="Exception.php" hash="592efcd13a2430fb8a8051c77af2bdbf"/><file name="ResourceBootstrapper.php" hash="b5697b89f0bee36d64f1323ae0e6fad7"/></dir><file name="Exception.php" hash="33b45075f371aa758ab73043d9bb345b"/><dir name="Module"><file name="Autoloader.php" hash="561bbbddfd1d5d66e9950b1c5435e822"/><file name="Bootstrap.php" hash="a982af99ca3f8583e7e06754c932bee6"/></dir><dir name="Resource"><file name="Cachemanager.php" hash="aed3b8889084e6b3b46b9e1ad2482309"/><file name="Db.php" hash="a5bc7745dd9416c3cee07ca45701672d"/><file name="Dojo.php" hash="ed17a22f02f2b4b52219cb1a8f5f283f"/><file name="Exception.php" hash="e7cc6162f923bea3163ab3c72a9144c2"/><file name="Frontcontroller.php" hash="4096de73ec4a62565475ade369fa2f10"/><file name="Layout.php" hash="cc29553ce7af25e5497433b38cb33d96"/><file name="Locale.php" hash="d9ddba5ce3e52cf74e06bcaa28e9f701"/><file name="Log.php" hash="6425ed565c8ffa8d6a2061b4bed90c77"/><file name="Mail.php" hash="43d891a5921b267f2298392f5de16f2e"/><file name="Modules.php" hash="de2fead30f02effe859de66503972e1a"/><file name="Multidb.php" hash="f958bb43354951af50a592a27c1de9c0"/><file name="Navigation.php" hash="fa7ac38efd17722bb2fd0181131af18d"/><file name="Resource.php" hash="fea870fdc0a7fe568ff6f7d1d10ab523"/><file name="ResourceAbstract.php" hash="5808f3f8a2c6a349aa21e4de678fef40"/><file name="Router.php" hash="54f15d496ef84d800897d8571523e5b5"/><file name="Session.php" hash="714544fe025fa8e5db47686b58fd410b"/><file name="Translate.php" hash="9b75da2a9e3f571a90f30f14bbe72582"/><file name="Useragent.php" hash="17a0a2deba744c0fd4091fb48958b782"/><file name="View.php" hash="18803d667bd908ccfc04edc3e39d209b"/></dir></dir><file name="Application.php" hash="a0c9ea8a48289b2bd9bafd2dfe76765c"/><dir name="Auth"><dir name="Adapter"><file name="DbTable.php" hash="c8b79405b8855b67ffd8d6f82e6a4045"/><file name="Digest.php" hash="bbc1edafb9a244774ca986a2790e5661"/><file name="Exception.php" hash="194d445ab6929d8c5a6faefe604c64a0"/><dir name="Http"><dir name="Resolver"><file name="Exception.php" hash="cf95d8463e66b8dcc7eb679aaa0127cb"/><file name="File.php" hash="56c75079c07a8f3081841dff74f4f8b5"/><file name="Interface.php" hash="136ff303d6f17f676641db12415a679e"/></dir></dir><file name="Http.php" hash="0cfb159e07de35d89ab6754c9e409b1e"/><file name="Interface.php" hash="9baba8292deab88415d58155627009ea"/><file name="Ldap.php" hash="5bec476c61237745110b07a6981f0ba7"/><file name="OpenId.php" hash="9b87324993b0882e8add83140b24799b"/></dir><file name="Exception.php" hash="0cbee6397372cb825d4d2330f1e01cbf"/><file name="Result.php" hash="011bad9ebfb3e12cde52dc199c1b9b0c"/><dir name="Storage"><file name="Exception.php" hash="7c0657994ccacd29c396728dd3e40ead"/><file name="Interface.php" hash="336438156ed6a7db4183fbb365ec24e0"/><file name="NonPersistent.php" hash="88366aa8fd16a4c565e7a6cf467c9d45"/><file name="Session.php" hash="128255a8d51a1d9fa137e137f17b773f"/></dir></dir><file name="Auth.php" hash="6ec79877089d5629bf32dc9cfca8a5ed"/><dir name="Barcode"><file name="Exception.php" hash="5cf74c43e0bb3bda36dab4cdcf435a7c"/><dir name="Object"><file name="Code128.php" hash="989d2bf6723d392c704a9d793a0870c6"/><file name="Code25.php" hash="945a62bd63cefd4bc548aca2175a798e"/><file name="Code25interleaved.php" hash="163795899dd207d6777ed489b3652783"/><file name="Code39.php" hash="6a9d919307643317d2670d0b5a0cfc75"/><file name="Ean13.php" hash="d073b0b3b0d548aa553128e61a8f739e"/><file name="Ean2.php" hash="244bfc6ef32a4d56629c045c929138f1"/><file name="Ean5.php" hash="198f60f22d8bb1d165bff02c5820a20b"/><file name="Ean8.php" hash="8cea912422779ab67e11d8a169063216"/><file name="Error.php" hash="20edaea0778ac6253009722af4bc1ba8"/><file name="Exception.php" hash="4222bc4babead0b78ff6cd53aa72e359"/><file name="Identcode.php" hash="8a1ac5c7c3b04d3e62aa8265c4e1c2f7"/><file name="Itf14.php" hash="9384e00165c9961a203d1f135a3eaa5d"/><file name="Leitcode.php" hash="3c805e7d37dfb51e8de1f35d16ed5da5"/><file name="ObjectAbstract.php" hash="017bd4e5560bfddab60971b889d9f0a0"/><file name="Planet.php" hash="e1c10362fbc9baa5aabede9041060d79"/><file name="Postnet.php" hash="5f6845e59e609f8991fa580bbdc5eefc"/><file name="Royalmail.php" hash="8cc2c93b813ed89f4b0f6cd60df29f77"/><file name="Upca.php" hash="1485da9e266c49e993a00f9d287b4019"/><file name="Upce.php" hash="7cbde278294ce55ff3cb0857f5c014c5"/></dir><dir name="Renderer"><file name="Exception.php" hash="8579d580dcc35ccd16c82590ff39c1b9"/><file name="Image.php" hash="dba737459af451c5c51bad867b77a0a6"/><file name="Pdf.php" hash="1e2d590fe769d9ebf74d901a34635aa7"/><file name="RendererAbstract.php" hash="359cbfacb66cc0fb5ae362845b3fbf58"/><file name="Svg.php" hash="93544d770411772a4dc2c995cced685e"/></dir></dir><file name="Barcode.php" hash="0586994cdf9871ebabd7aa8079566258"/><dir name="Cache"><dir name="Backend"><file name="Apc.php" hash="0770aacd96ff057d06978bcc7a22035e"/><file name="BlackHole.php" hash="f51e1f122876be7d7ba667e39c540901"/><file name="ExtendedInterface.php" hash="fb6c1f28d7049d8ebb5b367586a386b4"/><file name="File.php" hash="292986e780e4b420968b5dfa15267a01"/><file name="Interface.php" hash="9e9a235e4aa33de40ff9fbc97efa468d"/><file name="Libmemcached.php" hash="2f9d3d284be576c031ff2195afaabc20"/><file name="Memcached.php" hash="cbee447e2af7453a2a37ddee2206f971"/><file name="Sqlite.php" hash="8c2ffff28dbe7e5c27a2bfb6fa1a4759"/><file name="Static.php" hash="8b4e8ac2f3e416316d447266e1a6f8dd"/><file name="Test.php" hash="6bcaf9deb1e13215d9fada844fa0bb25"/><file name="TwoLevels.php" hash="1d48225fde0e61fc38401841b28740da"/><file name="WinCache.php" hash="57da7293a57294e3cc2878d872230aea"/><file name="Xcache.php" hash="364f350bb7e58a221a9dda26dfd940d3"/><file name="ZendPlatform.php" hash="dd2264172835c8ac2b1cd0eba670d1ee"/><dir name="ZendServer"><file name="Disk.php" hash="092b29cf8ea2e0391e156ca38a9c8dbd"/><file name="ShMem.php" hash="94d219bd689df1b0ce1f5fe48c0fda7e"/></dir><file name="ZendServer.php" hash="6397a63f6ceba054b9c4c774451109a6"/></dir><file name="Backend.php" hash="046904b4b5c7661bbdcb6c3ec7969af3"/><file name="Core.php" hash="26e9ed27936fe7c894f36a1241b6aa35"/><file name="Exception.php" hash="64896658ade26dbd6b15851aee788379"/><dir name="Frontend"><file name="Capture.php" hash="5e7254e902e587587a9f7c1749787690"/><file name="Class.php" hash="e0fba9da74e040fc5fcbfeede03147d2"/><file name="File.php" hash="291450665f2b240c3a1d0b8f81d9e505"/><file name="Function.php" hash="80926f9d0d94953c8534f381b3e9e92b"/><file name="Output.php" hash="b3902a3f0ddf1b4608b84f6172a317e6"/><file name="Page.php" hash="d447d1e18b8c9ccfe95f5cbd4f8ad0aa"/></dir><file name="Manager.php" hash="bba8e1dfc892616eccc5f033d3849aec"/></dir><file name="Cache.php" hash="dd6b3426e3682f832f5e73a5a5e7bbe4"/><dir name="Captcha"><file name="Adapter.php" hash="c80da3e14f86386865a1a11f386509f0"/><file name="Base.php" hash="f3f587f183c8dbb0f71b588a99f56728"/><file name="Dumb.php" hash="42cf7479a157ab4f6d92f4ea2edd402f"/><file name="Exception.php" hash="a1ea444d80d4629ae987f5120d7b6ab4"/><file name="Figlet.php" hash="9434c31c17fa4558d823f72863bda27e"/><file name="Image.php" hash="8f1bb1448407f673d986cc387846bf3f"/><file name="ReCaptcha.php" hash="7213da2f0082b6a209bf5659d5279036"/><file name="Word.php" hash="2b20aa38f1132306e259f4032ad1de6e"/></dir><dir name="Cloud"><file name="AbstractFactory.php" hash="0360f699d631c5eb6f1f5e117a2a6524"/><dir name="DocumentService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="3679fe7eef0b73516d98565b35e90366"/><dir name="SimpleDb"><file name="Query.php" hash="163f21a702cb5aa76d58682d29559bd2"/></dir><file name="SimpleDb.php" hash="78628ea1029ec6f267c83c302611b6e8"/><dir name="WindowsAzure"><file name="Query.php" hash="657934a415bd7d731906ebb3fa42187d"/></dir><file name="WindowsAzure.php" hash="9a48103bc6327e24a98f27307641c397"/></dir><file name="Adapter.php" hash="22799d67b8935e871e9fcb5403617a9d"/><file name="Document.php" hash="e76315e7e307aa99dae6d634b51c2ece"/><file name="DocumentSet.php" hash="53cabe8e2d6454beab6b476953fb9a58"/><file name="Exception.php" hash="e69eb63ef3ac0476422e553c0f9d0b7c"/><file name="Factory.php" hash="d11189e3ba364466584a8461e9bea29b"/><file name="Query.php" hash="dcf377f4d08e1adc178dcef42a7e21d4"/><file name="QueryAdapter.php" hash="b683d5360841a57b8b58f0ac937b4991"/></dir><file name="Exception.php" hash="baa1da441578d83ef668c947bc26993a"/><dir name="Infrastructure"><dir name="Adapter"><file name="AbstractAdapter.php" hash="1a0c85424e055522ed27fd848641adb9"/><file name="Ec2.php" hash="f702d42320cb2a843124faeff6308673"/><file name="Rackspace.php" hash="12ca011eaa260a98e5f0b021497d6d9f"/></dir><file name="Adapter.php" hash="8fd0db5ff41dd87d2730981cf6a651e6"/><file name="Exception.php" hash="dd74945bd044a9b569715d8b8f33d6c6"/><file name="Factory.php" hash="e35fedab839a9897bd494b4525c70d74"/><file name="Image.php" hash="d0b5a851095a8a6d00cc758e66de65d0"/><file name="ImageList.php" hash="330f4330efa43095c73963860719d8dc"/><file name="Instance.php" hash="aa600d04524311d6da4bfac324aae00f"/><file name="InstanceList.php" hash="9f5c27c450518e4090aa5200261e0804"/></dir><file name="OperationNotAvailableException.php" hash="cb15f6dfb2c6caf15bf3d3c7192a2859"/><dir name="QueueService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="6aafd9d7c44e76e68dd7b8ea83aea6fe"/><file name="Sqs.php" hash="03b431d971a7679aa43dba8d235fd9bb"/><file name="WindowsAzure.php" hash="b4762cebc1460850e73552d5a617ea6d"/><file name="ZendQueue.php" hash="d8aaa2f4ec3302693fcaee2833339bac"/></dir><file name="Adapter.php" hash="c950feca6fdab3f115ba62146e9c4061"/><file name="Exception.php" hash="0406a9d40baf106b1e7c7a52c58622ce"/><file name="Factory.php" hash="1489be14015fdbc7364317e2e6fdb4dc"/><file name="Message.php" hash="48907828e50d23674d1500834ac33d96"/><file name="MessageSet.php" hash="f4371e5f68036dbea532b7899c59679c"/></dir><dir name="StorageService"><dir name="Adapter"><file name="FileSystem.php" hash="c2066ccb70e97bfccf1dc6eca5beabed"/><file name="Rackspace.php" hash="d5b49d598b7a2ca875599df0c07d17e2"/><file name="S3.php" hash="36d663a296803282ec6ffbb4d1f6ecf7"/><file name="WindowsAzure.php" hash="1c266330be81f9034e491cdc5c0becee"/></dir><file name="Adapter.php" hash="4bf256cad4b27a0b4ccd0ea0d2e5df44"/><file name="Exception.php" hash="b1938d4a1d75a132c7896c9d1d49c316"/><file name="Factory.php" hash="e60551fd66495592c25f2143683c0eae"/></dir></dir><dir name="CodeGenerator"><file name="Abstract.php" hash="8bb5c3fb76b0953dad77b8aefd240552"/><file name="Exception.php" hash="2f35c31886c1506cbce95bd48ceb8302"/><dir name="Php"><file name="Abstract.php" hash="7ffc414197119b98d09c089d38b745cf"/><file name="Body.php" hash="4354cf77549e88c8ef742f74df428824"/><file name="Class.php" hash="e96e076b5e9a7a41b9dff5d65d65cbf8"/><dir name="Docblock"><dir name="Tag"><file name="License.php" hash="fa6989bdda9dcc8eed58dfcd5cd11d3e"/><file name="Param.php" hash="c5402463f594b0ada366547e2140c087"/><file name="Return.php" hash="d36a1b1dbd2383043b9703449212218e"/></dir><file name="Tag.php" hash="94c4d5bf7254f1122a9140578562cf4a"/></dir><file name="Docblock.php" hash="3630eee3a36264ed70bb414b1b6659d2"/><file name="Exception.php" hash="4d0d644d274ba0d93c86edabe96a937a"/><file name="File.php" hash="16190c6965142355870ea2d86065c2f3"/><dir name="Member"><file name="Abstract.php" hash="a07d1b1c01755725fd9c670b83e14c6e"/><file name="Container.php" hash="52c0f2936e0dd96e3efaca239e97a537"/></dir><file name="Method.php" hash="facb978030d8ed1148d3fd9b27647a5c"/><dir name="Parameter"><file name="DefaultValue.php" hash="402dc7efb5a973be4b3695d97df9d5e6"/></dir><file name="Parameter.php" hash="f963e92d375973d82c64e9aeeb99aa68"/><dir name="Property"><file name="DefaultValue.php" hash="23583ff2c6b01162f217d3f18e17f5bb"/></dir><file name="Property.php" hash="5d85c620c090d866edd2cc4af3bb0737"/></dir></dir><dir name="Config"><file name="Exception.php" hash="825b93db4d92fc10ff2334d0701ac39a"/><file name="Ini.php" hash="bc377745cc51608820d81f08bb5e622c"/><file name="Json.php" hash="191c7eb21cbb2042491e5548a59087a4"/><dir name="Writer"><file name="Array.php" hash="fa6b3a9d9f68cc5973db7309b93454eb"/><file name="FileAbstract.php" hash="14f344ccee37bac7224aa203e5be6bf5"/><file name="Ini.php" hash="c658c697e401b7fab66edac3e5ab5edf"/><file name="Json.php" hash="675cff174476aab6e44540ce20b9ef6f"/><file name="Xml.php" hash="0ff4954d3f6be816d2911cc236d588de"/><file name="Yaml.php" hash="0a6d7e361af7f4f5cff8a9eb81264318"/></dir><file name="Writer.php" hash="7bca990f32b4a7bf64b6d7bcd6a8b144"/><file name="Xml.php" hash="24d64c4d3269a55f1577d40717069b3f"/><file name="Yaml.php" hash="d559550b7de8c77f03a6d8c5ab1af715"/></dir><file name="Config.php" hash="0ec674c135a25bb65bf7f2f536496373"/><dir name="Console"><dir name="Getopt"><file name="Exception.php" hash="ba4d96e50ff729964f51d3ff320a695b"/></dir><file name="Getopt.php" hash="a8165d6a04ff959844c118bd1517d4af"/></dir><dir name="Controller"><dir name="Action"><file name="Exception.php" hash="5c5bfb99e09c49bfd42afc92cca046a3"/><dir name="Helper"><file name="Abstract.php" hash="2db15ec4775320a42a86fc96ded791f6"/><file name="ActionStack.php" hash="72d618b0c01345a39b86362d00b519e5"/><file name="AjaxContext.php" hash="d25cd19237deee404b1d78c3babc51e6"/><dir name="AutoComplete"><file name="Abstract.php" hash="8265a4c01db3fc5ef8359855b5bc7de7"/></dir><file name="AutoCompleteDojo.php" hash="bc727565a422d34c4ee642604bca989f"/><file name="AutoCompleteScriptaculous.php" hash="423035f705a0ead78f0b508915f9f11d"/><file name="Cache.php" hash="5e1ee2f20930ce3ce6c9ff95c7986fd5"/><file name="ContextSwitch.php" hash="bbde32302aea3a45df7525ee558ba61b"/><file name="FlashMessenger.php" hash="6f60de563b5b400d75b630f359ce09be"/><file name="Json.php" hash="46f702a70e0d5e4ecff66439b34502aa"/><file name="Redirector.php" hash="246b26f4b71cdab25a5992577986b119"/><file name="Url.php" hash="16c5a98afe9f6f14bee59bbb0ee58583"/><file name="ViewRenderer.php" hash="6eac5b3e0152d2c000145c6a4076456a"/></dir><dir name="HelperBroker"><file name="PriorityStack.php" hash="9919f1af00251ac5d7a362dba0a280c8"/></dir><file name="HelperBroker.php" hash="aa9cf211934ac5b4fc9e4220ad26d7ca"/><file name="Interface.php" hash="0cb0ece63ce5a245010b9c79927149fe"/></dir><file name="Action.php" hash="1eff5915284945de72327a06cb10c10a"/><dir name="Dispatcher"><file name="Abstract.php" hash="3a481b8b2beb61d223f1c90757339a6d"/><file name="Exception.php" hash="21e0c2b4a1f642448f391e0601bf8327"/><file name="Interface.php" hash="323c3bfe932dca40b3f0f18ebaa39bf4"/><file name="Standard.php" hash="ccbde33f1d7616c2c35ee556039b12a0"/></dir><file name="Exception.php" hash="75ef40958ca34b2ce0007a6a9bd11b62"/><file name="Front.php" hash="a0cd827d65e2d2cc1d51d96009d61032"/><dir name="Plugin"><file name="Abstract.php" hash="4f9c2a5fcb32f0f02d01559c2900e2ff"/><file name="ActionStack.php" hash="dc0f223ebf96304711e62b0ff066cbe6"/><file name="Broker.php" hash="4558d24e01418e1a7a4a45f8a0419b05"/><file name="ErrorHandler.php" hash="1b86cb0d967cb3a80091271532e5f29f"/><file name="PutHandler.php" hash="5b65c0f667538e81cd5152060b1fc50e"/></dir><dir name="Request"><file name="Abstract.php" hash="479150985f9f5b1ad60da1c627ba5422"/><file name="Apache404.php" hash="6e4073adcf927bc08c36267350259110"/><file name="Exception.php" hash="401a6bfe6ee4f2eef739d5622d457235"/><file name="Http.php" hash="4866762dc4e2d7f2f70ebcf3ec3f3174"/><file name="HttpTestCase.php" hash="fee8b0ea3da866bae3125716977e609a"/><file name="Simple.php" hash="4debb461f0bf9c865b3ef7e9a2f9eec1"/></dir><dir name="Response"><file name="Abstract.php" hash="41812ba5c1950b91ca6db21c36a65022"/><file name="Cli.php" hash="1be9de58bd3af4e70797422c5936b9f0"/><file name="Exception.php" hash="daf74bb0fb6ffed9c50a414b78947388"/><file name="Http.php" hash="1b97675e6f09aca759dd04cadc2ada31"/><file name="HttpTestCase.php" hash="b8e25dbcd9245fce7f9e985aedb53ab2"/></dir><dir name="Router"><file name="Abstract.php" hash="7c3976721fbba2c462793f6152a7952a"/><file name="Exception.php" hash="10f91dd02d28dfb9c5de84d778f5e451"/><file name="Interface.php" hash="3f0e4586ac18e02e172ff65e1228a197"/><file name="Rewrite.php" hash="333634b9f184476914d985f68d06b12a"/><dir name="Route"><file name="Abstract.php" hash="c0437b622e03a117783fc6d8c2a581da"/><file name="Chain.php" hash="eb747ff18f4f5549888a7964b8f16f2e"/><file name="Hostname.php" hash="b54e6b9f68ffa63f9c493f82606ab2ac"/><file name="Interface.php" hash="80dd1da3a1fe916fcf173891716985cc"/><file name="Module.php" hash="dca7ac356221ebd066c5b17a72557551"/><file name="Regex.php" hash="4bcd3642f6ee8d66b9ec9cf591cfa121"/><file name="Static.php" hash="2bc26cb37610470e8fbb0e9302e76175"/></dir><file name="Route.php" hash="9be953ae63b6074535656826c99f88dd"/></dir></dir><dir name="Crypt"><dir name="DiffieHellman"><file name="Exception.php" hash="27066062da23c7b0b5c8ea405d63424f"/></dir><file name="DiffieHellman.php" hash="b146591071090ba7dc2d120c8d7cfcb1"/><file name="Exception.php" hash="98d264f8b46a12e8e1fa644b37488636"/><dir name="Hmac"><file name="Exception.php" hash="3b8bf2fed9087ce573c7d9e461211d01"/></dir><file name="Hmac.php" hash="7beea2bae905ad98fc8212a5a2ba906c"/><dir name="Math"><dir name="BigInteger"><file name="Bcmath.php" hash="7ad0514366aa1cfbbacf9a841d17209d"/><file name="Exception.php" hash="c7047b1ec96c2c5bf9d2ec8fd516c232"/><file name="Gmp.php" hash="1e136ad9748ff4e120be567de7195084"/><file name="Interface.php" hash="a1a15aadc0d1232e19e3660778e25a4e"/></dir><file name="BigInteger.php" hash="5941fbc6fa7558f254212a5c704de46f"/><file name="Exception.php" hash="0a2a9e2cdf2619549bb1891d31565cb4"/></dir><file name="Math.php" hash="0e54c36e33bb980ba251c42719e72e48"/><dir name="Rsa"><file name="Exception.php" hash="9af79ec754f6202584671b395e9898cb"/><dir name="Key"><file name="Private.php" hash="6b8486eba224159d7c05dea23039ec8e"/><file name="Public.php" hash="8cd4ac9225b58e1a2990659f4a97a45d"/></dir><file name="Key.php" hash="a0c0daf511c3a74d1e754faeaace0f83"/></dir><file name="Rsa.php" hash="e46289dffb56184f7c15faa3b24a0a68"/></dir><file name="Crypt.php" hash="ae1d981cb224263c8625604621d0ffc9"/><dir name="Currency"><file name="CurrencyInterface.php" hash="c52c23140b8d66185e2792cb10c65b40"/><file name="Exception.php" hash="f04c4fcb9b9b4117ab0c91e688904a06"/></dir><file name="Currency.php" hash="e380eca83740d28bb55435c3489204cf"/><dir name="Date"><file name="Cities.php" hash="4698b47f264db687c97ea7fa5ccd717e"/><file name="DateObject.php" hash="05ef22746ef2b1925cce51d42a5670b9"/><file name="Exception.php" hash="b91a2d166cf91afa1325a07747bafe57"/></dir><file name="Date.php" hash="6d17472f661d6b599477f215dda67f82"/><dir name="Db"><dir name="Adapter"><file name="Abstract.php" hash="7d5a1b64e9f292c018fec8fca159311b"/><dir name="Db2"><file name="Exception.php" hash="b64143620db1d7e5cd7b90312aeaf7bf"/></dir><file name="Db2.php" hash="d27757593a5be92da47326b25af8b4a4"/><file name="Exception.php" hash="461a43822f24e3e79bf8a844541235a3"/><dir name="Mysqli"><file name="Exception.php" hash="71ae5837eee0e261ba7639dff878845c"/></dir><file name="Mysqli.php" hash="c997a7381205b413a03efba602f2debd"/><dir name="Oracle"><file name="Exception.php" hash="8a08377363d09d1711c31ed0e2b4f220"/></dir><file name="Oracle.php" hash="2c539f9ac5ce7e656f3432c9aa00daae"/><dir name="Pdo"><file name="Abstract.php" hash="1f71eaf0415b750ee0573a80374e61cb"/><dir name="Ibm"><file name="Db2.php" hash="b947c61e9abf1f277adb40dc1aaf6319"/><file name="Ids.php" hash="a2d4fcf42c7b9435515399862224d74c"/></dir><file name="Ibm.php" hash="1042d1f01417241dc09679e1edb3a248"/><file name="Mssql.php" hash="139b7b3957b4e2b347d220b9dc8e959d"/><file name="Mysql.php" hash="0ca1bc627085e101ce51e02328b16347"/><file name="Oci.php" hash="819a1b3d31d7f65ba3f9de49ceecdf30"/><file name="Pgsql.php" hash="1b7fde0593b3799e4afa1f74b63499d7"/><file name="Sqlite.php" hash="efb68039f3e1b9e34a81c3dc9d0e8f20"/></dir><dir name="Sqlsrv"><file name="Exception.php" hash="097530f562d1993a992d6f62aadea809"/></dir><file name="Sqlsrv.php" hash="0fb64191a2d9e688410094c736d5eda6"/></dir><file name="Exception.php" hash="aebb5d861915d6a2494c58fc343f2752"/><file name="Expr.php" hash="2dca05427df6b34d6da9fb872517f684"/><dir name="Profiler"><file name="Exception.php" hash="42d03d9fd63aada757d6dabacdb73cb0"/><file name="Firebug.php" hash="1f5b0198a97091bba6ec8a8f74f3cf1a"/><file name="Query.php" hash="fe0bfc38389c14cecc76d528e33bfe83"/></dir><file name="Profiler.php" hash="e7327368b94ae8e094c602e41f617609"/><dir name="Select"><file name="Exception.php" hash="f8b241a9791bc28c77ca8c14cf80ba84"/></dir><file name="Select.php" hash="0fb5975684da5ea68ed45e4437d759d6"/><dir name="Statement"><dir name="Db2"><file name="Exception.php" hash="05225962b3d3107841d87d0d6c4ca9de"/></dir><file name="Db2.php" hash="36c397903c5e07ebe5b82b5e76030c7a"/><file name="Exception.php" hash="d41110267373d38bb4af77e1785329ae"/><file name="Interface.php" hash="222f50673200f578767b1e0c43d5a6bd"/><dir name="Mysqli"><file name="Exception.php" hash="1932b0ae9232ab79ccacadd46a45f022"/></dir><file name="Mysqli.php" hash="64e3e41642115ec95cce487da79fe737"/><dir name="Oracle"><file name="Exception.php" hash="59588ef7feadf4b0a726d1e1410f10bd"/></dir><file name="Oracle.php" hash="3fd727a08bbb347495dd6a2fb044defb"/><dir name="Pdo"><file name="Ibm.php" hash="aadb46dbcc67223ab9e240c35301cb0d"/><file name="Oci.php" hash="75a7032f82e8e29f52a8994a847e9533"/></dir><file name="Pdo.php" hash="91da6eddeaa94a88bcea2c3c912480bb"/><dir name="Sqlsrv"><file name="Exception.php" hash="925701544428f06183ecbb6718047839"/></dir><file name="Sqlsrv.php" hash="4d49d2edc91902768b1685768ac0421c"/></dir><file name="Statement.php" hash="48578c5307d13998d3b9dc73486bb666"/><dir name="Table"><file name="Abstract.php" hash="d1f0eb94b3a83abab809a132edec8d70"/><file name="Definition.php" hash="056d17187e24f48f42059889802ade8d"/><file name="Exception.php" hash="4ad0192e2759ce865081bfd65fba1537"/><dir name="Row"><file name="Abstract.php" hash="79e1dca4c87a158d36b171b11ec721a5"/><file name="Exception.php" hash="3182c2febc7a67988a02a2f4e3262c7c"/></dir><file name="Row.php" hash="adb2429446ad01b98bf74a1c79802009"/><dir name="Rowset"><file name="Abstract.php" hash="6474578f17e077f0d176de3d41bd43fa"/><file name="Exception.php" hash="c5e373d4e4d06e728572b3ca8c5d7d40"/></dir><file name="Rowset.php" hash="0534466fa3f58d60e28761013df1035d"/><dir name="Select"><file name="Exception.php" hash="c87230b6b7401370de518e6ad7218203"/></dir><file name="Select.php" hash="4a86cf29c8e383613e79caa5ef51ca36"/></dir><file name="Table.php" hash="bddf2a8c1ee791ef8a75fd81362a95b9"/></dir><file name="Db.php" hash="944811d3042ae76f201ce5ccee064693"/><file name="Debug.php" hash="e91277596844e74a3189f72b260d743f"/><dir name="Dojo"><file name="BuildLayer.php" hash="59fd3f007b9ddfe836308735a4fad349"/><file name="Data.php" hash="584f49393cc79deedcd43f36ff7cf68e"/><file name="Exception.php" hash="ce849ec1ac41925ce396495a4c0b5e5f"/><dir name="Form"><dir name="Decorator"><file name="AccordionContainer.php" hash="5ccfa22f987078a553c8334a1751a78e"/><file name="AccordionPane.php" hash="bfb6959fc54968e6e631a7b812f795cc"/><file name="BorderContainer.php" hash="3630699c89e4d611d463952ab7b616af"/><file name="ContentPane.php" hash="f5e7d589fc667a74c537f1c4a1d2f1ee"/><file name="DijitContainer.php" hash="6e30cb3a91ee447e6d9ae587a5b08fdc"/><file name="DijitElement.php" hash="63a591c8ae6f23a5fac3c4c4799849b6"/><file name="DijitForm.php" hash="3107c8e3a51efd7cd960a4d140fd2552"/><file name="SplitContainer.php" hash="32118776073ace34a7a6e6b775f7a41d"/><file name="StackContainer.php" hash="511f80fb7e777c7420df3a33e5d36df3"/><file name="TabContainer.php" hash="bfba332a70e20ac8e4bc1f9a7b488ffe"/></dir><file name="DisplayGroup.php" hash="4fc35365159beb7532119735b43ac5ae"/><dir name="Element"><file name="Button.php" hash="3ed66e9ab5b21731a355a35cc0bdadc5"/><file name="CheckBox.php" hash="cdf55f6261658dc12c508397228c86d5"/><file name="ComboBox.php" hash="ad263405d78671cb38f39a42f4153306"/><file name="CurrencyTextBox.php" hash="8a0101a9a7fdc7504fe882222df91d8b"/><file name="DateTextBox.php" hash="b1a766b9190c2c124d34d59d8c742f04"/><file name="Dijit.php" hash="8389aeca66aecb8a39d9341f81ded916"/><file name="DijitMulti.php" hash="bd0fe55261b57bcd2c92ea196eceaf08"/><file name="Editor.php" hash="bb3636533a931bc1f9a5782ac4c66565"/><file name="FilteringSelect.php" hash="d330a4330b410089733f8c1eeb1839e2"/><file name="HorizontalSlider.php" hash="b23bd0da212335080121f31e318f743d"/><file name="NumberSpinner.php" hash="9ae185b60accc9edb7baed24b93ca540"/><file name="NumberTextBox.php" hash="cc340c040ab7c8eaa02bf401a9a91bc3"/><file name="PasswordTextBox.php" hash="48b304d5bbfb2417adf1724362e032b6"/><file name="RadioButton.php" hash="80e8b86eaf8258626084f54272a7a576"/><file name="SimpleTextarea.php" hash="69791b92fb7d656676266fe53592b6b0"/><file name="Slider.php" hash="21f9f99bb495bcf2997a022f6a43c276"/><file name="SubmitButton.php" hash="52c7e25fd90d33b9501150746b046e14"/><file name="TextBox.php" hash="874413d9bf8c39f9a7a73d7175842cf5"/><file name="Textarea.php" hash="1fab8c9619163b0fd1cdeaf4bf4113c7"/><file name="TimeTextBox.php" hash="6ab9be9f6555bdc14ba9a02fb18c3157"/><file name="ValidationTextBox.php" hash="dd456a154f47bc74e05834800490ad53"/><file name="VerticalSlider.php" hash="c99c979911b12b2907b9ce727d595f42"/></dir><file name="SubForm.php" hash="46b28da42e2447cdf7f23ce8635a6243"/></dir><file name="Form.php" hash="5dc7b152deef6e0fedf0c0caa73f7c68"/><dir name="View"><file name="Exception.php" hash="fed5a27397fd8fb08841c1db38364df7"/><dir name="Helper"><file name="AccordionContainer.php" hash="3b2eaa765a22ea9a2d3d2e507da446b8"/><file name="AccordionPane.php" hash="94b8d5edb317926ca8aee3539c33ce8a"/><file name="BorderContainer.php" hash="f8b3939b919a3f961c8da6196b2166be"/><file name="Button.php" hash="e1e816f2362a2f973acceadb1414de98"/><file name="CheckBox.php" hash="43f1a6ad27883f62cda4bc1b560c9f89"/><file name="ComboBox.php" hash="d2811e390eb44a4f3e953c241949db0e"/><file name="ContentPane.php" hash="041084c11934376f3f759154a1835abf"/><file name="CurrencyTextBox.php" hash="56f2046e985a0d1cd81ba0d045f91a7a"/><file name="CustomDijit.php" hash="34bfe4e1501f8dc1227adcc9b7e2b20b"/><file name="DateTextBox.php" hash="81bdffce0b2acb693a7c2cbd3941f156"/><file name="Dijit.php" hash="7a1eb3742998cbbabac1b2338a590566"/><file name="DijitContainer.php" hash="3091a920fbfb48215a59f73be1988eaa"/><dir name="Dojo"><file name="Container.php" hash="e40d8395af2e395a2e81d593e8f4602c"/></dir><file name="Dojo.php" hash="6303c9d4ede5b67cc828ead89c4016a6"/><file name="Editor.php" hash="f251624a2b798b53eea465d9938ac276"/><file name="FilteringSelect.php" hash="60bbdd84239febff9241199104b4cf1a"/><file name="Form.php" hash="105f502558eb241c81c39be0e5d85a72"/><file name="HorizontalSlider.php" hash="7b3c19156aee3db41dbaee18abe2ded7"/><file name="NumberSpinner.php" hash="cf27c892acfeb8ba60027bba29d8715a"/><file name="NumberTextBox.php" hash="9674fa01666c5622896d4513da69ce8d"/><file name="PasswordTextBox.php" hash="0ba727cff497c3b580bffaf04eecc75b"/><file name="RadioButton.php" hash="ddd9733fd29a47cf20f224115895d2cb"/><file name="SimpleTextarea.php" hash="8162db2b947a8b380099ee4266bd2edb"/><file name="Slider.php" hash="b09cd129a4885cb799978b234e8ef496"/><file name="SplitContainer.php" hash="8fa96d45ff63d2b0f24250856afea806"/><file name="StackContainer.php" hash="f3f24abf9640124f26274b9663eccd5d"/><file name="SubmitButton.php" hash="9083d4797eb4be0a879951a88be9a6f3"/><file name="TabContainer.php" hash="8b6865aa0b8015b220896d3487ec0966"/><file name="TextBox.php" hash="75b65da85221b840ff6f3bd4d38890e2"/><file name="Textarea.php" hash="58421d644f61edc039bdaf8b2d13af7d"/><file name="TimeTextBox.php" hash="7865f42c62fd06ead74987324d2310d0"/><file name="ValidationTextBox.php" hash="59bc7469004e22811c038791462d67a7"/><file name="VerticalSlider.php" hash="9c113d757c1b99048d09ba8949452034"/></dir></dir></dir><file name="Dojo.php" hash="3d5a5b6120bb16fbde6a24fc082bb2e7"/><dir name="Dom"><file name="Exception.php" hash="764e44b0e7b8346387c4b677e725d6bf"/><dir name="Query"><file name="Css2Xpath.php" hash="84d8020779e37ed005fa2ca53052731c"/><file name="Result.php" hash="2c8f3fdb6f945804d2a2b5881b5c0567"/></dir><file name="Query.php" hash="ac0c71f2c7a030485756a780c2ca5904"/></dir><dir name="EventManager"><file name="Event.php" hash="73a22bba4a1536ad0bedb311992ed841"/><file name="EventCollection.php" hash="6846535fe1c08a148593082878839b2b"/><file name="EventDescription.php" hash="6cb5b7a743c322cc486c09de9e2466c1"/><file name="EventManager.php" hash="775973335393a6aab98b63fd7e580f6f"/><file name="EventManagerAware.php" hash="616ae31ca46f1f0206e28851f408e777"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4651b42388b3cc0f6a8c77b8c92a988f"/></dir><file name="Exception.php" hash="a7a76fcb8615694bebfd1b7a6c63cc2e"/><dir name="Filter"><file name="FilterIterator.php" hash="479bdbab563e57ade8718744d6a9eaed"/></dir><file name="Filter.php" hash="a6705be98a15d9abb250329a18bc5f44"/><file name="FilterChain.php" hash="0bbe4e22e4bd7731c91b0d8849e24dd4"/><file name="GlobalEventManager.php" hash="2448f17e7235ad32e0986dccaaf6f21f"/><file name="ListenerAggregate.php" hash="e0bf702bb54b9ba2d54828a2d66d2954"/><file name="ResponseCollection.php" hash="14500f355513b35b17a7dd7e947f5301"/><file name="SharedEventCollection.php" hash="0504cdf3c7168fa6e6a1d164705617c7"/><file name="SharedEventCollectionAware.php" hash="c53dea67b8742191c78911a87cf4c1c5"/><file name="SharedEventManager.php" hash="973daf2597a36f485ec43ae91f53fbef"/><file name="StaticEventManager.php" hash="47bc3c834d44e64eab6ea0b0c0a83eba"/></dir><file name="Exception.php" hash="fdca55eece8acc76af7ec98eca620311"/><dir name="Feed"><file name="Abstract.php" hash="66b85329fd8524fc66b93c16397cc49d"/><file name="Atom.php" hash="24d80774c71e1932b8be5054793d4fd6"/><dir name="Builder"><file name="Entry.php" hash="4871eb1a5d2084552d48b346fb9424ae"/><file name="Exception.php" hash="f8d2074819dd7157b4de4428579958c9"/><dir name="Header"><file name="Itunes.php" hash="da87e20a7e6b587316644377c8cc3c55"/></dir><file name="Header.php" hash="7e1b1053ef90762e3b6d9933cab4964b"/><file name="Interface.php" hash="407dbfd89e522c6e033214974954ad9c"/></dir><file name="Builder.php" hash="9453c5958f2cc22bd37a1e8e8de22ff7"/><file name="Element.php" hash="04f6a067ec047936af106f5a3ee9f0ee"/><dir name="Entry"><file name="Abstract.php" hash="44340d16439984b02edd6f26d7a1885e"/><file name="Atom.php" hash="a2642776469712e0e2dfcc0912e98aa3"/><file name="Rss.php" hash="93e478df77e9c9c43c55334ce2165a8d"/></dir><file name="Exception.php" hash="3ce015184369dd3392923dba02ccb4ab"/><dir name="Pubsubhubbub"><file name="CallbackAbstract.php" hash="5fc3da695c59069c88f54206485038c9"/><file name="CallbackInterface.php" hash="3b8478bc6bac3d9309c0fe7ba6f89dd0"/><file name="Exception.php" hash="028e2d741379246df90e62b96393ffe9"/><file name="HttpResponse.php" hash="6a929e3ac877b89fd0b8664b9894f953"/><dir name="Model"><file name="ModelAbstract.php" hash="ce0a0b0b03f77348b066a947e4d4a087"/><file name="Subscription.php" hash="99c0b396f4e21b0fe2bc3c068220958e"/><file name="SubscriptionInterface.php" hash="63f95bde2e9254d0e3c31b905fea78bc"/></dir><file name="Publisher.php" hash="44d781a089ad5ac1ee949b74badad6ca"/><dir name="Subscriber"><file name="Callback.php" hash="c50e22f4bec18ed4365b7a7fd472db69"/></dir><file name="Subscriber.php" hash="3a06e76251527da315017fd545595ee2"/></dir><file name="Pubsubhubbub.php" hash="9187f4accebd9b1b23010e141485f2c8"/><dir name="Reader"><dir name="Collection"><file name="Author.php" hash="bd0aee1688a6905cfa60ad3df2876d42"/><file name="Category.php" hash="0ac74f5a4ea9492998e7f76e6e959283"/><file name="CollectionAbstract.php" hash="a0d023979ca9ca7c2fdf93e0acb36745"/></dir><file name="Collection.php" hash="6a92b8355578f92468d24f03c33f6e7b"/><dir name="Entry"><file name="Atom.php" hash="c4f9ba356c97d5ad4ad6a5a210fa5d31"/><file name="Rss.php" hash="01b9d9b750ec9c730bc3fa624629deeb"/></dir><file name="EntryAbstract.php" hash="b9e05d05ad657e24bca3947764bf4aba"/><file name="EntryInterface.php" hash="3e33c60c08158ac0398bb9f05ec2090b"/><dir name="Extension"><dir name="Atom"><file name="Entry.php" hash="6baacc2e3ddc23ad3cfa9e190fd54157"/><file name="Feed.php" hash="16e84c49d96b759d10b1fe86982cca2f"/></dir><dir name="Content"><file name="Entry.php" hash="4a01e7b785bc08518739d03825f8c7af"/></dir><dir name="CreativeCommons"><file name="Entry.php" hash="4c7cc6a5ddcb6971e2a7d30c701151b7"/><file name="Feed.php" hash="40b8c9f5146271c2fe7433f7daff07ac"/></dir><dir name="DublinCore"><file name="Entry.php" hash="3ff54fc3fe5df35c8ba4075ed42dabeb"/><file name="Feed.php" hash="56f06a3e2739c70c66da54e7608c9496"/></dir><file name="EntryAbstract.php" hash="fb62ce68f7a440fac11ec666e9e4bc22"/><file name="FeedAbstract.php" hash="c1283a62809662e762cd0a7875b0b913"/><dir name="Podcast"><file name="Entry.php" hash="738c47a9b19c44bedbce6a6e901ee173"/><file name="Feed.php" hash="23c593352bc891c6bbce22e98da18f6e"/></dir><dir name="Slash"><file name="Entry.php" hash="29d24797987342ea6a580a48af0accb5"/></dir><dir name="Syndication"><file name="Feed.php" hash="67ec064681ba8a77b4f6d44a35d4d8f7"/></dir><dir name="Thread"><file name="Entry.php" hash="202da1cb171c55d435b125cfb264d874"/></dir><dir name="WellFormedWeb"><file name="Entry.php" hash="88c3ee8f88632712522d206426a2927c"/></dir></dir><dir name="Feed"><dir name="Atom"><file name="Source.php" hash="71d4bceda67dd3a4acbc45bbee33853a"/></dir><file name="Atom.php" hash="042c93075ae2e933e5241750c101d3de"/><file name="Rss.php" hash="e354bd24fbf48a5bab9d518e3912bd93"/></dir><file name="FeedAbstract.php" hash="e577cfdd039f4025877f12d2d08dcce6"/><file name="FeedInterface.php" hash="7eaed63ef055848aa1b299bc98d8cc11"/><file name="FeedSet.php" hash="5ba5f156ac7607b73929dac85826c659"/></dir><file name="Reader.php" hash="d9bc6e5b898eb8be4fa72e313e89bccb"/><file name="Rss.php" hash="e14ca674ad56d9ce18df5d9728c770bc"/><dir name="Writer"><file name="Deleted.php" hash="35aad5db793b86ca638a81d052c6ae14"/><file name="Entry.php" hash="87c1a1d4b637d4918f5fabe8b56c1a9a"/><dir name="Exception"><file name="InvalidMethodException.php" hash="02419d36ca4d923b7ae46f8cf5e9808b"/></dir><dir name="Extension"><dir name="Atom"><dir name="Renderer"><file name="Feed.php" hash="e1c642e0775de8ace9639daff1a932aa"/></dir></dir><dir name="Content"><dir name="Renderer"><file name="Entry.php" hash="f86cd399902d04ab6652aa952c81916f"/></dir></dir><dir name="DublinCore"><dir name="Renderer"><file name="Entry.php" hash="6f79082f7b75e1d7b73930169ff6d5e0"/><file name="Feed.php" hash="8b6825b40579ce795e0018eac48a0fa6"/></dir></dir><dir name="ITunes"><file name="Entry.php" hash="e23d802f1cc74b432a3c5362be650c55"/><file name="Feed.php" hash="ffa388bb1b1c868a92978ee85f3c8d50"/><dir name="Renderer"><file name="Entry.php" hash="184f5e6f780c987cb55374c6b899dee2"/><file name="Feed.php" hash="c5df3307f99f2349024d3a31612d67a5"/></dir></dir><file name="RendererAbstract.php" hash="427c8bd29a3f0aec64f2034405b8fa89"/><file name="RendererInterface.php" hash="2cbb9d13b450a08098921fe99f5084bf"/><dir name="Slash"><dir name="Renderer"><file name="Entry.php" hash="95b4d946971ccd12e852d36125e241ad"/></dir></dir><dir name="Threading"><dir name="Renderer"><file name="Entry.php" hash="81fa4f73e25ce35482f8ea2d01ceac48"/></dir></dir><dir name="WellFormedWeb"><dir name="Renderer"><file name="Entry.php" hash="45c4795ca01add23d35af6ca1961a27b"/></dir></dir></dir><dir name="Feed"><file name="FeedAbstract.php" hash="65fa012f95547e0e63deb8715038c9c0"/></dir><file name="Feed.php" hash="699463ea19aa24d3cf48d9ddf37d63d4"/><dir name="Renderer"><dir name="Entry"><dir name="Atom"><file name="Deleted.php" hash="65126201b8fb20b29f945956c3c7aa14"/></dir><file name="Atom.php" hash="fd98f2be04963b4a660c49cd0bb9db5e"/><file name="Rss.php" hash="f0e70e6a183416e6c04a1aa58d91b128"/></dir><dir name="Feed"><dir name="Atom"><file name="AtomAbstract.php" hash="2762eb27cc4182026d7cb5d4a2d8e7d0"/><file name="Source.php" hash="b4432fc84152c9922c2a0318043431e2"/></dir><file name="Atom.php" hash="a4e0a7056233cc18c1abcbcf45895b3a"/><file name="Rss.php" hash="b01a32487ec79c8e29848e56d12f4fef"/></dir><file name="RendererAbstract.php" hash="e818b72ef7cccb7e411218194c4a90c2"/><file name="RendererInterface.php" hash="b9d0002ea9fd72117b6438231ca2db9e"/></dir><file name="Source.php" hash="3cce4bf24782f65948e0078eee3af8b8"/></dir><file name="Writer.php" hash="31915fe86b889b38f29cd365dfa2eef8"/></dir><file name="Feed.php" hash="90930372cd8489f1be5480df69e492a3"/><dir name="File"><file name="ClassFileLocator.php" hash="a763041253fb82e55d99e50078f9e791"/><file name="PhpClassFile.php" hash="95812fdfe2ea77215eaf98220970d2bc"/><dir name="Transfer"><dir name="Adapter"><file name="Abstract.php" hash="9f8caf0965ee20c3e394cc9abd39dc64"/><file name="Http.php" hash="98db3d564539a149becd025db2996089"/></dir><file name="Exception.php" hash="825fcee61f10cdfe37140f8053177a3f"/></dir><file name="Transfer.php" hash="3b238f59905a999aa851bd4e7b641d64"/></dir><dir name="Filter"><file name="Alnum.php" hash="4ca46f20de00a3ae2c141f1ceff56bad"/><file name="Alpha.php" hash="5b07ed4ed80ac52058355dc25eab7f17"/><file name="BaseName.php" hash="625ce144adaded5d1a792f2cdff08ddb"/><file name="Boolean.php" hash="8a4ccc8b5fe35cc6371f2a876c1687c4"/><file name="Callback.php" hash="877df95b6818f3919ff98ef2b792beab"/><dir name="Compress"><file name="Bz2.php" hash="85a13672065e12d52a4a53c7d57b5956"/><file name="CompressAbstract.php" hash="e31d6c9f72772def373f5f947ebb4857"/><file name="CompressInterface.php" hash="fea3425ce29a7262ac9aa37ca15e7ccd"/><file name="Gz.php" hash="e1a5c9d4301ba780b0fc2a2ab69b9cef"/><file name="Lzf.php" hash="238dbeb23d34fab2ce1fd53c5728c981"/><file name="Rar.php" hash="ee424491867ca2fce1556bdcf01e0a7f"/><file name="Tar.php" hash="e9fc01174f800ebf4e87294361714fe8"/><file name="Zip.php" hash="1adcddd63511b526c388dbbfb2693ca5"/></dir><file name="Compress.php" hash="17af88fb4588855a0fa2ad0c747e567c"/><file name="Decompress.php" hash="9900b029a91c9c1620903061b15d8b5d"/><file name="Decrypt.php" hash="ea36fb417859a47bc8090908f91c79b0"/><file name="Digits.php" hash="988e652d047ccb2b3f51368702b39932"/><file name="Dir.php" hash="ded6da050ac44e21c8729c4fd74559f0"/><dir name="Encrypt"><file name="Interface.php" hash="02481da5488767e23939a73b434d6728"/><file name="Mcrypt.php" hash="2320868b4e3235e934023f6339edb9ee"/><file name="Openssl.php" hash="37f02c9e5fd864557aca070ca8525e36"/></dir><file name="Encrypt.php" hash="41b1fa4536947b9ce5e4dcadb3bf80b7"/><file name="Exception.php" hash="ee7fa3aa3daed6b376e4fe3ff0533a65"/><dir name="File"><file name="Decrypt.php" hash="f82c770a201d0016ed0054874f39c90f"/><file name="Encrypt.php" hash="63c6232b0c216381bee8c18df751ab59"/><file name="LowerCase.php" hash="664f911dfcba8fb26ad86605eda4ad93"/><file name="Rename.php" hash="d854b8b98abd89db4d4b0eca30a2b496"/><file name="UpperCase.php" hash="9aad43cc07b024188734fe231ec7a80e"/></dir><file name="HtmlEntities.php" hash="6ce1c0425b0b5f48c21649c15ffe1d26"/><file name="Inflector.php" hash="b6b671c8956fe8c359af7739c56867a8"/><file name="Input.php" hash="fc8cc25c2f9da1b1da7b2839eb914c99"/><file name="Int.php" hash="41724f5b9f96f08b6b01281891bc3eab"/><file name="Interface.php" hash="0f810dcab23fc1f455c960af3f317a04"/><file name="LocalizedToNormalized.php" hash="6b98acca5dc278027620e0d5361a316e"/><file name="NormalizedToLocalized.php" hash="27f9795714f46c3d4a143330e77219ce"/><file name="Null.php" hash="fe5c2ff3f08d7ef9ffc140ad251dd6da"/><file name="PregReplace.php" hash="7b0c18825dcc9016d0cc2a0fea8fee53"/><file name="RealPath.php" hash="133f0776eaa042a0712e2d8e7db3ed7c"/><file name="StringToLower.php" hash="9a7352bfa73b4ac825bc2af9fef3c286"/><file name="StringToUpper.php" hash="ec2165f772585dcf346b589bbf9bc716"/><file name="StringTrim.php" hash="ca76b8743fd9ec88290ef11a24d48a03"/><file name="StripNewlines.php" hash="fe69c99129f9bd2b69ea16c0bbfc61c1"/><file name="StripTags.php" hash="78d7393075f2327644e873d4e9196082"/><dir name="Word"><file name="CamelCaseToDash.php" hash="3793e4ef36c6778b9e5df032dfc15b67"/><file name="CamelCaseToSeparator.php" hash="cd445e16f5d3ef145c4b0f35a10b1dcd"/><file name="CamelCaseToUnderscore.php" hash="932bcf0ead2bda7d9ba9544458fe2de8"/><file name="DashToCamelCase.php" hash="705245ae67e4a9eede0bb3c0bf0e6ac4"/><file name="DashToSeparator.php" hash="6edcb2382b8fc7acc8448679d6fb46b4"/><file name="DashToUnderscore.php" hash="1075b2edc67d246d7f300c336a00a745"/><dir name="Separator"><file name="Abstract.php" hash="7c13a127a26229fc8d5e0678e8efcb5f"/></dir><file name="SeparatorToCamelCase.php" hash="87f3c3a2ab24e2146db100710050d873"/><file name="SeparatorToDash.php" hash="d13f2d966ffd8cfb05114fbb9f3906b1"/><file name="SeparatorToSeparator.php" hash="3f70eae82b1616c098cd9aec7be41f9c"/><file name="UnderscoreToCamelCase.php" hash="5f19c37337b901edd5fe5080a8353116"/><file name="UnderscoreToDash.php" hash="2f25783e6e165b827fc113f046f30f44"/><file name="UnderscoreToSeparator.php" hash="b0e92b24b679b3dcbee459cd752a2478"/></dir></dir><file name="Filter.php" hash="383fca34ab08e0a803adb2c7766fad95"/><dir name="Form"><dir name="Decorator"><file name="Abstract.php" hash="8522e625655a35646b477ad4ff99dfe5"/><file name="Callback.php" hash="190782b871a222c75dfc8444b863da11"/><dir name="Captcha"><file name="ReCaptcha.php" hash="39b4156e05bfd86a8bc607c94f437e32"/><file name="Word.php" hash="880894024cfbed08b5f1078076512a25"/></dir><file name="Captcha.php" hash="1d07f76a5ba267e35b801bbfa6437b1f"/><file name="Description.php" hash="4c386b676076f9d5839eea503b633567"/><file name="DtDdWrapper.php" hash="124076232159f0fa26fc9fe67685830f"/><file name="Errors.php" hash="e10d634460b6dae52065a83cd5c3b3a2"/><file name="Exception.php" hash="7540f704e53237cd3a6715d1e480c3b9"/><file name="Fieldset.php" hash="6bd5c5b9ff8e9e489e5a7c560aff175a"/><file name="File.php" hash="c06f2200db61e4ebffa266d99260c726"/><file name="Form.php" hash="c0117ea6a352a32b780baae652d717b9"/><file name="FormElements.php" hash="8cb9c8f03fb877b45696b534c1b39b14"/><file name="FormErrors.php" hash="723036887204776c398e63c715b762fa"/><file name="HtmlTag.php" hash="2b90f769619b1e6624e14922dc2c32ec"/><file name="Image.php" hash="2a1a7dd1624ee71cfc13b7c96b4796e9"/><file name="Interface.php" hash="60d51f6f15d396b5a16519ba5eeec204"/><file name="Label.php" hash="277f64b41efc25890d78eba58db9b780"/><dir name="Marker"><dir name="File"><file name="Interface.php" hash="30667e6ff2ccced89c3b62cf0e13f931"/></dir></dir><file name="PrepareElements.php" hash="0ff6fb16d6c5a748c9c3d3e48037755d"/><file name="Tooltip.php" hash="bb7394628ade765908544c69c6790844"/><file name="ViewHelper.php" hash="c5cc8db2e0cec01b77be69fa2e1b9299"/><file name="ViewScript.php" hash="23ef6fc6fdac5fd8c9105738c5cd3ccf"/></dir><file name="DisplayGroup.php" hash="ee080ba86203eeb41ac17d38877651f5"/><dir name="Element"><file name="Button.php" hash="730df0b76e3957882f877197447d5f1d"/><file name="Captcha.php" hash="0752ad99fb0f43536c91367c70a494df"/><file name="Checkbox.php" hash="e39255d645c7c1b2ac042cc64c2e7cc9"/><file name="Exception.php" hash="c1a78bc6fbcad9d8544ef102ee578bd7"/><file name="File.php" hash="8a78cdb33c6d598fee1f22fe008e7479"/><file name="Hash.php" hash="98a63f7085dc662488f510b8341a450a"/><file name="Hidden.php" hash="4f1b7d49e10c937cbe9bc1f481a24e9e"/><file name="Image.php" hash="050990ff646853c7def62d5912a3a57e"/><file name="Multi.php" hash="546108cee3f938abc94159392b279638"/><file name="MultiCheckbox.php" hash="8da3e1c8f63673889aa82c8a477bc19e"/><file name="Multiselect.php" hash="70685894797a172bfbfeed0b3ca0c8c9"/><file name="Note.php" hash="db0386ab8c66da2df8c912e37b11110f"/><file name="Password.php" hash="4cee94cd5c56812e101f9cae256d79cf"/><file name="Radio.php" hash="088e0a26f8b959fd252edc7080cbe3c6"/><file name="Reset.php" hash="782f1aa0cbe1a792a0d05a51d58d8beb"/><file name="Select.php" hash="ee8919ec27665b02cc44cc0083609878"/><file name="Submit.php" hash="0a97601d86f82bd50d3ea6777937254c"/><file name="Text.php" hash="781ee2e638e37fc613ad760bbd2d30bb"/><file name="Textarea.php" hash="85a7119e8e0fa3377b0576b16aa05c51"/><file name="Xhtml.php" hash="4c20761fbbb7ca24ea9b49ac3cd41e58"/></dir><file name="Element.php" hash="f03fcc6dcd7b3e0da5a36046d36d727f"/><file name="Exception.php" hash="d33a48b9d1ec7e213210383b1f7bca68"/><file name="SubForm.php" hash="ba968be3402ccdf8b4185f4d53234120"/></dir><file name="Form.php" hash="4001592cf753a1170ba2cf1c178c17ce"/><dir name="Gdata"><dir name="Analytics"><file name="AccountEntry.php" hash="e12468f4c63d78e8edecbc473933aa4a"/><file name="AccountFeed.php" hash="a2f9b14dbdc470693a82907f57c4d258"/><file name="AccountQuery.php" hash="8f5b153ae38c2c0598dcdd0f4ca851a4"/><file name="DataEntry.php" hash="e45ec9042ba8356cdf29505e1e9e2d0b"/><file name="DataFeed.php" hash="5db9ffeb61cefb3659e9be8400ed20e8"/><file name="DataQuery.php" hash="f42425d8f43dada50bb8f128d8f975f6"/><dir name="Extension"><file name="Dimension.php" hash="38282ab7af5abb515f4aa658f820fc34"/><file name="Goal.php" hash="2c46c1d7db9b5f507a47e4bb121e2b4c"/><file name="Metric.php" hash="8560747659930f23b28cc94bd837440b"/><file name="Property.php" hash="d1ba271f052e44a1152eed24533824b0"/><file name="TableId.php" hash="60e5a4486c861d393b6f3183c2485267"/></dir></dir><file name="Analytics.php" hash="a97cd7d0faa0f65351e65f55c28fcc60"/><dir name="App"><file name="AuthException.php" hash="6f8d23065cd17d239b2cec093015ad8e"/><file name="BadMethodCallException.php" hash="86fe8ce683680f512145d94a22ab21d5"/><file name="Base.php" hash="109e590e151826d3347d1f2f58dcab56"/><file name="BaseMediaSource.php" hash="d1ec6648e8c89711225d42a07e4738d7"/><file name="CaptchaRequiredException.php" hash="7a3e3893b6f8a9c282d920acb9928e21"/><file name="Entry.php" hash="06786f3fe9e30b60c79888be9c70c067"/><file name="Exception.php" hash="82c41ada4e9863867adb2795fe7b1ca0"/><dir name="Extension"><file name="Author.php" hash="2df6f04ec34d35d1d79bbd189a9c53a8"/><file name="Category.php" hash="273bbd08b463d8394b8528294f2f43ef"/><file name="Content.php" hash="ba2ae463fc480db7c017c495c47f8380"/><file name="Contributor.php" hash="b06a5ee82e874422c7053e9bc4efa7a7"/><file name="Control.php" hash="2215659703162befaa49e7a18ad7abe1"/><file name="Draft.php" hash="45da888e1837d3002d099e483cc4e117"/><file name="Edited.php" hash="94503a1886214c959eb189dc1331a1e3"/><file name="Element.php" hash="1ff84c0f8b8e3e9be1edf28774125044"/><file name="Email.php" hash="f3733ecc80e481cd3e35b93df18a216d"/><file name="Generator.php" hash="aef1362208e44f2be51e4094089b4795"/><file name="Icon.php" hash="36d027f0cf96a2deb42b6c1aab0468ef"/><file name="Id.php" hash="9609dfb9218d0b8263086504e6b0d63c"/><file name="Link.php" hash="de21b9578b8592c5b3e3fcfb84419671"/><file name="Logo.php" hash="23c88a04e6897da7a7606733d5880094"/><file name="Name.php" hash="bcefb468fb70012b66b7322b1b9c618f"/><file name="Person.php" hash="5190427185a73d6cd253d4ad37d3130e"/><file name="Published.php" hash="f5b6d374545f8fea7382644413c786ee"/><file name="Rights.php" hash="add154a43b16eea075f70fef1dc0c614"/><file name="Source.php" hash="9b5c51a557d100b8d32f04c2e631d51e"/><file name="Subtitle.php" hash="87ccbc9582dabb57b4e5254c3cdb5419"/><file name="Summary.php" hash="308fcbd2860bac275a68bbaa455d75e5"/><file name="Text.php" hash="bcb0f1d994917499bb98c2045839cf78"/><file name="Title.php" hash="37736e9d970dbfb6508fe95c8b1d4c4a"/><file name="Updated.php" hash="3a00f1cac5e73b47fe960a4568d753a2"/><file name="Uri.php" hash="c8a0fd8b1e0ef4620dcb4f8d3bdf2f02"/></dir><file name="Extension.php" hash="e8d500cede8625e9a513241cb9340b8b"/><file name="Feed.php" hash="2a9b8a370e645cac248df5cec9752bf4"/><file name="FeedEntryParent.php" hash="03a2448db19430ce9d63af5a794c49ee"/><file name="FeedSourceParent.php" hash="ad513f8bba194a7c597d62332e1b748d"/><file name="HttpException.php" hash="e235854ac6db814217beb8e0f4432bda"/><file name="IOException.php" hash="4fe86dbdc8efd68b4f4e91eb720476fe"/><file name="InvalidArgumentException.php" hash="bb79aa3b093b89f2d1740e3de29c591b"/><file name="LoggingHttpClientAdapterSocket.php" hash="6c6fcbec1d914d2f0f1b4c9f9f9d6ded"/><file name="MediaEntry.php" hash="665829aa3a0b00efad9d39516ac20296"/><file name="MediaFileSource.php" hash="33e29faf6b09ad55399f8c4605de560b"/><file name="MediaSource.php" hash="956d976c017eb2969ec6980ba6a10227"/><file name="Util.php" hash="a978ace39e376ebb7a77168bb980e500"/><file name="VersionException.php" hash="46a96dcdf49d163f2b558f6af76770f8"/></dir><file name="App.php" hash="0611ada3705cf91a416144719aa34f4d"/><file name="AuthSub.php" hash="7d6c8fa90f00569465838f7485e6f8c9"/><dir name="Books"><file name="CollectionEntry.php" hash="e9400464091b197c1406c31904c89f46"/><file name="CollectionFeed.php" hash="50eb4262a08af25008fc23dc8ce38261"/><dir name="Extension"><file name="AnnotationLink.php" hash="229515a8187537875bec1df18a216e70"/><file name="BooksCategory.php" hash="94043b4e41582b92bd585a2f6ca55401"/><file name="BooksLink.php" hash="d4d4d737a079e5a06f9ec239156acc3b"/><file name="Embeddability.php" hash="02ea13af1b4c9e4bdf019cf85bd2e1e3"/><file name="InfoLink.php" hash="e901bc048235143eca51ac93750e148f"/><file name="PreviewLink.php" hash="96cc9f7155d4a8420b59dfab337df144"/><file name="Review.php" hash="8263c22752814fc5b8ed79f5b8fb0c64"/><file name="ThumbnailLink.php" hash="d39c8c46fdcd113b6e78b0a291e3fb7e"/><file name="Viewability.php" hash="00ab00c410d09d756c1f4eac2617dd85"/></dir><file name="VolumeEntry.php" hash="c792cd0a1600d1f82b359e4488ca96d6"/><file name="VolumeFeed.php" hash="df63b570832f03352f8fd9caf5dd0ad9"/><file name="VolumeQuery.php" hash="7c4eafbfe2dffe63d19da553d7116784"/></dir><file name="Books.php" hash="2b24e8b1f35eeb6c045c82aaea8ff279"/><dir name="Calendar"><file name="EventEntry.php" hash="3a8929e9b816b58b948bb27c5f5b7b11"/><file name="EventFeed.php" hash="cb77e63f75b7b00e3ad977160bf1df3b"/><file name="EventQuery.php" hash="c87b0d6fb40e7b41509bbf0c72c35563"/><dir name="Extension"><file name="AccessLevel.php" hash="0c08117546cfc5687e831e7c1c911386"/><file name="Color.php" hash="173b3b7765f71816d9474b4d662fa78b"/><file name="Hidden.php" hash="e013d7fa1de0281467fd342b68d82e47"/><file name="Link.php" hash="9024ffbc848c26dc7142791d334ed4c6"/><file name="QuickAdd.php" hash="b27ef7921a5f849c6d3670e80205a826"/><file name="Selected.php" hash="af19756358007c35c1e97b25d3c40f98"/><file name="SendEventNotifications.php" hash="ad25cf943facb4ca07b5eea08b29d6c0"/><file name="Timezone.php" hash="f42b5243c11888a5ba4075b0e9663d64"/><file name="WebContent.php" hash="b7097ddc1f180e4a85097a414b96bba9"/></dir><file name="ListEntry.php" hash="0579d1450de838b1b893f9720a7dacc1"/><file name="ListFeed.php" hash="e21a404f7d250f78fdac64f729d2b377"/></dir><file name="Calendar.php" hash="507e33fa6d185c57b0c2c351c0fbc060"/><file name="ClientLogin.php" hash="d5025122f58267716ea25d7546da7d62"/><dir name="Docs"><file name="DocumentListEntry.php" hash="08219506950f07c0cb16e1196dc4e09c"/><file name="DocumentListFeed.php" hash="dd7d591781ad9cf3293f73bc94e64e78"/><file name="Query.php" hash="e6c962a8f8cfe02d3ca0701b932dd5c9"/></dir><file name="Docs.php" hash="f29d7a621a95734e8b83a4afa5a6fe42"/><dir name="DublinCore"><dir name="Extension"><file name="Creator.php" hash="c56d34f65d24a0ad25e60a4e913fd54a"/><file name="Date.php" hash="54b46f21e08d7ca7d230c6b7e83e7210"/><file name="Description.php" hash="6f4bb927deae9cb5b501b37e4cbdeca7"/><file name="Format.php" hash="a2eb4fd88c1197f1b122adfcca64e4c5"/><file name="Identifier.php" hash="7900202e14b61bf0323069f736521521"/><file name="Language.php" hash="b47e4dafd3fcebd4d11b4ac0806cea70"/><file name="Publisher.php" hash="1660d7ee8e0fa26d24376ed8414849e3"/><file name="Rights.php" hash="1cddf53544c56ad8a29f012f1501501e"/><file name="Subject.php" hash="a287af1b176e22b3f7001e4a8d69129f"/><file name="Title.php" hash="77bbd2f9afb01b6337b03b12c19cd0ba"/></dir></dir><file name="DublinCore.php" hash="6fa896e35490d67182eb013b08ef6d75"/><file name="Entry.php" hash="b2f85f13672d64d288bbcf9824058488"/><dir name="Exif"><file name="Entry.php" hash="cba9027e69ca0d3431f5fa8e84519d22"/><dir name="Extension"><file name="Distance.php" hash="69d8d71b3c8f02fd85e22e72453f5e7c"/><file name="Exposure.php" hash="5b4f1e1c91ada58e661412e391c9167c"/><file name="FStop.php" hash="78c90acf5134d6a8cd7debc8dfff3942"/><file name="Flash.php" hash="bc1c363115d8ee05fc043ae829ca9398"/><file name="FocalLength.php" hash="ba8dba20995e7ad0dc5fbe056a13a431"/><file name="ImageUniqueId.php" hash="3007c391ed138e7db78cca05ad964cb5"/><file name="Iso.php" hash="9b7340beb6cd2f991d0b590da9929207"/><file name="Make.php" hash="b96528e1c95904dcf7a32b6d2b855c4a"/><file name="Model.php" hash="de354ebd3ac53b26c7ba7d07b7eaf74e"/><file name="Tags.php" hash="0b6dca99d61d601cd89ddfe6d9af5990"/><file name="Time.php" hash="880ab5825cab35d85036460d54b18148"/></dir><file name="Feed.php" hash="d102e026496f926fa8dbf0024e75ea22"/></dir><file name="Exif.php" hash="31c98117fa58af3fbc8a9504aed7f05d"/><dir name="Extension"><file name="AttendeeStatus.php" hash="dac3c0490bccbf09f924948ad44232cd"/><file name="AttendeeType.php" hash="3b42bd943b0536d5bde7e735fd8615d4"/><file name="Comments.php" hash="9afbcf4a4ce1d7dd52706e0e8928a8ee"/><file name="EntryLink.php" hash="5a280e630417eb616c257813c3ead727"/><file name="EventStatus.php" hash="61f988f2bfafa564543cabe4e7f86f29"/><file name="ExtendedProperty.php" hash="2d80f08e6e2e79da98134e959b58fbbd"/><file name="FeedLink.php" hash="679a6f5c9ebed486b6b41bac1522fba3"/><file name="OpenSearchItemsPerPage.php" hash="8430c39b6ce1bfb8deb8d2ff4070edf6"/><file name="OpenSearchStartIndex.php" hash="118645c4f8d38b135ebdd9792ba30234"/><file name="OpenSearchTotalResults.php" hash="8e7bbe094d00d023b1ac76184bbc871c"/><file name="OriginalEvent.php" hash="799806cbff3654b92028550a96d3f418"/><file name="Rating.php" hash="96f79437551070a76a0ffc8cf0ce3f93"/><file name="Recurrence.php" hash="da2e478f7368e9fae3e91aa4975769b9"/><file name="RecurrenceException.php" hash="1565fac963250d130a9a18d0e87a9462"/><file name="Reminder.php" hash="84525523e8827d09cda261f02f4c4214"/><file name="Transparency.php" hash="2c99f3896ceaa90632f565d3910eba43"/><file name="Visibility.php" hash="df49298225481498f3a082cc88092ed6"/><file name="When.php" hash="4a02d7db9ade6210d5d01fd401938732"/><file name="Where.php" hash="5d1d9557f1a8a24be5c6076464f35cda"/><file name="Who.php" hash="8d3c827558b62b6fbbdb1786bc6dc8f0"/></dir><file name="Extension.php" hash="3dbf28598313aea3fbcb6ae0a9218373"/><file name="Feed.php" hash="8ae61588a220ed9e612bd0d306ed7be9"/><dir name="Gapps"><file name="EmailListEntry.php" hash="beeaa4d8624538255fd4fa414bf2aa2b"/><file name="EmailListFeed.php" hash="dae8f9390c01ce354aacf7a03b56faa3"/><file name="EmailListQuery.php" hash="38e4255133125d1c3cd461769ff2bbf6"/><file name="EmailListRecipientEntry.php" hash="5042400a2ccf63b598d11098c08a02a8"/><file name="EmailListRecipientFeed.php" hash="e67f7530086c3c3de9bf49ce731ba816"/><file name="EmailListRecipientQuery.php" hash="6b48a9d58feb39241c63a1c448259894"/><file name="Error.php" hash="2739432a885e3aa64112124acf85666a"/><dir name="Extension"><file name="EmailList.php" hash="d83a001f6b79d69a55a534c352df4518"/><file name="Login.php" hash="068572b0a7d975d816564d334aa6cf07"/><file name="Name.php" hash="b895fe7b562ab015bc391c82be75d63e"/><file name="Nickname.php" hash="12ce7eb02489b501861272c13acec59d"/><file name="Property.php" hash="4517466631d6a91e771e3eba6c4d028e"/><file name="Quota.php" hash="18a9c44fdf6146c74b51d123c00bd7d4"/></dir><file name="GroupEntry.php" hash="5c36b2030c5394629693de197c909286"/><file name="GroupFeed.php" hash="13b68ebe7768fabe2f408b5a317bb088"/><file name="GroupQuery.php" hash="fc3f172f6fda1a3b50c6c8c2f3beebd6"/><file name="MemberEntry.php" hash="987fddd8e68938e62d4fb4c80a0b7586"/><file name="MemberFeed.php" hash="aaec820fc096293a6e6f4e5dc9a213a7"/><file name="MemberQuery.php" hash="1fe4b7f18ca161de836a9bf2b18cf123"/><file name="NicknameEntry.php" hash="f0fbcba505a6cac9d64328acf86c168a"/><file name="NicknameFeed.php" hash="80df6633ccad4aea2f1b0ff1fc56fedc"/><file name="NicknameQuery.php" hash="b3fc90f01854679f692ca2d34f1ef867"/><file name="OwnerEntry.php" hash="a66d48e8d46fddf2a9e3ea0330bcea45"/><file name="OwnerFeed.php" hash="98123454cb3cc6dc134d9ad827d297b2"/><file name="OwnerQuery.php" hash="5c829232390b828f06565012b2af3ce6"/><file name="Query.php" hash="a893bb0bebd43c558fac8f7b58477577"/><file name="ServiceException.php" hash="e62bc29c1a67ab44455ebc10fb033887"/><file name="UserEntry.php" hash="327e60ce8bad4fad8aa9d785902a0488"/><file name="UserFeed.php" hash="12a6e44ebb6b809f1ab17884c957d034"/><file name="UserQuery.php" hash="36d9b6e3c53812f1a0b3ba58b8348d1f"/></dir><file name="Gapps.php" hash="006b69cd2b4bb52efbc481cba3ded85d"/><dir name="Gbase"><file name="Entry.php" hash="d1c0594bd7f509ee8b71a0d4c6e93cef"/><dir name="Extension"><file name="BaseAttribute.php" hash="9860f259d07b1d7c48953ac145e91173"/></dir><file name="Feed.php" hash="a3a9a55b4dafc0c71da475d0b8ab4ed3"/><file name="ItemEntry.php" hash="4ad3d155cdb9fce8010cb9ff27d3ff54"/><file name="ItemFeed.php" hash="44ffbf3810fe7d602fa50a219f4d0c6b"/><file name="ItemQuery.php" hash="d85aa16b033dfc7478cbfa9cd38cbd69"/><file name="Query.php" hash="feaa71301ffc82297a5c768b267ff5b2"/><file name="SnippetEntry.php" hash="023249497ffc22f6fbad8645c50dc78d"/><file name="SnippetFeed.php" hash="5197182ca6edcf33fa8452f809597510"/><file name="SnippetQuery.php" hash="17365d8dc24d1da93b8b730c6fe6d864"/></dir><file name="Gbase.php" hash="78c17b83a499c8c31d31762990d83d3b"/><dir name="Geo"><file name="Entry.php" hash="bf5d39448208c58aba61ec64d6a79ad8"/><dir name="Extension"><file name="GeoRssWhere.php" hash="914e0e1155c117f5908f07dadc6ee889"/><file name="GmlPoint.php" hash="a5bf5b02bdec49c06e1aa44763bba1a8"/><file name="GmlPos.php" hash="8ef27447e497a39031e475372a8cb08a"/></dir><file name="Feed.php" hash="c2adb51ac77e046f74ac15f7bcfb53d3"/></dir><file name="Geo.php" hash="2a5a5a2dfa2462e061234e4946fbc8f4"/><dir name="Health"><dir name="Extension"><file name="Ccr.php" hash="5f6686a6c63958e949db8bf5deb92f2b"/></dir><file name="ProfileEntry.php" hash="a2c0dd3747b54680f62089aa25ca26c0"/><file name="ProfileFeed.php" hash="1a41a46d2871e28239c45f23f0b50868"/><file name="ProfileListEntry.php" hash="ee7b66b18af7f3d7406c10c82dbe903a"/><file name="ProfileListFeed.php" hash="1d15e991cf6dc94a83b52ec64aed7a2a"/><file name="Query.php" hash="6dd89b579a5aa4d35de32e74c0df5502"/></dir><file name="Health.php" hash="6b0a156697fe84a09efbde31eea3f497"/><file name="HttpAdapterStreamingProxy.php" hash="6b2964e32bf7c0e110b8ab25445ed53f"/><file name="HttpAdapterStreamingSocket.php" hash="b5b74e5c1cb8206da4b163666a81fed4"/><file name="HttpClient.php" hash="9cee0a291d6c4b11f7358628923f925f"/><dir name="Kind"><file name="EventEntry.php" hash="1f1204191536089911a984770ce0cb47"/></dir><dir name="Media"><file name="Entry.php" hash="9cc1bd304119ff7d428225d3107c3a34"/><dir name="Extension"><file name="MediaCategory.php" hash="8f9345afe735f43c0936d2741556db13"/><file name="MediaContent.php" hash="947b1ca390fa6021690d0a67f81c0c28"/><file name="MediaCopyright.php" hash="947dadff8c8d2708ccb7af6aaa5d928e"/><file name="MediaCredit.php" hash="6d2b9d4be6e3c896fc9c9f9a9581ce9d"/><file name="MediaDescription.php" hash="eeaf98530facd9f42d2e3c46661db3f3"/><file name="MediaGroup.php" hash="9e6dcb6e453393b23d7efb8dde3fb4b0"/><file name="MediaHash.php" hash="2f84bf6db86d3302709347222ad1eba4"/><file name="MediaKeywords.php" hash="6a1a4c5eee620173c5c1995a8bc0aa25"/><file name="MediaPlayer.php" hash="c7d51126d6604718daec1674785e90af"/><file name="MediaRating.php" hash="915d64d3fa690969aa6697c945ef7b28"/><file name="MediaRestriction.php" hash="8921f3bd9d80f7a530b826ab009668c4"/><file name="MediaText.php" hash="557defecdbd618e8917ed5fcd6ccddbf"/><file name="MediaThumbnail.php" hash="e5e272a715318c877fae805dc78e3fee"/><file name="MediaTitle.php" hash="4134d9c00494d89ba462ae9500d1e2bc"/></dir><file name="Feed.php" hash="f67c9bb85cbfbf098fb53ae50a026044"/></dir><file name="Media.php" hash="752e78b67dca41a50ffb85dee3b3e483"/><file name="MediaMimeStream.php" hash="de9b3dd42e0f9f62341fa075bb900c6c"/><file name="MimeBodyString.php" hash="ea742b4f32d34ddac64454b990d4ef37"/><file name="MimeFile.php" hash="0afbad3bc750c1cc5d3f93c54c3c5019"/><dir name="Photos"><file name="AlbumEntry.php" hash="1ab5e6bdc070df30938e912d52eada85"/><file name="AlbumFeed.php" hash="07c42ecd6819d25e428b94f31882c1a0"/><file name="AlbumQuery.php" hash="5da3a372fe52f8c076e9d97a35f823e1"/><file name="CommentEntry.php" hash="f7822566e08ea7b3f74c955abf89a41f"/><dir name="Extension"><file name="Access.php" hash="8d4c3dfe21dbb25632e87659070125d1"/><file name="AlbumId.php" hash="45b3059567bf5e49a6f8edf6b8a16937"/><file name="BytesUsed.php" hash="fd2a43339909b5c7402208dccbdf68c0"/><file name="Checksum.php" hash="5ca31e3430e2e9b747d91c94c000de8a"/><file name="Client.php" hash="2a3276f0666bc92c7d7155bcfbc74f42"/><file name="CommentCount.php" hash="48176e51ea9b1c3c0de6edcf24e25d19"/><file name="CommentingEnabled.php" hash="5b460e8f02be0079867d34af9ab54bce"/><file name="Height.php" hash="d913feb4798b7f3c8ba645bc6ecd1d59"/><file name="Id.php" hash="c5c6fcef6647a1523b99463cfb0a6ebe"/><file name="Location.php" hash="b2b10096aeca032d37e138b09f4ce18e"/><file name="MaxPhotosPerAlbum.php" hash="d1b61411c47e1eb91cb0b80be60998a0"/><file name="Name.php" hash="7e6637d23584ef1ebc3834940fc2ad52"/><file name="Nickname.php" hash="c4345329b15d815de6527d0f8e0277e6"/><file name="NumPhotos.php" hash="160edc7a3b4837435a36befe5378e01e"/><file name="NumPhotosRemaining.php" hash="a3b358f036c2fbefdf93830c92a027fd"/><file name="PhotoId.php" hash="ff997a353b24d944f439702d4ece0966"/><file name="Position.php" hash="cf9f8b0c29c98c1680b2675ebf47e6b2"/><file name="QuotaCurrent.php" hash="a57ff86ba83287a1f145f272ca463756"/><file name="QuotaLimit.php" hash="00c6e94954fbe136a09d4b7ca8f7128c"/><file name="Rotation.php" hash="513a2712c12e10fb61dde21976824b7e"/><file name="Size.php" hash="ab29ba1766a003c1b3ad22db180d18cc"/><file name="Thumbnail.php" hash="6a59c5bebc192e34992e8058ccfd11c1"/><file name="Timestamp.php" hash="b52abdc854529af5cb545691692375ec"/><file name="User.php" hash="3a21cef935fd5fb42f97e308b1997583"/><file name="Version.php" hash="9625bc1c6aefcf580c5fbe0d2f045b4e"/><file name="Weight.php" hash="a8bc3ed41e626323f92adf87410af458"/><file name="Width.php" hash="06f910c1bb1e4e747c38c26ed409522b"/></dir><file name="PhotoEntry.php" hash="ada12abf9bb991fa672ca9a05cb979a5"/><file name="PhotoFeed.php" hash="3b29ec6d750456cdd799bcbaa751e89b"/><file name="PhotoQuery.php" hash="93b28eba3750d181f44fe41181e45663"/><file name="TagEntry.php" hash="8c088bb0af6e8a14eced2775aa3a291c"/><file name="UserEntry.php" hash="15e59c396a645fc30f03cb42d2efc351"/><file name="UserFeed.php" hash="e1498967cc3f5d361c96a0bcde82437d"/><file name="UserQuery.php" hash="26f3ef6227851523817358a97544ebd6"/></dir><file name="Photos.php" hash="c46ff72fca949809ff42f17b0079c069"/><file name="Query.php" hash="100dee31d0a572c4d2e990a96f7e9a0e"/><dir name="Spreadsheets"><file name="CellEntry.php" hash="93cc5079095d6daa6c2147b62131a890"/><file name="CellFeed.php" hash="ca07b9478e1b6ecae9147bc2105c8bd7"/><file name="CellQuery.php" hash="bc7fbfd4e84481e19df568357bc22e37"/><file name="DocumentQuery.php" hash="fd2935ddca76445d1bea58c4f6799ebc"/><dir name="Extension"><file name="Cell.php" hash="917abed62f74a5101511f4449c805140"/><file name="ColCount.php" hash="dba4f0796d79fe80ff15d4dc9bebcd24"/><file name="Custom.php" hash="8f805dee81206d515ab43097cecedb1b"/><file name="RowCount.php" hash="be76b9f5b367cb349576283ab9765d34"/></dir><file name="ListEntry.php" hash="7b8c759afeb6cee40fc5ce231dcf6f2e"/><file name="ListFeed.php" hash="688c2cd0aab8cffabce85d835e4fe077"/><file name="ListQuery.php" hash="2bd4f1eb97b6b3c92c8d2f52fcdbbccf"/><file name="SpreadsheetEntry.php" hash="e43a1862baadf19907770d4a61a56626"/><file name="SpreadsheetFeed.php" hash="2cd1cf91c61a54ea236e1aaf73877009"/><file name="WorksheetEntry.php" hash="7091ab92f732197dbf7e45dcc9c87bf3"/><file name="WorksheetFeed.php" hash="3a4c334028cc35e76255507be1efe061"/></dir><file name="Spreadsheets.php" hash="5706fa18d101c716c73b5f1f6869f33b"/><dir name="YouTube"><file name="ActivityEntry.php" hash="19c73663008cbcbb141c35e8717521aa"/><file name="ActivityFeed.php" hash="5e45cff4ae0df9e35683067769a26386"/><file name="CommentEntry.php" hash="8f17768b645f4165b9601e59fab4045a"/><file name="CommentFeed.php" hash="a391a8ea8c0b27904e365eace8b03458"/><file name="ContactEntry.php" hash="440d8c1c0196e59dd80c6c52e30b2459"/><file name="ContactFeed.php" hash="ae3698b6ccf9d339f7a30b4a5789f698"/><dir name="Extension"><file name="AboutMe.php" hash="8011ef3b524bea9fff089882ea4ed0ab"/><file name="Age.php" hash="e2a9893b2e911b3db507465320cbcf63"/><file name="Books.php" hash="89b35f4bc0027463f91824b5cd2e47cb"/><file name="Company.php" hash="549c355f976cc892cebc6811fe2580a1"/><file name="Control.php" hash="578a083eabf62931b62d095600b80003"/><file name="CountHint.php" hash="666969cd9d5d77e06c9a115fae9de6b8"/><file name="Description.php" hash="8a7dbf10f59ccd573eb0c90cc5971cf6"/><file name="Duration.php" hash="24f2181f720fe6db1cb22503ffee459c"/><file name="FirstName.php" hash="d28dd3cd580a2fa7c6bfb829e8711166"/><file name="Gender.php" hash="260b84dc18e9c01eac563404d0fa5f5d"/><file name="Hobbies.php" hash="2dd89e1c8199ef743d771702ecc95c8f"/><file name="Hometown.php" hash="fda3ebb42524b3ab8d54467887da61f5"/><file name="LastName.php" hash="f19b93c1d745cafe6ecf20c7bc8d0c3d"/><file name="Link.php" hash="d93c9801f25b8c8cb13d87ff3b3b460e"/><file name="Location.php" hash="20909b4d155c9fd517081322b835f306"/><file name="MediaContent.php" hash="1b53bccaa9f1de51c19378fc8c442868"/><file name="MediaCredit.php" hash="4571da70916493177e72f0aebeaa78ac"/><file name="MediaGroup.php" hash="36cca7fb741bb294f4dcb4142733d100"/><file name="MediaRating.php" hash="099d0984cdb2c9110ca259311047d0de"/><file name="Movies.php" hash="464957a1f90eb56899ec503c4ede6ef9"/><file name="Music.php" hash="947c3294f34d0f35ab88c7f7a9c4f4b3"/><file name="NoEmbed.php" hash="1e6e4a5995de606554e7145a0df0b6d4"/><file name="Occupation.php" hash="b33c3053639572a312fec678395d7436"/><file name="PlaylistId.php" hash="af87bcfda7115ae9c55bf3c1f2986754"/><file name="PlaylistTitle.php" hash="79b89ae7bdce993a758fd1bf45188252"/><file name="Position.php" hash="d92a78e714b2f7afdfabd8d09f73ff1d"/><file name="Private.php" hash="93bd6eeaf228e882ccceda591813228f"/><file name="QueryString.php" hash="5e5c57c2e219ef2e5ca3184997d87ccd"/><file name="Racy.php" hash="ad019d20c5c40d12da9cfc9df9daeaec"/><file name="Recorded.php" hash="7af195c7f3f045946f13504cc38522a0"/><file name="Relationship.php" hash="b42aac9538b504662222635a29149436"/><file name="ReleaseDate.php" hash="beb4a4d9830ff40a06816a341de8dd15"/><file name="School.php" hash="51a1ff928489cc7cd3aacc7a7aaf08a3"/><file name="State.php" hash="04cd3d54d4050aafc5ce27e719d234e9"/><file name="Statistics.php" hash="73270160b45c7ec91914467ccda850ef"/><file name="Status.php" hash="aadcb325d6f3b51cae180406d4caf9a4"/><file name="Token.php" hash="8686b59bd2a0048283389bc01acf77bb"/><file name="Uploaded.php" hash="9ee6ea6660e515f1440d92b2ef4d97dd"/><file name="Username.php" hash="c3782552a9accafea073e8f0081e43f3"/><file name="VideoId.php" hash="30fdd4c5cd5b212a1e4c17cd28fbb12b"/></dir><file name="InboxEntry.php" hash="24eb593b56341f919f0bc0446b4b71f8"/><file name="InboxFeed.php" hash="69487f9424ad1686f1b00e2b1f73ad29"/><file name="MediaEntry.php" hash="924fd5fcbfec4c44e965812618c08b6e"/><file name="PlaylistListEntry.php" hash="367ad32e10ea7203408d99bcfae836a2"/><file name="PlaylistListFeed.php" hash="6a2db1a031b1f749231326b4bd57d9bd"/><file name="PlaylistVideoEntry.php" hash="5453811dc274201e95b9ca6450180669"/><file name="PlaylistVideoFeed.php" hash="54be8eb4c90f3a5a4b6ce1ce578f7e56"/><file name="SubscriptionEntry.php" hash="f602292610ce553fb7493cda0bc25cb0"/><file name="SubscriptionFeed.php" hash="576b63779940d7e3576a1c505bff284f"/><file name="UserProfileEntry.php" hash="4eafc0f86b477f85405429572ba1ba62"/><file name="VideoEntry.php" hash="1ef39076a4e9cd95f91bf8d69bf4f52c"/><file name="VideoFeed.php" hash="aa4889f83dab3ed5524583b48a7a5a22"/><file name="VideoQuery.php" hash="a2a973590b187f7314e994d824a6a288"/></dir><file name="YouTube.php" hash="a8dc12d5116ec45b159b59dacddbf946"/></dir><file name="Gdata.php" hash="f1583b57defcf04cb1b35c2875a95ea1"/><dir name="Http"><dir name="Client"><dir name="Adapter"><file name="Curl.php" hash="a4300f6a2b52d63e0edd1e81c4fe2dd5"/><file name="Exception.php" hash="edeae8782f6926386f145d8a873d23bb"/><file name="Interface.php" hash="588b60a6607675c8698be8b3fd2d4e22"/><file name="Proxy.php" hash="6892b7d0c9de3a441adb25d4fbbd22ec"/><file name="Socket.php" hash="6078a103596ba3a8b2544563d252d505"/><file name="Stream.php" hash="14a0106f768a6388688690a54a3eef27"/><file name="Test.php" hash="35e3087f1d6baa3b6fa2cda8228febf9"/></dir><file name="Exception.php" hash="a5f986ab6d87cb83bed91a1caf56ac00"/></dir><file name="Client.php" hash="26f6df4ccf15f65b213ebd0f5538978a"/><file name="Cookie.php" hash="a56a600d64c9bae67c66ae784de2fe58"/><file name="CookieJar.php" hash="7d93690c2caf40108c35a66b10e25586"/><file name="Exception.php" hash="b345b84b1e9b8a1ae2478ff04f37fc2f"/><dir name="Header"><dir name="Exception"><file name="InvalidArgumentException.php" hash="02d00d00a945c0595a648ea418fe3673"/><file name="RuntimeException.php" hash="8c166ae41ab4e516abda9289f19e973c"/></dir><file name="HeaderValue.php" hash="c0e08b696c63818f37faa68a0f733d32"/><file name="SetCookie.php" hash="5f5620b08a9a298bd60cab553cc4f213"/></dir><dir name="Response"><file name="Stream.php" hash="8a41b22b489629a6766dfb3cb96e0ed2"/></dir><file name="Response.php" hash="a34c934977d3bbc1da1a2153692a5743"/><dir name="UserAgent"><file name="AbstractDevice.php" hash="e52f1ad149795aad5075c4bc6cf977f3"/><file name="Bot.php" hash="e5679a2e30d3f1ef581d508446c1f482"/><file name="Checker.php" hash="0b6bb9cb341b75ca7bfb749cb2c871bd"/><file name="Console.php" hash="93650b34bd1238887e88c238291853c0"/><file name="Desktop.php" hash="9829ee285a2cdc4388326a07644d042c"/><file name="Device.php" hash="72533d95dea2a7fe6366bd2145b5b938"/><file name="Email.php" hash="f0a3fab08e59378c0189073237611af7"/><file name="Exception.php" hash="beb38f75f587ac56cbb7a843f59a84ae"/><dir name="Features"><dir name="Adapter"><file name="Browscap.php" hash="a88ccf8fa0b5aca789f32a08f83c98e7"/><file name="DeviceAtlas.php" hash="725061814353e65cc2d89e2a67a00673"/><file name="TeraWurfl.php" hash="1f91bc3ded39c5b108d8232d18cd17f4"/></dir><file name="Adapter.php" hash="a4dcf44cd31de8969f3e941f9a14d0a5"/><file name="Exception.php" hash="a8fba4a7bf9a1a58225ab313b5fa4dd3"/></dir><file name="Feed.php" hash="716918e5334ac352997eac35ca5956dc"/><file name="Mobile.php" hash="00d3e607c4ac5e298492bd3d7762c555"/><file name="Offline.php" hash="6c1ce88c65a43a63416928292c5f9f5c"/><file name="Probe.php" hash="b4df007dbdeb6ef7c49f599d728eed49"/><file name="Spam.php" hash="a4402ccfc92bdf4c49ed1a27bb1905eb"/><dir name="Storage"><file name="Exception.php" hash="ab40f3958bb905a85cfa5cf14af640d4"/><file name="NonPersistent.php" hash="9c8d459eb114f70df099bd397a542a1f"/><file name="Session.php" hash="6b94c84a472e0a767d42be7e26aec3c7"/></dir><file name="Storage.php" hash="ec42c71aae122ea711cbf87ef261c4e4"/><file name="Text.php" hash="711458780f3c17ad437f3d56b5109321"/><file name="Validator.php" hash="69d6afb8a82293c61a642c791f5a16db"/></dir><file name="UserAgent.php" hash="460734f564ed89053481a1204db01c79"/></dir><dir name="Json"><file name="Decoder.php" hash="be80f4b8fe57afd69752fc51c349dcc8"/><file name="Encoder.php" hash="0282ee4cb81e78771c8829398f64082f"/><file name="Exception.php" hash="949bff931d3430258aa0d8688d70df18"/><file name="Expr.php" hash="5985e830701d7f8d5daeb230ce56b1a3"/><dir name="Server"><file name="Cache.php" hash="149b4bcdb085ccd0d535903aa463a0a6"/><file name="Error.php" hash="f3bec127c343a8e14a7a9b1339ab28aa"/><file name="Exception.php" hash="1b0ac33c450ec1bee800421995576fa7"/><dir name="Request"><file name="Http.php" hash="832d82cb88edefb954c4d4d730d0a95c"/></dir><file name="Request.php" hash="35999aec48306723cd44da4c5a62fe35"/><dir name="Response"><file name="Http.php" hash="a5f156d547e04bd224295be634e864da"/></dir><file name="Response.php" hash="a3c115766d7a5e6e57cb4a27887cad2a"/><dir name="Smd"><file name="Service.php" hash="9aef500f4cef8c72886b6103820397e5"/></dir><file name="Smd.php" hash="c8dce4255950f809a22ee60febb2bc2c"/></dir><file name="Server.php" hash="90dcadb42953db253627a783aafa0b80"/></dir><file name="Json.php" hash="9c8bd17cde28999638cd2f05fe470cbb"/><dir name="Layout"><dir name="Controller"><dir name="Action"><dir name="Helper"><file name="Layout.php" hash="c049699d9228b85c2823d7bfdba7d8de"/></dir></dir><dir name="Plugin"><file name="Layout.php" hash="2af276e070314489ccdd514b841d86ad"/></dir></dir><file name="Exception.php" hash="a479f33598f2c4e1cb228883ae6f22ac"/></dir><file name="Layout.php" hash="6d7b1d2ad0c1bf5d5d1ea058ca5a24f7"/><dir name="Ldap"><file name="Attribute.php" hash="a334347a968defb0fda698c3c54f46d7"/><dir name="Collection"><dir name="Iterator"><file name="Default.php" hash="8f8a4876cf258d6b1f71582a805df017"/></dir></dir><file name="Collection.php" hash="ac57de545867cf7cd1df3d6c113263ca"/><dir name="Converter"><file name="Exception.php" hash="4e029f2da6d5c7df7644bfd2c434c6d0"/></dir><file name="Converter.php" hash="8e09bff7ca34d3051cee4a873f5b58a1"/><file name="Dn.php" hash="b5653205b12da006a91e498ca7fc7dc4"/><file name="Exception.php" hash="e12baa19246087c376b7d5cbf0ab7eca"/><dir name="Filter"><file name="Abstract.php" hash="efc802cd50bc28c4181e5bbab247e725"/><file name="And.php" hash="662ca1c25383de02b569c76bc62a058f"/><file name="Exception.php" hash="4f8ae5e40c68e60f00550dd5ccd7aa34"/><file name="Logical.php" hash="06aad3c5c574bae76adc46927ae21474"/><file name="Mask.php" hash="904d6707c87b202d9b66e1e3532fbd94"/><file name="Not.php" hash="028697704f21551b33dcb7c160369691"/><file name="Or.php" hash="8dec15db06446ad375c61c7f46912d7c"/><file name="String.php" hash="b1cc0c074d1822be6124f6c48e351a86"/></dir><file name="Filter.php" hash="c50df357d992c35c217ac7803ce314b2"/><dir name="Ldif"><file name="Encoder.php" hash="d1116ef8bfa81ce18fd5cbae52942227"/></dir><dir name="Node"><file name="Abstract.php" hash="e84bbf67046f975a1f5775aa0d49348d"/><file name="ChildrenIterator.php" hash="8b0c6775e5111e80938ccc9cb60aed0c"/><file name="Collection.php" hash="11098b8c84df455895877fad99f30a20"/><dir name="RootDse"><file name="ActiveDirectory.php" hash="c5f5e80b8dd2cb1e31ac3e03fc279024"/><file name="OpenLdap.php" hash="dcd6e7ebc3775e6a5cba8485bd78c8d6"/><file name="eDirectory.php" hash="f946fccdb3015b015d3cff00829a6ea6"/></dir><file name="RootDse.php" hash="c247acc47a79441717304abade296309"/><dir name="Schema"><file name="ActiveDirectory.php" hash="85bc7915ab42dae47c2d4fb8e3dba51c"/><dir name="AttributeType"><file name="ActiveDirectory.php" hash="04a142f499e0848e9ae43a64786328d4"/><file name="Interface.php" hash="ae4ab45b50efa4e032e32912d9c6a776"/><file name="OpenLdap.php" hash="a823f4b81c597a3820e4fe67e5454e70"/></dir><file name="Item.php" hash="fe670cbd69aa5863f9f66efadfcd3dd2"/><dir name="ObjectClass"><file name="ActiveDirectory.php" hash="e678fbe8c0e965cf7db01e829adff67f"/><file name="Interface.php" hash="166b71e4032d84ecfc88365d89b1de11"/><file name="OpenLdap.php" hash="428b8707dc060e1f9e7854005c51d58e"/></dir><file name="OpenLdap.php" hash="2e52c69ae03823a1d0f42e83aff2f316"/></dir><file name="Schema.php" hash="2745fb40a9578d326a48718ee91cc5fa"/></dir><file name="Node.php" hash="648c759b832b68b000e8bf08af0339ce"/></dir><file name="Ldap.php" hash="da470d2a2a451bc59b2ed1ecb118ec5d"/><dir name="Loader"><dir name="Autoloader"><file name="Interface.php" hash="5a8847bbf702beb3c5d03d9b6620291a"/><file name="Resource.php" hash="b9e4409e67051a21f4e2ae855c1bd691"/></dir><file name="Autoloader.php" hash="4882de8624fe2953294bb4a2a2a6f8f6"/><file name="AutoloaderFactory.php" hash="3ec199fa5c2dec860143b37f17b5ce65"/><file name="ClassMapAutoloader.php" hash="2acb3037511952ac7eb2bab70501dcd9"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4286045d7c3bad36fa3e101f0beadfaa"/></dir><file name="Exception.php" hash="81dbec797bf5464d3dd93886de055be3"/><dir name="PluginLoader"><file name="Exception.php" hash="fba867bd38d0dbb235f86cc6899d834e"/><file name="Interface.php" hash="60638720a3d503c41b6679d1a12c9e59"/></dir><file name="PluginLoader.php" hash="6be3d7edad844778eb79c52494f04eb8"/><file name="SplAutoloader.php" hash="b35315f66536a170485d6a91cc962a4f"/><file name="StandardAutoloader.php" hash="181406bd273d500ef771e5f24b0bd909"/></dir><file name="Loader.php" hash="817eebfff3c19cf057a8bd92f0c9c679"/><dir name="Log"><file name="Exception.php" hash="b163db6d6600897c6d7d9675f5b2082a"/><file name="FactoryInterface.php" hash="950fce8f1016b9149a3afa78cb5d6bdd"/><dir name="Filter"><file name="Abstract.php" hash="588c7a33b8cc18516fb09f45b6e4df27"/><file name="Interface.php" hash="8e207e5fde37a093bc429eca471abdb5"/><file name="Message.php" hash="42c00aa794507e263369816ebd6ecfb9"/><file name="Priority.php" hash="3bc818826edb7d8d47778c71534968ca"/><file name="Suppress.php" hash="6198f609922c91844696ad749f8f988b"/></dir><dir name="Formatter"><file name="Abstract.php" hash="f6b6a3a2f08104b92f02916dfae10819"/><file name="Firebug.php" hash="18bf525dd98a338a0068adc7223004aa"/><file name="Interface.php" hash="f304a62a7dc3774938c9a4c0386e312a"/><file name="Simple.php" hash="e99de8b500f61444ef4ffd6bd44f8b28"/><file name="Xml.php" hash="dc3361c1aeaa94dca0dac28920c7ea8d"/></dir><dir name="Writer"><file name="Abstract.php" hash="79ccb8a60f0146adc3d1019487a99a69"/><file name="Db.php" hash="e9dd86777ca1735ccec177c7e385316e"/><file name="Firebug.php" hash="6227fe3e164c36db1829e4afd5fdddd2"/><file name="Mail.php" hash="3f76aaf2c1bfa288b7f126efd127c306"/><file name="Mock.php" hash="be44a2526cd397f294cb3350334479cc"/><file name="Null.php" hash="7dc63aa32e13ee72975d68873d87d85d"/><file name="Stream.php" hash="5a287635e4c1d74763215959ba19b70a"/><file name="Syslog.php" hash="06022b333a8ca4d896eaea75f92fe543"/><file name="ZendMonitor.php" hash="3e508d727439f6c10212e70617d68b20"/></dir></dir><file name="Log.php" hash="1c6f8b389780f0bb85202471def93ea7"/><dir name="Mail"><file name="Exception.php" hash="8d01b40eca451bee7c9401d2498ae65d"/><dir name="Header"><file name="HeaderName.php" hash="ecd8c8336e3619779a72d1e1f105675c"/><file name="HeaderValue.php" hash="d55840608558bb29022bca0c565ae55e"/></dir><dir name="Message"><file name="File.php" hash="7415d6300a134322e1f9b5723f456375"/><file name="Interface.php" hash="37f65eeadf5f7d8c46e5740810a91f31"/></dir><file name="Message.php" hash="eea17eeae16ed0696aef9794f947791b"/><dir name="Part"><file name="File.php" hash="2973a0c512d8a12ae250f0310e7ab715"/><file name="Interface.php" hash="5a08dd0d4abfeba0e2b6a3bcd0647cb0"/></dir><file name="Part.php" hash="b948eb534e24b93bb22d34d6dc78c494"/><dir name="Protocol"><file name="Abstract.php" hash="75f76eb34f20aef472da005983e4ade4"/><file name="Exception.php" hash="324b88f119661b2fb45e50e03fdbb797"/><file name="Imap.php" hash="4be011d91db7e932867a9ef04b9e3f1c"/><file name="Pop3.php" hash="a3f36e5260b3fdf15ff91afb4edd06c8"/><dir name="Smtp"><dir name="Auth"><file name="Crammd5.php" hash="989efed470312ec3d252f04f48b13f1f"/><file name="Login.php" hash="eeb279a39d84d0c34b5b3c57a0d8e1fb"/><file name="Plain.php" hash="4e4fb49d2c0a4c3cc6326b9362663812"/></dir></dir><file name="Smtp.php" hash="a99437c462526c3ab7c4a16e6dd73dd5"/></dir><dir name="Storage"><file name="Abstract.php" hash="c80a746bb73014c266f2785247770e77"/><file name="Exception.php" hash="8dfb9dc508a506017fa2aba591171706"/><dir name="Folder"><file name="Interface.php" hash="e46d56b2092b8e66b0de59f089f28dbc"/><file name="Maildir.php" hash="2ffec84ff5cebbc06f42a4bf4e8e49a0"/><file name="Mbox.php" hash="a6bc27702d0e9acbc52d83efdbb623c0"/></dir><file name="Folder.php" hash="710f0f79f55eb9c16523b59b3e46026d"/><file name="Imap.php" hash="63b4ec9c47e81d973c0cecb781a0e398"/><file name="Maildir.php" hash="c298cee3127aebf1d902bc6a263cd67f"/><file name="Mbox.php" hash="96e1d239b5d88772aacd245255d35cc5"/><file name="Pop3.php" hash="fe599c6260e22c23dcd3bfd698271b77"/><dir name="Writable"><file name="Interface.php" hash="a5a3487a8b0dcc8c1f957e10b9535c96"/><file name="Maildir.php" hash="f9dc51e0430fed3cb7fb06a6fc46b4c1"/></dir></dir><file name="Storage.php" hash="bf94dde2f63c2ea5933cff36fd0d96d2"/><dir name="Transport"><file name="Abstract.php" hash="b5e088f0f4a65356307e1e6048558c5a"/><file name="Exception.php" hash="2fc585f21c0c0bbfb8d9218788a99d91"/><file name="File.php" hash="976dec70144df18e87d527ff7e516758"/><file name="Sendmail.php" hash="0a64fedcc87ebe0c9c15695805201bef"/><file name="Smtp.php" hash="6f916608a1b6f93dc6d116e8d8f40b94"/></dir></dir><file name="Mail.php" hash="233f0679a2a5101183c73419cc14e184"/><dir name="Markup"><file name="Exception.php" hash="6acb9e012348c31a98e8016f689bd83b"/><dir name="Parser"><file name="Bbcode.php" hash="fe5258254d43407c8ebf45121d5d3443"/><file name="Exception.php" hash="96b47171a5e4994dcb75bfeb964a3261"/><file name="ParserInterface.php" hash="22f4cab8c966e18965cc16bf1ac58a2e"/></dir><dir name="Renderer"><file name="Exception.php" hash="c27375ebcd69a8eb56a5c3e3229ef88c"/><dir name="Html"><file name="Code.php" hash="c919be3dcefb797b425cd65153302f6e"/><file name="HtmlAbstract.php" hash="7dc1ee614c7d125582f34ded495bd5a3"/><file name="Img.php" hash="6a130ace451a6ed0a2d0a1f1ea3bff58"/><file name="List.php" hash="e8474711d02734026d531708832e1310"/><file name="Url.php" hash="6bb6f2015aa632299941bf9997e8110e"/></dir><file name="Html.php" hash="b607c5add3adcb046c58771b79ecdca5"/><file name="RendererAbstract.php" hash="bf2e4d797e26ef28885babcf2d9e2722"/><file name="TokenConverterInterface.php" hash="e5b38c0b3ba387f0df071a35c7fb1f3f"/></dir><file name="Token.php" hash="925b6878c35fd1e0855a73ecf684f25c"/><file name="TokenList.php" hash="590aa72556941d672184f1aca02ef30c"/></dir><file name="Markup.php" hash="70327a385551a40429dbf98def244565"/><dir name="Measure"><file name="Abstract.php" hash="a844b711aca6638ea933630264ab309f"/><file name="Acceleration.php" hash="f6b1c64dd6bacb4f38d91f72cd8db6d9"/><file name="Angle.php" hash="6c7ec7f864050be14c1735017d149b18"/><file name="Area.php" hash="88b0f14de44d235235da841062691dd1"/><file name="Binary.php" hash="5f9e527c1e8d01535d9bfea7105ac76c"/><file name="Capacitance.php" hash="8bff74324cadcd21836b5acc547a544e"/><dir name="Cooking"><file name="Volume.php" hash="334d3bd9a1023acfed66eb41bf307a15"/><file name="Weight.php" hash="d970ef6d6f08a37db72285917d30ccd6"/></dir><file name="Current.php" hash="1747ffe7532a5c7c060343e3271a27f2"/><file name="Density.php" hash="f4cb05733337475f59762b41a29ae3bc"/><file name="Energy.php" hash="2ed086e65b6f7a4ce1280d8ef9d0f1c3"/><file name="Exception.php" hash="d00039899c6aa43c6b250588bbc07e35"/><dir name="Flow"><file name="Mass.php" hash="2d322913557ff2bfc45afc2ab480babd"/><file name="Mole.php" hash="ff0fe19858605f8c65cbc6f1f377aba4"/><file name="Volume.php" hash="66df34980d0aa473755280393b0f0d7c"/></dir><file name="Force.php" hash="9525a6c47d1e4cbaded7b3477d3c4ba7"/><file name="Frequency.php" hash="80bf10cfe7eeebc3d281b7ed11b397ea"/><file name="Illumination.php" hash="98ee18ab173727ba4dc93a3ada6edd33"/><file name="Length.php" hash="7318f5740bfe039f8c6bda66f172251a"/><file name="Lightness.php" hash="ea419ded90ccd0f5c053262458cc80eb"/><file name="Number.php" hash="7a63c36bbf2089aef5e8ee3e7347e24c"/><file name="Power.php" hash="c896cc783192f260057584f2ba881f87"/><file name="Pressure.php" hash="49c451f9eacd6d162ba6bb629e9118e1"/><file name="Speed.php" hash="c601fe3564d6f3d1f8813a0a7013e335"/><file name="Temperature.php" hash="0d5d33464d00562675fd5d801eebe117"/><file name="Time.php" hash="1c8b825d84b6ccffd76906404d92173a"/><file name="Torque.php" hash="1f530a46616ba82d78541493fb321445"/><dir name="Viscosity"><file name="Dynamic.php" hash="5f002bc79a1c1138cacacec371db37ab"/><file name="Kinematic.php" hash="bd10456069dc6d35a3e1713bd4c6dd71"/></dir><file name="Volume.php" hash="0fbf0ca1290f4aa1af5b23982a6914c3"/><file name="Weight.php" hash="a821fffd5941ccd527cc1d0694336b00"/></dir><dir name="Memory"><file name="AccessController.php" hash="a70d4c42eea7b98f61113d798b55259a"/><dir name="Container"><file name="Interface.php" hash="6068d380217bf27b6453cf894edb8695"/><file name="Locked.php" hash="9bc2f25899430f7ad02853e88dfca0a9"/><file name="Movable.php" hash="4c3c042f5e2bcc2531715dde401171cf"/></dir><file name="Container.php" hash="8feed8c3f2b8f5f0e8d688f13c48c2aa"/><file name="Exception.php" hash="3329d69fccf497932b1a2c27e9919c18"/><file name="Manager.php" hash="1a5c0de427d4436a95fb9d2c0953f279"/><file name="Value.php" hash="697a03309f774813690845eac71d4702"/></dir><file name="Memory.php" hash="2e82b15d077661c5c4b8201ea5bab1fc"/><dir name="Mime"><file name="Decode.php" hash="0cd721f3b84a257348cbfcb73919759e"/><file name="Exception.php" hash="994fc2875e99f10a522cb82e4a54b2b7"/><file name="Message.php" hash="4e3dd5e95f8621955641c7e1b4de46c5"/><file name="Part.php" hash="a11ac478688ef12d8cd0ccecff33670c"/></dir><file name="Mime.php" hash="39042a59c2be063d736a04dac55e903f"/><dir name="Mobile"><file name="Exception.php" hash="519a024f65881a7a4237732573710059"/><dir name="Push"><file name="Abstract.php" hash="456f8a825509d342fcfef1439673f54c"/><file name="Apns.php" hash="d8429732ef082dd5db604fea4c8915b5"/><dir name="Exception"><file name="DeviceQuotaExceeded.php" hash="86b9ff4bc83a799a58f7dffea7382284"/><file name="InvalidAuthToken.php" hash="5ad87658c33a7d9cc6f917d0b5920253"/><file name="InvalidPayload.php" hash="25c5f5d11619d662e9274418d98ed4f8"/><file name="InvalidRegistration.php" hash="8658ffa721150d321de50135d2e5a807"/><file name="InvalidToken.php" hash="713a8d260276537743a4d04b4aa81c11"/><file name="InvalidTopic.php" hash="7c829b73a958a1a5b2727d2819061578"/><file name="QuotaExceeded.php" hash="be67af28f9904f0fc42004751daff33a"/><file name="ServerUnavailable.php" hash="ed4b06b1ef3e3c429b90731ae2920412"/></dir><file name="Exception.php" hash="f894173f4a187922ee49522cf8d3353a"/><file name="Gcm.php" hash="920c224bf5d2829b12e860785f1fcb02"/><file name="Interface.php" hash="8ac308916b40869193bfe9f4924c6d8d"/><dir name="Message"><file name="Abstract.php" hash="60010ad2c300cc7aaeef6e09bd1f0eb7"/><file name="Apns.php" hash="3aa335c6ee551991ad704c6ec1965399"/><file name="Exception.php" hash="14efc16a622ee08a4d66f6b966aa8afc"/><file name="Gcm.php" hash="8e5c08acd168e10c7e0b7be393683846"/><file name="Interface.php" hash="aa9b1e963e71262791a2e85f9d5e03d4"/><dir name="Mpns"><file name="Raw.php" hash="cd49049ab99df63e747b3cf21ce49056"/><file name="Tile.php" hash="eeb12c6d00f840c828e8f928ef28e747"/><file name="Toast.php" hash="6b7b461af1ebd47bc8278388762e186d"/></dir><file name="Mpns.php" hash="bfb031f22738438461df23e002feb93c"/></dir><file name="Mpns.php" hash="d027a3baf86b7808b8f5dd097dd748dc"/><dir name="Response"><file name="Gcm.php" hash="02cdfb00622182c505e7c4916fb51397"/></dir><dir name="Test"><file name="ApnsProxy.php" hash="ef5b18b7cac0826d10cca487ab851180"/></dir></dir></dir><dir name="Navigation"><file name="Container.php" hash="ae908f801587df5bbc7a44d94e290365"/><file name="Exception.php" hash="1f907b7d1a68ca8d29b29f8f9694ca3c"/><dir name="Page"><file name="Mvc.php" hash="bb408e6676cc27d470e41f21084d050f"/><file name="Uri.php" hash="45e78f322e869f7570a82cac147f9985"/></dir><file name="Page.php" hash="ecc7fc65c84c45b552ea81d280fc13d2"/></dir><file name="Navigation.php" hash="bee97615ae02af0c039d61863d0b1e00"/><dir name="Oauth"><file name="Client.php" hash="74d6c02debac4961c253da9d8cc2fe5e"/><dir name="Config"><file name="ConfigInterface.php" hash="1cabd35d6a7f0f92529457b4ea62e17a"/></dir><file name="Config.php" hash="a02e7f37acbb42bc34feebc920d49871"/><file name="Consumer.php" hash="3dc938414065746a37763d2b592e1ee5"/><file name="Exception.php" hash="570bf15ce9b8ccf76e4bcd949adeef50"/><dir name="Http"><file name="AccessToken.php" hash="986d7e25f96d5bed67914e08404bbb5f"/><file name="RequestToken.php" hash="f4f86a01a6e424aaa7e8edb99e518f59"/><file name="UserAuthorization.php" hash="758cc6c3df942ac5ac3b103527a99a10"/><file name="Utility.php" hash="9c69fe9d58add25eda7730460eeb4ae1"/></dir><file name="Http.php" hash="cef52b37622bcfb2efd2a9644babc94d"/><dir name="Signature"><file name="Hmac.php" hash="26331323b06095d36ea1b3d8de214c79"/><file name="Plaintext.php" hash="11266c5bf1d868c63fac84ff14c22061"/><file name="Rsa.php" hash="4ea7e936077c094ee6365ee33707c4fb"/><file name="SignatureAbstract.php" hash="09e632d7cfb30720b43cd8e33ca867f7"/></dir><dir name="Token"><file name="Access.php" hash="974b61753e392b577562e7090dec4102"/><file name="AuthorizedRequest.php" hash="2c5a7071f93bfc03e8098a367c1b95ad"/><file name="Request.php" hash="3253abe4f0340e7fa12d6c26c669e1cf"/></dir><file name="Token.php" hash="19cbcf77a287619c7043efc9cf4cc2fb"/></dir><file name="Oauth.php" hash="239174147ad1cac48ff43b86ca768b5d"/><dir name="OpenId"><dir name="Consumer"><dir name="Storage"><file name="File.php" hash="53a1aec62db8e0bf8153d2363b8afdcd"/></dir><file name="Storage.php" hash="96636f4707d5090dd777ca16ff5f9498"/></dir><file name="Consumer.php" hash="d4129677162161a383a8327a8a5f5cb4"/><file name="Exception.php" hash="9ae51477a152a9993db86a2b3e87a792"/><dir name="Extension"><file name="Sreg.php" hash="a46ab3f654e7718b74f256863398070d"/></dir><file name="Extension.php" hash="d0cbcdb2874105fad8d517731ee682dd"/><dir name="Provider"><dir name="Storage"><file name="File.php" hash="78e54dc83e5862422be8c086458815bb"/></dir><file name="Storage.php" hash="a111906ee39dd25c3e8f03edf73a3f0b"/><dir name="User"><file name="Session.php" hash="184de6934deff211975387b3d0eea0c7"/></dir><file name="User.php" hash="1130cc8407f1607fcc19e0e0e7048953"/></dir><file name="Provider.php" hash="e82af61658678702cf9b92879c70494d"/></dir><file name="OpenId.php" hash="3afe8be181b4ee86ebca1531a1bd8b0b"/><dir name="Paginator"><dir name="Adapter"><file name="Array.php" hash="b19b7013fca38d006a2b638b89312764"/><file name="DbSelect.php" hash="3bd5b7dc7a01b4dcb161f396be0b8670"/><file name="DbTableSelect.php" hash="cab2b30b8210b2979b0c6bed4b123fad"/><file name="Interface.php" hash="5762707d8b9db19faf2a773eb78edd76"/><file name="Iterator.php" hash="3a51f92d688197a2967eef55d802f56e"/><file name="Null.php" hash="2e58e92129e83d96b61e5ba5bf679157"/></dir><file name="AdapterAggregate.php" hash="b6ed68617efff6b9dd41ba5d27cde51f"/><file name="Exception.php" hash="bd8961847f8ea166c7e222e2344d586b"/><dir name="ScrollingStyle"><file name="All.php" hash="7a024155b60bcbb024b3ab8418ea1737"/><file name="Elastic.php" hash="a7d8784429dc1e520b3f98d14c5eac09"/><file name="Interface.php" hash="1d6adbef71c9c1966676ede68de7f977"/><file name="Jumping.php" hash="2e2e9f1633d9ec60e0e111a5794aed93"/><file name="Sliding.php" hash="9f768e8bcaf3bd6f12e0e939c00775d4"/></dir><file name="SerializableLimitIterator.php" hash="411f2359e449e170c5dadaa24803a54b"/></dir><file name="Paginator.php" hash="0d3667499c2f0c3a8c9e5907e812b7a5"/><dir name="Pdf"><dir name="Action"><file name="GoTo.php" hash="d1e30bb7d45aedbeaa31b5dc8b40e287"/><file name="GoTo3DView.php" hash="fcd5460403b8433315caeca12418a5cf"/><file name="GoToE.php" hash="599ebb6d2df80852cfca9a9cedb8d6b0"/><file name="GoToR.php" hash="474402a7102d563261bd914a721b36d2"/><file name="Hide.php" hash="8810efbd459a87d1ee9de7cd007d1644"/><file name="ImportData.php" hash="ecd6feef7d654d60b8efc24bf26d4662"/><file name="JavaScript.php" hash="9bdf7f5f8360300bc95e3e293431f425"/><file name="Launch.php" hash="3e3b49828aefff82b9b44b295084e413"/><file name="Movie.php" hash="b65daa361fc8e77f5ffc4ecedb3becff"/><file name="Named.php" hash="7a1ea555152631327d04a9eb263b4a5a"/><file name="Rendition.php" hash="363bd0314e6d20994934dabd3ad63684"/><file name="ResetForm.php" hash="f4637cd51199245ab14aa6021ffe71be"/><file name="SetOCGState.php" hash="301da63cac76237c91818aac076cbddc"/><file name="Sound.php" hash="ee1e489704abce5aa0dee9047bd8b456"/><file name="SubmitForm.php" hash="657a9f4bc9cd87ca3551370d195b7a35"/><file name="Thread.php" hash="ecee0d4d74deafefed77cd0f6798093a"/><file name="Trans.php" hash="d9f99fb44efc3651ca5e2c56fd7e96b6"/><file name="URI.php" hash="7e52db0fd92d4edb87ab4f4e789d45e3"/><file name="Unknown.php" hash="a8602a55e7a0792d6cd0615c9ac23c41"/></dir><file name="Action.php" hash="ec5a813b9a9a0caf8beb63b890c68450"/><dir name="Annotation"><file name="FileAttachment.php" hash="f3864019953d49d9cd83d322f9a54f4d"/><file name="Link.php" hash="bff1663cb2b899d96d2b5e539f516d63"/><file name="Markup.php" hash="ab0f2e3e12ec5c7e75b2daf9851c59d1"/><file name="Text.php" hash="7b507f12f45421db845a74e91a0c78fb"/></dir><file name="Annotation.php" hash="0d098c2160f4b3267e7fd7f367f30290"/><dir name="Canvas"><file name="Abstract.php" hash="364364cb99b19cdf0d622397424e155d"/><file name="Interface.php" hash="1795a31a88af11db1f8eaefae3751d65"/></dir><file name="Canvas.php" hash="00dcbc00ee5b0678292c40c62709bb37"/><dir name="Cmap"><dir name="ByteEncoding"><file name="Static.php" hash="bca21500f7be22a1c6349cce6b489afa"/></dir><file name="ByteEncoding.php" hash="84d9e9e1afe70befb0b7c193516a7ad6"/><file name="SegmentToDelta.php" hash="34570bbef3c618d344e056a65a86310e"/><file name="TrimmedTable.php" hash="1a8eaed30b4393a4ad1972ccfa586275"/></dir><file name="Cmap.php" hash="9d7432c932a1f5260c8752cd0eb09cb9"/><dir name="Color"><file name="Cmyk.php" hash="9024fe208254093dfedb355f1a56bfa3"/><file name="GrayScale.php" hash="ac29a955a5422d31e3c6342c9ba5df7f"/><file name="Html.php" hash="98c75da7b5c1e27d72029a612973c33b"/><file name="Rgb.php" hash="db12cfc9dfbb80831d4b1e5436ff8323"/></dir><file name="Color.php" hash="104cf49d07c358cc85220fc3122e800e"/><dir name="Destination"><file name="Explicit.php" hash="13bd68687766542d36847199a9dd478a"/><file name="Fit.php" hash="1aa3f00fde3170cae69b69bd17786c3b"/><file name="FitBoundingBox.php" hash="b59f2ed44504d9f3df4a8e05450c0f07"/><file name="FitBoundingBoxHorizontally.php" hash="1271088bf2557a2eb8c18f388e1853ee"/><file name="FitBoundingBoxVertically.php" hash="16948b893fe63488b34891f82d409d52"/><file name="FitHorizontally.php" hash="88e880e0528a4f7060d233e687e90667"/><file name="FitRectangle.php" hash="408a9be40986151fff98af1efabe8a28"/><file name="FitVertically.php" hash="136c71dd521fb51103f98a76734fb8c1"/><file name="Named.php" hash="a65c919e6fa48d4453a9581ebb908adb"/><file name="Unknown.php" hash="1a2e8b67ee995941dc43b43070a3971f"/><file name="Zoom.php" hash="c9325d991fc179afcca30c3636e72e1b"/></dir><file name="Destination.php" hash="b7605192c93386f3fd25520d180343dc"/><dir name="Element"><file name="Array.php" hash="b644069461389d8cffe6d3bd1cc49835"/><file name="Boolean.php" hash="d4a4de598d871b0ae391dd72ee4cbd2a"/><file name="Dictionary.php" hash="fa2156732ab46185f1412c3e22c54c92"/><file name="Name.php" hash="be8084d6e0fec7b6941bfcb2cbc93535"/><file name="Null.php" hash="a982c3b2f79e698e80cccc4cd794219a"/><file name="Numeric.php" hash="020e5a151377a7f95b0ab846f4cf5829"/><dir name="Object"><file name="Stream.php" hash="9a4d7197a43ba30df5e1871cf85a05f2"/></dir><file name="Object.php" hash="f0b69fb983587a2f68a1f40e3e417663"/><dir name="Reference"><file name="Context.php" hash="e15ad61d18c94f11179594e9a58cb6d3"/><file name="Table.php" hash="6a90fd67ff295547877255bf8bfbe2a1"/></dir><file name="Reference.php" hash="0725ddc6094e61656354a949986d4def"/><file name="Stream.php" hash="166a0bef11c118de4591b7436a9e999f"/><dir name="String"><file name="Binary.php" hash="f6a6e7ce998124ba104470dcb4734dec"/></dir><file name="String.php" hash="e776be7acc388a17af23bec80954de82"/></dir><file name="Element.php" hash="3595c5f91616d00f51af614feafda5f5"/><dir name="ElementFactory"><file name="Interface.php" hash="d1a6e36aaeee2b4a4a7f8b6111facbec"/><file name="Proxy.php" hash="a07e4d22cba4810f367ca6b7240fbc83"/></dir><file name="ElementFactory.php" hash="024f30704c4c693597c11f4b032dfedc"/><file name="Exception.php" hash="7b3b6c5890b43cd2fb05b68f6282f521"/><dir name="FileParser"><dir name="Font"><dir name="OpenType"><file name="TrueType.php" hash="b493bcd28a5c4006be3f5c0a1081b28c"/></dir><file name="OpenType.php" hash="a5d6ab27fa54d414b01532d4830ef090"/></dir><file name="Font.php" hash="56634e0dcb7ade369b564643c5a5d171"/><dir name="Image"><file name="Png.php" hash="15d071e3ce65f9eb9936ca4149910fb7"/></dir><file name="Image.php" hash="29748c74077a30e3b3d108c316ee1910"/></dir><file name="FileParser.php" hash="4d54f7155401a9fb7df70998a2da9a50"/><dir name="FileParserDataSource"><file name="File.php" hash="1e9148d68ab81b33f2d88c403d9495a5"/><file name="String.php" hash="e4cd122d052ef39e6da5c38ec452d161"/></dir><file name="FileParserDataSource.php" hash="eb883b69beb455a62c8931a878151085"/><dir name="Filter"><file name="Ascii85.php" hash="b65b7f97285f88f9f11265191cf20849"/><file name="AsciiHex.php" hash="ed846de8708cd7026f551d78de57782d"/><dir name="Compression"><file name="Flate.php" hash="faf5cfc2e9c94444e43d7e6944247988"/><file name="Lzw.php" hash="9c28f750f6600ce94877b78ad7c71324"/></dir><file name="Compression.php" hash="73050021440ac2c7b18bd20513157c3f"/><file name="Interface.php" hash="e90f59d18816fbaacd86b59b392686d4"/><file name="RunLength.php" hash="e80a6edbe6fa87c4702d09d65db1a2ea"/></dir><file name="Font.php" hash="51087d7787fad796537357c3ac69dc73"/><file name="Image.php" hash="7877b76dd9e150104b83037266258658"/><file name="NameTree.php" hash="da4cc3e1566938790d1c613174aa23eb"/><dir name="Outline"><file name="Created.php" hash="9d373dc681d5b2805d30b5685ef862c2"/><file name="Loaded.php" hash="d6d0bcbbbc7125de10670b4e6562b59d"/></dir><file name="Outline.php" hash="f26766891dc3d3bce49b037adcfef12e"/><file name="Page.php" hash="13f4483dfd5d93e7e94d273c662b46ac"/><file name="Parser.php" hash="ba36ebc92a1b6e525ed8c0408e251bef"/><file name="RecursivelyIteratableObjectsContainer.php" hash="715f93a595f54a38111141fd5968213d"/><dir name="Resource"><file name="ContentStream.php" hash="a1749fec0cba8e9cb72efb1304de2346"/><file name="Extractor.php" hash="bb8efb4919fa8775f711f61d183a4e12"/><dir name="Font"><dir name="CidFont"><file name="TrueType.php" hash="1290b18c2ed5643477c1e88b0c76987e"/></dir><file name="CidFont.php" hash="382f00c4a207bea2ffd82a5d77da6304"/><file name="Extracted.php" hash="bd8bedaf4a31c4ae1eddf944644ecce5"/><file name="FontDescriptor.php" hash="9fcedd31b44153c7ad83cae939397e42"/><dir name="Simple"><dir name="Parsed"><file name="TrueType.php" hash="e060a25bc471d15d43a51d580679326d"/></dir><file name="Parsed.php" hash="becce62602415adde90984b7590993ba"/><dir name="Standard"><file name="Courier.php" hash="1a8795c6738e56ecc9b223ed823c0e0a"/><file name="CourierBold.php" hash="271652240d7b89827820060a185aef0d"/><file name="CourierBoldOblique.php" hash="f8e6fa84ffdc7ffcb8069c67e813f09b"/><file name="CourierOblique.php" hash="7b4080d45eff2b8fd5d66db97512a8bd"/><file name="Helvetica.php" hash="fdf4947a20fbf3f694f4fe940cec5df2"/><file name="HelveticaBold.php" hash="1340145daef0b6ed9e4d15ede06a0530"/><file name="HelveticaBoldOblique.php" hash="ae26d6990824525b0cb3c99e87674000"/><file name="HelveticaOblique.php" hash="a05d94e11e3e1db842ac7f1795074373"/><file name="Symbol.php" hash="9443a7d26e4c2a752cf3f4ff883ffa05"/><file name="TimesBold.php" hash="b2619f7edcc8abab8ff28a4009123f84"/><file name="TimesBoldItalic.php" hash="433fcd37d348fa4458cf437ea2cdabad"/><file name="TimesItalic.php" hash="76ec1fbba59e77bb848f8696337aadf0"/><file name="TimesRoman.php" hash="953b76c5e03a7858bd8361872e412ded"/><file name="ZapfDingbats.php" hash="548d057f0040392a4828264f24e243cd"/></dir><file name="Standard.php" hash="f332565c96e87d79436790a096f46aef"/></dir><file name="Simple.php" hash="334a3b36ea5235902d79cdb31cd05d73"/><file name="Type0.php" hash="6c0a83ed854fdbb16bf525fcd219a4ca"/></dir><file name="Font.php" hash="6046881c1057ef05d0a420998a05c1a4"/><file name="GraphicsState.php" hash="b51172933cdb59ea271e7a9ae323fe29"/><dir name="Image"><file name="Jpeg.php" hash="0a1a368f9642c0b98d8ff24f0aae7c3e"/><file name="Png.php" hash="f77b42c714316c69714df0a2a94cfb7c"/><file name="Tiff.php" hash="06e9fd0b542ecc53649d868fbb59372b"/></dir><file name="Image.php" hash="dbec25fbc65e673b12f311785249ae4f"/><file name="ImageFactory.php" hash="45222c4b5170b11e9b1fc9f16700f1a2"/><file name="Unified.php" hash="710f5f418d4939a609144eab68a8b797"/></dir><file name="Resource.php" hash="b71cd04a74a88e040f06ea7663ea5e65"/><file name="StringParser.php" hash="5376c86288c13e706f2c76478ae474f5"/><file name="Style.php" hash="8aceb18b61204e8157a46c41bbcdd7e9"/><file name="Target.php" hash="1a2badb1e3ca52a2368a77b0646efef7"/><dir name="Trailer"><file name="Generator.php" hash="2c12f38db376c57935d09f8527fa786d"/><file name="Keeper.php" hash="df14918b0e392a71bd41817f0abfaf55"/></dir><file name="Trailer.php" hash="8069878c1e9320d2b8533cf1e144f4f5"/><file name="UpdateInfoContainer.php" hash="39f4700c55860bb9ec1b3f122258930f"/></dir><file name="Pdf.php" hash="7f96ca856c0dde6e6074711e0db2487b"/><dir name="ProgressBar"><dir name="Adapter"><file name="Console.php" hash="09f7268da0ecd77f2d174f4a8a3de869"/><file name="Exception.php" hash="6a2ed89846b42f86a235044d05555198"/><file name="JsPull.php" hash="582d2e3d4fe457d4c961701b014886d1"/><file name="JsPush.php" hash="229b568b05cf46950fbb3707ca150c01"/></dir><file name="Adapter.php" hash="8297cf770c0ee628158397e3b089c621"/><file name="Exception.php" hash="6fd9c59515c836a7e044c07b146c1e6d"/></dir><file name="ProgressBar.php" hash="581036cf36019829ad17b626f15344f8"/><dir name="Queue"><dir name="Adapter"><file name="Activemq.php" hash="b419df4c2da5f1188e2f9fc07fa17d6b"/><file name="AdapterAbstract.php" hash="77fdf9a85df53d3a3b2a2f5d22e80626"/><file name="AdapterInterface.php" hash="0dcaaa3d94f0c384a3c37e45c7529b3e"/><file name="Array.php" hash="b3227f915782241e3ebdce389d3f0a18"/><dir name="Db"><file name="Message.php" hash="017e049117119a01fd2acf00fac7c5c4"/><file name="Queue.php" hash="0036c67014f3b5787878ecb638088423"/><file name="mysql.sql" hash="487d5a36b9172382351a7cc39d20d221"/><file name="postgresql.sql" hash="42dfaf91f8a425170c9b4b2c9318c875"/><file name="queue_sqlite.sql" hash="b0e5a2e43dfc9a230a5ec397c351eaf1"/><file name="sqlsrv.sql" hash="646346084e937e9239d911485bc0296c"/></dir><file name="Db.php" hash="876370736f86a93dedc206bdaea8ac05"/><file name="Memcacheq.php" hash="f0a6604c99debe72daf655a2f97ddc03"/><file name="Null.php" hash="abbd08fab4a38429460cd70b6170c492"/><file name="PlatformJobQueue.php" hash="0e9187b14fcb15711fc18e6bf0dd1383"/></dir><file name="Exception.php" hash="279bbedb61b1778812827fb636c62bd2"/><dir name="Message"><file name="Iterator.php" hash="11ea9382769f547d17a66ac1a54d655b"/><file name="PlatformJob.php" hash="2988e7c33a68ff837ffd7dcbd835de3c"/></dir><file name="Message.php" hash="fb9762a45a532513ff209e2b4820f871"/><dir name="Stomp"><dir name="Client"><file name="Connection.php" hash="aff6c9c41035654ec0d4a4887b4dd218"/><file name="ConnectionInterface.php" hash="e4adc375b6e177fafbd45e47b93ad1b1"/></dir><file name="Client.php" hash="1d64509385a30e21abb7df5e31aa11ae"/><file name="Frame.php" hash="d909edb1b42697e4f557de5a68368932"/><file name="FrameInterface.php" hash="16c13ddfcf2b1bcc50b85c61dc546646"/></dir></dir><file name="Queue.php" hash="1c9e3ec5bc7508a98b7de1f77ee61ba2"/><dir name="Reflection"><file name="Class.php" hash="ba4973471396d116ba92824b47d313a8"/><dir name="Docblock"><dir name="Tag"><file name="Param.php" hash="2a51f3907ad2ee281175d3cdb28a2e6b"/><file name="Return.php" hash="b0200cc0b804828031ab3a8582dbdcad"/></dir><file name="Tag.php" hash="0eebe17d3442b754d9422f8c9721231f"/></dir><file name="Docblock.php" hash="d0856efe818bee5c5d39645662312ba6"/><file name="Exception.php" hash="c43315831b3596fc86aba74529571aad"/><file name="Extension.php" hash="f4dd6dbfb0d48aabdbf359fa6bfaee9b"/><file name="File.php" hash="47206736078efdd5eefc6527408bd922"/><file name="Function.php" hash="1713773cab56cf753f7f90a1108953c8"/><file name="Method.php" hash="25ecb48f4e4f7029ea6fd759fba663f9"/><file name="Parameter.php" hash="7a34d5982a0dec35c6323160114dcb62"/><file name="Property.php" hash="7ca9b4aca176f18bf89b711b5f0929d3"/></dir><file name="Registry.php" hash="3b697b3b783d2821e69137c4dc3851b2"/><dir name="Rest"><dir name="Client"><file name="Exception.php" hash="2e86578bbe604d335a622957c1b0ae26"/><dir name="Result"><file name="Exception.php" hash="49193abd246224f975676b9bdd41349a"/></dir><file name="Result.php" hash="ffc3f1ee709136ab403949d4274098e1"/></dir><file name="Client.php" hash="b76ff6282552bcd098403cebc7b08ed6"/><file name="Controller.php" hash="86e1b0b6bc3ad11653dfe9e17c7d075f"/><file name="Exception.php" hash="c62bd750b3b4cd33407d99869c600d14"/><file name="Route.php" hash="20875e10d835e380c294d2edfb56b08f"/><dir name="Server"><file name="Exception.php" hash="235457f9f3a4f7720ac2013b51ad4ee9"/></dir><file name="Server.php" hash="ceb61231f7fc67faa657837a9fb2c9a3"/></dir><dir name="Search"><file name="Exception.php" hash="915c3138aac999bdce9426a8acd40556"/><dir name="Lucene"><dir name="Analysis"><dir name="Analyzer"><dir name="Common"><dir name="Text"><file name="CaseInsensitive.php" hash="307dc051465ca81322c5e85e8ec022cc"/></dir><file name="Text.php" hash="758df150a1df6eba4b64004148a672a4"/><dir name="TextNum"><file name="CaseInsensitive.php" hash="e5940381671ed3f7c321b3fda9862881"/></dir><file name="TextNum.php" hash="36acd4b130e2f8b78e2de06ac9b4f942"/><dir name="Utf8"><file name="CaseInsensitive.php" hash="44697c595e22b385d0a7616e7af30ac6"/></dir><file name="Utf8.php" hash="1b7f394340ca0d04c8e6a19fe22d4d23"/><dir name="Utf8Num"><file name="CaseInsensitive.php" hash="9325aa4566ece4546b23c82d1aedb57d"/></dir><file name="Utf8Num.php" hash="76dfe3f7ab2e55f1e8190054dd788790"/></dir><file name="Common.php" hash="04cd47fabbd6c404aff39664da13df9a"/></dir><file name="Analyzer.php" hash="85a3a397e4d2c53d185523e25e7ae53a"/><file name="Token.php" hash="b7c5544e368acd06d81d7539983ed85b"/><dir name="TokenFilter"><file name="LowerCase.php" hash="d3be32b9f01fa4343a427721fc3b82b3"/><file name="LowerCaseUtf8.php" hash="9293ea00a25a3e7f129723c9f74b3b9a"/><file name="ShortWords.php" hash="1e296157ac5b8dc2f80a441811707202"/><file name="StopWords.php" hash="c935b1d071ab560816f3a591e3a662e9"/></dir><file name="TokenFilter.php" hash="7e7caefe49ee420c8b5c1561e84f012e"/></dir><dir name="Document"><file name="Docx.php" hash="e6730cac4ab560138c45c9db700d28f0"/><file name="Exception.php" hash="d1f92a2cc3ea06517d5626e96429a5af"/><file name="Html.php" hash="64e7ae4d564af7e71f44c01e48c8e03a"/><file name="OpenXml.php" hash="b21a3c28a95e7a0c9980db28bbc65842"/><file name="Pptx.php" hash="5a2b150c6c2a98b80e1e7765cec8297e"/><file name="Xlsx.php" hash="cae7aa77e2e49c47ecf8a89f169c629f"/></dir><file name="Document.php" hash="81e9c33cd2320e8344181ac5bf78819c"/><file name="Exception.php" hash="2d392bf05fe81a16cd8a3b10618bc6bd"/><file name="FSM.php" hash="5009e011f0b10421ef6e9c6b2c509753"/><file name="FSMAction.php" hash="54cc85832b139caef30d62a66a8008c5"/><file name="Field.php" hash="62d99dc9804e4f352bb55f69a61e5764"/><dir name="Index"><file name="DictionaryLoader.php" hash="dd18c7bb937d629cd0960ba4e8156307"/><file name="DocsFilter.php" hash="a464c3ab082438689658bd370ea21887"/><file name="FieldInfo.php" hash="49cdf39b3445b209adc9370a9970d834"/><file name="SegmentInfo.php" hash="3e9803053f230d7309cce21a643c9e76"/><file name="SegmentMerger.php" hash="335a52ca7e40a79dd6cb95f72cbaa140"/><dir name="SegmentWriter"><file name="DocumentWriter.php" hash="5061bbd3c4b375f3304813ff93a6401b"/><file name="StreamWriter.php" hash="0f6d8ea058813929a7448a4958a3c7c7"/></dir><file name="SegmentWriter.php" hash="13a8736ed2991f513e57f68e61926a76"/><file name="Term.php" hash="490ae3da5ccd138e9b060792766646bb"/><file name="TermInfo.php" hash="4930aa466ba2eb3b65dae3c02aa03221"/><file name="TermsPriorityQueue.php" hash="32663e0ebb7d0279bbcea377903c12df"/><dir name="TermsStream"><file name="Interface.php" hash="751e8ab0d56bb26f7b795d9530dd2494"/></dir><file name="Writer.php" hash="b7ef933d12a1b2f5376584b2420d7976"/></dir><dir name="Interface"><file name="MultiSearcher.php" hash="3f40f5b499a8ee03957fb21aada499da"/></dir><file name="Interface.php" hash="a78e2d90755e526ac9db7eb1c4185f3a"/><file name="LockManager.php" hash="5f61443ba5976b5fa021fb36bba30371"/><file name="MultiSearcher.php" hash="2fde43036355b990e0ac0227a00b6c8e"/><file name="PriorityQueue.php" hash="5c915507c33213ddb4b4ac613f1f68c9"/><file name="Proxy.php" hash="11944c7b4d9879615fd4f3a5d768aed3"/><dir name="Search"><file name="BooleanExpressionRecognizer.php" hash="3896532815243d89040fecb2fd65f606"/><dir name="Highlighter"><file name="Default.php" hash="b1dbdc2d70bb032a5d2b9f9e11273ea0"/><file name="Interface.php" hash="7dca815c9e9f444b9a2a9765fe349dd2"/></dir><dir name="Query"><file name="Boolean.php" hash="5be6706e75dd3e9ccdfaa0eb22f93ca4"/><file name="Empty.php" hash="2e16007df371f28191f785ab85d4d103"/><file name="Fuzzy.php" hash="e66032fc9f9cb06422cac6da95f7b8f6"/><file name="Insignificant.php" hash="1f61e2f1ef8ff38101f2a85c87b9529e"/><file name="MultiTerm.php" hash="ec939add6f7d0424029b12106385afd0"/><file name="Phrase.php" hash="424cc7d460f4bac0907d0170b60ba625"/><dir name="Preprocessing"><file name="Fuzzy.php" hash="cae1047630f98baf520483fa68af463a"/><file name="Phrase.php" hash="d8afc95f2e9da2a44d9495cbce775c98"/><file name="Term.php" hash="b099d749d723fbb53d3991e3f61458be"/></dir><file name="Preprocessing.php" hash="83dba0878c9ed171628b7a9ac70d26b3"/><file name="Range.php" hash="d8bda3ad418d24e0db7e59c446be13fc"/><file name="Term.php" hash="54e883c87d7368fa5be1e105723db357"/><file name="Wildcard.php" hash="9c1c8ebeca45a6332ede6fab8d5bee54"/></dir><file name="Query.php" hash="2a9f2ceda3cfacd24f892dd8bccd8d28"/><dir name="QueryEntry"><file name="Phrase.php" hash="407da910b0015ff8d95432cc193d608a"/><file name="Subquery.php" hash="a33d941498f632d859bec94a1cb9c10b"/><file name="Term.php" hash="808b02c1c1aeae4316fee3c9c466facf"/></dir><file name="QueryEntry.php" hash="9620d76904656a0727091f449603c662"/><file name="QueryHit.php" hash="6d1727ed01abc54503badc7176955882"/><file name="QueryLexer.php" hash="57a592ea29129b28d1144063e152c878"/><file name="QueryParser.php" hash="569f6439976128dbc471bd42fa9511d9"/><file name="QueryParserContext.php" hash="45c71a353821fc29101c1ae2f8eba02a"/><file name="QueryParserException.php" hash="358f89eaca92ac3175b26c419b317640"/><file name="QueryToken.php" hash="f85c3ac0ab04b5abff04d034cf127f43"/><dir name="Similarity"><file name="Default.php" hash="43f6f75cb50b7c7f344a5bac85ef172a"/></dir><file name="Similarity.php" hash="194c9c6c1c2815a8491952ece299ef9e"/><dir name="Weight"><file name="Boolean.php" hash="537c06e5f44c3d014d98a88a39c834f3"/><file name="Empty.php" hash="0bfe83149630af587846c7d5df63e72b"/><file name="MultiTerm.php" hash="c95f65634ed9d8c2896f5ba66a833f10"/><file name="Phrase.php" hash="51bc4912b1784bfa58841e4bf14fb177"/><file name="Term.php" hash="2e0f6fc3511928f1e94349d375dec8b8"/></dir><file name="Weight.php" hash="49ece1259ec183d66d2a1ccc8c319299"/></dir><dir name="Storage"><dir name="Directory"><file name="Filesystem.php" hash="7928063a85bf3c53e2afd754c111cc6b"/></dir><file name="Directory.php" hash="25a0d0c262a3c4fa7dbc3f1f11f0a4ab"/><dir name="File"><file name="Filesystem.php" hash="5c2819323a9878475d31eba6992e6abd"/><file name="Memory.php" hash="89bce18491ebcd885736c5c9a790eab6"/></dir><file name="File.php" hash="2b77f8354d79c7dd57330677651f8fc6"/></dir><file name="TermStreamsPriorityQueue.php" hash="a26104e3325d2533afffdfc66dd1ead0"/></dir><file name="Lucene.php" hash="fe6103d1d763df12d670dfe5103defb7"/></dir><dir name="Serializer"><dir name="Adapter"><file name="AdapterAbstract.php" hash="8bd5c797ff2230e804b916545a67694b"/><file name="AdapterInterface.php" hash="cb397638959459eef297b8114ebb0504"/><file name="Amf0.php" hash="734f3143371bffe28f65e144f1d4fde3"/><file name="Amf3.php" hash="05a939a59cad0622a7627572f931e909"/><file name="Igbinary.php" hash="dc0da7256a83c6f0a06582b21b160156"/><file name="Json.php" hash="e62019ed95f69a184f735f1d3d4d32c0"/><file name="PhpCode.php" hash="731fc343849f966c1b532284822060a6"/><file name="PhpSerialize.php" hash="d7bc5453b1c516a6895e62fee2f94ec7"/><file name="PythonPickle.php" hash="8eaa4d904fa3ac33cc3d405f6eeb92bf"/><file name="Wddx.php" hash="4321621736a7d3940a27357608c66c28"/></dir><file name="Exception.php" hash="dd736f6d29e3a1f8d688bdf6b24f8d30"/></dir><file name="Serializer.php" hash="47d6232a605b0fc1b0dfd5bc6738d4a4"/><dir name="Server"><file name="Abstract.php" hash="878b796b9b09bac46361e73e3b76943d"/><file name="Cache.php" hash="8851d8d1c35c11be49192fc875141632"/><file name="Definition.php" hash="c37f863e7395e761f9601a4f918f0fc9"/><file name="Exception.php" hash="1ad53d7cdaadfe1377fe30f61814ce33"/><file name="Interface.php" hash="ef219942e75a7dd72f757ae0fee1fe94"/><dir name="Method"><file name="Callback.php" hash="204c77c05f77dab719f7e8d4d9940990"/><file name="Definition.php" hash="6a7435cbdd3791b656f0f7945e68e724"/><file name="Parameter.php" hash="5bb143b2c5472570019deb5c8df7e13e"/><file name="Prototype.php" hash="e6926328f51c97152380eef1cb9503a1"/></dir><dir name="Reflection"><file name="Class.php" hash="7c3040f1cdaa12303fa3aa8a87bbee33"/><file name="Exception.php" hash="81a1918244112e6992e608c37a128f81"/><dir name="Function"><file name="Abstract.php" hash="baf97034eb2f6541a0b04448cdb0c8ee"/></dir><file name="Function.php" hash="b931e2381290e01a62197a41f7d4a43e"/><file name="Method.php" hash="2589efa5b95e88475509c07460869c1a"/><file name="Node.php" hash="a764c4cdbcfd48911882e73801f55c9f"/><file name="Parameter.php" hash="2cb12fe3fdca85cb9056909277002912"/><file name="Prototype.php" hash="c8f4e9fc01efed6ef3b5a10bab70ddc5"/><file name="ReturnValue.php" hash="bd7392e46dac77ad14597e24fbe9297a"/></dir><file name="Reflection.php" hash="7b01bebd0c5e02694d94946a7ff4cd2a"/></dir><dir name="Service"><file name="Abstract.php" hash="057d0faabba16e34faa0ed6d43ca61af"/><file name="Akismet.php" hash="c63f5c6b7b1be4b2bbedb84a7f026bf7"/><dir name="Amazon"><file name="Abstract.php" hash="16b70230ca4bf9fd43feaedc24416f7c"/><file name="Accessories.php" hash="c0f666b47ccd5ca407ca7ab3e62a28cd"/><dir name="Authentication"><file name="Exception.php" hash="f1ba0e03f16bf019c0246384f6797093"/><file name="S3.php" hash="35c859c9bf7221844df79260142e3e55"/><file name="V1.php" hash="a4f6e5db52a4ae4b8200ac26b1bc413b"/><file name="V2.php" hash="b91365a27a1019d793f3821d50cf0209"/></dir><file name="Authentication.php" hash="5e503da9b9bf0a83fd61326aabaa7bc2"/><file name="CustomerReview.php" hash="970806dbbd0244f317183a7d121dd23b"/><dir name="Ec2"><file name="Abstract.php" hash="add0a48733a5b51010fab03133fcf8a9"/><file name="Availabilityzones.php" hash="0df01ed765ce15c35a783a66d7f8ff44"/><file name="CloudWatch.php" hash="e601ca48308ac50dc3727f992f7e62dd"/><file name="Ebs.php" hash="1f82b128c7b5d35d37b3024b6c42f712"/><file name="Elasticip.php" hash="bfad9fcffa9bcd6ad7d7cff8cec45c64"/><file name="Exception.php" hash="b212f735d14f127feb9a33d220bf2261"/><file name="Image.php" hash="335cf797d7a3a3d49e029ef7ce991bca"/><dir name="Instance"><file name="Reserved.php" hash="6027f89632821d100f27363ffbf293f3"/><file name="Windows.php" hash="f823795a24808167f1b87d91ece5cd1a"/></dir><file name="Instance.php" hash="52e9fb6d557898648a7dd9c71bb9100a"/><file name="Keypair.php" hash="e035010eee1a949d1d2b5b1ddd43e5a6"/><file name="Region.php" hash="7283cb6f54f68c09949e4c0535ed8a3b"/><file name="Response.php" hash="ad34c2acb59516d6075d12294fcf6bd3"/><file name="Securitygroups.php" hash="68c70053d0e4284169a5e2c49cb2ef2e"/></dir><file name="Ec2.php" hash="4a39d1eb801af3fd096582c2428e1371"/><file name="EditorialReview.php" hash="edc54626cf681ff42bdbc3207063e50a"/><file name="Exception.php" hash="25e8e93c6e940a70c57e0d4b6b35271c"/><file name="Image.php" hash="8cb0ff1afc2b9f99b7e4db1c61c27e99"/><file name="Item.php" hash="49164d984e1888291b9a1b0b82df2204"/><file name="ListmaniaList.php" hash="d319a0d6c264c92c22196d6a9a84762e"/><file name="Offer.php" hash="a04c4d2faf859a590fe2e74ef0440429"/><file name="OfferSet.php" hash="cce61ade0766251d602204b65ad5f73e"/><file name="Query.php" hash="a8a6c152fa729f7047f352552bee7367"/><file name="ResultSet.php" hash="b15520c352dfb95481aa26509c84211e"/><dir name="S3"><file name="Exception.php" hash="2fa452933db70802a191be880cec481b"/><file name="Stream.php" hash="62544ad7a8d493023c4a62272a68d4f5"/></dir><file name="S3.php" hash="224a86bfc54f7c6df36b8d5eb3febbd0"/><file name="SimilarProduct.php" hash="abcd839cfcc6c194e0b2ee0461216e12"/><dir name="SimpleDb"><file name="Attribute.php" hash="329401b2dac2ad11141f5077093ce70a"/><file name="Exception.php" hash="72cd6853d02b6c4335292d38f310ea54"/><file name="Page.php" hash="4c6b5dda8a61a932584eaf332ba25ae4"/><file name="Response.php" hash="763d18b153c7296ae4a1acc9dd52fea6"/></dir><file name="SimpleDb.php" hash="26a2419a5c73550f8ef47ac2a7c161ce"/><dir name="Sqs"><file name="Exception.php" hash="4d8c014ecb492938b3234fb250dcc21b"/></dir><file name="Sqs.php" hash="e5a368178455cc62f0c1e6272876e31f"/></dir><file name="Amazon.php" hash="8bf9c8bd3d16372566cc6dda58d26f57"/><file name="Audioscrobbler.php" hash="0931bdaeda5594a4b367fd4901b5444e"/><dir name="Console"><dir name="Command"><dir name="ParameterSource"><file name="Argv.php" hash="6acc204436c9d0de0d1e5d2063dff1d3"/><file name="ConfigFile.php" hash="0ac0fcf2907eed649d9f720d9c98cfb1"/><file name="Env.php" hash="83579d583b977fb4a890933d5795588f"/><file name="ParameterSourceInterface.php" hash="c1161355277be3eefdadb4853d8ee1b2"/><file name="Prompt.php" hash="8a9b67aa3eaa61b7ff33aa0110b129fd"/><file name="StdIn.php" hash="fd5c89a584ce532ae64ce2e607e28e02"/></dir></dir><file name="Command.php" hash="c94204e49bc285a615c281253cb41641"/><file name="Exception.php" hash="e1a199ba28f3255efc3ad5f0c272d247"/></dir><dir name="Delicious"><file name="Exception.php" hash="8b4644f2ad354c3e8c668bf6f4d8757c"/><file name="Post.php" hash="00f3ca873d1da362fe1ed121b1d18c32"/><file name="PostList.php" hash="41dbf9ff7c15a8eaec5153cebc705bb2"/><file name="SimplePost.php" hash="9ae5bac1252734db8bda2c2cbceb901c"/></dir><file name="Delicious.php" hash="2f725816f82a4ba6ebeace7bcaf6e0ff"/><dir name="Ebay"><file name="Abstract.php" hash="2e334688b614c983b6a7ce3592e08899"/><file name="Exception.php" hash="83aa9409ac7d1e2bf9fd83e86c39a6c6"/><dir name="Finding"><file name="Abstract.php" hash="7238678f990b585b50271ceafe5058f3"/><dir name="Aspect"><dir name="Histogram"><file name="Container.php" hash="45aab272db8949fc7ef41c1f5b9a5d65"/><dir name="Value"><file name="Set.php" hash="6a00192243d8ab215f368459e932d145"/></dir><file name="Value.php" hash="ffd36e8de497a77bd42cccb63ce3235b"/></dir><file name="Set.php" hash="c39339e0e65827c882eac9fa8d4d4fff"/></dir><file name="Aspect.php" hash="df96cb57c1c2b88a8244384894f1b9dc"/><dir name="Category"><dir name="Histogram"><file name="Container.php" hash="e99d9fdf2028e7f627fa7692d6e5e5af"/><file name="Set.php" hash="d10aeaf449c591a7884a38a1b5f90399"/></dir><file name="Histogram.php" hash="5fda3e21a2a68bbca36838425d54c454"/></dir><file name="Category.php" hash="aef46c1abec0621af48a4398de94bca0"/><dir name="Error"><dir name="Data"><file name="Set.php" hash="51d6f2c75eb549150dbb4255a747e238"/></dir><file name="Data.php" hash="06579aec01d55e0e27e48b66b32814a5"/><file name="Message.php" hash="f0082bf2e41b9fa997891d55536d6c94"/></dir><file name="Exception.php" hash="0d04308f626b6d80255403034766b93f"/><file name="ListingInfo.php" hash="37689bb7f7f1312e0a8690b1ec55d17f"/><file name="PaginationOutput.php" hash="dbd144ea4155492ca485092140ed7342"/><dir name="Response"><file name="Abstract.php" hash="13c8ef07cd6c8b9e0b54b183099d3c2d"/><file name="Histograms.php" hash="7e67ea07bdf9e34cb277b87cdad8db8c"/><file name="Items.php" hash="87e78262a0463b3689f75ade1a97bf0d"/><file name="Keywords.php" hash="501b1eb2db688abcb8926a924b2467c4"/></dir><dir name="Search"><dir name="Item"><file name="Set.php" hash="72dc95aa03723a96c6ad4e16bb6c1f04"/></dir><file name="Item.php" hash="8cc709c5b81a662e1b42f6fdcfbcd057"/><file name="Result.php" hash="bde45f1eff1c6745093e1fb16a25fa21"/></dir><file name="SellerInfo.php" hash="0a3e7e31682c1b4139860b692e3a7a93"/><file name="SellingStatus.php" hash="40cc9f7feb5534c9b7ffd77cde164d8e"/><dir name="Set"><file name="Abstract.php" hash="d68b570966c8c13d07ecc8e1c093a3f8"/></dir><file name="ShippingInfo.php" hash="ef20bffb5c3917bd631a79f6520aaa47"/><file name="Storefront.php" hash="59e0796869417ef09b2fabf17a0f51a2"/></dir><file name="Finding.php" hash="38297aa7141bd29cb58f499a6f301958"/></dir><file name="Exception.php" hash="065ed88e73a47544f5432781b553b095"/><dir name="Flickr"><file name="Image.php" hash="c18c420085a325a88aa32c6e8940febe"/><file name="Result.php" hash="3dae64d1fed5642f400e5a3ed34001e0"/><file name="ResultSet.php" hash="1141813d476af74ac4482982352df257"/></dir><file name="Flickr.php" hash="80ee3a6a56f644931629923efaa74f58"/><dir name="LiveDocx"><file name="Exception.php" hash="b7c0f8f23822ab34863ae7c8ba65fca0"/><file name="MailMerge.php" hash="9c3df9f5097d2426f98f3e4afd5417b2"/></dir><file name="LiveDocx.php" hash="bb79b5d68e67e91aa7c6678cf9d33fe5"/><dir name="Rackspace"><file name="Abstract.php" hash="38c670e3ba06278b4fed19a7a20ffa09"/><file name="Exception.php" hash="0e02a57f8eb16972b101ec5b2d5ee5c8"/><dir name="Files"><file name="Container.php" hash="59b5965b06c12c8f32f191d6d81578ed"/><file name="ContainerList.php" hash="60cab750d4475f791b0f6ef9487b2b5f"/><file name="Exception.php" hash="ff4c1a6d5b3c15b0134eea798aaebb5a"/><file name="Object.php" hash="fa7d117f207e2a26dfa5db744a098cdf"/><file name="ObjectList.php" hash="d2eaf4ebe570b3ca456844b294cfc6f6"/></dir><file name="Files.php" hash="fba4bd666821a5eec5cf17f5f91dd15a"/><dir name="Servers"><file name="Exception.php" hash="90e7248491ba6728731b35821a6797b3"/><file name="Image.php" hash="6977cee9fc642f32c2a3dd9b99739ab6"/><file name="ImageList.php" hash="0bc789d18d41f62ae1db82159487edc0"/><file name="Server.php" hash="73f6c2a5e062bf36b3b89ed8d1041eaf"/><file name="ServerList.php" hash="f76bf22857872982ce35e7afa2ea49f1"/><file name="SharedIpGroup.php" hash="75bc0d1b089228114a5bdbbc764f6799"/><file name="SharedIpGroupList.php" hash="97feec662c70d87bf02c0dd689d59962"/></dir><file name="Servers.php" hash="d7c9cd6f524ef033e9c4836623171ad4"/></dir><dir name="ReCaptcha"><file name="Exception.php" hash="e49c53a3c431f49911028b571a76bc06"/><dir name="MailHide"><file name="Exception.php" hash="fc56e06dc9697c40498f1015c0e76c08"/></dir><file name="MailHide.php" hash="ff143c31b0aaac1c852ae438ccc57a4a"/><file name="Response.php" hash="10d73062279da9040e445fe8d1820c36"/></dir><file name="ReCaptcha.php" hash="518a917f321d64422010babcdc82921a"/><dir name="ShortUrl"><file name="AbstractShortener.php" hash="7e0fa90e0324b377677bd8847412ffa5"/><file name="BitLy.php" hash="3e07fa8e265d44e7225af2f11ac75607"/><file name="Exception.php" hash="fa58bd8ee297581ecafe8e15d9c41858"/><file name="IsGd.php" hash="5d18b0c134f1da253893391c720144e7"/><file name="JdemCz.php" hash="6892d0e3e81cc3aeca234d4fb5164ac5"/><file name="MetamarkNet.php" hash="747c5d10917401f1d0d11ba38b1af8e2"/><file name="Shortener.php" hash="64e2ceca93f66c375605e62d6431a628"/><file name="TinyUrlCom.php" hash="1b7f09510d1b029c117e6c59c5419714"/></dir><dir name="SlideShare"><file name="Exception.php" hash="67b547c02b4b9c9440f5c11e570171f1"/><file name="SlideShow.php" hash="9d01060ec6c7a7583a21c824a3e74e21"/></dir><file name="SlideShare.php" hash="1cdc74e57a3be59df8d702bc3d9f7362"/><dir name="SqlAzure"><file name="Exception.php" hash="24d9e2d3dfca7d6ce54137652027152c"/><dir name="Management"><file name="Client.php" hash="e46b9564db9ae2344357919b4760ac4f"/><file name="Exception.php" hash="731e875bfd4df360b37ca082877bc1c6"/><file name="FirewallRuleInstance.php" hash="f564f5454ee9cb2b1ffa97499124d0e7"/><file name="ServerInstance.php" hash="7f3198f120d54ca4b70b5f58399cf0ab"/><file name="ServiceEntityAbstract.php" hash="72ca3fc5ef5341bf549685beb08dad5f"/></dir></dir><dir name="StrikeIron"><file name="Base.php" hash="0b1451704136ab44598ac7204bde94a1"/><file name="Decorator.php" hash="68741c986d506462846a6aa007f94cef"/><file name="Exception.php" hash="e61ee74d3ae19b3e61c1894264d6530a"/><file name="SalesUseTaxBasic.php" hash="43823d20d58aaf73be598f5282e7f841"/><file name="USAddressVerification.php" hash="f5dd585a282a046ebfb95125c29ed866"/><file name="ZipCodeInfo.php" hash="76beb6125d1035ffd7e67101cbd9df44"/></dir><file name="StrikeIron.php" hash="7eca35cee7479ac035ec83f456ddb2ec"/><dir name="Twitter"><file name="Exception.php" hash="d5a3fb65437ac5663d5262b19c226483"/><file name="Response.php" hash="f78d457745cd7df85d83b33e9b43a01f"/></dir><file name="Twitter.php" hash="8b3dc7c575b35c1351a9a00afd1b57c5"/><dir name="WindowsAzure"><dir name="CommandLine"><file name="Certificate.php" hash="82f6c9535209f9d9800b1ec5227ea5a8"/><file name="Deployment.php" hash="d77fb324a62e1d5bbec2ce07dbcd6051"/><file name="GetAsynchronousOperation.php" hash="da2b5c820d693a4fdcdc5f53378a317c"/><file name="Package.php" hash="4ed8d218b529fa358b9bad365caeda1c"/><dir name="PackageScaffolder"><file name="PackageScaffolderAbstract.php" hash="077b5928c2f1ff061f447754e17051c9"/></dir><dir name="Scaffolders"><dir name="DefaultScaffolder"><file name="build.bat" hash="651c7fb8b72233f40f4f25ca8905573b"/><file name="index.php" hash="894c44229a940ea713205338f8e490f7"/><dir name="resources"><dir name="PhpOnAzure.Web"><file name="Web.config" hash="65f639e413e4ff122d92623a1c14b2ae"/><dir name="bin"><file name="add-environment-variables.cmd" hash="b0e00d591398ec40968189bc4e35c139"/><file name="add-environment-variables.ps1" hash="19a5afae543fd10d118ad21136fc4bec"/><file name="install-php.cmd" hash="8248bad7c6981ab8f8ad34cbb6e224c3"/></dir><file name="diagnostics.wadcfg" hash="5188e0200f5446cae89c1be78db568c2"/><dir name="resources"><dir name="WebPICmdLine"><file name="Microsoft.Web.Deployment.dll" hash="ce4bedba97839fb3b3991c9e76d9a5f8"/><file name="Microsoft.Web.PlatformInstaller.UI.dll" hash="c692c64ac1ff35a256b05b3d0389d77a"/><file name="Microsoft.Web.PlatformInstaller.dll" hash="b3c7917c493dc73aab9ad4f3b32d3722"/><file name="WebpiCmdLine.exe" hash="23ee0847ce84831042e2094f8bb946a7"/><file name="license.rtf" hash="e19c7c8161a0d2cf8cd2bfa815edd707"/></dir></dir></dir><file name="ServiceConfiguration.cscfg" hash="aef39d43590593be9d2fe5fe4a3b5c80"/><file name="ServiceDefinition.csdef" hash="cc148db5e38df6777513c343f0552408"/></dir></dir><file name="DefaultScaffolder.phar" hash="7213da0e7d624e8c2a4ba1f3b5ff05eb"/></dir><file name="Service.php" hash="ff88b79b64947f883986e77838d8cb24"/><file name="Storage.php" hash="8944ded3eb414aa4826b6f53040049d9"/></dir><dir name="Credentials"><file name="CredentialsAbstract.php" hash="d4f022ee969ebb28059bb4fe1dc15bbd"/><file name="Exception.php" hash="46253077f849f4d86ff19bcd5c4ffbb2"/><file name="SharedAccessSignature.php" hash="b812dfc04bcc4349faa4b684e3c17ffe"/><file name="SharedKey.php" hash="d09970fb25d6649fc3626d016e57a71a"/><file name="SharedKeyLite.php" hash="a7af3a465e3b62edddd79fcfb8b5bfd0"/></dir><dir name="Diagnostics"><file name="ConfigurationDataSources.php" hash="164e443f79bf6b018796cbe4ace8552e"/><file name="ConfigurationDiagnosticInfrastructureLogs.php" hash="5ed3b44951c19fe3899d77e57777ccca"/><file name="ConfigurationDirectories.php" hash="ac9628ef7d6d5291b4a9755ffa83c4bc"/><file name="ConfigurationInstance.php" hash="2ffcb3db9f9ecfe5764d497f08175c1c"/><file name="ConfigurationLogs.php" hash="79cb3324521884a79c422318e9df0996"/><file name="ConfigurationObjectBaseAbstract.php" hash="574ad31edf5de775857d4d9818e09515"/><file name="ConfigurationPerformanceCounters.php" hash="f518fc30a51d61ee73f44fd54304d115"/><file name="ConfigurationWindowsEventLog.php" hash="7b071634e38e532d5faf245310846396"/><file name="DirectoryConfigurationSubscription.php" hash="5c72f815ecb4a4b619a43b05e0767d3e"/><file name="Exception.php" hash="ecc6ffb64bcd2b7e219b9e57ae8261c4"/><file name="LogLevel.php" hash="b63f1b837619bd6475f30b5c2862354b"/><file name="Manager.php" hash="0d92a4ee3426b0a3fa98efabad20850e"/><file name="PerformanceCounterSubscription.php" hash="f3793033b70429e761b5715d26a9b052"/></dir><file name="Exception.php" hash="ae2961639357d61fd0edbb1f8b19e600"/><dir name="Log"><file name="Exception.php" hash="f293efa4c7d400034fdd32b61e398d75"/><dir name="Formatter"><file name="WindowsAzure.php" hash="d2803e471ad8f151337b9b06adf840e2"/></dir><dir name="Writer"><file name="WindowsAzure.php" hash="898cc3aab9ed4a1143ad98af4c82828f"/></dir></dir><dir name="Management"><file name="AffinityGroupInstance.php" hash="999fccb597ded5e9bb1a3a49d0461238"/><file name="CertificateInstance.php" hash="e38186727c337efeb26e1edb3395c3aa"/><file name="Client.php" hash="7ea9a8aeec1b66c29127ce846788caeb"/><file name="DeploymentInstance.php" hash="da71eb3b750c5accba7df6a02a936572"/><file name="Exception.php" hash="e38e9729e738a5c98b7a444377dc390f"/><file name="HostedServiceInstance.php" hash="52a7a4f5e90fcddbba2da67f6ec1a714"/><file name="LocationInstance.php" hash="d7fc5f02f835fbea9bd39e25a2953415"/><file name="OperatingSystemFamilyInstance.php" hash="5463dc6555a2894cf77c15dd015b2bbe"/><file name="OperatingSystemInstance.php" hash="8d8fc32400bbb73a3765f06ccaefc05f"/><file name="OperationStatusInstance.php" hash="acb817c0203ca17237b430c7d086b7b3"/><file name="ServiceEntityAbstract.php" hash="6013b8d4f6378d945e29013d54dc634f"/><file name="StorageServiceInstance.php" hash="6d89ea4e90ac780fce17efba7e38976a"/><file name="SubscriptionOperationInstance.php" hash="9fb50cd722cc80be2d660e78cd42d3de"/></dir><dir name="RetryPolicy"><file name="Exception.php" hash="b83b70d8c828de010cfa12f027a2da23"/><file name="NoRetry.php" hash="faa7ed56468ce39f77162aa1888f8480"/><file name="RetryN.php" hash="340d6ccaa8d41eba0f3cd943dbff201b"/><file name="RetryPolicyAbstract.php" hash="57b861c1f66f83295ce1ae8284b6870c"/></dir><file name="SessionHandler.php" hash="49abc2db2f8cd60249889013eeb6c28f"/><dir name="Storage"><file name="Batch.php" hash="54321d9853919241064631b7fd5e404a"/><file name="BatchStorageAbstract.php" hash="1911d06beacc5afdee2e0214fadb48f7"/><dir name="Blob"><file name="Stream.php" hash="fca729afd6bced397324a092598c4348"/></dir><file name="Blob.php" hash="ba54d4c7b42bfb8536df0ace27d68ac5"/><file name="BlobContainer.php" hash="3762000f605bc3b601d33508d11ba9cb"/><file name="BlobInstance.php" hash="3acc55cc558e3003164dde92463f0f74"/><file name="DynamicTableEntity.php" hash="c0f1e5b79b12857c233299a4445bb168"/><file name="LeaseInstance.php" hash="3d0fc9b5d6808aec75d9aa5bfb537e3d"/><file name="PageRegionInstance.php" hash="ad3d6fda6950c0f1fa6516507ca9662b"/><file name="Queue.php" hash="e0f744f5a2c30c4368babc77282987d1"/><file name="QueueInstance.php" hash="fc1d2fe33c92b9709174fdb78b014839"/><file name="QueueMessage.php" hash="1743f7a02f0d443c7a2f85d87dc43e0f"/><file name="SignedIdentifier.php" hash="cd0fa8a05e3acd402a1e337b1ca7eee0"/><file name="StorageEntityAbstract.php" hash="f3ef81a6dbd64aea38bc60b1f0c7bb8b"/><file name="Table.php" hash="3264067c6ef982f7bb216234451f5781"/><file name="TableEntity.php" hash="c9be1c41776a2ae5892d8f8d14b74fd6"/><file name="TableEntityQuery.php" hash="13880ce0f4c805205dcd10a5283c0539"/><file name="TableInstance.php" hash="54f43c27f93bee83a2c9ba42831d9c27"/></dir><file name="Storage.php" hash="cbac5a9bb9efb6e93a3d9871c8699035"/></dir><dir name="Yahoo"><file name="Image.php" hash="aa6abfa0f447d43f4828dc44c0fdf86f"/><file name="ImageResult.php" hash="7a64eac529ce21090e8b58997fc22041"/><file name="ImageResultSet.php" hash="7ad19487bce9a09855cf7d79707af347"/><file name="InlinkDataResult.php" hash="28305ce865dfb4011a285015a40a6a83"/><file name="InlinkDataResultSet.php" hash="fb09080f12f5348b37fdd5d62fc946fc"/><file name="LocalResult.php" hash="306431d361c2097b3b00cdbaba1bb372"/><file name="LocalResultSet.php" hash="68a4cb69982884c1bd7d6a7df86be90b"/><file name="NewsResult.php" hash="ea496bdeee3021d391df58a3be8636af"/><file name="NewsResultSet.php" hash="f80bcd0b1ac7632f3fb3020a7ff83255"/><file name="PageDataResult.php" hash="c8ea663819efe5ec5d374463f04a8f39"/><file name="PageDataResultSet.php" hash="69c99f8806a98868cb77e9db268eb8d8"/><file name="Result.php" hash="221286f5fbe491b570df8cec1fb7c91c"/><file name="ResultSet.php" hash="4477af82dcaac7fcd93ce9c29c68bdd5"/><file name="VideoResult.php" hash="6ba0d1ebb1c288b11b17ff6a9e434a4d"/><file name="VideoResultSet.php" hash="1a434e1b8bcf9b32e755a32e97e52838"/><file name="WebResult.php" hash="eacd11e6aace9570c6064c8fc1b47750"/><file name="WebResultSet.php" hash="bf5f6f43eb71f0469c961b0f5a6e4094"/></dir><file name="Yahoo.php" hash="27616706be89313b7b5be256be21e095"/></dir><dir name="Session"><file name="Abstract.php" hash="b43880e48ff9ee3040eca09d1458f7d5"/><file name="Exception.php" hash="ce01f1ceaa96bef8c71759f7e6c1e578"/><file name="Namespace.php" hash="b3e6effe8f53d5f9f407a4b5507df31c"/><dir name="SaveHandler"><file name="DbTable.php" hash="5b08339aa3e7f044b5602e725e6c65c0"/><file name="Exception.php" hash="06db90dee9421e4a8e09b946de252d41"/><file name="Interface.php" hash="617704bf38e31d51b79c636480447b91"/></dir><dir name="Validator"><file name="Abstract.php" hash="7bc8436592d308a702f37d64a8afbe72"/><file name="Exception.php" hash="c00d9dfbc04a9250f2359a5f31e726b8"/><file name="HttpUserAgent.php" hash="6a2a83e6baf37967b06cf993170ed03e"/><file name="Interface.php" hash="6e54358cefb41ccb7e591eaba391f74e"/></dir></dir><file name="Session.php" hash="da8c2bc8217bb09a7e86c573fa7a6553"/><dir name="Soap"><dir name="AutoDiscover"><file name="Exception.php" hash="3c71353889e5488f16cd0747a1337882"/></dir><file name="AutoDiscover.php" hash="abdfc4afb277a6e0c23216cb1d894dd1"/><dir name="Client"><file name="Common.php" hash="4c196fc850f65702741c044d12507769"/><file name="DotNet.php" hash="61bacfc1a99fabb15c58d5499c064c72"/><file name="Exception.php" hash="fe48793a358a7201ad7faee3a077a7db"/><file name="Local.php" hash="843caaab790dc3a322e570cae31dfda7"/></dir><file name="Client.php" hash="bb395c77d4e6ca127f48e15953c72f90"/><dir name="Server"><file name="Exception.php" hash="b5366c6128550c6904b5f0d83d9a4495"/><file name="Proxy.php" hash="4e3e39bf6b40e758bb8154900c0be4ae"/></dir><file name="Server.php" hash="2d3adb7e3b01a55889f4a9ccd1226758"/><dir name="Wsdl"><file name="Exception.php" hash="c30308763d2f85ccde3e48c399d977fa"/><dir name="Strategy"><file name="Abstract.php" hash="f09e005c0c35a51dbc906815f298a515"/><file name="AnyType.php" hash="7e0f81e8c1bde45bd858ae5c16b4cd11"/><file name="ArrayOfTypeComplex.php" hash="3b9998427588b55e16496ee51a1d7d5d"/><file name="ArrayOfTypeSequence.php" hash="8ea1226e6138e1d162b647b39daed36d"/><file name="Composite.php" hash="7ea40da650826369c79e7a17ff93da40"/><file name="DefaultComplexType.php" hash="9fefac807dbb4c843feec714a05ac521"/><file name="Interface.php" hash="d4f3ed1447d163ae1eedcfc886662719"/></dir></dir><file name="Wsdl.php" hash="8e4ad5d4d160d770740012ec920e30de"/></dir><dir name="Stdlib"><file name="CallbackHandler.php" hash="f33bb03784021305a529525bf125df09"/><dir name="Exception"><file name="InvalidCallbackException.php" hash="977bd070fc4de8c0bce940a2d0a0c530"/></dir><file name="Exception.php" hash="826ef583632fe8b71ce0916ce4c01030"/><file name="PriorityQueue.php" hash="886161c12418c95bda548c5e484db351"/><file name="SplPriorityQueue.php" hash="4ce44425f16b61d5cfa2b37a36c430b9"/></dir><dir name="Tag"><dir name="Cloud"><dir name="Decorator"><file name="Cloud.php" hash="c03f8a8a9acad9b124508cb5ec762ef6"/><file name="Exception.php" hash="da2286643dd90128c9bafdb55d4874d9"/><file name="HtmlCloud.php" hash="ac29df72f5738876b6c5c3220200aea5"/><file name="HtmlTag.php" hash="1c66e72d27e394b7a67e083a6a7e7635"/><file name="Tag.php" hash="38969d4df8dd12f7c75d5886a4309e2d"/></dir><file name="Exception.php" hash="f1f89e1176804f89966ffa1b6057aadc"/></dir><file name="Cloud.php" hash="b563d184a10c5780ac839964d05f5b70"/><file name="Exception.php" hash="bb95c48a0889e48b9621fc24ece1855d"/><file name="Item.php" hash="4d8899476ff7c0edc26227377437184a"/><file name="ItemList.php" hash="a37b92d4346128d6928c3ed75abe85e3"/><file name="Taggable.php" hash="754d26825a791b7b493479ab96de35ac"/></dir><dir name="Test"><file name="DbAdapter.php" hash="9f14c0c71238db11ce231ec608fa0748"/><file name="DbStatement.php" hash="ae071a2e217641e4431dbaffab4b475c"/><dir name="PHPUnit"><dir name="Constraint"><file name="DomQuery.php" hash="4a372f65097fddc842326acfb0873110"/><file name="DomQuery34.php" hash="4cfc2fccf97dcad8979afdeb5051d99d"/><file name="DomQuery37.php" hash="4918ef15cdbf82e30ee35bce62246f6a"/><file name="DomQuery41.php" hash="0e55e6f6ec4df95712cf6ae2592eaa4d"/><file name="Exception.php" hash="08a569be3229aa317e045e0bb5712aee"/><file name="Redirect.php" hash="bd29ebef3a5193019124cbe48e3b57a4"/><file name="Redirect34.php" hash="7fbaaf229a5e72fd9328b6b3355979e0"/><file name="Redirect37.php" hash="25ae9936724abf4f6c655e79a4b017a7"/><file name="Redirect41.php" hash="b15f5d011531a5f341691400758b7b94"/><file name="ResponseHeader.php" hash="d0c824d1d0825eaff50fbff17ad9fe68"/><file name="ResponseHeader34.php" hash="970159fe86220f6d79ae839787445e76"/><file name="ResponseHeader37.php" hash="b45fcfbc270c1dc1be8af6f967d74055"/><file name="ResponseHeader41.php" hash="d898287c0e3c5c5a29c8dfc23258c357"/></dir><file name="ControllerTestCase.php" hash="a1587e2519d6a108213338a8df626983"/><file name="DatabaseTestCase.php" hash="e660d4e0b896a1349b5b3a7b908abed9"/><dir name="Db"><file name="Connection.php" hash="a376a28b4f32640b77896ed71aa94103"/><dir name="DataSet"><file name="DbRowset.php" hash="619ddf7996bdbae5efe2667bf43f97fd"/><file name="DbTable.php" hash="c2f9df7d0a3cf0d37631d8f06c818bc8"/><file name="DbTableDataSet.php" hash="d4399f69a07e07e1cdf51ee779ed4d25"/><file name="QueryDataSet.php" hash="9923dfa4b4f6ec969e05af835f0c9578"/><file name="QueryTable.php" hash="49db01b854018eed9f97f9e87dd8ef99"/></dir><file name="Exception.php" hash="b4db1bec052e5f4326e4f69f8265b1f6"/><dir name="Metadata"><file name="Generic.php" hash="0d50fe34d4d444504a433c495a10f4c7"/></dir><dir name="Operation"><file name="DeleteAll.php" hash="ad2d32c7274f19ffd7ff00f6a9629831"/><file name="Insert.php" hash="76990ebfd7da444a380ef153fd4ec2c7"/><file name="Truncate.php" hash="aeb7cea4a23f9a4978838834184b827c"/></dir><file name="SimpleTester.php" hash="303a002e44573654515318426f06454c"/></dir></dir></dir><dir name="Text"><file name="Exception.php" hash="63dc12adf35209b68cb541fad9d13339"/><dir name="Figlet"><file name="Exception.php" hash="ce4743f212bc9dd406e7c5abd1499a8c"/><file name="zend-framework.flf" hash="e421545f78033d8a6a4324e54ccf0454"/></dir><file name="Figlet.php" hash="342b1851f3fddf6de881bfdcd6dbdc25"/><file name="MultiByte.php" hash="7beb126807547c59a29ff72918ce4cb6"/><dir name="Table"><file name="Column.php" hash="cb652d404e394051bb9463ef0f5e5fac"/><dir name="Decorator"><file name="Ascii.php" hash="642655dbd861110617fe242a5f5b2e49"/><file name="Interface.php" hash="b246cf5bf0cc2ccb3fd612987dda1ac6"/><file name="Unicode.php" hash="78c514875a100d295a884d52cbff6679"/></dir><file name="Exception.php" hash="a9ad309358591313a0b39a9dc6637ead"/><file name="Row.php" hash="2e1210709f13f36070015bf1e7c4bae8"/></dir><file name="Table.php" hash="fa040e017955cd19728968adc4d3263a"/></dir><dir name="TimeSync"><file name="Exception.php" hash="c5c88b4fa22c7aa853c99e80293d6b56"/><file name="Ntp.php" hash="670a72b056bc3ea5c6ca09fd51e5c0d1"/><file name="Protocol.php" hash="81ebccdcfad278c458e8f801743e8035"/><file name="Sntp.php" hash="f491dc0e0e4ad0a6909cc9518c443855"/></dir><file name="TimeSync.php" hash="e68ddd486d397ad8b8072df003f0dbe9"/><dir name="Tool"><dir name="Framework"><dir name="Action"><file name="Base.php" hash="ca10276b0b663e3946f30a7e85e2437a"/><file name="Exception.php" hash="033fe3dfcbe687a8fc14217124485646"/><file name="Interface.php" hash="4971f7cd01f81557e06c52442d1e10ec"/><file name="Repository.php" hash="763980637bc854efdabe4702cf90429a"/></dir><dir name="Client"><file name="Abstract.php" hash="c6aa9afeb508a90fac77fdd01490c917"/><file name="Config.php" hash="88d068ae943aaa028252208d2ffa9737"/><dir name="Console"><file name="ArgumentParser.php" hash="a7aca2e438a4ea02beea9efe4fc322e6"/><file name="HelpSystem.php" hash="c49dfb3e52bc4dbd0fb981d2d2db7ea0"/><file name="Manifest.php" hash="8ecaf5471c98b4adecf441fd0b239fd1"/><dir name="ResponseDecorator"><file name="AlignCenter.php" hash="aea5fb29315c501c879f1414ab30bdf1"/><file name="Blockize.php" hash="f6510cb7f02bdd000eff5b3cfc7c3f94"/><file name="Colorizer.php" hash="b4370450e0af8f8bc5b70bca3a3140e4"/><file name="Indention.php" hash="9d05c40f3bcf99606a4433c4f2f550c8"/></dir></dir><file name="Console.php" hash="70d696d68e6f889e25661568ae0cafef"/><file name="Exception.php" hash="9fc08df23e990977b31c58157458797f"/><dir name="Interactive"><file name="InputHandler.php" hash="d4a71d517cbdfca13bc442f915eadfa3"/><file name="InputInterface.php" hash="b76636ebb7563e128e1653de60a05e47"/><file name="InputRequest.php" hash="01746459e3c0d5114ba84376641ce516"/><file name="InputResponse.php" hash="fe6fb87211d75ac5d43a0afcd12b3438"/><file name="OutputInterface.php" hash="e6473dcec31887ba9fc189cf5ac4b5cb"/></dir><file name="Manifest.php" hash="a04f5f7452adbe2a7b9f572753c282e1"/><file name="Request.php" hash="337a50f6b8ca0346335666825a138400"/><dir name="Response"><dir name="ContentDecorator"><file name="Interface.php" hash="f5f2e4d82017c916a98e600c0ecf10fa"/><file name="Separator.php" hash="0bdedce341d3dc2456856bedb4e6fbfd"/></dir></dir><file name="Response.php" hash="047455ac32ab5c1f0913bd8be80408e2"/><dir name="Storage"><file name="AdapterInterface.php" hash="cbe1be24e10113b8355be82c17257d74"/><file name="Directory.php" hash="7f818fcabc4dd64292ec750d69a2cab2"/></dir><file name="Storage.php" hash="e1e34565e6f12ef7a6914bea4f21b495"/></dir><file name="Exception.php" hash="e8ab7ccbf5e2a5516a35ca4e887b1f5e"/><dir name="Loader"><file name="Abstract.php" hash="ac9b19649683e89c14f162643680d6d2"/><file name="BasicLoader.php" hash="eb441f57c872d051c8bf4ff334516776"/><dir name="IncludePathLoader"><file name="RecursiveFilterIterator.php" hash="e809fc3ffb30c42bd65defb0b841d5ea"/></dir><file name="IncludePathLoader.php" hash="ba1fdc0c41d1ac3ac9b86f7b295d62fe"/><file name="Interface.php" hash="5a982ccd517b7fa2c5d1e7a181f9a66d"/></dir><dir name="Manifest"><file name="ActionManifestable.php" hash="6b75a1363ec0989198f0577519f2a8d8"/><file name="ActionMetadata.php" hash="55c5c7fd4609c3a2c188c68f2b59996b"/><file name="Exception.php" hash="e4adb9a694c21dd46682009e1a25ba80"/><file name="Indexable.php" hash="f2fdb04e846a873a00178d44dfb7c134"/><file name="Interface.php" hash="65fb779fcdd624b743e1c70370ce1a2f"/><file name="Metadata.php" hash="79d13b52ad9aa5bffe103b61a404296e"/><file name="MetadataManifestable.php" hash="2974762fdea9eec82a74a6d3446f676a"/><file name="ProviderManifestable.php" hash="3d59e772c55a5a791844910d9acbb131"/><file name="ProviderMetadata.php" hash="b1fa45e3f1309e25c3e71e43e1a48263"/><file name="Repository.php" hash="b055ec6bcaa48d3536f376c7d196052b"/></dir><dir name="Metadata"><file name="Attributable.php" hash="3a1ae646ad3127bcd9d7f0b590b49d75"/><file name="Basic.php" hash="f8e243b4883d1f53ef6dd440c0d8b618"/><file name="Dynamic.php" hash="2ae310d375a9f1e29f0322c03350b718"/><file name="Interface.php" hash="dd418e0cfd979aa8caac73abbe8d65d7"/><file name="Tool.php" hash="d4cf6475ece71a871144a646c4653b88"/></dir><dir name="Provider"><file name="Abstract.php" hash="54efa5905a09985cfc5261116cdc808f"/><file name="DocblockManifestable.php" hash="0bb7be516c01ef1df2db65cac6782604"/><file name="Exception.php" hash="8340027bd3f883ce3bc60e5a4a779e1c"/><file name="Initializable.php" hash="21203810d42fc2c661b5a74a4db22afd"/><file name="Interactable.php" hash="1645bf6768d35a154b409e9fc8d23629"/><file name="Interface.php" hash="5acbcaa43439912bfc3f9be9aae48561"/><file name="Pretendable.php" hash="7320be8f080b47a7a3c7768ed5b82655"/><file name="Repository.php" hash="06ac616d5eca5d9769ad7d1d1a7ca9bc"/><file name="Signature.php" hash="5be099c081171cd11a6c5e6a80011f2c"/></dir><dir name="Registry"><file name="EnabledInterface.php" hash="87fe89d72c54ad50ec51bb2d683d2992"/><file name="Exception.php" hash="eccc229c4505a1ed3e85902496e1935e"/><file name="Interface.php" hash="85731cc24ee6598ac544956ba02a4847"/></dir><file name="Registry.php" hash="430ca6afc053d09a02faafa778f05ddc"/><dir name="System"><dir name="Action"><file name="Create.php" hash="ece59a9bf0b39f4c7731dd2c3c6a3687"/><file name="Delete.php" hash="93a02ef0a268f9a46140122e6b658831"/></dir><file name="Manifest.php" hash="2dc6db96a2eaec2f041f73eb9784426e"/><dir name="Provider"><file name="Config.php" hash="0f0ac44a62caaea96bdd741dc8d10fe1"/><file name="Manifest.php" hash="9834badd5250276130dd8f035fa3aa69"/><file name="Phpinfo.php" hash="a18c9de3ae3099a941d257fd8bb83286"/><file name="Version.php" hash="235916637c0ec94a08f86894dd211da4"/></dir></dir></dir><dir name="Project"><dir name="Context"><dir name="Content"><dir name="Engine"><file name="CodeGenerator.php" hash="28294bea1645211c3a55b04b03eb97e5"/><file name="Phtml.php" hash="b635fe45ef2a8b9de27be338ff80e0c8"/></dir><file name="Engine.php" hash="3edec5f50d35068768bd1ddb7cfcb242"/></dir><file name="Exception.php" hash="903019115f2291dac64e2d8316b069d0"/><dir name="Filesystem"><file name="Abstract.php" hash="7de036baa7d7a11fde54ba3d0d9e199c"/><file name="Directory.php" hash="346bbbf87ee7515d0b1ea6d468a23bbb"/><file name="File.php" hash="82a28fef9d3d33f3de763e2f4415ef66"/></dir><file name="Interface.php" hash="ec12cc9de36ab46a2afb96f61f3af90e"/><file name="Repository.php" hash="652c4bea315e3239fd99f22103c51140"/><dir name="System"><file name="Interface.php" hash="9011f3458a2b39fdf8867e639414a7bc"/><file name="NotOverwritable.php" hash="de0a563d5079199bf642b6811b7e5bac"/><file name="ProjectDirectory.php" hash="f5d33f4805cc35574112532f2f262579"/><file name="ProjectProfileFile.php" hash="48ff62386762440129ae4fb7337deb2f"/><file name="ProjectProvidersDirectory.php" hash="b5a9d7bba0ccd8554ca26f0149128acc"/><file name="TopLevelRestrictable.php" hash="2309be1ddaf737de9b7adafa6cb8632a"/></dir><dir name="Zf"><file name="AbstractClassFile.php" hash="22a8a9cc341edc796112df20983a43bc"/><file name="ActionMethod.php" hash="2f16d745e3a323f9ff416e2217358f54"/><file name="ApisDirectory.php" hash="0b39c81c051cc37f5492df965835eba1"/><file name="ApplicationConfigFile.php" hash="677abcc2fc67896b511af1f1181a8f81"/><file name="ApplicationDirectory.php" hash="42a08abbb3ecc267cd883a87f817981b"/><file name="BootstrapFile.php" hash="b76b4cf58705698399d06e8d4c9f6d67"/><file name="CacheDirectory.php" hash="5bb06a72dcd025a283c76c03a1ce9599"/><file name="ConfigFile.php" hash="2462d7d79f673c397d3a2f7284ccde66"/><file name="ConfigsDirectory.php" hash="b1cccd4669781cc33b9171a186236219"/><file name="ControllerFile.php" hash="090e5fe4d3b57933b9e7aed8eeef7cc5"/><file name="ControllersDirectory.php" hash="8543ca965e6d7a4cf78177ef0dcfc4eb"/><file name="DataDirectory.php" hash="5f8d27eca9e789c24dc039ea0f62748e"/><file name="DbTableDirectory.php" hash="92eda9ff83054cc8818bee744ed6e463"/><file name="DbTableFile.php" hash="b936fc7a4dd1e4726f0bb49f01ad931a"/><file name="DocsDirectory.php" hash="f58949c95502bd2ff8c31c59009c92b5"/><file name="FormFile.php" hash="b35ea0268fe07098b794eb24082ef53b"/><file name="FormsDirectory.php" hash="ffe9f7939c29068e7a1932dbc374bb7b"/><file name="HtaccessFile.php" hash="8e933afd24df22e6742aa972f8fc470d"/><file name="LayoutScriptFile.php" hash="8bd850a37a308efa3f4c83927fa5d8f5"/><file name="LayoutScriptsDirectory.php" hash="036f5cc0c38ead9183f7dd3f712848e6"/><file name="LayoutsDirectory.php" hash="c86cd320a91a46d439e4b419bd8ee428"/><file name="LibraryDirectory.php" hash="29a3c5283210c444e65284206b3da79c"/><file name="LocalesDirectory.php" hash="029c2897885aa476bd4103c48894ca87"/><file name="LogsDirectory.php" hash="3ee80aca0572bb9c5f6a44c6c021fcdc"/><file name="ModelFile.php" hash="958ed1603c25bd34ceb3f09ceeb6746f"/><file name="ModelsDirectory.php" hash="82dde848d95e686be57804162c11dc63"/><file name="ModuleDirectory.php" hash="7e219e82a6349ed878042cc17ee1faf5"/><file name="ModulesDirectory.php" hash="00182e9148959046c0a7d2d6e261e0b1"/><file name="ProjectProviderFile.php" hash="f3deaf3adf5c501237f22dc653430f91"/><file name="PublicDirectory.php" hash="e93bb7ed0ef00a864c097993ae1a2a94"/><file name="PublicImagesDirectory.php" hash="d769f00ec21961d66b41fffc8035277e"/><file name="PublicIndexFile.php" hash="4d3cf05ca9d35e24242dbf61d8189579"/><file name="PublicScriptsDirectory.php" hash="ff61ddca598a5ce42907b78140187614"/><file name="PublicStylesheetsDirectory.php" hash="8262d74f0f35523a912d95dd261fbc18"/><file name="SearchIndexesDirectory.php" hash="5ddf8701c47bcc6baf68cfdcc0ff7467"/><file name="ServicesDirectory.php" hash="825c4204f9f44f2280de370b0b156733"/><file name="SessionsDirectory.php" hash="af2fd72fa2bcf4d003c0a6368953cdb7"/><file name="TemporaryDirectory.php" hash="46790ecd95da8518c80dd8715fe7f8ad"/><file name="TestApplicationActionMethod.php" hash="4bbc3a869e69c2093bfa02068b6e057b"/><file name="TestApplicationBootstrapFile.php" hash="6f335bc4e4e047c948e77e8b0708f45e"/><file name="TestApplicationControllerDirectory.php" hash="1976699a04927fa3f5a1686934cdd08e"/><file name="TestApplicationControllerFile.php" hash="8f2956d50a3ba47f0b8c1fa96b361025"/><file name="TestApplicationDirectory.php" hash="09f0536bc206b5305862a21b65301016"/><file name="TestApplicationModuleDirectory.php" hash="da78a9b90b270578a9d36f8d62575a2f"/><file name="TestApplicationModulesDirectory.php" hash="4b54130f6c22e995308da7138d85330b"/><file name="TestLibraryBootstrapFile.php" hash="d78b732c8602c082ad1688c9bc6bf68d"/><file name="TestLibraryDirectory.php" hash="3626bc62a7c1c330369eb0001c4a9b16"/><file name="TestLibraryFile.php" hash="b45dc141518eab43f5c89e64b29aebfb"/><file name="TestLibraryNamespaceDirectory.php" hash="2e70388b581499815e6e2ba2c1cc0c81"/><file name="TestPHPUnitBootstrapFile.php" hash="40d55d88d6c84cd153adb2539ee323a9"/><file name="TestPHPUnitConfigFile.php" hash="1f136f46d817445285994244274f9276"/><file name="TestsDirectory.php" hash="0dec72680dea22074c8d370953effac0"/><file name="UploadsDirectory.php" hash="5d72a25ffd1ee7899fa182ddd7c9e028"/><file name="ViewControllerScriptsDirectory.php" hash="0ce107dd0b77183717845592b5be2550"/><file name="ViewFiltersDirectory.php" hash="59d3134c2b27c136adaa07177a72b28c"/><file name="ViewHelpersDirectory.php" hash="305d6bcc8066a02a658d82a69b73828f"/><file name="ViewScriptFile.php" hash="95b593cd475edcfd2a6ecea8f2668ffe"/><file name="ViewScriptsDirectory.php" hash="9aeac85b2f35bd6a666a4da29b465d45"/><file name="ViewsDirectory.php" hash="f36732d4b125b54a661356327d6850cf"/><file name="ZfStandardLibraryDirectory.php" hash="eea898b019c52dafd72f7de1aaa92d50"/></dir></dir><file name="Exception.php" hash="125c1606112c9ce2cfc8b697fb989d5f"/><dir name="Profile"><file name="Exception.php" hash="907a68043581559d3bf42ccc2c4b1322"/><dir name="FileParser"><file name="Interface.php" hash="325d41a29468a70dfe7476e1fcc8d20f"/><file name="Xml.php" hash="59f053468c48c4d9b881bc1b859ec28c"/></dir><dir name="Iterator"><file name="ContextFilter.php" hash="ff51879dcc3452e49ad8bf2d9e2c4910"/><file name="EnabledResourceFilter.php" hash="8d0d4add1f853aa9cfd89aaf138e2de3"/></dir><dir name="Resource"><file name="Container.php" hash="ab368c4da0867a25770b6f7970a782f4"/><file name="SearchConstraints.php" hash="9e4a7578e2879e6c9da8cfeb1fbfa9ba"/></dir><file name="Resource.php" hash="2a5467d1f6ff134cd8e35a2cb92eaedc"/></dir><file name="Profile.php" hash="db1e9708dc20fe27c3b39b9e6f57f1f5"/><dir name="Provider"><file name="Abstract.php" hash="8c55b9fe14b8d37beac8a5d1356c2cdd"/><file name="Action.php" hash="72581e6e7e4acd0a19f8ba9bbc0e73aa"/><file name="Application.php" hash="64fa6f041e1f5727a88bb9cbc7636f22"/><file name="Controller.php" hash="677b3b817a7fdb644cd150be124e9a96"/><file name="DbAdapter.php" hash="b831929398b67e053a395a548227695f"/><file name="DbTable.php" hash="6d922b240f64a010df894b03a44e0132"/><file name="Exception.php" hash="00d67294ec03f48a1e43fede57faee26"/><file name="Form.php" hash="95362baaf1eb17e9698573f6d7fbcb53"/><file name="Layout.php" hash="40528bb34ab9942db935b59b831ab909"/><file name="Manifest.php" hash="9d3a781e8c917a5cdb9e7dd10641cd35"/><file name="Model.php" hash="f561e3f60741f857d2a0a8d8d8509823"/><file name="Module.php" hash="f3cb636991bdb7fa9d69285ff5370a75"/><file name="Profile.php" hash="2bf881a5c9cf4e1032cb8de9d9297b16"/><file name="Project.php" hash="a7b3b98eeb5b8a38d7b003adde3a3c16"/><file name="ProjectProvider.php" hash="63455c931c8fa909d4a413ae91c99cdd"/><file name="Test.php" hash="ef752345daf66c4d3bfcdf94feea8602"/><file name="View.php" hash="1a8b7de4308dea33a847f1c590238d80"/></dir></dir></dir><dir name="Translate"><dir name="Adapter"><file name="Array.php" hash="539a98b29aa0bbcec264db5e29d810ff"/><file name="Csv.php" hash="698388dd2ac2843c3664586596e248f0"/><file name="Gettext.php" hash="321e228017b8049e94ea89f4e41f35b7"/><file name="Ini.php" hash="c03616b55e55e0c62363c4ee5e6b106f"/><file name="Qt.php" hash="19fd28ff1f5135d08c73c5faca961f96"/><file name="Tbx.php" hash="688c8d48dd29565f46d6f49d160e2f4a"/><file name="Tmx.php" hash="829f33d7444e30e4dc5053890fa22ccf"/><file name="Xliff.php" hash="0af804c51c85eea4b76941587aa673cb"/><file name="XmlTm.php" hash="39a37d7374fe3f0e3bf63a1e1f9ccb44"/></dir><file name="Adapter.php" hash="61940eb09da1bed1e6b8984370ad4088"/><file name="Exception.php" hash="469fbd261b8e8e1b91a8221fad6a79cb"/><file name="Plural.php" hash="4afe3e908bd63c3320fc7c899cd7b139"/></dir><file name="Translate.php" hash="0a7fda94b43cc10499fae10d9ec5d2e2"/><dir name="Uri"><file name="Exception.php" hash="0d12fb53167123e15aacbdddd8b11797"/><file name="Http.php" hash="55fae6ba863159381838ccc7bf8c651a"/></dir><file name="Uri.php" hash="f20bdab5c9c0694f64dd5b69f090e083"/><dir name="Validate"><file name="Abstract.php" hash="3382bfb0c407a0d3b490685a4f85678e"/><file name="Alnum.php" hash="2fe48d28207f9917e69f5edf99a392e1"/><file name="Alpha.php" hash="abeae56166032b791ae499883857d17d"/><dir name="Barcode"><file name="AdapterAbstract.php" hash="7bf5990b4b1dc34fe1fd7bcddd8f0348"/><file name="AdapterInterface.php" hash="c1b8934e5706e958f6e889e7c04a6931"/><file name="Code25.php" hash="f707195d53cd032ba5a9fbde32e75176"/><file name="Code25interleaved.php" hash="0c2ca046d04c43c4204e6cbb9d6dff7b"/><file name="Code39.php" hash="adff9a47dbf44dca5784dc8cdcc3ddc7"/><file name="Code39ext.php" hash="2e69f0103fbda86142024fc7466958be"/><file name="Code93.php" hash="2377845f1bee4dab114519c8f5dd4c5f"/><file name="Code93ext.php" hash="795aad78199cbc0668c70e12defcf9ec"/><file name="Ean12.php" hash="233d2f57fb2b36f1f2c7b3a36b0ead3b"/><file name="Ean13.php" hash="349560c5d4af7178e257a38c3a24735e"/><file name="Ean14.php" hash="30ab956febdabc3c13a7812f6e703bd1"/><file name="Ean18.php" hash="899007801fc5a8f97b577d711e2d692e"/><file name="Ean2.php" hash="0d73987f006070e0d15a573277a812e0"/><file name="Ean5.php" hash="806813312608a4ade42bbfab5d233711"/><file name="Ean8.php" hash="d0f3b4b0305e5dd0a7ba077fbb4978cd"/><file name="Gtin12.php" hash="da6df50e6751f4872604687602cc9695"/><file name="Gtin13.php" hash="dbd9c8a33ed3669917d10dee00a44a13"/><file name="Gtin14.php" hash="ae9c9fccedb5e71c87950c17bc5a3411"/><file name="Identcode.php" hash="9fed06deab51a31d97a66801fc68921e"/><file name="Intelligentmail.php" hash="9f4a16c7b78b3b1e5d9429569ea2aa11"/><file name="Issn.php" hash="e8de22a236a14b191225614ca730d343"/><file name="Itf14.php" hash="958a09981361b0cc8c83c0ae98831008"/><file name="Leitcode.php" hash="581e77d7ff774564ac3961077e40b27f"/><file name="Planet.php" hash="cda7f2f6910606728d4f6b375b17bbff"/><file name="Postnet.php" hash="9182081361daecfe6f0371fc4cabcd9e"/><file name="Royalmail.php" hash="e5bfd9d4ffd4935ca4b988f651270e4d"/><file name="Sscc.php" hash="eabc46811aff1a4a7f4468bd73a3f1e8"/><file name="Upca.php" hash="bb4f503adce344b6d3eb584843d7378a"/><file name="Upce.php" hash="368d3a61898baad1f968d2292a2692af"/></dir><file name="Barcode.php" hash="b3531dde74c28ed55c868d75615a9d3b"/><file name="Between.php" hash="5ccda5b2ac3d35bcc7faa8d8800108df"/><file name="Callback.php" hash="4e6874a0cb4bba53ef8edb9cde9eed18"/><file name="Ccnum.php" hash="1871fdfe01ac8f50e1b76f103297d7fb"/><file name="CreditCard.php" hash="2b68a89fbd9747e2a7308bc08aab9a12"/><file name="Date.php" hash="ac196efe9a75f1f5052881f0ad0fb7fc"/><dir name="Db"><file name="Abstract.php" hash="f32f786acb59d6936c87698c0ac868ad"/><file name="NoRecordExists.php" hash="de3eab3a488154fd14c3aeaad18c58b7"/><file name="RecordExists.php" hash="6203f6b21b338f28420fffd67f007dcf"/></dir><file name="Digits.php" hash="6536e4f93eea9d40663dc5b8308455c3"/><file name="EmailAddress.php" hash="f2fb48bbe83e3fb4288ee0f4825f485b"/><file name="Exception.php" hash="f05330fae73fa8a6fa5eb13b239492ae"/><dir name="File"><file name="Count.php" hash="fd4240625ed05056050c46051750d42a"/><file name="Crc32.php" hash="37be3ed367b5b7d13170fdc56c083488"/><file name="ExcludeExtension.php" hash="cffccfd1fcdae2be7676722ba8af7d9e"/><file name="ExcludeMimeType.php" hash="071a625f92fac84b76467a0eba3c467f"/><file name="Exists.php" hash="f5ab404939714ebf24c992bb3e4db124"/><file name="Extension.php" hash="21bf334b8b2ee214e82709c7bc1bf489"/><file name="FilesSize.php" hash="ab8dd66b1a133b1851d51927eabea61e"/><file name="Hash.php" hash="fd3f0e2888d1266d78da22e7d6647690"/><file name="ImageSize.php" hash="d277f5533a2aa61b2d5132babaf63c43"/><file name="IsCompressed.php" hash="1a0257de13523c8227a809b5673eb217"/><file name="IsImage.php" hash="7cd64b53b6e4a635e71b69e8ed5af7c4"/><file name="Md5.php" hash="4af983e349f6c2bc3a3fb6bc05d51e32"/><file name="MimeType.php" hash="c996e072363c49d15feba2a7ed35684c"/><file name="NotExists.php" hash="66d36bf5981467b276a1d97ae22ba5a9"/><file name="Sha1.php" hash="bf177eb68980e20cdf4a0db90bc32a08"/><file name="Size.php" hash="e6fe4f698bbe20ca0ccabe817462e0e7"/><file name="Upload.php" hash="a4099691c48b3427cdb144e3333b9145"/><file name="WordCount.php" hash="a2c3afef06b310c0b6a61867dfe25ab2"/></dir><file name="Float.php" hash="7d81882373a3c805ea6d890fd23d534d"/><file name="GreaterThan.php" hash="c8abc03e583058774db68388b71654ae"/><file name="Hex.php" hash="b491553d31f5894f2bd1303d685223f5"/><dir name="Hostname"><file name="Biz.php" hash="7696fce32b01be696c7a3f168ebd56de"/><file name="Cn.php" hash="fb00d241ff6f27a84d1c63758be2a14a"/><file name="Com.php" hash="5deccb0b547e92073687530b13870ce2"/><file name="Jp.php" hash="d22c9a1a27cfc135357a79c4608cbbd6"/></dir><file name="Hostname.php" hash="084ca6f450f36d3c76248663351f27dd"/><file name="Iban.php" hash="93312cb157edcb0735182b06a20d22dd"/><file name="Identical.php" hash="35b72f8c75851bb0dddfe4ac2126cef0"/><file name="InArray.php" hash="c75ec63d4745f66be627d1973bd76396"/><file name="Int.php" hash="222edd304fa91776951350e2659597fb"/><file name="Interface.php" hash="dbdfc01be0180334732bf0331fb19468"/><file name="Ip.php" hash="7abc354eed666e6b93c14c9187d2d0a3"/><file name="Isbn.php" hash="aedbe250623c9a9ef228d1863104b839"/><dir name="Ldap"><file name="Dn.php" hash="2716b9bc0c82519ab2fdbb52a0094eaf"/></dir><file name="LessThan.php" hash="e9fd4f35f101acb8fa94df0812ece205"/><file name="NotEmpty.php" hash="84a8e76bc9fd6fce9ce3d93f9e37b36f"/><file name="PostCode.php" hash="4513fb89c9215f1c987354ea552c0925"/><file name="Regex.php" hash="cd9c961f1bc2241a1beb61b8adc6325c"/><dir name="Sitemap"><file name="Changefreq.php" hash="02c174efb2eb92c1f99083d8d8a8201b"/><file name="Lastmod.php" hash="ecb2907a0827ca4f9a902b1842104f0c"/><file name="Loc.php" hash="43a32b211470fd207e614e122b373d5f"/><file name="Priority.php" hash="c4062b2af691dd790e88a80aa5f5400b"/></dir><file name="StringLength.php" hash="b57a08cb0418165feed0c8f3069830dc"/></dir><file name="Validate.php" hash="fdb819323b45ba50c37cefe43410afd6"/><file name="Version.php" hash="4050aa162960c6f935a49ffe910f81bd"/><dir name="View"><file name="Abstract.php" hash="1319cd055a57d8627ff0ed820f17daa9"/><file name="Exception.php" hash="7a4c976601978de749639c8b0914a03f"/><dir name="Helper"><file name="Abstract.php" hash="e1018e0e93049ac253c920888dc1133e"/><file name="Action.php" hash="786799b58e0fc8729abfde4de463e4df"/><file name="BaseUrl.php" hash="183857156a40c84f03eaea0ff24606bf"/><file name="Currency.php" hash="2ffa077bbe17cbda6974509421cd0582"/><file name="Cycle.php" hash="33bb85798e40541bc8e75cde27cf3499"/><file name="DeclareVars.php" hash="3cbcbf5083117f5f1dad9bac8df3b474"/><file name="Doctype.php" hash="b7e492a249f52859e00c287a8973edb9"/><file name="Fieldset.php" hash="4874b3f6f0658d8f9eae3bf750bf9793"/><file name="Form.php" hash="17d5d7e238c33e8e8cb0efbe043c01e0"/><file name="FormButton.php" hash="c62cf4a51db83501c7c7f1e2fad7cabe"/><file name="FormCheckbox.php" hash="3fefb8a82a8183e4cda683231bad496a"/><file name="FormElement.php" hash="9dc8f7fdd07eb031bc7cee049faa49e2"/><file name="FormErrors.php" hash="eb7e95a90d8a438d4b1043fd32a5f3ab"/><file name="FormFile.php" hash="cf7ec88f4ffd6c732a7df42737069d07"/><file name="FormHidden.php" hash="396bbe9d13da93ee84befb08a5c86f55"/><file name="FormImage.php" hash="3c9adc229035b5972678f634f690cd75"/><file name="FormLabel.php" hash="af00a20fba6e72eb035a605e72a814a7"/><file name="FormMultiCheckbox.php" hash="4033cf623ff32c24f0eaac26e96272d9"/><file name="FormNote.php" hash="94c3fe7ae9857d5d1c0f7e67bd817ee2"/><file name="FormPassword.php" hash="e743953bac753960ee4918c34372ede6"/><file name="FormRadio.php" hash="7df9c01b4e3bac15aca3394bd6bb20ae"/><file name="FormReset.php" hash="7463249d29ef3c895e6d73548c0d2250"/><file name="FormSelect.php" hash="b9076b91b3dd8880a74b9a1ff0f6fb2e"/><file name="FormSubmit.php" hash="abb3c753621b09e8251e88dd7d9cfb1b"/><file name="FormText.php" hash="c059e5863263faaa09d4e7fe99ef4fa1"/><file name="FormTextarea.php" hash="b5a12bd7577c3794b4f7536e1721254c"/><file name="Gravatar.php" hash="8b4c4ce3552c48ec148b81ebb4f843d7"/><file name="HeadLink.php" hash="c25bb4abcf60925394a915df38b006a5"/><file name="HeadMeta.php" hash="42d8fed1309297d58411bb7d487ebe28"/><file name="HeadScript.php" hash="c835c0d98daf0f2b89f2f486d22587a5"/><file name="HeadStyle.php" hash="2770400f4d12c2bf7b27c053aa1a6453"/><file name="HeadTitle.php" hash="329e23739809b5a55dc8d28c447dc91c"/><file name="HtmlElement.php" hash="e5e6b362d6001c20bbb805e31beb36e1"/><file name="HtmlFlash.php" hash="dff36a0bf66c600be3004bdd34cc8b08"/><file name="HtmlList.php" hash="f21ac692428d4c457dc2f3d2db5e7304"/><file name="HtmlObject.php" hash="dda5c4a84c32c4cdd73112a33c322c87"/><file name="HtmlPage.php" hash="d49d3e056e0aab1a8179bd2b3f1917e2"/><file name="HtmlQuicktime.php" hash="4455adb547e6d3a1d3fb52d6746df770"/><file name="InlineScript.php" hash="aabae2682812b3ee88a5bfafaa3d00dd"/><file name="Interface.php" hash="52fa974c83ce1fff7c9d56a994b1fbbc"/><file name="Json.php" hash="78621362d2c630ad5b8b7f7ef2cf2124"/><file name="Layout.php" hash="9e98d798baba317de41bc0cdf75cdf60"/><dir name="Navigation"><file name="Breadcrumbs.php" hash="6482ca2aa2565f318b49ce0458072ae4"/><file name="Helper.php" hash="673a27dfb10aa4442dfa2951e0ef0c4a"/><file name="HelperAbstract.php" hash="6bae63e5c54e21b87ebaf8d2622ac1b9"/><file name="Links.php" hash="b2b7b2403670be61982c1a73851ed2eb"/><file name="Menu.php" hash="8f5c5c42c0b10ac7a68c69b4503ecaa2"/><file name="Sitemap.php" hash="960d3bd171fbe2ca66ba073afd33140a"/></dir><file name="Navigation.php" hash="98f3a4adbd4c69df20c127f90e09156c"/><file name="PaginationControl.php" hash="b18eee7e9c52256b27384a982a75f0eb"/><dir name="Partial"><file name="Exception.php" hash="047c658de482d2ae0eb5d21ac0cd0a55"/></dir><file name="Partial.php" hash="abe72103b776eeee4a96ccbca003cabe"/><file name="PartialLoop.php" hash="637e144d4c2d369a35848d681b4b6464"/><dir name="Placeholder"><dir name="Container"><file name="Abstract.php" hash="8d885989d99888fc2798a85f07c9f17a"/><file name="Exception.php" hash="326371b5ef3489904fee8e387e7feb46"/><file name="Standalone.php" hash="637e4d2b742d9902ae6de414c0475237"/></dir><file name="Container.php" hash="16d8237399260e817a542e68a4828d4c"/><dir name="Registry"><file name="Exception.php" hash="b9a3969a1431cf44f4cd03764dd92e32"/></dir><file name="Registry.php" hash="ee6d81b2c630c83baac77a0d619ba7d1"/></dir><file name="Placeholder.php" hash="2fced270eb2e3474b4bd538cd73f517a"/><file name="RenderToPlaceholder.php" hash="5ad5803d78bad07455af8f5d3c876977"/><file name="ServerUrl.php" hash="c6a222f4e795320f6f07c6bb8f80d7f3"/><file name="Translate.php" hash="d341ce0f8809b691728672fe506736e6"/><file name="Url.php" hash="71f6c3948d28f8190bfc27b3586d3f93"/><file name="UserAgent.php" hash="dbee4e1b78fad667479a85e8e2d0cbd1"/></dir><file name="Interface.php" hash="eec709b1a8ebb0256a9f752db1a8ad75"/><file name="Stream.php" hash="6f4c3f620f6e2d2f92cd371db18d3a90"/></dir><file name="View.php" hash="604cd51ea9ba98756064b418d6785a5d"/><dir name="Wildfire"><dir name="Channel"><file name="HttpHeaders.php" hash="62dffc43581615ca6cb052efcb2a43f9"/><file name="Interface.php" hash="0bed6c7ae3ee56a17f5c5187eef3ce10"/></dir><file name="Exception.php" hash="a225536440492a4ef3d37702aea1cb40"/><dir name="Plugin"><dir name="FirePhp"><file name="Message.php" hash="f481d929bbb00bf2bac8dfb008ae37d8"/><file name="TableMessage.php" hash="074faf9136be2ea86add5cdf2b459dd8"/></dir><file name="FirePhp.php" hash="e23b81012ace71de3018a37deb708885"/><file name="Interface.php" hash="c3cb69d35db9a385f7caa140b9634dab"/></dir><dir name="Protocol"><file name="JsonStream.php" hash="38a7d96f9d4ec70f68492f1bcf4022f2"/></dir></dir><dir name="Xml"><file name="Exception.php" hash="2dfb5785f12ed3858b16ab075570d577"/><file name="Security.php" hash="b7b7a240b24574b06f73a59dd8a4e6f0"/></dir><dir name="XmlRpc"><dir name="Client"><file name="Exception.php" hash="8e96419287c2faeeb4412ed9e832d975"/><file name="FaultException.php" hash="28c34f9ec27f280c44d215ee38bd41c3"/><file name="HttpException.php" hash="8c2eac4d043926123b3691562ad47310"/><file name="IntrospectException.php" hash="39d33b723e4fb1d5ce2af5cfd1f41589"/><file name="ServerIntrospection.php" hash="e52c06c394a8c8ac91b5313e5c575024"/><file name="ServerProxy.php" hash="43f25d1783bc1f11462d21ab5a134976"/></dir><file name="Client.php" hash="ea8c5a084405ca13e4f43340e37fe866"/><file name="Exception.php" hash="a04feed37237658eb7c174518a4d9383"/><file name="Fault.php" hash="18685e9a87f2f7750fa968d86ab89625"/><dir name="Generator"><file name="DomDocument.php" hash="5fc0be6304c7a00e58ac39f033d0dd22"/><file name="GeneratorAbstract.php" hash="493eda4b0b32cb59a133c06d63fbef90"/><file name="XmlWriter.php" hash="45013d6c2e24f7ee77439df64a958172"/></dir><dir name="Request"><file name="Http.php" hash="70fcc3ae21a466a9295f42ebae0c2a93"/><file name="Stdin.php" hash="23583af65a719e197a70fcd4c5500ac0"/></dir><file name="Request.php" hash="6945ae9bdf8d76308651611848870e09"/><dir name="Response"><file name="Http.php" hash="50e6859ca7391fd453d7137697f57dc5"/></dir><file name="Response.php" hash="cc7fe267b740ab5c556b7b2d19b6d600"/><dir name="Server"><file name="Cache.php" hash="1cd78db98fe5499e4a64379e97689f77"/><file name="Exception.php" hash="6294a6b1a7d4da4b7a15e7ee489eb119"/><file name="Fault.php" hash="69b89d7568a910f82109b6f3cb0410de"/><file name="System.php" hash="d7b0d17c91367f44eb993da66672dbac"/></dir><file name="Server.php" hash="1087be94c4995db9c38a5335323e922e"/><dir name="Value"><file name="Array.php" hash="b7011fc480c395bfcbc67d68ead94cd7"/><file name="Base64.php" hash="91ea9215e1d57716c0cd79bb1906134e"/><file name="BigInteger.php" hash="10222f3f5cd5eeaaa9813d8ed9f2494c"/><file name="Boolean.php" hash="770874cea876566818fb9135f31e69c5"/><file name="Collection.php" hash="0708fe32732db76ebe9d7e89396b89e0"/><file name="DateTime.php" hash="1a9f56c65375240ee0385ed912731b84"/><file name="Double.php" hash="ee71a5a9eeb026f1eb75387b8158706e"/><file name="Exception.php" hash="b7adf50526128e43c344331e7250b935"/><file name="Integer.php" hash="66c8d75e059a4cf328ff108d15db5c5e"/><file name="Nil.php" hash="ad51cdbcfb5eff5e06d7fc2c6d4661e9"/><file name="Scalar.php" hash="e61890f60aff885a3bed37b093f36e6d"/><file name="String.php" hash="a9d992c1910d76c4ed5330e704a1d438"/><file name="Struct.php" hash="028b64a94eeca406537505ecd52788d1"/></dir><file name="Value.php" hash="7d09b0ce98deeb7a07c01ad1bc94aa0f"/></dir><file name="replace_recursive.php" hash="e886103ea1f75208cc11780718aa3094"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF_Locale</name><channel>community</channel><min>1.12.10.17</min><max>1.12.10.17</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_ZF_Locale-1.12.10.16.xml b/var/package/Lib_ZF_Locale-1.12.10.16.xml
deleted file mode 100644
index 65d7f70..0000000
--- a/var/package/Lib_ZF_Locale-1.12.10.16.xml
+++ /dev/null
@@ -1,19 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_ZF_Locale</name>
-    <version>1.12.10.16</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Zend Framework Locale</summary>
-    <description>Zend Framework Locale
-splitted from ZF to avoid memory overruns during installation and upgrades</description>
-    <notes>1.12.10.16</notes>
-    <authors><author><name>Magento Enterprise Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:05</time>
-    <contents><target name="magelib"><dir name="Zend"><dir name="Locale"><dir name="Data"><file name="Translation.php" hash="3c4e6ddf022e279cdbc77a860c6cb657"/><file name="aa.xml" hash="6ba5c871d22f64a769c70a1af71a04c3"/><file name="aa_DJ.xml" hash="369c4c2c9eca85c0b60d762a6bc98aa8"/><file name="aa_ER.xml" hash="64dd3e36ee4831d967e49ca2e3acaaff"/><file name="aa_ET.xml" hash="c05abb8269fff734e511dc4d0a11c1a9"/><file name="af.xml" hash="67b34f34749792149e0358fbc902c167"/><file name="af_NA.xml" hash="4034171f9b1450a37ed070aa3d90c5ba"/><file name="af_ZA.xml" hash="6c3da14996bf1b58cd8017df3313b8ea"/><file name="agq.xml" hash="5fd93a5c707e73e4aa5c519c6d64afd4"/><file name="agq_CM.xml" hash="06499c36298cb9eeb23e6dc0dbe20322"/><file name="ak.xml" hash="69320ac48004c58405d12d800a2d81ff"/><file name="ak_GH.xml" hash="5c5c86078d71e30c0399a762e5cf7f0d"/><file name="am.xml" hash="95b934943f754f649861fcc29f378976"/><file name="am_ET.xml" hash="584cb88741cf24321e0c047dcef574e9"/><file name="ar.xml" hash="8ec3de78c7d4ff42daa956025eeebc20"/><file name="ar_001.xml" hash="bc30b0854e32d00739413feb7a5414ec"/><file name="ar_AE.xml" hash="f70fd224cd066586d1b8cf5309774b21"/><file name="ar_BH.xml" hash="0c953018f40ce82e9de064a4cb95a488"/><file name="ar_DJ.xml" hash="66fa3cc4267b7fd0d96a2669a0401d8d"/><file name="ar_DZ.xml" hash="c070ac57992c1611059859954354e256"/><file name="ar_EG.xml" hash="7a422d856e2ec72b9c1494316b89aa02"/><file name="ar_EH.xml" hash="a21177328a2e94087fbae06f1c7471b4"/><file name="ar_ER.xml" hash="0a7472b1683fc78bd1a3a5cafb8b84c6"/><file name="ar_IL.xml" hash="1bca56bc324229351c0089b67d490cb6"/><file name="ar_IQ.xml" hash="0da352ff695a5a3e8e5dd155cd7c4ddc"/><file name="ar_JO.xml" hash="4c7b8b4b5eb54adc1f9c3f6e4dc4dea4"/><file name="ar_KM.xml" hash="e919d368ba30dfdeaa95f70532b4e255"/><file name="ar_KW.xml" hash="9b6ca92c240ea68d66acbb49f91992f0"/><file name="ar_LB.xml" hash="18b007c4b842620480c8bb88aae29b77"/><file name="ar_LY.xml" hash="4da8f8faf728c8a65aae9c4a66008b34"/><file name="ar_MA.xml" hash="f1b35950f3e3e3f4237a5a39c7da2be8"/><file name="ar_MR.xml" hash="f2ffa3c86e1b19b17b09f9099273e9d4"/><file name="ar_OM.xml" hash="ed0e25061367e82694d8cb7c0eaee387"/><file name="ar_PS.xml" hash="e7ee58c19554a466dab9fdb752d24a6f"/><file name="ar_QA.xml" hash="7b180beb5da6eac09e84b58a240d6991"/><file name="ar_SA.xml" hash="d016c7a9ff9de9e45c9136109f8f493c"/><file name="ar_SD.xml" hash="9dfcaa9bb696f5cedc059a4109c8b3ab"/><file name="ar_SO.xml" hash="84afb054141b7c24b7b448b5602359e0"/><file name="ar_SS.xml" hash="6c3734aea87be71cffb4556464be4fd4"/><file name="ar_SY.xml" hash="5a198ba2fef0281de890f996fbf644ef"/><file name="ar_TD.xml" hash="948d829d89a161430f83912af024f141"/><file name="ar_TN.xml" hash="7faf65c744cf5e52bfdb59542bbe7899"/><file name="ar_YE.xml" hash="8c10abba56d6a234a55c654078016a9b"/><file name="as.xml" hash="8fc5e45c11ceac7f52c78ff5166159d6"/><file name="as_IN.xml" hash="694909593f1415ef0e4fda6d5e58be0b"/><file name="asa.xml" hash="67790459fbf5470067fda4eab8703753"/><file name="asa_TZ.xml" hash="a7ff94e5a530dc21c43ab7174ae813d2"/><file name="ast.xml" hash="64deedf1c37b39d07b45a5080fc94190"/><file name="ast_ES.xml" hash="77b6d2a7c40dfcdd70fcd5a48dbc937b"/><file name="az.xml" hash="e5c36c36cb81eca6d5cfa86ef058d989"/><file name="az_Cyrl.xml" hash="4489b815e2f3f628619ccbbe09afe72f"/><file name="az_Cyrl_AZ.xml" hash="827b611f5206f27d79f2c07525340bfa"/><file name="az_Latn.xml" hash="7a9c14a8afa4e30e677b6d588788a515"/><file name="az_Latn_AZ.xml" hash="ef3f0e6fe96210ee2e21ed77c73716a8"/><file name="bas.xml" hash="b5e926cff825d6a19ecdd30aa6ed7309"/><file name="bas_CM.xml" hash="b96cd37b4240f82a00400bceef16106e"/><file name="be.xml" hash="b9e6bfe9f98012d6e2e3adbb8d7f4a33"/><file name="be_BY.xml" hash="f7decbc88e0b84a81c61c33b752f7f35"/><file name="bem.xml" hash="b32d7fab640633d84596c781c5729972"/><file name="bem_ZM.xml" hash="a41416d42e206b3499ed1327002ce5da"/><file name="bez.xml" hash="700611e0dce26a8fc22647aa5708dc74"/><file name="bez_TZ.xml" hash="c767af253038caf4cbfede8a067453f5"/><file name="bg.xml" hash="51b19b644a9796463b91bb8ec236adca"/><file name="bg_BG.xml" hash="05e86d4ebf3b91764d3a0d2551e16bf1"/><file name="bm.xml" hash="09d5b79929820ae15c0c6d5ea4afb6dd"/><file name="bm_ML.xml" hash="4d5e1b37325ed9e57f8c590fe1d3a762"/><file name="bn.xml" hash="199a113c26a1608720ca7e3c660d23e8"/><file name="bn_BD.xml" hash="794e3d0d4fcb61f260ac7bf8673378d5"/><file name="bn_IN.xml" hash="0848d84be54a2646adc33af1c9e4b968"/><file name="bo.xml" hash="febea3f15347297281d6ecfcc5771b73"/><file name="bo_CN.xml" hash="30fd400db11b971da287cea6be2ef3c1"/><file name="bo_IN.xml" hash="d68dac66b5b843ce88da031b16b3afe1"/><file name="br.xml" hash="e870097efcb0cd34bb6e4d1f2dc5b278"/><file name="br_FR.xml" hash="11652862f633f7aec19a1c0433c4b204"/><file name="brx.xml" hash="8047b46746f02a39674f0beefc07e194"/><file name="brx_IN.xml" hash="99404538d96a071935efe231780663dc"/><file name="bs.xml" hash="940b48d89bdb239461bd8b3427469342"/><file name="bs_Cyrl.xml" hash="8580494f42dcf27b664a012d4658982b"/><file name="bs_Cyrl_BA.xml" hash="3f8c9a61ac978bd30d6d64bf86dffec8"/><file name="bs_Latn.xml" hash="0c8b503dcc0f9853d3af20768e662aea"/><file name="bs_Latn_BA.xml" hash="9496b4ae275da058251832af52888167"/><file name="byn.xml" hash="5b73a1af7b8ba27dc8262d81934c3f14"/><file name="byn_ER.xml" hash="4da388f09780d86134689dc5f10a3862"/><file name="ca.xml" hash="581f561afd2a2296430eebbd9cd7cf1f"/><file name="ca_AD.xml" hash="f3f80fa4f38bb72a397d94e6e12175d6"/><file name="ca_ES.xml" hash="24c8e24495f99d3921a5a4e77f8bfb81"/><file name="ca_ES_VALENCIA.xml" hash="e9703c4cedea0d7756a06a653c1c8442"/><file name="ca_FR.xml" hash="84537f1e57ba4476c1f923d12f4f7b42"/><file name="ca_IT.xml" hash="e842526f0ecfcef2904d206b2a810041"/><file name="cgg.xml" hash="054e8d83970f37440d169e964c743447"/><file name="cgg_UG.xml" hash="c6f0a77828c43211f72e10e83f9f666d"/><file name="characters.xml" hash="578bec00fbe6d6416ba89e6fa7986357"/><file name="chr.xml" hash="d5c69b967b2ca2744b8a46d9c95260e8"/><file name="chr_US.xml" hash="53b9e050bf58ab63900197dc8fb43d9c"/><file name="coverageLevels.xml" hash="90d4dc96d148cbd970ac8ff49c209bea"/><file name="cs.xml" hash="23e2ba0f38fbb0021ecd6aaa24db77a1"/><file name="cs_CZ.xml" hash="baa89fb49d1c50a5e7ef632f75d56fa7"/><file name="cy.xml" hash="0657a743b16b94e59c26b692dd79943b"/><file name="cy_GB.xml" hash="9bfe606c96d3d035ad644efe57bc67f6"/><file name="da.xml" hash="507243848cb4398daf768f735cfb432f"/><file name="da_DK.xml" hash="2347254255ce488182e37214c7d0694f"/><file name="da_GL.xml" hash="84ea22e10d4f6aa9ff8a0c6644fd7dd9"/><file name="dav.xml" hash="47ee87a9cdba6d211639776a608c1e86"/><file name="dav_KE.xml" hash="37e7d66af32b1fe4ac81be34fbee5d2e"/><file name="dayPeriods.xml" hash="56449b799dac8fc8daafbb0f3d3d99ef"/><file name="de.xml" hash="198aa0c550d4c41406bd0df6f7b70a7f"/><file name="de_AT.xml" hash="4b960a6fac173340ac276ce5c9d82532"/><file name="de_BE.xml" hash="dce45b8b94a4c3aab891a2c7bf3ca151"/><file name="de_CH.xml" hash="c4e68ad1a19e6e92daa571edb12cb36a"/><file name="de_DE.xml" hash="fa5913f6081a8a4650cef19d22acca20"/><file name="de_LI.xml" hash="0dfda8f44bc729219bb5de48f7694393"/><file name="de_LU.xml" hash="409b134c2c81689c16df1a79c0a4baa2"/><file name="dje.xml" hash="7da22550436ba325fd7b0dfde195b9a7"/><file name="dje_NE.xml" hash="7e318b89d05df66eea3fe59bf75c7ac7"/><file name="dua.xml" hash="ba4657ecd1b3bc014c5dd1622d107e90"/><file name="dua_CM.xml" hash="5bba1b38dc6495219fcb1a0432cc8df3"/><file name="dyo.xml" hash="612804b11d342d9e3b4bb2d58b5f66a7"/><file name="dyo_SN.xml" hash="dc003c4af3987ec2d7255d3c1f541738"/><file name="dz.xml" hash="244f80bfc2f658780ba016281354fe0b"/><file name="dz_BT.xml" hash="9d287c1c61edf1fa5ef3d765b2c7da86"/><file name="ebu.xml" hash="76696c080f20a7db39abc05dd272f090"/><file name="ebu_KE.xml" hash="7c4abeeb255cf7bf2bc500abb12ce387"/><file name="ee.xml" hash="4518057dd1b1b514e3bd12e5b5e85bf2"/><file name="ee_GH.xml" hash="082d3a0d2203319b9e51004a710e3e6a"/><file name="ee_TG.xml" hash="d99900de319d3584f1a115d4b5eb76f0"/><file name="el.xml" hash="1710cdf160e6cab0c4d47c15bab5be18"/><file name="el_CY.xml" hash="6da5d159d499ba4754a2e7d4553d5059"/><file name="el_GR.xml" hash="477e3b1f10320e95a0c12511cb0c8368"/><file name="en.xml" hash="9256d3ec622d04bd406376827d31012b"/><file name="en_001.xml" hash="768d1b54436a379dd71d0239702810a6"/><file name="en_150.xml" hash="7f9a887b30b86016fe8a29cabb6b8ce0"/><file name="en_AG.xml" hash="4d2c7e568ab71d4b4e49c934b47d5c4a"/><file name="en_AI.xml" hash="70e59d70a946d5026659413cecd2da7f"/><file name="en_AS.xml" hash="2b134e308540cf74f34c2aa665112301"/><file name="en_AU.xml" hash="ed81bf367e4f715e9a5c4271bf49822e"/><file name="en_BB.xml" hash="5dff42e201010656bc3dbac5887d015f"/><file name="en_BE.xml" hash="f91d2ce67b1818708d15c091c4c9d720"/><file name="en_BM.xml" hash="2908ee96a408ec7b9d7fd659615d90ff"/><file name="en_BS.xml" hash="91eab1ca2779d23f13df0347f536ca0f"/><file name="en_BW.xml" hash="e37d57c47fd205e31473eb60bb1c973d"/><file name="en_BZ.xml" hash="59d8c1d1deac2a7b0f73992516c999bd"/><file name="en_CA.xml" hash="7f81353970624138037a527f761e6571"/><file name="en_CC.xml" hash="38e31ba2efac50bc06a5caa4bce5fa02"/><file name="en_CK.xml" hash="4a677485a65e531f1468c1543347c1ce"/><file name="en_CM.xml" hash="5a02b7f5fa1bedd6a05f96196e95b711"/><file name="en_CX.xml" hash="fc592a771a64d862c3739a898ce18dd3"/><file name="en_DG.xml" hash="1ec938ecb46bd092323b4f8ce4ba2cc2"/><file name="en_DM.xml" hash="89bee96e1185ba2dbb3ded508dda16a8"/><file name="en_Dsrt.xml" hash="6fbff7ba19f432150086850bc2e2f804"/><file name="en_Dsrt_US.xml" hash="0850b836f2faef6ec3423c7705160ab7"/><file name="en_ER.xml" hash="a99ce4a7be566be0b20822f418a4a589"/><file name="en_FJ.xml" hash="f5cfe8032f32fde1289d2fce5696a6c7"/><file name="en_FK.xml" hash="632a6ac34df2048f5160f1cbb21684e4"/><file name="en_FM.xml" hash="1e288d9366e0ac40b241b90d550d6424"/><file name="en_GB.xml" hash="5b73aa8057d95008d24c3eb91f265fd1"/><file name="en_GD.xml" hash="7d6d4bfad9463d051c6aba6301581460"/><file name="en_GG.xml" hash="a75e2a293cd4eb9e49d495c13b6e37ae"/><file name="en_GH.xml" hash="97e8cffb72f9e6651f8dee6ca086c0ea"/><file name="en_GI.xml" hash="6441468454ea9cf06468b0e19db106aa"/><file name="en_GM.xml" hash="7497ca9f4f962f57dffc9ad93ab78077"/><file name="en_GU.xml" hash="ae33e0859c963b265fdf32cd026ad26b"/><file name="en_GY.xml" hash="50aed051f78b38a1d1156c36d3ad7f9c"/><file name="en_HK.xml" hash="1aa1133bec835a760695dd994a6ca259"/><file name="en_IE.xml" hash="63130f36882b6a6917606b7c6624aa80"/><file name="en_IM.xml" hash="2e981e6e96db2a140dbef95db013522c"/><file name="en_IN.xml" hash="7433385f2bb2afa211e5c33cd9f921bd"/><file name="en_IO.xml" hash="b63a354d390f7b3eb564394b6ea5ebd1"/><file name="en_JE.xml" hash="a37431bab3c66fbc361a775b62627154"/><file name="en_JM.xml" hash="3c59b2850c79e9a7371e8f7a12dd7d75"/><file name="en_KE.xml" hash="2554dd9bd652f9ea57cd18da1a19df18"/><file name="en_KI.xml" hash="f24474b7d06fc2f0220ee7095e6fbff7"/><file name="en_KN.xml" hash="4d68bb1ef92eefad6f2fcc0e0b0d5076"/><file name="en_KY.xml" hash="b686bd51fe232c2107a08e8d9a5f1577"/><file name="en_LC.xml" hash="2ffab8614818ecca5af1c84ddb96a6bc"/><file name="en_LR.xml" hash="eb8f5ac9ca72306127d86db0085a92c0"/><file name="en_LS.xml" hash="8255d2c42f06b2d7c511353e82edf59e"/><file name="en_MG.xml" hash="5d7a723320b05e8fd7a4a1c8017bb57c"/><file name="en_MH.xml" hash="3c762f2aa253bef5b3cd1ad5940c3cc9"/><file name="en_MO.xml" hash="c20af1a8a15c19b9a52dd56c36b5598c"/><file name="en_MP.xml" hash="d535408f7920814d2d2b7c4ddfbba7e5"/><file name="en_MS.xml" hash="d74c01a6b57a68fc4d149b0f2bd5faf2"/><file name="en_MT.xml" hash="a0779f1ed61a4fa24f2549fc37df1523"/><file name="en_MU.xml" hash="484d1081e00dfe315b01368e63a8e547"/><file name="en_MW.xml" hash="6f5546f3143027e27250f1b471f3722c"/><file name="en_NA.xml" hash="43792f7465fd56dff8129154cd568400"/><file name="en_NF.xml" hash="9ced4a796c1db1693c526340fdda01d0"/><file name="en_NG.xml" hash="ba618207a64de97e9420801e8909f076"/><file name="en_NR.xml" hash="56f2eb49dc7a336e5eb0e2f4503dc3ed"/><file name="en_NU.xml" hash="524a420bdbf2d1bfe4ced79e690fadff"/><file name="en_NZ.xml" hash="3960c92d3ef55d1e55bc7bb7808a1c58"/><file name="en_PG.xml" hash="9fdf21ef2f976e068dfddbdd0bfcbbbf"/><file name="en_PH.xml" hash="6d0b1441355b533aa7231a45f330bb68"/><file name="en_PK.xml" hash="48a4db2301d34ccedf58942f3b41b181"/><file name="en_PN.xml" hash="846a0b8c74785cf3ffb562abbd5d5cd3"/><file name="en_PR.xml" hash="76bec34e4f081c2cc6ea562b9d3c3552"/><file name="en_PW.xml" hash="258fb50d80e798ffe19514bceaab9c85"/><file name="en_RW.xml" hash="aaa4befd7267fe5afd6682a00241eca2"/><file name="en_SB.xml" hash="0c50f8257806c71a8fba4cda42acb2ac"/><file name="en_SC.xml" hash="d8769c5bbd31f66c1a40d82ad4f9959e"/><file name="en_SD.xml" hash="9d3a24c9a0bd4f99653130314a6cca29"/><file name="en_SG.xml" hash="f32241b6135eb9e8733ffc80fab1b110"/><file name="en_SH.xml" hash="c35756da3a6effbfa9af4d488f7292c4"/><file name="en_SL.xml" hash="dd9fc72730ab0e6e58086a662fefa69d"/><file name="en_SS.xml" hash="35c730c6f16af1d572ef33bbea15fde3"/><file name="en_SX.xml" hash="d33e0d2eb46c1dc7004b84f6606dff0e"/><file name="en_SZ.xml" hash="a53c6878dcddbc32d37ab6b77e17da36"/><file name="en_TC.xml" hash="55127dfa22212f6abded3dd606af5a85"/><file name="en_TK.xml" hash="64ecd71d4530f1668e9da48f1039f508"/><file name="en_TO.xml" hash="a5e77bc5a7beecf3ff8f6b3156a87668"/><file name="en_TT.xml" hash="8b168ae6e9c3d9c8fceb0582365264af"/><file name="en_TV.xml" hash="7f98c91cd0dd96a66e4c8684d1d60639"/><file name="en_TZ.xml" hash="0cf0401e55af54ff68da8bab8c901182"/><file name="en_UG.xml" hash="a028dc8e13686a9ebafb83ace5315206"/><file name="en_UM.xml" hash="b883319cb6ecd9b1a6cb1deef89db236"/><file name="en_US.xml" hash="6435b96852569c7e355302c17814f77f"/><file name="en_US_POSIX.xml" hash="535c6ed9fd3be4db0fbf7ba3c79533b6"/><file name="en_VC.xml" hash="e745b417ac7ff1c93f281070740e901e"/><file name="en_VG.xml" hash="66ebc85cc70895db528d868b2318e5d6"/><file name="en_VI.xml" hash="3f30ee6f1c7383f6d906106f09cf5eff"/><file name="en_VU.xml" hash="6eea6dd6ac0cc9d00386059ff12a865c"/><file name="en_WS.xml" hash="bdc0360cf4fb7b517dbee39de8d0cd58"/><file name="en_ZA.xml" hash="031afdaa1011735bbc6555c5e76d7ff6"/><file name="en_ZM.xml" hash="c7bdd89484bff8dcf4daf3f57f6d6bc8"/><file name="en_ZW.xml" hash="b3f51877ba7ce7ead43ef50b499b4444"/><file name="eo.xml" hash="82ba66eacea4e98f8923944eddcc1745"/><file name="eo_001.xml" hash="1801937ded337e21aa03e2592deedb46"/><file name="es.xml" hash="a60ed8506871160a17c4fc3b81e53b0a"/><file name="es_419.xml" hash="c1bef1732b664c23cb1b799181cba5a9"/><file name="es_AR.xml" hash="d404e53f4de755d9c09aa856e916f110"/><file name="es_BO.xml" hash="2876119c46a9c697baba1a65240c051e"/><file name="es_CL.xml" hash="e3910edbae206638b9250ecbf9949905"/><file name="es_CO.xml" hash="53be4c39e4a34867fcbaa8fd05c2c881"/><file name="es_CR.xml" hash="1f0e1d3c965de545b50aab4577b038fe"/><file name="es_CU.xml" hash="2380f966916741dcba3c34c04a5d8009"/><file name="es_DO.xml" hash="9ea0a69084ae8dbdd86459e2806a8bdc"/><file name="es_EA.xml" hash="ec6ce434e2fb8f15ab4daa8cb2bc4dff"/><file name="es_EC.xml" hash="efb247470c0fe88c36a7864184a01a8a"/><file name="es_ES.xml" hash="da94ab8a06feb23c6d567dc75f85531c"/><file name="es_GQ.xml" hash="cac80878e350ca7a728940550bd9393f"/><file name="es_GT.xml" hash="d360a7b0a15a0515a21f1e0d5b4dd21e"/><file name="es_HN.xml" hash="fa13c1e703f00b11d038fe3bfe19c08b"/><file name="es_IC.xml" hash="d5324caf07a8db6ba668a1b749baa6e3"/><file name="es_MX.xml" hash="05df2b2f76636b0097cf9431ff9c84eb"/><file name="es_NI.xml" hash="7d59d82986b3ab47e1b7a2dad383a0aa"/><file name="es_PA.xml" hash="21a4164b1d73365f9b63431247053db4"/><file name="es_PE.xml" hash="8df05dafd2807169296d11f75eb74537"/><file name="es_PH.xml" hash="7240ee508f9500d779bd5109450a057f"/><file name="es_PR.xml" hash="de86ff57cd2f3e3c67111b0163a72b6a"/><file name="es_PY.xml" hash="191bbd042c95ef246cda798581ed9598"/><file name="es_SV.xml" hash="9caba354843c2b055f8f5da17082e245"/><file name="es_US.xml" hash="90b97e0328d50ed134c0b36391a4aa99"/><file name="es_UY.xml" hash="a30737900d956dc397357f6463d532a1"/><file name="es_VE.xml" hash="03449a8b82e4d21e0a59836ceb148536"/><file name="et.xml" hash="d3e8e213866259a27ab9511efe348e0c"/><file name="et_EE.xml" hash="3e92af6dec71aa1ae7a3c62c931534ba"/><file name="eu.xml" hash="7111ceef4472ba0c4e52dfc654a2841a"/><file name="eu_ES.xml" hash="66e48ee02f5d1e5a7076cf9cab709d23"/><file name="ewo.xml" hash="8f5e287d463fbbc8711d46265141be36"/><file name="ewo_CM.xml" hash="47ee8a04b5a0327405d006bd1a99266a"/><file name="fa.xml" hash="1bd0e404ad8d9d3cbc943f04676b03dc"/><file name="fa_AF.xml" hash="3736139f38116f0586eb7aae46f6dcfb"/><file name="fa_IR.xml" hash="98698b67604b8e5589fd75601080cd3d"/><file name="ff.xml" hash="8eec6f2da84d33d3236797c62b96a9d0"/><file name="ff_CM.xml" hash="4bcc2690dc2eb5347be28c55fc008f88"/><file name="ff_GN.xml" hash="a56cbd27d6d838338a535a06db281d34"/><file name="ff_MR.xml" hash="17dd52ffc9809b26db2a067612d92d53"/><file name="ff_SN.xml" hash="9ab32fee7af1d2666669efa4386769d3"/><file name="fi.xml" hash="f1e171910ef4c2137d9a6149cf3c2c55"/><file name="fi_FI.xml" hash="8d9498723893c53c1b6a8ede4d3b796c"/><file name="fil.xml" hash="c44f7b3edadc43b02a927e6cd1e780e8"/><file name="fil_PH.xml" hash="233305bd4c15da54bc9b4847fc753165"/><file name="fo.xml" hash="5715134bd8e1798d5f25d165f8a0bd98"/><file name="fo_FO.xml" hash="99e842dbbd201862703a98e160936c8d"/><file name="fr.xml" hash="125a25633190ef898fe18f2827d2397e"/><file name="fr_BE.xml" hash="1f86df32f3eaddd9b139fbacb7c199f5"/><file name="fr_BF.xml" hash="8eaa50ea5da82e3e8cfea4af20946852"/><file name="fr_BI.xml" hash="eb2d856258ead7da474505881452f613"/><file name="fr_BJ.xml" hash="ef18313c305832ea7049ddf758c9d51d"/><file name="fr_BL.xml" hash="ee7f161cc4c9f844448d9da6fcbb349d"/><file name="fr_CA.xml" hash="64a0b0100ee5e8918ca1d502f06ccb3e"/><file name="fr_CD.xml" hash="d5d62a20e80bfc90badec8a72d8a9d1a"/><file name="fr_CF.xml" hash="d0e96516835a44fcfadd25d0db4e48a1"/><file name="fr_CG.xml" hash="e2852122d57450cd7a388a3545709994"/><file name="fr_CH.xml" hash="2fd3f24252e081fc4c74e9e707c00365"/><file name="fr_CI.xml" hash="e72b4fb87bbb5751e49093c24f4fbd5d"/><file name="fr_CM.xml" hash="e06d4dc5c3604d9cd9cc64376e206daf"/><file name="fr_DJ.xml" hash="7e87bdb7669cbf73ac0bb191d43400a4"/><file name="fr_DZ.xml" hash="64558f39d1553f56217f80ec3ef92536"/><file name="fr_FR.xml" hash="3d82e2934dd28c26c7382de85d95ac11"/><file name="fr_GA.xml" hash="87cc610fd5f6a486c63e5cb105cc2d7f"/><file name="fr_GF.xml" hash="cdecac5dac6e7e10336de1dec5982673"/><file name="fr_GN.xml" hash="0ed99a0d3cec1034899413196dde9c06"/><file name="fr_GP.xml" hash="78ffa2393237a67fd202f96784bcea5a"/><file name="fr_GQ.xml" hash="359c388c94381b4bd09868afb8557b43"/><file name="fr_HT.xml" hash="7ecc803d1e947635fcbf0aa1b201ce60"/><file name="fr_KM.xml" hash="ea71c8291e7c8aeaaad03880b7308a2b"/><file name="fr_LU.xml" hash="2f467a6cc20912bea31f2932c26be870"/><file name="fr_MA.xml" hash="a0fcbe1f955e3d76f9e38eef202ffa07"/><file name="fr_MC.xml" hash="9a6304e508d08737c7969b44d9d57939"/><file name="fr_MF.xml" hash="46968723e86571f7455ee534302d3471"/><file name="fr_MG.xml" hash="ff234d4ba2e66cbb7b798ca787c67026"/><file name="fr_ML.xml" hash="7d1c047089abbf427b3635bc977444b1"/><file name="fr_MQ.xml" hash="f8bb16f92cdb67bc46ceb7aa7048d908"/><file name="fr_MR.xml" hash="d838bbdbd611c35862b89899816befb9"/><file name="fr_MU.xml" hash="ead1fa2ecb9031315ac554ca214d551e"/><file name="fr_NC.xml" hash="3d6500c28264363b27bf842259ff8a17"/><file name="fr_NE.xml" hash="f5bec7e22bd5db13346937f58a1312f2"/><file name="fr_PF.xml" hash="d9c7edabd1f8fd52c5320d874c96c021"/><file name="fr_PM.xml" hash="bae26570b49ab5979729a5f5b66ce087"/><file name="fr_RE.xml" hash="0c9b4ea0bf6c26c33ed0cef26f428af4"/><file name="fr_RW.xml" hash="8725f9ee61c3054199536d6d8eec42ba"/><file name="fr_SC.xml" hash="1eeb10b51d815098e01a3f60d71f793f"/><file name="fr_SN.xml" hash="fa6da2f3ae651bd93705f26587ed135c"/><file name="fr_SY.xml" hash="b6ef0c074642c951a04131a3cadfdfe6"/><file name="fr_TD.xml" hash="ff554940988b4f7bd210a2138575c6c8"/><file name="fr_TG.xml" hash="2256df16de2fd7331fbfbeaeaf0ddba3"/><file name="fr_TN.xml" hash="d9996b3dba7d6ca0aa12c1e6766d2f27"/><file name="fr_VU.xml" hash="4f07ba927564fd6d3507816cf3aafe45"/><file name="fr_WF.xml" hash="a6c659de13b695c7e229681b819ed473"/><file name="fr_YT.xml" hash="821b7a10ac601226696fa7d71d0f8247"/><file name="fur.xml" hash="62a65af07d949f1117573e425bee90fd"/><file name="fur_IT.xml" hash="647415f7e2ebd1d55b260dac3823e3f9"/><file name="fy.xml" hash="14a7805cafcf18dc2f21a7925e9d7182"/><file name="fy_NL.xml" hash="dac6922c58516864d0d18df09753b917"/><file name="ga.xml" hash="7cc3d8d5796c554549ea5ebe5fb9cc35"/><file name="ga_IE.xml" hash="49dfc6b41e17ddc6cd93d17b1aad62f6"/><file name="gd.xml" hash="49f89d47c209b25730d8d731973f29b5"/><file name="gd_GB.xml" hash="721b95588bf8f0ab4004d868128cf286"/><file name="genderList.xml" hash="12c8a32237c76cd85cdb15f8cd140023"/><file name="gl.xml" hash="f7c56b822d2cc164b6691956fc79669e"/><file name="gl_ES.xml" hash="05e04a61e62eab6b94d6cfa3ef96ef25"/><file name="gsw.xml" hash="2b9d820569249f8fe88f6f77320223f2"/><file name="gsw_CH.xml" hash="ec2f1146d4fe5125f42c6281bb2f10b7"/><file name="gsw_LI.xml" hash="a6031e3e7ab4512a905d91484d8f5f00"/><file name="gu.xml" hash="8fe2967cebfbb4a19bfdbff9a8029cab"/><file name="gu_IN.xml" hash="0f93d2cd4139a9fa96df164cdf0357ca"/><file name="guz.xml" hash="65566bd2674a999999affe67ddef45a0"/><file name="guz_KE.xml" hash="7891c10bba2ae36ce29ce34f996ded25"/><file name="gv.xml" hash="bdb5556e04a5f2acb2141197e09020ef"/><file name="gv_IM.xml" hash="cf6d862525015e25038f60fc93175e84"/><file name="ha.xml" hash="310c626b795a231ad736c44ffe0df31f"/><file name="ha_Latn.xml" hash="a470076b9866db162e1415aa32350a44"/><file name="ha_Latn_GH.xml" hash="e213acaf6a53ba1d9c33d2ebda346ab3"/><file name="ha_Latn_NE.xml" hash="7983a567b1473874f3bea1dfb045ab29"/><file name="ha_Latn_NG.xml" hash="d2191f02d90e7b9912fe0e66aed70d24"/><file name="haw.xml" hash="5012e655132a7a5a7ad8397052baf955"/><file name="haw_US.xml" hash="5bb77c6692d33c8488fd008640434b2b"/><file name="he.xml" hash="70cd2438f74f6ea64543ec52bbb06e56"/><file name="he_IL.xml" hash="bdc2d75f46f4dced46dd4fbce6cac4f8"/><file name="hi.xml" hash="20e5122052162ec860cd27db34fc1dcb"/><file name="hi_IN.xml" hash="fbc59458d4ad8d295265e79fec26534a"/><file name="hr.xml" hash="ad2c7a5102cb05cec7ae0478d2f5b552"/><file name="hr_BA.xml" hash="bb36010b5b7cb83bf623d27eddc90678"/><file name="hr_HR.xml" hash="0a5068d64bfd804afa623562e6c556b1"/><file name="hu.xml" hash="35260b5e75ed941097710b0a0483e407"/><file name="hu_HU.xml" hash="b816b69e9814d33ad14907c9c3b6316d"/><file name="hy.xml" hash="4dd0bd1e21762124de07651094889237"/><file name="hy_AM.xml" hash="cc2c8134ca77e5bd55315c5faf80c61c"/><file name="ia.xml" hash="a57208d2e90856e670b25cafa90caaa0"/><file name="ia_FR.xml" hash="dbfd4721237b03875d50cb0770f1a5bb"/><file name="id.xml" hash="ad0dbea4ed9c97b2ef44ea451ff43aa5"/><file name="id_ID.xml" hash="349192acc73b4d40b3ea684999c5cd4a"/><file name="ig.xml" hash="0cd19cfcc514c8c5c0d8b8f085e64a72"/><file name="ig_NG.xml" hash="666845e6dc06958bdd682bf40b9a0251"/><file name="ii.xml" hash="db4ca0fa7cd320163163a97946399d6a"/><file name="ii_CN.xml" hash="a112d1ad1b7fa51a30f6cdb0850168b5"/><file name="is.xml" hash="a4587bd0d57e17d1960dba1a45b5e1b4"/><file name="is_IS.xml" hash="5d2fff72bd6199e1e79cdb3fa126b6a3"/><file name="it.xml" hash="dfa19eadbd4b5819453159c12e5bc32c"/><file name="it_CH.xml" hash="da4122fb147f2652de469a3f7703862b"/><file name="it_IT.xml" hash="0fded926a8f00f5f491f4ba2486b0686"/><file name="it_SM.xml" hash="4706ecb3a92e9e05f6d9f54bacbacf34"/><file name="ja.xml" hash="a4bdd8fef7cac5c8ab8a706781d475b8"/><file name="ja_JP.xml" hash="b87ae521fe2527bc9051ee631bd1001f"/><file name="jgo.xml" hash="9471f4b7fa6323bf54a3b8b74813aeb7"/><file name="jgo_CM.xml" hash="8ded303577f1a672dd255dd1fc1490fc"/><file name="jmc.xml" hash="fb1bd646841f4b8af118996f1ffc4591"/><file name="jmc_TZ.xml" hash="fc0d97c3788543fb5a53695be429dd96"/><file name="ka.xml" hash="6223813b9ac5f055c2c682eb79e6e05e"/><file name="ka_GE.xml" hash="b5df45beb8ba26df37d00154fe2e8deb"/><file name="kab.xml" hash="28e3bfe8412eeac7fda8a154c2dc9375"/><file name="kab_DZ.xml" hash="c398b9636cc7716ab1152528de39599f"/><file name="kam.xml" hash="078f9f3de5e4a2e405f91db0580fee61"/><file name="kam_KE.xml" hash="671d06ee91b5451d3bcef26cf6d0962a"/><file name="kde.xml" hash="db0e85e0f1bd852d8d467e13f8a2dfd3"/><file name="kde_TZ.xml" hash="9f41da9a28fdfd1cf618deba5d9e70ee"/><file name="kea.xml" hash="5504f98e950dd836749ecf3eabbb9d03"/><file name="kea_CV.xml" hash="88602da9c4e3bf124a330f1d0fb84113"/><file name="khq.xml" hash="f0deb2302861cb75bfa96b4b11cb6fa9"/><file name="khq_ML.xml" hash="44d6228f6585a0ddfd53f2b13f7f18c7"/><file name="ki.xml" hash="26a88ce1af8c274b1b5ff3a5c11fb3eb"/><file name="ki_KE.xml" hash="2b5e5cf6cd0d7e38ca3d1d1cb63be4fb"/><file name="kk.xml" hash="a298ecc37ae4d60ce87cb0eaad919d3d"/><file name="kk_Cyrl.xml" hash="07046177e2ec5347df348912409e4283"/><file name="kk_Cyrl_KZ.xml" hash="5bfb35389063a05e63ddec93b4ffad82"/><file name="kkj.xml" hash="3a97c2408dfbbbf2ee181c7c70b2ea8a"/><file name="kkj_CM.xml" hash="095d6748ff7c6f070fae30938ef729c5"/><file name="kl.xml" hash="95ed0d90dae8db61f7b46db63aac0a0f"/><file name="kl_GL.xml" hash="ef6c30e0b4063b1b8fad4e4511e3e33c"/><file name="kln.xml" hash="67441932af9b0b24bc2c2ca2e018d5e8"/><file name="kln_KE.xml" hash="f10af3f43ee9aee1bbf52ca5ff1c5196"/><file name="km.xml" hash="dee5bb763d56521b3c2919a340021c62"/><file name="km_KH.xml" hash="8a31a83be02152f33704d7dc2d2e3e4f"/><file name="kn.xml" hash="0b9d9e33559353f7c074672472ad8f7f"/><file name="kn_IN.xml" hash="e4135fa646d16bb15bf8c24919a4122b"/><file name="ko.xml" hash="9f2d95effdc2374377d41ff61f1f8ace"/><file name="ko_KP.xml" hash="cf696a9af609810d08337fb56f4b2a51"/><file name="ko_KR.xml" hash="0e6404f41f456011631a67da431ec48b"/><file name="kok.xml" hash="deea0756950d5465bf3d529ddf533e4b"/><file name="kok_IN.xml" hash="9ae56f19c07124aa5801d3f2d21dbdfc"/><file name="ks.xml" hash="62e4a1072ac6d8a14df457bb325d97bd"/><file name="ks_Arab.xml" hash="2c7ee60c2f9764e87ce01dace3089799"/><file name="ks_Arab_IN.xml" hash="2fea656a91f684489095e5f13d76c778"/><file name="ksb.xml" hash="d4c84ad5e9ce333697588c7cfc6a8ac1"/><file name="ksb_TZ.xml" hash="ccfb53a163d96d54debdaa15d3499027"/><file name="ksf.xml" hash="a8187b83f4ae0a05f0219f6262c38a70"/><file name="ksf_CM.xml" hash="203147426344f510947dcfe51ee77b83"/><file name="ksh.xml" hash="2617cb6c2b91f15403ce462da0021275"/><file name="ksh_DE.xml" hash="8e085f8da562734068ff0141aa759eaa"/><file name="kw.xml" hash="91ad55b87458489c861988b7fb6280c1"/><file name="kw_GB.xml" hash="7e2024541e7aba767e844c0b9663e155"/><file name="ky.xml" hash="a7545fd81340fd75464e271076dc5279"/><file name="ky_Cyrl.xml" hash="2fe62d616b564a7316ef4a8a72210488"/><file name="ky_Cyrl_KG.xml" hash="757d4898a54dcc119b43698784cc8967"/><file name="lag.xml" hash="a8a25a77df5909db3b73340774221cb5"/><file name="lag_TZ.xml" hash="ebd0c62787658dec41e3e49017e2705a"/><file name="languageInfo.xml" hash="9a33723a317db6855c7dc4a37a9fffd5"/><file name="lg.xml" hash="2cc89f3e98775beee70bdd3e3404d9dc"/><file name="lg_UG.xml" hash="d98767310f065c6a3755cfb5fec6b9a0"/><file name="likelySubtags.xml" hash="6a042c9e337512b06f75e101a49981f5"/><file name="lkt.xml" hash="dba6053b63f4c6e3bf2e21f603c8d78b"/><file name="lkt_US.xml" hash="bd6f8a8cc0acca0ad53b85350f2f5b80"/><file name="ln.xml" hash="0cea3d899d3dad394a5e92db22044bc9"/><file name="ln_AO.xml" hash="9eabbf5b540202c5e5b521cdd06564b4"/><file name="ln_CD.xml" hash="5a6fd6126bf58147cdad6a565bae8af5"/><file name="ln_CF.xml" hash="349ec0ad936ee0fc9c5a00530e259390"/><file name="ln_CG.xml" hash="25c98dbc645d64b7cd800fbf6674fc4b"/><file name="lo.xml" hash="52aa20460fe494c813927fdab64feb08"/><file name="lo_LA.xml" hash="0266874e3970a24dab991fc54e111360"/><file name="lt.xml" hash="6d485e98ca9590acf70ea1838e488ad7"/><file name="lt_LT.xml" hash="738d6dfb27e54f7f9a44875b6dacf0e5"/><file name="lu.xml" hash="5ee43a091cdfb35d5f14067f45b0b05c"/><file name="lu_CD.xml" hash="dbe948b08a594210a3d088e414123d86"/><file name="luo.xml" hash="69779720b4294de854bf82a170ffbec9"/><file name="luo_KE.xml" hash="ad6df8710e3b4976c7bc95b0ec739fa3"/><file name="luy.xml" hash="d0e4e4766a744edc1ab08418bec0ee61"/><file name="luy_KE.xml" hash="28a00f1eb2977ad409b0dfca45a0ca9d"/><file name="lv.xml" hash="3a85d69acd0b15e47f9b2df341be7573"/><file name="lv_LV.xml" hash="6e07fe6de844f63ae1605a6a1a5575a5"/><file name="mas.xml" hash="b1ee3c8d903462d3b217b7056a31df20"/><file name="mas_KE.xml" hash="e494f8d43607f742e3a0cf393ad83bcb"/><file name="mas_TZ.xml" hash="a5785e18c75185c28f284f2e18e7f6e0"/><file name="mer.xml" hash="2023c272b2b6e1169d0d45bb195c7d53"/><file name="mer_KE.xml" hash="52600bcaac77d9e6aa9c9741e67323c5"/><file name="metaZones.xml" hash="64a142f5cc668612c9c6ad2ff0af875f"/><file name="mfe.xml" hash="cec57c842e65ebeaf746db91ac55f5b1"/><file name="mfe_MU.xml" hash="990e405c5cae3b6d7226d0482d0b6848"/><file name="mg.xml" hash="fd8b564029dfa72a913ff627c834082c"/><file name="mg_MG.xml" hash="81a7d92eedd7a4d9cb8c8687badf4aec"/><file name="mgh.xml" hash="6008ffd778c2d670383ab125848d5a68"/><file name="mgh_MZ.xml" hash="ed7a568c678bb3ec003732ba4e7c19a8"/><file name="mgo.xml" hash="3e834a9a979970d5c82d963a56947a11"/><file name="mgo_CM.xml" hash="0cf9ba215d10e1f3db255adcccb3d6b8"/><file name="mk.xml" hash="3ee88bf8c02b4f244b5cd1d3ab617f45"/><file name="mk_MK.xml" hash="aeb740a529d8b51b53242d1f1cf59b2e"/><file name="ml.xml" hash="94d67dd84bc66f80d4a6ffaf27a2c508"/><file name="ml_IN.xml" hash="80849e5c197f5dd2b2ea0317f3517ca1"/><file name="mn.xml" hash="e6a18ab3a3c20fe7ab283cf6a901a549"/><file name="mn_Cyrl.xml" hash="9bdcd159b3be6e0ecf96795d5fc1e91e"/><file name="mn_Cyrl_MN.xml" hash="f11f2f4a083ef35c66ff0a10429b5614"/><file name="mr.xml" hash="f2073dc2a11fd9c7be8ba932e45b830a"/><file name="mr_IN.xml" hash="1623ff448071fe23a70309fa70ac531f"/><file name="ms.xml" hash="9b53207db5cc656f53ac5ea3d90195fd"/><file name="ms_Latn.xml" hash="cda2abbda8d3482f36361e946f37b5a8"/><file name="ms_Latn_BN.xml" hash="5740a4fdad13e0eb211736bf0a2f17ec"/><file name="ms_Latn_MY.xml" hash="c537239c8ae70b442dcbf67911f3fd4d"/><file name="ms_Latn_SG.xml" hash="05424711271e51b0e552063edd05b547"/><file name="mt.xml" hash="961881542802dc1cc9f20f8fcb774f45"/><file name="mt_MT.xml" hash="5282b27d9d6a57d726612a09395e6c22"/><file name="mua.xml" hash="8ebb1a4b5ef4baffddb2894b307f2cbc"/><file name="mua_CM.xml" hash="2df1fe2f39dc3402d5892946ab88f2ef"/><file name="my.xml" hash="64f4ef77afb342a522c3b4779ab19486"/><file name="my_MM.xml" hash="02d8bea58fd9bd5e8dc7796477ef5ce0"/><file name="naq.xml" hash="a29dfa41b2e1630f136a18b12d2c2324"/><file name="naq_NA.xml" hash="0ec1dfc6dc7eed7588f1d1bc41ad56dc"/><file name="nb.xml" hash="46eb58f192d18746c09c8c8582ddd8b1"/><file name="nb_NO.xml" hash="626d2f263762cde6e41328a0bf6768e3"/><file name="nb_SJ.xml" hash="02508dd6f1be1de58fefd7b1159564eb"/><file name="nd.xml" hash="db8baa59e10b31daafd068e55ba882da"/><file name="nd_ZW.xml" hash="ccd1724534080cdf1a784ae0435f7785"/><file name="ne.xml" hash="7cb434ada9a049184fd0a2e021012406"/><file name="ne_IN.xml" hash="84558af586315178078c8e91aa410d9d"/><file name="ne_NP.xml" hash="81a679056920fedc05dad2cda150ef53"/><file name="nl.xml" hash="9f122648b0ae9fbf47dc6364311c9b14"/><file name="nl_AW.xml" hash="d44d954375e2f11a3571f0849dc5b116"/><file name="nl_BE.xml" hash="8e255c2c3d01f7680e6b1931521d15c1"/><file name="nl_BQ.xml" hash="05ea3eec1520c8ef9889b627f3c11624"/><file name="nl_CW.xml" hash="b4b444e991046f1e3e3c44eaa6d825bb"/><file name="nl_NL.xml" hash="4e0467c9db5288462ceb8f78611f6fc5"/><file name="nl_SR.xml" hash="ac0e3ff1c6706ecd9ad0b727583e024e"/><file name="nl_SX.xml" hash="3081384591890c797dfc87c4f4ec40d2"/><file name="nmg.xml" hash="96a40607cf05ce8f8ecbd81edfe54188"/><file name="nmg_CM.xml" hash="e4b39732f25ed7f4fd5f8eeab2296cc0"/><file name="nn.xml" hash="df403882fc0d4fbde259805dbb578133"/><file name="nn_NO.xml" hash="bff2529dd25fc5eff4e45c62e57a6102"/><file name="nnh.xml" hash="604802e1f48c5efb5006478f6096cba2"/><file name="nnh_CM.xml" hash="0797c07c5503386e902db37bb81036a1"/><file name="nr.xml" hash="537dfb7c804216084ff12405a79e6363"/><file name="nr_ZA.xml" hash="deaad06361e3310f47a0ae239b2dde45"/><file name="nso.xml" hash="d8d03686f2a5498288ab934b1d23af35"/><file name="nso_ZA.xml" hash="b8d56986c8588034819ce4112447bb7a"/><file name="numberingSystems.xml" hash="978a66b09ff3a7fe924e5220ac632035"/><file name="nus.xml" hash="aeb47a867f44fc22028eea112a9f20d7"/><file name="nus_SD.xml" hash="5b01ebcdeb5e0925420a1ec5a81078e0"/><file name="nyn.xml" hash="7a00226944592e03fbf05992fc97cb37"/><file name="nyn_UG.xml" hash="f98eb55dcdecb237d0d5f4442e967df1"/><file name="om.xml" hash="d7dd5059b280e4e673d39c6681dedae6"/><file name="om_ET.xml" hash="a2bd53f37a0cbde29c75476d11efd951"/><file name="om_KE.xml" hash="6f499797aaf7cddf5c96510055b1cb6b"/><file name="or.xml" hash="a1f44afb1360bea5213e7769b0d555ab"/><file name="or_IN.xml" hash="b8384a249e94ac1d3aeccffe6456d213"/><file name="ordinals.xml" hash="8105f05e542d711fb1c58eda93ee1970"/><file name="os.xml" hash="d3994c255a9ed31b3b485e2a60100bb6"/><file name="os_GE.xml" hash="b707a294c3bda74ce1fe3de56d5a2065"/><file name="os_RU.xml" hash="ed7de0aca2851389edb27ec27cfbff14"/><file name="pa.xml" hash="eb25b28dccb7fc2b9e8a58529383e7ad"/><file name="pa_Arab.xml" hash="d066d05609c4bb72a91b66960df82d4c"/><file name="pa_Arab_PK.xml" hash="af6c1f47b0c9125afa5f1d8b4465afae"/><file name="pa_Guru.xml" hash="3b5761c3adfe0fd8f769757108a33d74"/><file name="pa_Guru_IN.xml" hash="962eb7156fcccfee1c3b62562bcb4c9e"/><file name="pl.xml" hash="4badef8c402fbce8a919fe0345018145"/><file name="pl_PL.xml" hash="9f5e5245cb2b2a52ef56e3fd69363f31"/><file name="plurals.xml" hash="4223a72c769da4553aeaffc82409128d"/><file name="postalCodeData.xml" hash="ee416690bc7b0b51c62a4f60df3c6e49"/><file name="ps.xml" hash="71320ee03ab67c4d86b2042a2a450044"/><file name="ps_AF.xml" hash="e2b047a904f02a454f193f37856e9f6c"/><file name="pt.xml" hash="6c0d496db88b044f4bccea7b2bcf5bb2"/><file name="pt_AO.xml" hash="502a761ed5e5ca0b44403ff8d0e85e94"/><file name="pt_BR.xml" hash="9ec9d29dec55f67013d4e3ce15799d05"/><file name="pt_CV.xml" hash="3f8377d6db982dc7b9cc6294ee963517"/><file name="pt_GW.xml" hash="bec710dffaed02976223f5671fb48ec5"/><file name="pt_MO.xml" hash="1df59a4a05e1141e225a7da25c58ec4b"/><file name="pt_MZ.xml" hash="b5b28ee99e7f12e1c14e015c3ecf5c4d"/><file name="pt_PT.xml" hash="66b28e650fb563d84b53da41a1f261b4"/><file name="pt_ST.xml" hash="7c96e96d8bf1b811ff3358073e3aeb63"/><file name="pt_TL.xml" hash="9e2647ac1cc2d8f949cd000ffc5dd2fd"/><file name="rm.xml" hash="aa5e41d750b8392990ce00c29f4feb4d"/><file name="rm_CH.xml" hash="3bef003a0204b4d2291ee73c46d8f1ee"/><file name="rn.xml" hash="80a76b1975488f778da8abe7dc0292db"/><file name="rn_BI.xml" hash="c5010d52f27f95cf794396339752dda6"/><file name="ro.xml" hash="fd309802d4e90aa4e51d9f014621e5b6"/><file name="ro_MD.xml" hash="4763fe9a5ac2d57fa9cb7bc5aaa09f7a"/><file name="ro_RO.xml" hash="a7f41f443fcc6daed26d608373a0ebcb"/><file name="rof.xml" hash="4d03559ef40f836156f5e516a9eaa5aa"/><file name="rof_TZ.xml" hash="99f8c6ad97c8acbade2a9f3553b57225"/><file name="root.xml" hash="f74f320723d5a31ba06aa2c79de43bd2"/><file name="ru.xml" hash="3aaf7853667c37781e3d886f364968c1"/><file name="ru_BY.xml" hash="931ca3d10a511ea18c705a22c8baaf1d"/><file name="ru_KG.xml" hash="edee35024102c3ffd1c9acd89f0c9c30"/><file name="ru_KZ.xml" hash="7d4138b25f5c8cbafead8f321fd1954e"/><file name="ru_MD.xml" hash="4d629ff877f4c3a1e214548dc7ecccaf"/><file name="ru_RU.xml" hash="ee8433fc8dbc67a22b31c6be08d13402"/><file name="ru_UA.xml" hash="33fe877250fbd7077b4edf45c50bf300"/><file name="rw.xml" hash="73b90e15bea65ad98ac5cea78e878d91"/><file name="rw_RW.xml" hash="c5cb01f5b236208dc96d3268cf85ffbb"/><file name="rwk.xml" hash="af9317a0322bd40302363d5e6bd4b291"/><file name="rwk_TZ.xml" hash="d0f470b223d25203a611bdb7c395c988"/><file name="sah.xml" hash="f4b2cb698fd582845afb18f984089ee7"/><file name="sah_RU.xml" hash="6ee074c02940d5e9a525a7b8a9c2176e"/><file name="saq.xml" hash="130d69870ed3f95808bced7bed701c3b"/><file name="saq_KE.xml" hash="008b90c332f06e019efc1d8e33f401b3"/><file name="sbp.xml" hash="158d785177f949347356d59dc7883ad8"/><file name="sbp_TZ.xml" hash="0d4f52a378680dcd6230f00cc8ed1f61"/><file name="se.xml" hash="10a3649dbfd8bdff0f8b8fe102b444ed"/><file name="se_FI.xml" hash="ea379a5c51168210274b50711f032355"/><file name="se_NO.xml" hash="0a890443d1477c9d275bb945b0c5b589"/><file name="seh.xml" hash="4361fff00579a2efd8d283a152ccc682"/><file name="seh_MZ.xml" hash="a3f4cc61fa6d995fa5d2cc7b193ee1ad"/><file name="ses.xml" hash="00e9cfea10372a6b62590346a596d054"/><file name="ses_ML.xml" hash="dc0cd9eabaf2c08d66007e6c31a6a477"/><file name="sg.xml" hash="e1bda394071d1796efc18e00467e425c"/><file name="sg_CF.xml" hash="ed51c88dd34a233c82150338436c250c"/><file name="shi.xml" hash="b57def0c24096d11985586f621c09159"/><file name="shi_Latn.xml" hash="61054fc24b89c1842a53be5f5e6016e7"/><file name="shi_Latn_MA.xml" hash="d0f90c1ab8e1b3f7340fc2b77f37ff4f"/><file name="shi_Tfng.xml" hash="4670d2933f9ff2b00c787336498fc149"/><file name="shi_Tfng_MA.xml" hash="271bc282c75731c883ea8fbbd72361b8"/><file name="si.xml" hash="8a27b7c7c9bcdb45049974693c8db484"/><file name="si_LK.xml" hash="b637f75035a4fdfe10f0d3fb39781db1"/><file name="sk.xml" hash="c8b930f68837a7fcaa7e0c34aec1235b"/><file name="sk_SK.xml" hash="7beda18d4fd023382190bc9797d51cfc"/><file name="sl.xml" hash="51bf1ccaecc51b117ea843100b2bc782"/><file name="sl_SI.xml" hash="b71c5b3968b50875758dfdf825c6b21a"/><file name="sn.xml" hash="9aa3b734aa010864b0ff582a67e677e8"/><file name="sn_ZW.xml" hash="24a9dfc3030bf253882c9d661eaef17c"/><file name="so.xml" hash="5b1ade5ca9f6416d2a42aaeefe08803b"/><file name="so_DJ.xml" hash="2850875e1e4d197c81948325e8741024"/><file name="so_ET.xml" hash="6210a645a2c598eed597bab39f36d557"/><file name="so_KE.xml" hash="208c20fcd4d27f3ea7a63a1ccd70b64c"/><file name="so_SO.xml" hash="65f7b820f3de2da5fb6adbbf3fed4244"/><file name="sq.xml" hash="9814afac7a465e293306c2036e97397a"/><file name="sq_AL.xml" hash="6b08a2f02bd463c8854d377761d14ad4"/><file name="sq_MK.xml" hash="7b1a4a47c69c2c11539ecf5f2b306dbf"/><file name="sq_XK.xml" hash="a4be94b459a7ddf3c64782b932c43edd"/><file name="sr.xml" hash="a907b6ed4a9233dce8fb2cafacbb9d07"/><file name="sr_Cyrl.xml" hash="df126a848168eebb92d2cb08b0f47051"/><file name="sr_Cyrl_BA.xml" hash="379078c0a256b4f9ec7111cc9f75a2e4"/><file name="sr_Cyrl_ME.xml" hash="fdc47e86343568ccbf1e619800f26614"/><file name="sr_Cyrl_RS.xml" hash="f269bfd320ba2b38a6a614ca4da321a9"/><file name="sr_Cyrl_XK.xml" hash="8e3b5caa0e9997575201e3f7823a81ac"/><file name="sr_Latn.xml" hash="b26fdb85fcea35960444294ab6f10b21"/><file name="sr_Latn_BA.xml" hash="8abd2f52848f701a485ce865e97b851a"/><file name="sr_Latn_ME.xml" hash="49c92f426cc5a5188399c80878686f83"/><file name="sr_Latn_RS.xml" hash="713a42425709d2a2448ed3ceefed8d07"/><file name="sr_Latn_XK.xml" hash="d9f80fc5757c8be78a8bf06b0090bb1e"/><file name="ss.xml" hash="1c8e4708d8197d98b32e84db842531ac"/><file name="ss_SZ.xml" hash="36bd3ae71800ee1509cb005345b7d0d4"/><file name="ss_ZA.xml" hash="929a6fc019f32616331578d55a36412a"/><file name="ssy.xml" hash="4cd34c993f3f737c52ef02dc0c65180c"/><file name="ssy_ER.xml" hash="6500f7ea9752b2272ff4c93530514345"/><file name="st.xml" hash="13de7725514e5dd58f49e0b01ec7858f"/><file name="st_LS.xml" hash="16fac9f2505893a9ae5df24174ec8e94"/><file name="st_ZA.xml" hash="c769d53933a0816218637180bfe3b1e6"/><file name="supplementalData.xml" hash="7c64143e835c0a2facebe573b95c735d"/><file name="supplementalMetadata.xml" hash="89562abe6d40c4c7245a8c465905e618"/><file name="sv.xml" hash="157cbade1293f5bf503b8ce03cac9260"/><file name="sv_AX.xml" hash="eb9596e23c3e3597f9167c56bc456ba8"/><file name="sv_FI.xml" hash="c7985fcaa170e42535eebb8f2821fd8c"/><file name="sv_SE.xml" hash="a234be39c4fe51d5360e867ef057e9cc"/><file name="sw.xml" hash="baa99fb8dae1057541cd174d8c479f63"/><file name="sw_KE.xml" hash="841c4e403526c85c138ec30908f0e639"/><file name="sw_TZ.xml" hash="d8c70853021414f35fff5160e777afc4"/><file name="sw_UG.xml" hash="2f39a025d909e27a3b4d42ada4494f44"/><file name="swc.xml" hash="b78d391b482ebeaaa8d2589248b99475"/><file name="swc_CD.xml" hash="7ef627a3af8e94ce44e118facc634280"/><file name="ta.xml" hash="f14aabe0b254b16a7656cf0eb924a937"/><file name="ta_IN.xml" hash="a3cf28d4dffdfb99fbd06c56f7407690"/><file name="ta_LK.xml" hash="c4cb7d38b9ab64f09398af90233929b6"/><file name="ta_MY.xml" hash="50b7aa25e1de2ba3060cf7f1542dbb1e"/><file name="ta_SG.xml" hash="467cf5081dce3961ff108329da18461f"/><file name="te.xml" hash="9000f302efec5389067682dcb37713ec"/><file name="te_IN.xml" hash="46c5a0f8ad33a8207687131b1e30dbc3"/><file name="telephoneCodeData.xml" hash="df7976ae3ed9a46df9b7a3d153a08782"/><file name="teo.xml" hash="1a54151c61645deebd146ce8167ebb7b"/><file name="teo_KE.xml" hash="28904dbd23feee396d235bddafb88a5f"/><file name="teo_UG.xml" hash="a3c2615908baa53ef6c06c1bbc46d03f"/><file name="tg.xml" hash="b0a784936ff2b4d986bea0a5abaafc41"/><file name="tg_Cyrl.xml" hash="dad9b0de0bca8885769e3eb3b986ed38"/><file name="tg_Cyrl_TJ.xml" hash="ecd76f8a9c11ea36f23aecbd4ba10f94"/><file name="th.xml" hash="93a93b50d5bc06c3aba030a2bc8f3a2c"/><file name="th_TH.xml" hash="16920f2948dfc0169fa4120b6bef4c6c"/><file name="ti.xml" hash="68ba067a766e83fa56b3f8b64e911709"/><file name="ti_ER.xml" hash="fc1625e77b8ee3b39e5a21a5778c6352"/><file name="ti_ET.xml" hash="eda9e0f13702f4f4d6c56bf8702bc158"/><file name="tig.xml" hash="dcbea52ddac1a8641439c191ef8cad3c"/><file name="tig_ER.xml" hash="9e8951b4b641d755277bba697641eeb4"/><file name="tn.xml" hash="5ecf790feae7a56e7d3dda69a3dcdd29"/><file name="tn_BW.xml" hash="5db54fb06600c505374663377ae3c87d"/><file name="tn_ZA.xml" hash="5ffaceb20f45593cf1526096d44811ae"/><file name="to.xml" hash="6abeea01835e1fa2e62a489842917a71"/><file name="to_TO.xml" hash="e17fa8026e023e8614eb6fe68b223300"/><file name="tr.xml" hash="a73038379e7e0396200158e0cb9b2101"/><file name="tr_CY.xml" hash="c02e5d602dc71097faf6e40c43c00df5"/><file name="tr_TR.xml" hash="98e092d092bd6efdacd4c9181bdf1269"/><file name="ts.xml" hash="d4de7842ad3ed50f09e585aeb8fd2b48"/><file name="ts_ZA.xml" hash="a058d38e5fc52060f992a09c44bd2dd4"/><file name="twq.xml" hash="8cb693f4457b01d524eb4dd3a9202fee"/><file name="twq_NE.xml" hash="f3887ed69d01de60ea150fb49741dd7e"/><file name="tzm.xml" hash="184e66cab1c6bfb1c1ede84b1b9b8d5d"/><file name="tzm_Latn.xml" hash="c48b72028daead39c63e06be5940b06f"/><file name="tzm_Latn_MA.xml" hash="adeed44054a352a8a95fb63a47b1277d"/><file name="ug.xml" hash="0048db54db7e96e66309f27990302912"/><file name="ug_Arab.xml" hash="b0916370f9a3dcbe9f9ef7f4941e83ff"/><file name="ug_Arab_CN.xml" hash="ca617ed54b6b547d9cd4929653765e69"/><file name="uk.xml" hash="82e297c9a0e35a239300e9d781246ca7"/><file name="uk_UA.xml" hash="f1f43742973c3e0684078ad1585c09a8"/><file name="ur.xml" hash="4330b97cdc580fd937fb4b48c30138dc"/><file name="ur_IN.xml" hash="620558a8d2b16341b990f739d96fa656"/><file name="ur_PK.xml" hash="4929ef93fcd09c110306500b7b5df200"/><file name="uz.xml" hash="e885a45d72df08108a5fb5553caf5650"/><file name="uz_Arab.xml" hash="bbccf5949290b9a88bdb05112ef0f1f1"/><file name="uz_Arab_AF.xml" hash="e8b2a9bcdfcddf5fe0923bdb79586e3b"/><file name="uz_Cyrl.xml" hash="f11985a357906a9764a2eeae61d87834"/><file name="uz_Cyrl_UZ.xml" hash="e34ac326ca872838cb51f7d95f2cad57"/><file name="uz_Latn.xml" hash="6d1de019d75988a154546b7a6ec4cecb"/><file name="uz_Latn_UZ.xml" hash="9f0dd4f61e4ad966fd33e26c0af5d722"/><file name="vai.xml" hash="4ccc7bd3230a4395017327e278bea5d7"/><file name="vai_Latn.xml" hash="78b6884327d1a568c1dcb55edcc8e8c7"/><file name="vai_Latn_LR.xml" hash="d60cdef15dbd84e66ebf6532935f2735"/><file name="vai_Vaii.xml" hash="4d3b525d05e85213d169a04051aed2cd"/><file name="vai_Vaii_LR.xml" hash="64e621f56506d7b70656d056ed8e8214"/><file name="ve.xml" hash="0238fc0b60b7f9f80a821455e85a26df"/><file name="ve_ZA.xml" hash="cfd73cf7fc6d3bef016b3dea6c1464c2"/><file name="vi.xml" hash="1ec60312f7c6e419dc883676a3cfb10b"/><file name="vi_VN.xml" hash="cfb0ceae9f2e78e0459f062016230998"/><file name="vo.xml" hash="a696981962fe9a84ccf27cd4f46a07a6"/><file name="vo_001.xml" hash="ca84f69da9df24a4e409104c54a8a3d5"/><file name="vun.xml" hash="2838dac67405ebb6515ed35b983f13c5"/><file name="vun_TZ.xml" hash="5c00fe9a927fa96193d8be8f22c4ee99"/><file name="wae.xml" hash="7a6a03e67b505d33af84383427ff1db9"/><file name="wae_CH.xml" hash="bc6ad0fbf82a5317ade928730b115b91"/><file name="wal.xml" hash="5fa5a9a4263c2c0c75cb61e137ec19b7"/><file name="wal_ET.xml" hash="fe6ba6e078852d9949dc023b20e40462"/><file name="windowsZones.xml" hash="bb1d22fd1c7e1073f31559d4ec4f6ea0"/><file name="xh.xml" hash="c4561fd383180394c1719f7af01252ed"/><file name="xh_ZA.xml" hash="7cc6e52fd5bbde7d7a09835462c9005a"/><file name="xog.xml" hash="d159722255a22bf4b113822364e3aa42"/><file name="xog_UG.xml" hash="c9d9ce8325ccd943d17be076e2348509"/><file name="yav.xml" hash="7cd6b28230ea1b592f4f6dc656d7dac6"/><file name="yav_CM.xml" hash="d99d7f9815108fe4040253b525fb1e65"/><file name="yo.xml" hash="94b71c3a56a7d571cdd2cdcca0e3639d"/><file name="yo_BJ.xml" hash="ad14fab000b1bdba3ad0959b41692125"/><file name="yo_NG.xml" hash="1381c16f38223fcd4e645a66f06d3947"/><file name="zgh.xml" hash="47980624ea61e97a271f180c98a7f012"/><file name="zgh_MA.xml" hash="7e72d86646a8b5045dfbedd721e5d0f1"/><file name="zh.xml" hash="7ce5cf9353eaeee426d5d5eb87670dfb"/><file name="zh_Hans.xml" hash="bdb68fe0878c430dc788e383b389dc2c"/><file name="zh_Hans_CN.xml" hash="24a14d8c675ae0c5b2fd211477240405"/><file name="zh_Hans_HK.xml" hash="7c82d550690d9ea63bc19cc76fbb61de"/><file name="zh_Hans_MO.xml" hash="9e4291c5bb0facb592b3ea3c14147e72"/><file name="zh_Hans_SG.xml" hash="01f85db499b693f4d3032e8683db390d"/><file name="zh_Hant.xml" hash="fb57450622d2383ac2f9d0e9c03872d0"/><file name="zh_Hant_HK.xml" hash="8648266bec5d9594fff57e030ff88e53"/><file name="zh_Hant_MO.xml" hash="3625e00e40fe8377de3a9a03628657ad"/><file name="zh_Hant_TW.xml" hash="66f700074df27309b3c6c71701d3b9b0"/><file name="zu.xml" hash="6542a2fe4304ba6289f66b2a68bbbcc7"/><file name="zu_ZA.xml" hash="db4d81680d06e598e322a26e9255ea69"/></dir><file name="Data.php" hash="8fa12d0abbc5557b89cd824b0e18d3bb"/><file name="Exception.php" hash="48210cc1272d8350acafdb8b26e86081"/><file name="Format.php" hash="eb7d886a80ca361bd0c38ec54b5d8bf2"/><dir name="Math"><file name="Exception.php" hash="37609bd0e120bcb0ed890523ac7cd35e"/><file name="PhpMath.php" hash="aa289ad314dc08e0abf97a3f147b6750"/></dir><file name="Math.php" hash="8f03d1a239fa7f642dd43ef7f7c642ad"/></dir><file name="Locale.php" hash="aad364df1a2dcad576c9ae09d94f46d8"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_ZF_Locale-1.12.10.17.xml b/var/package/Lib_ZF_Locale-1.12.10.17.xml
new file mode 100644
index 0000000..20cd8b9
--- /dev/null
+++ b/var/package/Lib_ZF_Locale-1.12.10.17.xml
@@ -0,0 +1,19 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_ZF_Locale</name>
+    <version>1.12.10.17</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Zend Framework Locale</summary>
+    <description>Zend Framework Locale
+splitted from ZF to avoid memory overruns during installation and upgrades</description>
+    <notes>1.12.10.17</notes>
+    <authors><author><name>Magento Enterprise Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:49</time>
+    <contents><target name="magelib"><dir name="Zend"><dir name="Locale"><dir name="Data"><file name="Translation.php" hash="3c4e6ddf022e279cdbc77a860c6cb657"/><file name="aa.xml" hash="6ba5c871d22f64a769c70a1af71a04c3"/><file name="aa_DJ.xml" hash="369c4c2c9eca85c0b60d762a6bc98aa8"/><file name="aa_ER.xml" hash="64dd3e36ee4831d967e49ca2e3acaaff"/><file name="aa_ET.xml" hash="c05abb8269fff734e511dc4d0a11c1a9"/><file name="af.xml" hash="67b34f34749792149e0358fbc902c167"/><file name="af_NA.xml" hash="4034171f9b1450a37ed070aa3d90c5ba"/><file name="af_ZA.xml" hash="6c3da14996bf1b58cd8017df3313b8ea"/><file name="agq.xml" hash="5fd93a5c707e73e4aa5c519c6d64afd4"/><file name="agq_CM.xml" hash="06499c36298cb9eeb23e6dc0dbe20322"/><file name="ak.xml" hash="69320ac48004c58405d12d800a2d81ff"/><file name="ak_GH.xml" hash="5c5c86078d71e30c0399a762e5cf7f0d"/><file name="am.xml" hash="95b934943f754f649861fcc29f378976"/><file name="am_ET.xml" hash="584cb88741cf24321e0c047dcef574e9"/><file name="ar.xml" hash="8ec3de78c7d4ff42daa956025eeebc20"/><file name="ar_001.xml" hash="bc30b0854e32d00739413feb7a5414ec"/><file name="ar_AE.xml" hash="f70fd224cd066586d1b8cf5309774b21"/><file name="ar_BH.xml" hash="0c953018f40ce82e9de064a4cb95a488"/><file name="ar_DJ.xml" hash="66fa3cc4267b7fd0d96a2669a0401d8d"/><file name="ar_DZ.xml" hash="c070ac57992c1611059859954354e256"/><file name="ar_EG.xml" hash="7a422d856e2ec72b9c1494316b89aa02"/><file name="ar_EH.xml" hash="a21177328a2e94087fbae06f1c7471b4"/><file name="ar_ER.xml" hash="0a7472b1683fc78bd1a3a5cafb8b84c6"/><file name="ar_IL.xml" hash="1bca56bc324229351c0089b67d490cb6"/><file name="ar_IQ.xml" hash="0da352ff695a5a3e8e5dd155cd7c4ddc"/><file name="ar_JO.xml" hash="4c7b8b4b5eb54adc1f9c3f6e4dc4dea4"/><file name="ar_KM.xml" hash="e919d368ba30dfdeaa95f70532b4e255"/><file name="ar_KW.xml" hash="9b6ca92c240ea68d66acbb49f91992f0"/><file name="ar_LB.xml" hash="18b007c4b842620480c8bb88aae29b77"/><file name="ar_LY.xml" hash="4da8f8faf728c8a65aae9c4a66008b34"/><file name="ar_MA.xml" hash="f1b35950f3e3e3f4237a5a39c7da2be8"/><file name="ar_MR.xml" hash="f2ffa3c86e1b19b17b09f9099273e9d4"/><file name="ar_OM.xml" hash="ed0e25061367e82694d8cb7c0eaee387"/><file name="ar_PS.xml" hash="e7ee58c19554a466dab9fdb752d24a6f"/><file name="ar_QA.xml" hash="7b180beb5da6eac09e84b58a240d6991"/><file name="ar_SA.xml" hash="d016c7a9ff9de9e45c9136109f8f493c"/><file name="ar_SD.xml" hash="9dfcaa9bb696f5cedc059a4109c8b3ab"/><file name="ar_SO.xml" hash="84afb054141b7c24b7b448b5602359e0"/><file name="ar_SS.xml" hash="6c3734aea87be71cffb4556464be4fd4"/><file name="ar_SY.xml" hash="5a198ba2fef0281de890f996fbf644ef"/><file name="ar_TD.xml" hash="948d829d89a161430f83912af024f141"/><file name="ar_TN.xml" hash="7faf65c744cf5e52bfdb59542bbe7899"/><file name="ar_YE.xml" hash="8c10abba56d6a234a55c654078016a9b"/><file name="as.xml" hash="8fc5e45c11ceac7f52c78ff5166159d6"/><file name="as_IN.xml" hash="694909593f1415ef0e4fda6d5e58be0b"/><file name="asa.xml" hash="67790459fbf5470067fda4eab8703753"/><file name="asa_TZ.xml" hash="a7ff94e5a530dc21c43ab7174ae813d2"/><file name="ast.xml" hash="64deedf1c37b39d07b45a5080fc94190"/><file name="ast_ES.xml" hash="77b6d2a7c40dfcdd70fcd5a48dbc937b"/><file name="az.xml" hash="e5c36c36cb81eca6d5cfa86ef058d989"/><file name="az_Cyrl.xml" hash="4489b815e2f3f628619ccbbe09afe72f"/><file name="az_Cyrl_AZ.xml" hash="827b611f5206f27d79f2c07525340bfa"/><file name="az_Latn.xml" hash="7a9c14a8afa4e30e677b6d588788a515"/><file name="az_Latn_AZ.xml" hash="ef3f0e6fe96210ee2e21ed77c73716a8"/><file name="bas.xml" hash="b5e926cff825d6a19ecdd30aa6ed7309"/><file name="bas_CM.xml" hash="b96cd37b4240f82a00400bceef16106e"/><file name="be.xml" hash="b9e6bfe9f98012d6e2e3adbb8d7f4a33"/><file name="be_BY.xml" hash="f7decbc88e0b84a81c61c33b752f7f35"/><file name="bem.xml" hash="b32d7fab640633d84596c781c5729972"/><file name="bem_ZM.xml" hash="a41416d42e206b3499ed1327002ce5da"/><file name="bez.xml" hash="700611e0dce26a8fc22647aa5708dc74"/><file name="bez_TZ.xml" hash="c767af253038caf4cbfede8a067453f5"/><file name="bg.xml" hash="51b19b644a9796463b91bb8ec236adca"/><file name="bg_BG.xml" hash="05e86d4ebf3b91764d3a0d2551e16bf1"/><file name="bm.xml" hash="09d5b79929820ae15c0c6d5ea4afb6dd"/><file name="bm_ML.xml" hash="4d5e1b37325ed9e57f8c590fe1d3a762"/><file name="bn.xml" hash="199a113c26a1608720ca7e3c660d23e8"/><file name="bn_BD.xml" hash="794e3d0d4fcb61f260ac7bf8673378d5"/><file name="bn_IN.xml" hash="0848d84be54a2646adc33af1c9e4b968"/><file name="bo.xml" hash="febea3f15347297281d6ecfcc5771b73"/><file name="bo_CN.xml" hash="30fd400db11b971da287cea6be2ef3c1"/><file name="bo_IN.xml" hash="d68dac66b5b843ce88da031b16b3afe1"/><file name="br.xml" hash="e870097efcb0cd34bb6e4d1f2dc5b278"/><file name="br_FR.xml" hash="11652862f633f7aec19a1c0433c4b204"/><file name="brx.xml" hash="8047b46746f02a39674f0beefc07e194"/><file name="brx_IN.xml" hash="99404538d96a071935efe231780663dc"/><file name="bs.xml" hash="940b48d89bdb239461bd8b3427469342"/><file name="bs_Cyrl.xml" hash="8580494f42dcf27b664a012d4658982b"/><file name="bs_Cyrl_BA.xml" hash="3f8c9a61ac978bd30d6d64bf86dffec8"/><file name="bs_Latn.xml" hash="0c8b503dcc0f9853d3af20768e662aea"/><file name="bs_Latn_BA.xml" hash="9496b4ae275da058251832af52888167"/><file name="byn.xml" hash="5b73a1af7b8ba27dc8262d81934c3f14"/><file name="byn_ER.xml" hash="4da388f09780d86134689dc5f10a3862"/><file name="ca.xml" hash="581f561afd2a2296430eebbd9cd7cf1f"/><file name="ca_AD.xml" hash="f3f80fa4f38bb72a397d94e6e12175d6"/><file name="ca_ES.xml" hash="24c8e24495f99d3921a5a4e77f8bfb81"/><file name="ca_ES_VALENCIA.xml" hash="e9703c4cedea0d7756a06a653c1c8442"/><file name="ca_FR.xml" hash="84537f1e57ba4476c1f923d12f4f7b42"/><file name="ca_IT.xml" hash="e842526f0ecfcef2904d206b2a810041"/><file name="cgg.xml" hash="054e8d83970f37440d169e964c743447"/><file name="cgg_UG.xml" hash="c6f0a77828c43211f72e10e83f9f666d"/><file name="characters.xml" hash="578bec00fbe6d6416ba89e6fa7986357"/><file name="chr.xml" hash="d5c69b967b2ca2744b8a46d9c95260e8"/><file name="chr_US.xml" hash="53b9e050bf58ab63900197dc8fb43d9c"/><file name="coverageLevels.xml" hash="90d4dc96d148cbd970ac8ff49c209bea"/><file name="cs.xml" hash="23e2ba0f38fbb0021ecd6aaa24db77a1"/><file name="cs_CZ.xml" hash="baa89fb49d1c50a5e7ef632f75d56fa7"/><file name="cy.xml" hash="0657a743b16b94e59c26b692dd79943b"/><file name="cy_GB.xml" hash="9bfe606c96d3d035ad644efe57bc67f6"/><file name="da.xml" hash="507243848cb4398daf768f735cfb432f"/><file name="da_DK.xml" hash="2347254255ce488182e37214c7d0694f"/><file name="da_GL.xml" hash="84ea22e10d4f6aa9ff8a0c6644fd7dd9"/><file name="dav.xml" hash="47ee87a9cdba6d211639776a608c1e86"/><file name="dav_KE.xml" hash="37e7d66af32b1fe4ac81be34fbee5d2e"/><file name="dayPeriods.xml" hash="56449b799dac8fc8daafbb0f3d3d99ef"/><file name="de.xml" hash="198aa0c550d4c41406bd0df6f7b70a7f"/><file name="de_AT.xml" hash="4b960a6fac173340ac276ce5c9d82532"/><file name="de_BE.xml" hash="dce45b8b94a4c3aab891a2c7bf3ca151"/><file name="de_CH.xml" hash="c4e68ad1a19e6e92daa571edb12cb36a"/><file name="de_DE.xml" hash="fa5913f6081a8a4650cef19d22acca20"/><file name="de_LI.xml" hash="0dfda8f44bc729219bb5de48f7694393"/><file name="de_LU.xml" hash="409b134c2c81689c16df1a79c0a4baa2"/><file name="dje.xml" hash="7da22550436ba325fd7b0dfde195b9a7"/><file name="dje_NE.xml" hash="7e318b89d05df66eea3fe59bf75c7ac7"/><file name="dua.xml" hash="ba4657ecd1b3bc014c5dd1622d107e90"/><file name="dua_CM.xml" hash="5bba1b38dc6495219fcb1a0432cc8df3"/><file name="dyo.xml" hash="612804b11d342d9e3b4bb2d58b5f66a7"/><file name="dyo_SN.xml" hash="dc003c4af3987ec2d7255d3c1f541738"/><file name="dz.xml" hash="244f80bfc2f658780ba016281354fe0b"/><file name="dz_BT.xml" hash="9d287c1c61edf1fa5ef3d765b2c7da86"/><file name="ebu.xml" hash="76696c080f20a7db39abc05dd272f090"/><file name="ebu_KE.xml" hash="7c4abeeb255cf7bf2bc500abb12ce387"/><file name="ee.xml" hash="4518057dd1b1b514e3bd12e5b5e85bf2"/><file name="ee_GH.xml" hash="082d3a0d2203319b9e51004a710e3e6a"/><file name="ee_TG.xml" hash="d99900de319d3584f1a115d4b5eb76f0"/><file name="el.xml" hash="1710cdf160e6cab0c4d47c15bab5be18"/><file name="el_CY.xml" hash="6da5d159d499ba4754a2e7d4553d5059"/><file name="el_GR.xml" hash="477e3b1f10320e95a0c12511cb0c8368"/><file name="en.xml" hash="9256d3ec622d04bd406376827d31012b"/><file name="en_001.xml" hash="768d1b54436a379dd71d0239702810a6"/><file name="en_150.xml" hash="7f9a887b30b86016fe8a29cabb6b8ce0"/><file name="en_AG.xml" hash="4d2c7e568ab71d4b4e49c934b47d5c4a"/><file name="en_AI.xml" hash="70e59d70a946d5026659413cecd2da7f"/><file name="en_AS.xml" hash="2b134e308540cf74f34c2aa665112301"/><file name="en_AU.xml" hash="ed81bf367e4f715e9a5c4271bf49822e"/><file name="en_BB.xml" hash="5dff42e201010656bc3dbac5887d015f"/><file name="en_BE.xml" hash="f91d2ce67b1818708d15c091c4c9d720"/><file name="en_BM.xml" hash="2908ee96a408ec7b9d7fd659615d90ff"/><file name="en_BS.xml" hash="91eab1ca2779d23f13df0347f536ca0f"/><file name="en_BW.xml" hash="e37d57c47fd205e31473eb60bb1c973d"/><file name="en_BZ.xml" hash="59d8c1d1deac2a7b0f73992516c999bd"/><file name="en_CA.xml" hash="7f81353970624138037a527f761e6571"/><file name="en_CC.xml" hash="38e31ba2efac50bc06a5caa4bce5fa02"/><file name="en_CK.xml" hash="4a677485a65e531f1468c1543347c1ce"/><file name="en_CM.xml" hash="5a02b7f5fa1bedd6a05f96196e95b711"/><file name="en_CX.xml" hash="fc592a771a64d862c3739a898ce18dd3"/><file name="en_DG.xml" hash="1ec938ecb46bd092323b4f8ce4ba2cc2"/><file name="en_DM.xml" hash="89bee96e1185ba2dbb3ded508dda16a8"/><file name="en_Dsrt.xml" hash="6fbff7ba19f432150086850bc2e2f804"/><file name="en_Dsrt_US.xml" hash="0850b836f2faef6ec3423c7705160ab7"/><file name="en_ER.xml" hash="a99ce4a7be566be0b20822f418a4a589"/><file name="en_FJ.xml" hash="f5cfe8032f32fde1289d2fce5696a6c7"/><file name="en_FK.xml" hash="632a6ac34df2048f5160f1cbb21684e4"/><file name="en_FM.xml" hash="1e288d9366e0ac40b241b90d550d6424"/><file name="en_GB.xml" hash="5b73aa8057d95008d24c3eb91f265fd1"/><file name="en_GD.xml" hash="7d6d4bfad9463d051c6aba6301581460"/><file name="en_GG.xml" hash="a75e2a293cd4eb9e49d495c13b6e37ae"/><file name="en_GH.xml" hash="97e8cffb72f9e6651f8dee6ca086c0ea"/><file name="en_GI.xml" hash="6441468454ea9cf06468b0e19db106aa"/><file name="en_GM.xml" hash="7497ca9f4f962f57dffc9ad93ab78077"/><file name="en_GU.xml" hash="ae33e0859c963b265fdf32cd026ad26b"/><file name="en_GY.xml" hash="50aed051f78b38a1d1156c36d3ad7f9c"/><file name="en_HK.xml" hash="1aa1133bec835a760695dd994a6ca259"/><file name="en_IE.xml" hash="63130f36882b6a6917606b7c6624aa80"/><file name="en_IM.xml" hash="2e981e6e96db2a140dbef95db013522c"/><file name="en_IN.xml" hash="7433385f2bb2afa211e5c33cd9f921bd"/><file name="en_IO.xml" hash="b63a354d390f7b3eb564394b6ea5ebd1"/><file name="en_JE.xml" hash="a37431bab3c66fbc361a775b62627154"/><file name="en_JM.xml" hash="3c59b2850c79e9a7371e8f7a12dd7d75"/><file name="en_KE.xml" hash="2554dd9bd652f9ea57cd18da1a19df18"/><file name="en_KI.xml" hash="f24474b7d06fc2f0220ee7095e6fbff7"/><file name="en_KN.xml" hash="4d68bb1ef92eefad6f2fcc0e0b0d5076"/><file name="en_KY.xml" hash="b686bd51fe232c2107a08e8d9a5f1577"/><file name="en_LC.xml" hash="2ffab8614818ecca5af1c84ddb96a6bc"/><file name="en_LR.xml" hash="eb8f5ac9ca72306127d86db0085a92c0"/><file name="en_LS.xml" hash="8255d2c42f06b2d7c511353e82edf59e"/><file name="en_MG.xml" hash="5d7a723320b05e8fd7a4a1c8017bb57c"/><file name="en_MH.xml" hash="3c762f2aa253bef5b3cd1ad5940c3cc9"/><file name="en_MO.xml" hash="c20af1a8a15c19b9a52dd56c36b5598c"/><file name="en_MP.xml" hash="d535408f7920814d2d2b7c4ddfbba7e5"/><file name="en_MS.xml" hash="d74c01a6b57a68fc4d149b0f2bd5faf2"/><file name="en_MT.xml" hash="a0779f1ed61a4fa24f2549fc37df1523"/><file name="en_MU.xml" hash="484d1081e00dfe315b01368e63a8e547"/><file name="en_MW.xml" hash="6f5546f3143027e27250f1b471f3722c"/><file name="en_NA.xml" hash="43792f7465fd56dff8129154cd568400"/><file name="en_NF.xml" hash="9ced4a796c1db1693c526340fdda01d0"/><file name="en_NG.xml" hash="ba618207a64de97e9420801e8909f076"/><file name="en_NR.xml" hash="56f2eb49dc7a336e5eb0e2f4503dc3ed"/><file name="en_NU.xml" hash="524a420bdbf2d1bfe4ced79e690fadff"/><file name="en_NZ.xml" hash="3960c92d3ef55d1e55bc7bb7808a1c58"/><file name="en_PG.xml" hash="9fdf21ef2f976e068dfddbdd0bfcbbbf"/><file name="en_PH.xml" hash="6d0b1441355b533aa7231a45f330bb68"/><file name="en_PK.xml" hash="48a4db2301d34ccedf58942f3b41b181"/><file name="en_PN.xml" hash="846a0b8c74785cf3ffb562abbd5d5cd3"/><file name="en_PR.xml" hash="76bec34e4f081c2cc6ea562b9d3c3552"/><file name="en_PW.xml" hash="258fb50d80e798ffe19514bceaab9c85"/><file name="en_RW.xml" hash="aaa4befd7267fe5afd6682a00241eca2"/><file name="en_SB.xml" hash="0c50f8257806c71a8fba4cda42acb2ac"/><file name="en_SC.xml" hash="d8769c5bbd31f66c1a40d82ad4f9959e"/><file name="en_SD.xml" hash="9d3a24c9a0bd4f99653130314a6cca29"/><file name="en_SG.xml" hash="f32241b6135eb9e8733ffc80fab1b110"/><file name="en_SH.xml" hash="c35756da3a6effbfa9af4d488f7292c4"/><file name="en_SL.xml" hash="dd9fc72730ab0e6e58086a662fefa69d"/><file name="en_SS.xml" hash="35c730c6f16af1d572ef33bbea15fde3"/><file name="en_SX.xml" hash="d33e0d2eb46c1dc7004b84f6606dff0e"/><file name="en_SZ.xml" hash="a53c6878dcddbc32d37ab6b77e17da36"/><file name="en_TC.xml" hash="55127dfa22212f6abded3dd606af5a85"/><file name="en_TK.xml" hash="64ecd71d4530f1668e9da48f1039f508"/><file name="en_TO.xml" hash="a5e77bc5a7beecf3ff8f6b3156a87668"/><file name="en_TT.xml" hash="8b168ae6e9c3d9c8fceb0582365264af"/><file name="en_TV.xml" hash="7f98c91cd0dd96a66e4c8684d1d60639"/><file name="en_TZ.xml" hash="0cf0401e55af54ff68da8bab8c901182"/><file name="en_UG.xml" hash="a028dc8e13686a9ebafb83ace5315206"/><file name="en_UM.xml" hash="b883319cb6ecd9b1a6cb1deef89db236"/><file name="en_US.xml" hash="6435b96852569c7e355302c17814f77f"/><file name="en_US_POSIX.xml" hash="535c6ed9fd3be4db0fbf7ba3c79533b6"/><file name="en_VC.xml" hash="e745b417ac7ff1c93f281070740e901e"/><file name="en_VG.xml" hash="66ebc85cc70895db528d868b2318e5d6"/><file name="en_VI.xml" hash="3f30ee6f1c7383f6d906106f09cf5eff"/><file name="en_VU.xml" hash="6eea6dd6ac0cc9d00386059ff12a865c"/><file name="en_WS.xml" hash="bdc0360cf4fb7b517dbee39de8d0cd58"/><file name="en_ZA.xml" hash="031afdaa1011735bbc6555c5e76d7ff6"/><file name="en_ZM.xml" hash="c7bdd89484bff8dcf4daf3f57f6d6bc8"/><file name="en_ZW.xml" hash="b3f51877ba7ce7ead43ef50b499b4444"/><file name="eo.xml" hash="82ba66eacea4e98f8923944eddcc1745"/><file name="eo_001.xml" hash="1801937ded337e21aa03e2592deedb46"/><file name="es.xml" hash="a60ed8506871160a17c4fc3b81e53b0a"/><file name="es_419.xml" hash="c1bef1732b664c23cb1b799181cba5a9"/><file name="es_AR.xml" hash="d404e53f4de755d9c09aa856e916f110"/><file name="es_BO.xml" hash="2876119c46a9c697baba1a65240c051e"/><file name="es_CL.xml" hash="e3910edbae206638b9250ecbf9949905"/><file name="es_CO.xml" hash="53be4c39e4a34867fcbaa8fd05c2c881"/><file name="es_CR.xml" hash="1f0e1d3c965de545b50aab4577b038fe"/><file name="es_CU.xml" hash="2380f966916741dcba3c34c04a5d8009"/><file name="es_DO.xml" hash="9ea0a69084ae8dbdd86459e2806a8bdc"/><file name="es_EA.xml" hash="ec6ce434e2fb8f15ab4daa8cb2bc4dff"/><file name="es_EC.xml" hash="efb247470c0fe88c36a7864184a01a8a"/><file name="es_ES.xml" hash="da94ab8a06feb23c6d567dc75f85531c"/><file name="es_GQ.xml" hash="cac80878e350ca7a728940550bd9393f"/><file name="es_GT.xml" hash="d360a7b0a15a0515a21f1e0d5b4dd21e"/><file name="es_HN.xml" hash="fa13c1e703f00b11d038fe3bfe19c08b"/><file name="es_IC.xml" hash="d5324caf07a8db6ba668a1b749baa6e3"/><file name="es_MX.xml" hash="05df2b2f76636b0097cf9431ff9c84eb"/><file name="es_NI.xml" hash="7d59d82986b3ab47e1b7a2dad383a0aa"/><file name="es_PA.xml" hash="21a4164b1d73365f9b63431247053db4"/><file name="es_PE.xml" hash="8df05dafd2807169296d11f75eb74537"/><file name="es_PH.xml" hash="7240ee508f9500d779bd5109450a057f"/><file name="es_PR.xml" hash="de86ff57cd2f3e3c67111b0163a72b6a"/><file name="es_PY.xml" hash="191bbd042c95ef246cda798581ed9598"/><file name="es_SV.xml" hash="9caba354843c2b055f8f5da17082e245"/><file name="es_US.xml" hash="90b97e0328d50ed134c0b36391a4aa99"/><file name="es_UY.xml" hash="a30737900d956dc397357f6463d532a1"/><file name="es_VE.xml" hash="03449a8b82e4d21e0a59836ceb148536"/><file name="et.xml" hash="d3e8e213866259a27ab9511efe348e0c"/><file name="et_EE.xml" hash="3e92af6dec71aa1ae7a3c62c931534ba"/><file name="eu.xml" hash="7111ceef4472ba0c4e52dfc654a2841a"/><file name="eu_ES.xml" hash="66e48ee02f5d1e5a7076cf9cab709d23"/><file name="ewo.xml" hash="8f5e287d463fbbc8711d46265141be36"/><file name="ewo_CM.xml" hash="47ee8a04b5a0327405d006bd1a99266a"/><file name="fa.xml" hash="1bd0e404ad8d9d3cbc943f04676b03dc"/><file name="fa_AF.xml" hash="3736139f38116f0586eb7aae46f6dcfb"/><file name="fa_IR.xml" hash="98698b67604b8e5589fd75601080cd3d"/><file name="ff.xml" hash="8eec6f2da84d33d3236797c62b96a9d0"/><file name="ff_CM.xml" hash="4bcc2690dc2eb5347be28c55fc008f88"/><file name="ff_GN.xml" hash="a56cbd27d6d838338a535a06db281d34"/><file name="ff_MR.xml" hash="17dd52ffc9809b26db2a067612d92d53"/><file name="ff_SN.xml" hash="9ab32fee7af1d2666669efa4386769d3"/><file name="fi.xml" hash="f1e171910ef4c2137d9a6149cf3c2c55"/><file name="fi_FI.xml" hash="8d9498723893c53c1b6a8ede4d3b796c"/><file name="fil.xml" hash="c44f7b3edadc43b02a927e6cd1e780e8"/><file name="fil_PH.xml" hash="233305bd4c15da54bc9b4847fc753165"/><file name="fo.xml" hash="5715134bd8e1798d5f25d165f8a0bd98"/><file name="fo_FO.xml" hash="99e842dbbd201862703a98e160936c8d"/><file name="fr.xml" hash="125a25633190ef898fe18f2827d2397e"/><file name="fr_BE.xml" hash="1f86df32f3eaddd9b139fbacb7c199f5"/><file name="fr_BF.xml" hash="8eaa50ea5da82e3e8cfea4af20946852"/><file name="fr_BI.xml" hash="eb2d856258ead7da474505881452f613"/><file name="fr_BJ.xml" hash="ef18313c305832ea7049ddf758c9d51d"/><file name="fr_BL.xml" hash="ee7f161cc4c9f844448d9da6fcbb349d"/><file name="fr_CA.xml" hash="64a0b0100ee5e8918ca1d502f06ccb3e"/><file name="fr_CD.xml" hash="d5d62a20e80bfc90badec8a72d8a9d1a"/><file name="fr_CF.xml" hash="d0e96516835a44fcfadd25d0db4e48a1"/><file name="fr_CG.xml" hash="e2852122d57450cd7a388a3545709994"/><file name="fr_CH.xml" hash="2fd3f24252e081fc4c74e9e707c00365"/><file name="fr_CI.xml" hash="e72b4fb87bbb5751e49093c24f4fbd5d"/><file name="fr_CM.xml" hash="e06d4dc5c3604d9cd9cc64376e206daf"/><file name="fr_DJ.xml" hash="7e87bdb7669cbf73ac0bb191d43400a4"/><file name="fr_DZ.xml" hash="64558f39d1553f56217f80ec3ef92536"/><file name="fr_FR.xml" hash="3d82e2934dd28c26c7382de85d95ac11"/><file name="fr_GA.xml" hash="87cc610fd5f6a486c63e5cb105cc2d7f"/><file name="fr_GF.xml" hash="cdecac5dac6e7e10336de1dec5982673"/><file name="fr_GN.xml" hash="0ed99a0d3cec1034899413196dde9c06"/><file name="fr_GP.xml" hash="78ffa2393237a67fd202f96784bcea5a"/><file name="fr_GQ.xml" hash="359c388c94381b4bd09868afb8557b43"/><file name="fr_HT.xml" hash="7ecc803d1e947635fcbf0aa1b201ce60"/><file name="fr_KM.xml" hash="ea71c8291e7c8aeaaad03880b7308a2b"/><file name="fr_LU.xml" hash="2f467a6cc20912bea31f2932c26be870"/><file name="fr_MA.xml" hash="a0fcbe1f955e3d76f9e38eef202ffa07"/><file name="fr_MC.xml" hash="9a6304e508d08737c7969b44d9d57939"/><file name="fr_MF.xml" hash="46968723e86571f7455ee534302d3471"/><file name="fr_MG.xml" hash="ff234d4ba2e66cbb7b798ca787c67026"/><file name="fr_ML.xml" hash="7d1c047089abbf427b3635bc977444b1"/><file name="fr_MQ.xml" hash="f8bb16f92cdb67bc46ceb7aa7048d908"/><file name="fr_MR.xml" hash="d838bbdbd611c35862b89899816befb9"/><file name="fr_MU.xml" hash="ead1fa2ecb9031315ac554ca214d551e"/><file name="fr_NC.xml" hash="3d6500c28264363b27bf842259ff8a17"/><file name="fr_NE.xml" hash="f5bec7e22bd5db13346937f58a1312f2"/><file name="fr_PF.xml" hash="d9c7edabd1f8fd52c5320d874c96c021"/><file name="fr_PM.xml" hash="bae26570b49ab5979729a5f5b66ce087"/><file name="fr_RE.xml" hash="0c9b4ea0bf6c26c33ed0cef26f428af4"/><file name="fr_RW.xml" hash="8725f9ee61c3054199536d6d8eec42ba"/><file name="fr_SC.xml" hash="1eeb10b51d815098e01a3f60d71f793f"/><file name="fr_SN.xml" hash="fa6da2f3ae651bd93705f26587ed135c"/><file name="fr_SY.xml" hash="b6ef0c074642c951a04131a3cadfdfe6"/><file name="fr_TD.xml" hash="ff554940988b4f7bd210a2138575c6c8"/><file name="fr_TG.xml" hash="2256df16de2fd7331fbfbeaeaf0ddba3"/><file name="fr_TN.xml" hash="d9996b3dba7d6ca0aa12c1e6766d2f27"/><file name="fr_VU.xml" hash="4f07ba927564fd6d3507816cf3aafe45"/><file name="fr_WF.xml" hash="a6c659de13b695c7e229681b819ed473"/><file name="fr_YT.xml" hash="821b7a10ac601226696fa7d71d0f8247"/><file name="fur.xml" hash="62a65af07d949f1117573e425bee90fd"/><file name="fur_IT.xml" hash="647415f7e2ebd1d55b260dac3823e3f9"/><file name="fy.xml" hash="14a7805cafcf18dc2f21a7925e9d7182"/><file name="fy_NL.xml" hash="dac6922c58516864d0d18df09753b917"/><file name="ga.xml" hash="7cc3d8d5796c554549ea5ebe5fb9cc35"/><file name="ga_IE.xml" hash="49dfc6b41e17ddc6cd93d17b1aad62f6"/><file name="gd.xml" hash="49f89d47c209b25730d8d731973f29b5"/><file name="gd_GB.xml" hash="721b95588bf8f0ab4004d868128cf286"/><file name="genderList.xml" hash="12c8a32237c76cd85cdb15f8cd140023"/><file name="gl.xml" hash="f7c56b822d2cc164b6691956fc79669e"/><file name="gl_ES.xml" hash="05e04a61e62eab6b94d6cfa3ef96ef25"/><file name="gsw.xml" hash="2b9d820569249f8fe88f6f77320223f2"/><file name="gsw_CH.xml" hash="ec2f1146d4fe5125f42c6281bb2f10b7"/><file name="gsw_LI.xml" hash="a6031e3e7ab4512a905d91484d8f5f00"/><file name="gu.xml" hash="8fe2967cebfbb4a19bfdbff9a8029cab"/><file name="gu_IN.xml" hash="0f93d2cd4139a9fa96df164cdf0357ca"/><file name="guz.xml" hash="65566bd2674a999999affe67ddef45a0"/><file name="guz_KE.xml" hash="7891c10bba2ae36ce29ce34f996ded25"/><file name="gv.xml" hash="bdb5556e04a5f2acb2141197e09020ef"/><file name="gv_IM.xml" hash="cf6d862525015e25038f60fc93175e84"/><file name="ha.xml" hash="310c626b795a231ad736c44ffe0df31f"/><file name="ha_Latn.xml" hash="a470076b9866db162e1415aa32350a44"/><file name="ha_Latn_GH.xml" hash="e213acaf6a53ba1d9c33d2ebda346ab3"/><file name="ha_Latn_NE.xml" hash="7983a567b1473874f3bea1dfb045ab29"/><file name="ha_Latn_NG.xml" hash="d2191f02d90e7b9912fe0e66aed70d24"/><file name="haw.xml" hash="5012e655132a7a5a7ad8397052baf955"/><file name="haw_US.xml" hash="5bb77c6692d33c8488fd008640434b2b"/><file name="he.xml" hash="70cd2438f74f6ea64543ec52bbb06e56"/><file name="he_IL.xml" hash="bdc2d75f46f4dced46dd4fbce6cac4f8"/><file name="hi.xml" hash="20e5122052162ec860cd27db34fc1dcb"/><file name="hi_IN.xml" hash="fbc59458d4ad8d295265e79fec26534a"/><file name="hr.xml" hash="ad2c7a5102cb05cec7ae0478d2f5b552"/><file name="hr_BA.xml" hash="bb36010b5b7cb83bf623d27eddc90678"/><file name="hr_HR.xml" hash="0a5068d64bfd804afa623562e6c556b1"/><file name="hu.xml" hash="35260b5e75ed941097710b0a0483e407"/><file name="hu_HU.xml" hash="b816b69e9814d33ad14907c9c3b6316d"/><file name="hy.xml" hash="4dd0bd1e21762124de07651094889237"/><file name="hy_AM.xml" hash="cc2c8134ca77e5bd55315c5faf80c61c"/><file name="ia.xml" hash="a57208d2e90856e670b25cafa90caaa0"/><file name="ia_FR.xml" hash="dbfd4721237b03875d50cb0770f1a5bb"/><file name="id.xml" hash="ad0dbea4ed9c97b2ef44ea451ff43aa5"/><file name="id_ID.xml" hash="349192acc73b4d40b3ea684999c5cd4a"/><file name="ig.xml" hash="0cd19cfcc514c8c5c0d8b8f085e64a72"/><file name="ig_NG.xml" hash="666845e6dc06958bdd682bf40b9a0251"/><file name="ii.xml" hash="db4ca0fa7cd320163163a97946399d6a"/><file name="ii_CN.xml" hash="a112d1ad1b7fa51a30f6cdb0850168b5"/><file name="is.xml" hash="a4587bd0d57e17d1960dba1a45b5e1b4"/><file name="is_IS.xml" hash="5d2fff72bd6199e1e79cdb3fa126b6a3"/><file name="it.xml" hash="dfa19eadbd4b5819453159c12e5bc32c"/><file name="it_CH.xml" hash="da4122fb147f2652de469a3f7703862b"/><file name="it_IT.xml" hash="0fded926a8f00f5f491f4ba2486b0686"/><file name="it_SM.xml" hash="4706ecb3a92e9e05f6d9f54bacbacf34"/><file name="ja.xml" hash="a4bdd8fef7cac5c8ab8a706781d475b8"/><file name="ja_JP.xml" hash="b87ae521fe2527bc9051ee631bd1001f"/><file name="jgo.xml" hash="9471f4b7fa6323bf54a3b8b74813aeb7"/><file name="jgo_CM.xml" hash="8ded303577f1a672dd255dd1fc1490fc"/><file name="jmc.xml" hash="fb1bd646841f4b8af118996f1ffc4591"/><file name="jmc_TZ.xml" hash="fc0d97c3788543fb5a53695be429dd96"/><file name="ka.xml" hash="6223813b9ac5f055c2c682eb79e6e05e"/><file name="ka_GE.xml" hash="b5df45beb8ba26df37d00154fe2e8deb"/><file name="kab.xml" hash="28e3bfe8412eeac7fda8a154c2dc9375"/><file name="kab_DZ.xml" hash="c398b9636cc7716ab1152528de39599f"/><file name="kam.xml" hash="078f9f3de5e4a2e405f91db0580fee61"/><file name="kam_KE.xml" hash="671d06ee91b5451d3bcef26cf6d0962a"/><file name="kde.xml" hash="db0e85e0f1bd852d8d467e13f8a2dfd3"/><file name="kde_TZ.xml" hash="9f41da9a28fdfd1cf618deba5d9e70ee"/><file name="kea.xml" hash="5504f98e950dd836749ecf3eabbb9d03"/><file name="kea_CV.xml" hash="88602da9c4e3bf124a330f1d0fb84113"/><file name="khq.xml" hash="f0deb2302861cb75bfa96b4b11cb6fa9"/><file name="khq_ML.xml" hash="44d6228f6585a0ddfd53f2b13f7f18c7"/><file name="ki.xml" hash="26a88ce1af8c274b1b5ff3a5c11fb3eb"/><file name="ki_KE.xml" hash="2b5e5cf6cd0d7e38ca3d1d1cb63be4fb"/><file name="kk.xml" hash="a298ecc37ae4d60ce87cb0eaad919d3d"/><file name="kk_Cyrl.xml" hash="07046177e2ec5347df348912409e4283"/><file name="kk_Cyrl_KZ.xml" hash="5bfb35389063a05e63ddec93b4ffad82"/><file name="kkj.xml" hash="3a97c2408dfbbbf2ee181c7c70b2ea8a"/><file name="kkj_CM.xml" hash="095d6748ff7c6f070fae30938ef729c5"/><file name="kl.xml" hash="95ed0d90dae8db61f7b46db63aac0a0f"/><file name="kl_GL.xml" hash="ef6c30e0b4063b1b8fad4e4511e3e33c"/><file name="kln.xml" hash="67441932af9b0b24bc2c2ca2e018d5e8"/><file name="kln_KE.xml" hash="f10af3f43ee9aee1bbf52ca5ff1c5196"/><file name="km.xml" hash="dee5bb763d56521b3c2919a340021c62"/><file name="km_KH.xml" hash="8a31a83be02152f33704d7dc2d2e3e4f"/><file name="kn.xml" hash="0b9d9e33559353f7c074672472ad8f7f"/><file name="kn_IN.xml" hash="e4135fa646d16bb15bf8c24919a4122b"/><file name="ko.xml" hash="9f2d95effdc2374377d41ff61f1f8ace"/><file name="ko_KP.xml" hash="cf696a9af609810d08337fb56f4b2a51"/><file name="ko_KR.xml" hash="0e6404f41f456011631a67da431ec48b"/><file name="kok.xml" hash="deea0756950d5465bf3d529ddf533e4b"/><file name="kok_IN.xml" hash="9ae56f19c07124aa5801d3f2d21dbdfc"/><file name="ks.xml" hash="62e4a1072ac6d8a14df457bb325d97bd"/><file name="ks_Arab.xml" hash="2c7ee60c2f9764e87ce01dace3089799"/><file name="ks_Arab_IN.xml" hash="2fea656a91f684489095e5f13d76c778"/><file name="ksb.xml" hash="d4c84ad5e9ce333697588c7cfc6a8ac1"/><file name="ksb_TZ.xml" hash="ccfb53a163d96d54debdaa15d3499027"/><file name="ksf.xml" hash="a8187b83f4ae0a05f0219f6262c38a70"/><file name="ksf_CM.xml" hash="203147426344f510947dcfe51ee77b83"/><file name="ksh.xml" hash="2617cb6c2b91f15403ce462da0021275"/><file name="ksh_DE.xml" hash="8e085f8da562734068ff0141aa759eaa"/><file name="kw.xml" hash="91ad55b87458489c861988b7fb6280c1"/><file name="kw_GB.xml" hash="7e2024541e7aba767e844c0b9663e155"/><file name="ky.xml" hash="a7545fd81340fd75464e271076dc5279"/><file name="ky_Cyrl.xml" hash="2fe62d616b564a7316ef4a8a72210488"/><file name="ky_Cyrl_KG.xml" hash="757d4898a54dcc119b43698784cc8967"/><file name="lag.xml" hash="a8a25a77df5909db3b73340774221cb5"/><file name="lag_TZ.xml" hash="ebd0c62787658dec41e3e49017e2705a"/><file name="languageInfo.xml" hash="9a33723a317db6855c7dc4a37a9fffd5"/><file name="lg.xml" hash="2cc89f3e98775beee70bdd3e3404d9dc"/><file name="lg_UG.xml" hash="d98767310f065c6a3755cfb5fec6b9a0"/><file name="likelySubtags.xml" hash="6a042c9e337512b06f75e101a49981f5"/><file name="lkt.xml" hash="dba6053b63f4c6e3bf2e21f603c8d78b"/><file name="lkt_US.xml" hash="bd6f8a8cc0acca0ad53b85350f2f5b80"/><file name="ln.xml" hash="0cea3d899d3dad394a5e92db22044bc9"/><file name="ln_AO.xml" hash="9eabbf5b540202c5e5b521cdd06564b4"/><file name="ln_CD.xml" hash="5a6fd6126bf58147cdad6a565bae8af5"/><file name="ln_CF.xml" hash="349ec0ad936ee0fc9c5a00530e259390"/><file name="ln_CG.xml" hash="25c98dbc645d64b7cd800fbf6674fc4b"/><file name="lo.xml" hash="52aa20460fe494c813927fdab64feb08"/><file name="lo_LA.xml" hash="0266874e3970a24dab991fc54e111360"/><file name="lt.xml" hash="6d485e98ca9590acf70ea1838e488ad7"/><file name="lt_LT.xml" hash="738d6dfb27e54f7f9a44875b6dacf0e5"/><file name="lu.xml" hash="5ee43a091cdfb35d5f14067f45b0b05c"/><file name="lu_CD.xml" hash="dbe948b08a594210a3d088e414123d86"/><file name="luo.xml" hash="69779720b4294de854bf82a170ffbec9"/><file name="luo_KE.xml" hash="ad6df8710e3b4976c7bc95b0ec739fa3"/><file name="luy.xml" hash="d0e4e4766a744edc1ab08418bec0ee61"/><file name="luy_KE.xml" hash="28a00f1eb2977ad409b0dfca45a0ca9d"/><file name="lv.xml" hash="3a85d69acd0b15e47f9b2df341be7573"/><file name="lv_LV.xml" hash="6e07fe6de844f63ae1605a6a1a5575a5"/><file name="mas.xml" hash="b1ee3c8d903462d3b217b7056a31df20"/><file name="mas_KE.xml" hash="e494f8d43607f742e3a0cf393ad83bcb"/><file name="mas_TZ.xml" hash="a5785e18c75185c28f284f2e18e7f6e0"/><file name="mer.xml" hash="2023c272b2b6e1169d0d45bb195c7d53"/><file name="mer_KE.xml" hash="52600bcaac77d9e6aa9c9741e67323c5"/><file name="metaZones.xml" hash="64a142f5cc668612c9c6ad2ff0af875f"/><file name="mfe.xml" hash="cec57c842e65ebeaf746db91ac55f5b1"/><file name="mfe_MU.xml" hash="990e405c5cae3b6d7226d0482d0b6848"/><file name="mg.xml" hash="fd8b564029dfa72a913ff627c834082c"/><file name="mg_MG.xml" hash="81a7d92eedd7a4d9cb8c8687badf4aec"/><file name="mgh.xml" hash="6008ffd778c2d670383ab125848d5a68"/><file name="mgh_MZ.xml" hash="ed7a568c678bb3ec003732ba4e7c19a8"/><file name="mgo.xml" hash="3e834a9a979970d5c82d963a56947a11"/><file name="mgo_CM.xml" hash="0cf9ba215d10e1f3db255adcccb3d6b8"/><file name="mk.xml" hash="3ee88bf8c02b4f244b5cd1d3ab617f45"/><file name="mk_MK.xml" hash="aeb740a529d8b51b53242d1f1cf59b2e"/><file name="ml.xml" hash="94d67dd84bc66f80d4a6ffaf27a2c508"/><file name="ml_IN.xml" hash="80849e5c197f5dd2b2ea0317f3517ca1"/><file name="mn.xml" hash="e6a18ab3a3c20fe7ab283cf6a901a549"/><file name="mn_Cyrl.xml" hash="9bdcd159b3be6e0ecf96795d5fc1e91e"/><file name="mn_Cyrl_MN.xml" hash="f11f2f4a083ef35c66ff0a10429b5614"/><file name="mr.xml" hash="f2073dc2a11fd9c7be8ba932e45b830a"/><file name="mr_IN.xml" hash="1623ff448071fe23a70309fa70ac531f"/><file name="ms.xml" hash="9b53207db5cc656f53ac5ea3d90195fd"/><file name="ms_Latn.xml" hash="cda2abbda8d3482f36361e946f37b5a8"/><file name="ms_Latn_BN.xml" hash="5740a4fdad13e0eb211736bf0a2f17ec"/><file name="ms_Latn_MY.xml" hash="c537239c8ae70b442dcbf67911f3fd4d"/><file name="ms_Latn_SG.xml" hash="05424711271e51b0e552063edd05b547"/><file name="mt.xml" hash="961881542802dc1cc9f20f8fcb774f45"/><file name="mt_MT.xml" hash="5282b27d9d6a57d726612a09395e6c22"/><file name="mua.xml" hash="8ebb1a4b5ef4baffddb2894b307f2cbc"/><file name="mua_CM.xml" hash="2df1fe2f39dc3402d5892946ab88f2ef"/><file name="my.xml" hash="64f4ef77afb342a522c3b4779ab19486"/><file name="my_MM.xml" hash="02d8bea58fd9bd5e8dc7796477ef5ce0"/><file name="naq.xml" hash="a29dfa41b2e1630f136a18b12d2c2324"/><file name="naq_NA.xml" hash="0ec1dfc6dc7eed7588f1d1bc41ad56dc"/><file name="nb.xml" hash="46eb58f192d18746c09c8c8582ddd8b1"/><file name="nb_NO.xml" hash="626d2f263762cde6e41328a0bf6768e3"/><file name="nb_SJ.xml" hash="02508dd6f1be1de58fefd7b1159564eb"/><file name="nd.xml" hash="db8baa59e10b31daafd068e55ba882da"/><file name="nd_ZW.xml" hash="ccd1724534080cdf1a784ae0435f7785"/><file name="ne.xml" hash="7cb434ada9a049184fd0a2e021012406"/><file name="ne_IN.xml" hash="84558af586315178078c8e91aa410d9d"/><file name="ne_NP.xml" hash="81a679056920fedc05dad2cda150ef53"/><file name="nl.xml" hash="9f122648b0ae9fbf47dc6364311c9b14"/><file name="nl_AW.xml" hash="d44d954375e2f11a3571f0849dc5b116"/><file name="nl_BE.xml" hash="8e255c2c3d01f7680e6b1931521d15c1"/><file name="nl_BQ.xml" hash="05ea3eec1520c8ef9889b627f3c11624"/><file name="nl_CW.xml" hash="b4b444e991046f1e3e3c44eaa6d825bb"/><file name="nl_NL.xml" hash="4e0467c9db5288462ceb8f78611f6fc5"/><file name="nl_SR.xml" hash="ac0e3ff1c6706ecd9ad0b727583e024e"/><file name="nl_SX.xml" hash="3081384591890c797dfc87c4f4ec40d2"/><file name="nmg.xml" hash="96a40607cf05ce8f8ecbd81edfe54188"/><file name="nmg_CM.xml" hash="e4b39732f25ed7f4fd5f8eeab2296cc0"/><file name="nn.xml" hash="df403882fc0d4fbde259805dbb578133"/><file name="nn_NO.xml" hash="bff2529dd25fc5eff4e45c62e57a6102"/><file name="nnh.xml" hash="604802e1f48c5efb5006478f6096cba2"/><file name="nnh_CM.xml" hash="0797c07c5503386e902db37bb81036a1"/><file name="nr.xml" hash="537dfb7c804216084ff12405a79e6363"/><file name="nr_ZA.xml" hash="deaad06361e3310f47a0ae239b2dde45"/><file name="nso.xml" hash="d8d03686f2a5498288ab934b1d23af35"/><file name="nso_ZA.xml" hash="b8d56986c8588034819ce4112447bb7a"/><file name="numberingSystems.xml" hash="978a66b09ff3a7fe924e5220ac632035"/><file name="nus.xml" hash="aeb47a867f44fc22028eea112a9f20d7"/><file name="nus_SD.xml" hash="5b01ebcdeb5e0925420a1ec5a81078e0"/><file name="nyn.xml" hash="7a00226944592e03fbf05992fc97cb37"/><file name="nyn_UG.xml" hash="f98eb55dcdecb237d0d5f4442e967df1"/><file name="om.xml" hash="d7dd5059b280e4e673d39c6681dedae6"/><file name="om_ET.xml" hash="a2bd53f37a0cbde29c75476d11efd951"/><file name="om_KE.xml" hash="6f499797aaf7cddf5c96510055b1cb6b"/><file name="or.xml" hash="a1f44afb1360bea5213e7769b0d555ab"/><file name="or_IN.xml" hash="b8384a249e94ac1d3aeccffe6456d213"/><file name="ordinals.xml" hash="8105f05e542d711fb1c58eda93ee1970"/><file name="os.xml" hash="d3994c255a9ed31b3b485e2a60100bb6"/><file name="os_GE.xml" hash="b707a294c3bda74ce1fe3de56d5a2065"/><file name="os_RU.xml" hash="ed7de0aca2851389edb27ec27cfbff14"/><file name="pa.xml" hash="eb25b28dccb7fc2b9e8a58529383e7ad"/><file name="pa_Arab.xml" hash="d066d05609c4bb72a91b66960df82d4c"/><file name="pa_Arab_PK.xml" hash="af6c1f47b0c9125afa5f1d8b4465afae"/><file name="pa_Guru.xml" hash="3b5761c3adfe0fd8f769757108a33d74"/><file name="pa_Guru_IN.xml" hash="962eb7156fcccfee1c3b62562bcb4c9e"/><file name="pl.xml" hash="4badef8c402fbce8a919fe0345018145"/><file name="pl_PL.xml" hash="9f5e5245cb2b2a52ef56e3fd69363f31"/><file name="plurals.xml" hash="4223a72c769da4553aeaffc82409128d"/><file name="postalCodeData.xml" hash="ee416690bc7b0b51c62a4f60df3c6e49"/><file name="ps.xml" hash="71320ee03ab67c4d86b2042a2a450044"/><file name="ps_AF.xml" hash="e2b047a904f02a454f193f37856e9f6c"/><file name="pt.xml" hash="6c0d496db88b044f4bccea7b2bcf5bb2"/><file name="pt_AO.xml" hash="502a761ed5e5ca0b44403ff8d0e85e94"/><file name="pt_BR.xml" hash="9ec9d29dec55f67013d4e3ce15799d05"/><file name="pt_CV.xml" hash="3f8377d6db982dc7b9cc6294ee963517"/><file name="pt_GW.xml" hash="bec710dffaed02976223f5671fb48ec5"/><file name="pt_MO.xml" hash="1df59a4a05e1141e225a7da25c58ec4b"/><file name="pt_MZ.xml" hash="b5b28ee99e7f12e1c14e015c3ecf5c4d"/><file name="pt_PT.xml" hash="66b28e650fb563d84b53da41a1f261b4"/><file name="pt_ST.xml" hash="7c96e96d8bf1b811ff3358073e3aeb63"/><file name="pt_TL.xml" hash="9e2647ac1cc2d8f949cd000ffc5dd2fd"/><file name="rm.xml" hash="aa5e41d750b8392990ce00c29f4feb4d"/><file name="rm_CH.xml" hash="3bef003a0204b4d2291ee73c46d8f1ee"/><file name="rn.xml" hash="80a76b1975488f778da8abe7dc0292db"/><file name="rn_BI.xml" hash="c5010d52f27f95cf794396339752dda6"/><file name="ro.xml" hash="fd309802d4e90aa4e51d9f014621e5b6"/><file name="ro_MD.xml" hash="4763fe9a5ac2d57fa9cb7bc5aaa09f7a"/><file name="ro_RO.xml" hash="a7f41f443fcc6daed26d608373a0ebcb"/><file name="rof.xml" hash="4d03559ef40f836156f5e516a9eaa5aa"/><file name="rof_TZ.xml" hash="99f8c6ad97c8acbade2a9f3553b57225"/><file name="root.xml" hash="f74f320723d5a31ba06aa2c79de43bd2"/><file name="ru.xml" hash="3aaf7853667c37781e3d886f364968c1"/><file name="ru_BY.xml" hash="931ca3d10a511ea18c705a22c8baaf1d"/><file name="ru_KG.xml" hash="edee35024102c3ffd1c9acd89f0c9c30"/><file name="ru_KZ.xml" hash="7d4138b25f5c8cbafead8f321fd1954e"/><file name="ru_MD.xml" hash="4d629ff877f4c3a1e214548dc7ecccaf"/><file name="ru_RU.xml" hash="ee8433fc8dbc67a22b31c6be08d13402"/><file name="ru_UA.xml" hash="33fe877250fbd7077b4edf45c50bf300"/><file name="rw.xml" hash="73b90e15bea65ad98ac5cea78e878d91"/><file name="rw_RW.xml" hash="c5cb01f5b236208dc96d3268cf85ffbb"/><file name="rwk.xml" hash="af9317a0322bd40302363d5e6bd4b291"/><file name="rwk_TZ.xml" hash="d0f470b223d25203a611bdb7c395c988"/><file name="sah.xml" hash="f4b2cb698fd582845afb18f984089ee7"/><file name="sah_RU.xml" hash="6ee074c02940d5e9a525a7b8a9c2176e"/><file name="saq.xml" hash="130d69870ed3f95808bced7bed701c3b"/><file name="saq_KE.xml" hash="008b90c332f06e019efc1d8e33f401b3"/><file name="sbp.xml" hash="158d785177f949347356d59dc7883ad8"/><file name="sbp_TZ.xml" hash="0d4f52a378680dcd6230f00cc8ed1f61"/><file name="se.xml" hash="10a3649dbfd8bdff0f8b8fe102b444ed"/><file name="se_FI.xml" hash="ea379a5c51168210274b50711f032355"/><file name="se_NO.xml" hash="0a890443d1477c9d275bb945b0c5b589"/><file name="seh.xml" hash="4361fff00579a2efd8d283a152ccc682"/><file name="seh_MZ.xml" hash="a3f4cc61fa6d995fa5d2cc7b193ee1ad"/><file name="ses.xml" hash="00e9cfea10372a6b62590346a596d054"/><file name="ses_ML.xml" hash="dc0cd9eabaf2c08d66007e6c31a6a477"/><file name="sg.xml" hash="e1bda394071d1796efc18e00467e425c"/><file name="sg_CF.xml" hash="ed51c88dd34a233c82150338436c250c"/><file name="shi.xml" hash="b57def0c24096d11985586f621c09159"/><file name="shi_Latn.xml" hash="61054fc24b89c1842a53be5f5e6016e7"/><file name="shi_Latn_MA.xml" hash="d0f90c1ab8e1b3f7340fc2b77f37ff4f"/><file name="shi_Tfng.xml" hash="4670d2933f9ff2b00c787336498fc149"/><file name="shi_Tfng_MA.xml" hash="271bc282c75731c883ea8fbbd72361b8"/><file name="si.xml" hash="8a27b7c7c9bcdb45049974693c8db484"/><file name="si_LK.xml" hash="b637f75035a4fdfe10f0d3fb39781db1"/><file name="sk.xml" hash="c8b930f68837a7fcaa7e0c34aec1235b"/><file name="sk_SK.xml" hash="7beda18d4fd023382190bc9797d51cfc"/><file name="sl.xml" hash="51bf1ccaecc51b117ea843100b2bc782"/><file name="sl_SI.xml" hash="b71c5b3968b50875758dfdf825c6b21a"/><file name="sn.xml" hash="9aa3b734aa010864b0ff582a67e677e8"/><file name="sn_ZW.xml" hash="24a9dfc3030bf253882c9d661eaef17c"/><file name="so.xml" hash="5b1ade5ca9f6416d2a42aaeefe08803b"/><file name="so_DJ.xml" hash="2850875e1e4d197c81948325e8741024"/><file name="so_ET.xml" hash="6210a645a2c598eed597bab39f36d557"/><file name="so_KE.xml" hash="208c20fcd4d27f3ea7a63a1ccd70b64c"/><file name="so_SO.xml" hash="65f7b820f3de2da5fb6adbbf3fed4244"/><file name="sq.xml" hash="9814afac7a465e293306c2036e97397a"/><file name="sq_AL.xml" hash="6b08a2f02bd463c8854d377761d14ad4"/><file name="sq_MK.xml" hash="7b1a4a47c69c2c11539ecf5f2b306dbf"/><file name="sq_XK.xml" hash="a4be94b459a7ddf3c64782b932c43edd"/><file name="sr.xml" hash="a907b6ed4a9233dce8fb2cafacbb9d07"/><file name="sr_Cyrl.xml" hash="df126a848168eebb92d2cb08b0f47051"/><file name="sr_Cyrl_BA.xml" hash="379078c0a256b4f9ec7111cc9f75a2e4"/><file name="sr_Cyrl_ME.xml" hash="fdc47e86343568ccbf1e619800f26614"/><file name="sr_Cyrl_RS.xml" hash="f269bfd320ba2b38a6a614ca4da321a9"/><file name="sr_Cyrl_XK.xml" hash="8e3b5caa0e9997575201e3f7823a81ac"/><file name="sr_Latn.xml" hash="b26fdb85fcea35960444294ab6f10b21"/><file name="sr_Latn_BA.xml" hash="8abd2f52848f701a485ce865e97b851a"/><file name="sr_Latn_ME.xml" hash="49c92f426cc5a5188399c80878686f83"/><file name="sr_Latn_RS.xml" hash="713a42425709d2a2448ed3ceefed8d07"/><file name="sr_Latn_XK.xml" hash="d9f80fc5757c8be78a8bf06b0090bb1e"/><file name="ss.xml" hash="1c8e4708d8197d98b32e84db842531ac"/><file name="ss_SZ.xml" hash="36bd3ae71800ee1509cb005345b7d0d4"/><file name="ss_ZA.xml" hash="929a6fc019f32616331578d55a36412a"/><file name="ssy.xml" hash="4cd34c993f3f737c52ef02dc0c65180c"/><file name="ssy_ER.xml" hash="6500f7ea9752b2272ff4c93530514345"/><file name="st.xml" hash="13de7725514e5dd58f49e0b01ec7858f"/><file name="st_LS.xml" hash="16fac9f2505893a9ae5df24174ec8e94"/><file name="st_ZA.xml" hash="c769d53933a0816218637180bfe3b1e6"/><file name="supplementalData.xml" hash="7c64143e835c0a2facebe573b95c735d"/><file name="supplementalMetadata.xml" hash="89562abe6d40c4c7245a8c465905e618"/><file name="sv.xml" hash="157cbade1293f5bf503b8ce03cac9260"/><file name="sv_AX.xml" hash="eb9596e23c3e3597f9167c56bc456ba8"/><file name="sv_FI.xml" hash="c7985fcaa170e42535eebb8f2821fd8c"/><file name="sv_SE.xml" hash="a234be39c4fe51d5360e867ef057e9cc"/><file name="sw.xml" hash="baa99fb8dae1057541cd174d8c479f63"/><file name="sw_KE.xml" hash="841c4e403526c85c138ec30908f0e639"/><file name="sw_TZ.xml" hash="d8c70853021414f35fff5160e777afc4"/><file name="sw_UG.xml" hash="2f39a025d909e27a3b4d42ada4494f44"/><file name="swc.xml" hash="b78d391b482ebeaaa8d2589248b99475"/><file name="swc_CD.xml" hash="7ef627a3af8e94ce44e118facc634280"/><file name="ta.xml" hash="f14aabe0b254b16a7656cf0eb924a937"/><file name="ta_IN.xml" hash="a3cf28d4dffdfb99fbd06c56f7407690"/><file name="ta_LK.xml" hash="c4cb7d38b9ab64f09398af90233929b6"/><file name="ta_MY.xml" hash="50b7aa25e1de2ba3060cf7f1542dbb1e"/><file name="ta_SG.xml" hash="467cf5081dce3961ff108329da18461f"/><file name="te.xml" hash="9000f302efec5389067682dcb37713ec"/><file name="te_IN.xml" hash="46c5a0f8ad33a8207687131b1e30dbc3"/><file name="telephoneCodeData.xml" hash="df7976ae3ed9a46df9b7a3d153a08782"/><file name="teo.xml" hash="1a54151c61645deebd146ce8167ebb7b"/><file name="teo_KE.xml" hash="28904dbd23feee396d235bddafb88a5f"/><file name="teo_UG.xml" hash="a3c2615908baa53ef6c06c1bbc46d03f"/><file name="tg.xml" hash="b0a784936ff2b4d986bea0a5abaafc41"/><file name="tg_Cyrl.xml" hash="dad9b0de0bca8885769e3eb3b986ed38"/><file name="tg_Cyrl_TJ.xml" hash="ecd76f8a9c11ea36f23aecbd4ba10f94"/><file name="th.xml" hash="93a93b50d5bc06c3aba030a2bc8f3a2c"/><file name="th_TH.xml" hash="16920f2948dfc0169fa4120b6bef4c6c"/><file name="ti.xml" hash="68ba067a766e83fa56b3f8b64e911709"/><file name="ti_ER.xml" hash="fc1625e77b8ee3b39e5a21a5778c6352"/><file name="ti_ET.xml" hash="eda9e0f13702f4f4d6c56bf8702bc158"/><file name="tig.xml" hash="dcbea52ddac1a8641439c191ef8cad3c"/><file name="tig_ER.xml" hash="9e8951b4b641d755277bba697641eeb4"/><file name="tn.xml" hash="5ecf790feae7a56e7d3dda69a3dcdd29"/><file name="tn_BW.xml" hash="5db54fb06600c505374663377ae3c87d"/><file name="tn_ZA.xml" hash="5ffaceb20f45593cf1526096d44811ae"/><file name="to.xml" hash="6abeea01835e1fa2e62a489842917a71"/><file name="to_TO.xml" hash="e17fa8026e023e8614eb6fe68b223300"/><file name="tr.xml" hash="a73038379e7e0396200158e0cb9b2101"/><file name="tr_CY.xml" hash="c02e5d602dc71097faf6e40c43c00df5"/><file name="tr_TR.xml" hash="98e092d092bd6efdacd4c9181bdf1269"/><file name="ts.xml" hash="d4de7842ad3ed50f09e585aeb8fd2b48"/><file name="ts_ZA.xml" hash="a058d38e5fc52060f992a09c44bd2dd4"/><file name="twq.xml" hash="8cb693f4457b01d524eb4dd3a9202fee"/><file name="twq_NE.xml" hash="f3887ed69d01de60ea150fb49741dd7e"/><file name="tzm.xml" hash="184e66cab1c6bfb1c1ede84b1b9b8d5d"/><file name="tzm_Latn.xml" hash="c48b72028daead39c63e06be5940b06f"/><file name="tzm_Latn_MA.xml" hash="adeed44054a352a8a95fb63a47b1277d"/><file name="ug.xml" hash="0048db54db7e96e66309f27990302912"/><file name="ug_Arab.xml" hash="b0916370f9a3dcbe9f9ef7f4941e83ff"/><file name="ug_Arab_CN.xml" hash="ca617ed54b6b547d9cd4929653765e69"/><file name="uk.xml" hash="82e297c9a0e35a239300e9d781246ca7"/><file name="uk_UA.xml" hash="f1f43742973c3e0684078ad1585c09a8"/><file name="ur.xml" hash="4330b97cdc580fd937fb4b48c30138dc"/><file name="ur_IN.xml" hash="620558a8d2b16341b990f739d96fa656"/><file name="ur_PK.xml" hash="4929ef93fcd09c110306500b7b5df200"/><file name="uz.xml" hash="e885a45d72df08108a5fb5553caf5650"/><file name="uz_Arab.xml" hash="bbccf5949290b9a88bdb05112ef0f1f1"/><file name="uz_Arab_AF.xml" hash="e8b2a9bcdfcddf5fe0923bdb79586e3b"/><file name="uz_Cyrl.xml" hash="f11985a357906a9764a2eeae61d87834"/><file name="uz_Cyrl_UZ.xml" hash="e34ac326ca872838cb51f7d95f2cad57"/><file name="uz_Latn.xml" hash="6d1de019d75988a154546b7a6ec4cecb"/><file name="uz_Latn_UZ.xml" hash="9f0dd4f61e4ad966fd33e26c0af5d722"/><file name="vai.xml" hash="4ccc7bd3230a4395017327e278bea5d7"/><file name="vai_Latn.xml" hash="78b6884327d1a568c1dcb55edcc8e8c7"/><file name="vai_Latn_LR.xml" hash="d60cdef15dbd84e66ebf6532935f2735"/><file name="vai_Vaii.xml" hash="4d3b525d05e85213d169a04051aed2cd"/><file name="vai_Vaii_LR.xml" hash="64e621f56506d7b70656d056ed8e8214"/><file name="ve.xml" hash="0238fc0b60b7f9f80a821455e85a26df"/><file name="ve_ZA.xml" hash="cfd73cf7fc6d3bef016b3dea6c1464c2"/><file name="vi.xml" hash="1ec60312f7c6e419dc883676a3cfb10b"/><file name="vi_VN.xml" hash="cfb0ceae9f2e78e0459f062016230998"/><file name="vo.xml" hash="a696981962fe9a84ccf27cd4f46a07a6"/><file name="vo_001.xml" hash="ca84f69da9df24a4e409104c54a8a3d5"/><file name="vun.xml" hash="2838dac67405ebb6515ed35b983f13c5"/><file name="vun_TZ.xml" hash="5c00fe9a927fa96193d8be8f22c4ee99"/><file name="wae.xml" hash="7a6a03e67b505d33af84383427ff1db9"/><file name="wae_CH.xml" hash="bc6ad0fbf82a5317ade928730b115b91"/><file name="wal.xml" hash="5fa5a9a4263c2c0c75cb61e137ec19b7"/><file name="wal_ET.xml" hash="fe6ba6e078852d9949dc023b20e40462"/><file name="windowsZones.xml" hash="bb1d22fd1c7e1073f31559d4ec4f6ea0"/><file name="xh.xml" hash="c4561fd383180394c1719f7af01252ed"/><file name="xh_ZA.xml" hash="7cc6e52fd5bbde7d7a09835462c9005a"/><file name="xog.xml" hash="d159722255a22bf4b113822364e3aa42"/><file name="xog_UG.xml" hash="c9d9ce8325ccd943d17be076e2348509"/><file name="yav.xml" hash="7cd6b28230ea1b592f4f6dc656d7dac6"/><file name="yav_CM.xml" hash="d99d7f9815108fe4040253b525fb1e65"/><file name="yo.xml" hash="94b71c3a56a7d571cdd2cdcca0e3639d"/><file name="yo_BJ.xml" hash="ad14fab000b1bdba3ad0959b41692125"/><file name="yo_NG.xml" hash="1381c16f38223fcd4e645a66f06d3947"/><file name="zgh.xml" hash="47980624ea61e97a271f180c98a7f012"/><file name="zgh_MA.xml" hash="7e72d86646a8b5045dfbedd721e5d0f1"/><file name="zh.xml" hash="7ce5cf9353eaeee426d5d5eb87670dfb"/><file name="zh_Hans.xml" hash="bdb68fe0878c430dc788e383b389dc2c"/><file name="zh_Hans_CN.xml" hash="24a14d8c675ae0c5b2fd211477240405"/><file name="zh_Hans_HK.xml" hash="7c82d550690d9ea63bc19cc76fbb61de"/><file name="zh_Hans_MO.xml" hash="9e4291c5bb0facb592b3ea3c14147e72"/><file name="zh_Hans_SG.xml" hash="01f85db499b693f4d3032e8683db390d"/><file name="zh_Hant.xml" hash="fb57450622d2383ac2f9d0e9c03872d0"/><file name="zh_Hant_HK.xml" hash="8648266bec5d9594fff57e030ff88e53"/><file name="zh_Hant_MO.xml" hash="3625e00e40fe8377de3a9a03628657ad"/><file name="zh_Hant_TW.xml" hash="66f700074df27309b3c6c71701d3b9b0"/><file name="zu.xml" hash="6542a2fe4304ba6289f66b2a68bbbcc7"/><file name="zu_ZA.xml" hash="db4d81680d06e598e322a26e9255ea69"/></dir><file name="Data.php" hash="8fa12d0abbc5557b89cd824b0e18d3bb"/><file name="Exception.php" hash="48210cc1272d8350acafdb8b26e86081"/><file name="Format.php" hash="eb7d886a80ca361bd0c38ec54b5d8bf2"/><dir name="Math"><file name="Exception.php" hash="37609bd0e120bcb0ed890523ac7cd35e"/><file name="PhpMath.php" hash="aa289ad314dc08e0abf97a3f147b6750"/></dir><file name="Math.php" hash="8f03d1a239fa7f642dd43ef7f7c642ad"/></dir><file name="Locale.php" hash="aad364df1a2dcad576c9ae09d94f46d8"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Mage_All_Latest-1.9.4.0.xml b/var/package/Mage_All_Latest-1.9.4.0.xml
deleted file mode 100644
index c040320..0000000
--- a/var/package/Mage_All_Latest-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_All_Latest</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Metapackage for latest Magento 1.9.0.0 release</summary>
-    <description>Metapackage for latest Magento 1.9.0.0 release</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:07</time>
-    <contents><target name="mage"><dir name="pkginfo"><file name="Mage_All_Latest.txt" hash=""/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Interface_Adminhtml_Default</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Interface_Frontend_Default</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Interface_Install_Default</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Downloader</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Centinel</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Interface_Frontend_Base_Default</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Phoenix_Moneybookers</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Compiler</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Magento_Mobile</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Cm</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Cm_RedisSession</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Interface_Frontend_Rwd_Default</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_All_Latest-1.9.4.1.xml b/var/package/Mage_All_Latest-1.9.4.1.xml
new file mode 100644
index 0000000..7b26480
--- /dev/null
+++ b/var/package/Mage_All_Latest-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_All_Latest</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Metapackage for latest Magento 1.9.0.0 release</summary>
+    <description>Metapackage for latest Magento 1.9.0.0 release</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:51</time>
+    <contents><target name="mage"><dir name="pkginfo"><file name="Mage_All_Latest.txt" hash=""/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Adminhtml_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Install_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Downloader</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Centinel</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Base_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Phoenix_Moneybookers</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Compiler</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Magento_Mobile</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Cm</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Cm_RedisSession</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Rwd_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Centinel-1.9.4.0.xml b/var/package/Mage_Centinel-1.9.4.0.xml
deleted file mode 100644
index a111f08..0000000
--- a/var/package/Mage_Centinel-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Centinel</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>3D Secure Card Validation</summary>
-    <description>An integration with Cardinalcommerce Centinel service. Provides option to validate Visa and Mastercard cards for eliminating possible fraudlent order placement attempts. Adds information about Electronic Commerce Identifier, that designates liability for chargeback.</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:07</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Centinel"><dir name="Block"><dir name="Adminhtml"><dir name="Validation"><file name="Form.php" hash="580157479767118dee89edaed4a76113"/></dir><file name="Validation.php" hash="f2d0ef35b0d1e0c44d76242fa8759056"/></dir><dir name="Authentication"><file name="Complete.php" hash="dea665844740663a5b3b73d6d9488d18"/><file name="Start.php" hash="ba6b0d9be0b88a7d091ac5b728f582c9"/></dir><file name="Authentication.php" hash="ca8f75378fdfa3be9e0f17ecccb19155"/><file name="Logo.php" hash="dc4a3574a704c526087cac985c2a80e3"/></dir><dir name="Helper"><file name="Data.php" hash="24d32ec5d70b80c141c1271847f0a13f"/></dir><dir name="Model"><dir name="Api"><file name="Client.php" hash="85ed4326d7f65d3ab01b3f9fe96e1a7f"/></dir><file name="Api.php" hash="710f50c969fb12c68886fe3b7ac8fb62"/><file name="Config.php" hash="007459edff2f1643b066cb5250643d69"/><file name="Observer.php" hash="711718e38cee3100a3a1ccc80fd65a51"/><file name="Service.php" hash="fd85486672f08eb04b3b26553c453e69"/><file name="Session.php" hash="6e15f94b628e241976a28cea8f9a7248"/><dir name="State"><file name="Jcb.php" hash="77fafb70b39703157708caff6b29e805"/><file name="Mastercard.php" hash="6f024a9bad1bed64c95e103debedadb6"/><file name="Visa.php" hash="18798952155a487795444f03b656b00b"/></dir><file name="StateAbstract.php" hash="3986af10adf4cb6cb88ed5a5bfa19037"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Centinel"><file name="IndexController.php" hash="f9ced0c082cdd3b850f7d68f1b9344d2"/></dir></dir><file name="IndexController.php" hash="3285b063676d3ccce91a5ca18ff1f8a0"/></dir><dir name="etc"><file name="config.xml" hash="98edbbf17c1f45426aa398bc353023ed"/><file name="system.xml" hash="8b43b85598f61adf4a733c64571a1bb7"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Centinel.xml" hash="dff618646b6bc218832ef3e74fbfabb9"/></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><dir name="sales"><file name="centinel.js" hash="97e8ee7196b3190d7b89fa9a1862ccba"/></dir></dir></dir></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="eda63e314921612475ff67612ff8e964"/><file name="start.phtml" hash="a61848102f51ccb5658d56c41ef8a1f8"/></dir><dir name="validation"><file name="form.phtml" hash="db8c9333d07c1ce4d70f58e6b19ec922"/></dir></dir></dir><dir name="layout"><file name="centinel.xml" hash="a489258d441c8576868bedf0847cd1e7"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="fc86cabbbea065226fa0d10e96cee144"/><file name="start.phtml" hash="1feeae7ab6443bcb40989c8385dd864e"/></dir><file name="authentication.phtml" hash="ab19ae6f5fd16fa4c8a6def308a04a13"/><file name="logo.phtml" hash="ca126d969c7820f43e78716686261222"/></dir></dir><dir name="layout"><file name="centinel.xml" hash="8db835f09e4060d10e3fcc5f2381fe4c"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Centinel.csv" hash="20f331c149ccf32faabdd406626805e0"/></dir></target><target name="magelib"><dir name="3Dsecure"><file name="CentinelClient.php" hash="e8459bd7d542e38058529e9bbb27ca25"/><file name="CentinelErrors.php" hash="e99aa9e865cc56beb2cf99d616ff0ceb"/><file name="XMLParser.php" hash="d089f3a81ac81378c889eee73a52f413"/></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="centinel"><file name="sc_learn_62x34.png" hash="7d6ec4b19f8eeb6baa2cddd5d4274f87"/><file name="v_activate_steps.gif" hash="005312b14c6aed41e8a47c4acaac7c1a"/><file name="vbv_ltbg_71x57.png" hash="324e5de7f6c75dc3cecb61646113ac41"/></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Centinel-1.9.4.1.xml b/var/package/Mage_Centinel-1.9.4.1.xml
new file mode 100644
index 0000000..69b41ba
--- /dev/null
+++ b/var/package/Mage_Centinel-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Centinel</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>3D Secure Card Validation</summary>
+    <description>An integration with Cardinalcommerce Centinel service. Provides option to validate Visa and Mastercard cards for eliminating possible fraudlent order placement attempts. Adds information about Electronic Commerce Identifier, that designates liability for chargeback.</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:51</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Centinel"><dir name="Block"><dir name="Adminhtml"><dir name="Validation"><file name="Form.php" hash="6fd9bc0ba636aca1277bd74884dec37a"/></dir><file name="Validation.php" hash="ace0940b991411bf8a90aa2dff370af9"/></dir><dir name="Authentication"><file name="Complete.php" hash="92c6cadff8c32007edfe0fbf75f8fac6"/><file name="Start.php" hash="96e03cb1f01a73d2a7bae807d02c6cda"/></dir><file name="Authentication.php" hash="7d2047ae6dff17172adfa3e5fe0f3faa"/><file name="Logo.php" hash="df7454a04c00cebfbc1a70496c264350"/></dir><dir name="Helper"><file name="Data.php" hash="60e2be29acc4f8f1c95650907fc9ff13"/></dir><dir name="Model"><dir name="Api"><file name="Client.php" hash="772a33df44fa004b8bbc5c29f7433eb9"/></dir><file name="Api.php" hash="c59e3344aa844b6b8e16e54bc42bb928"/><file name="Config.php" hash="18fc369415ccaf4d198ad8b9544cb247"/><file name="Observer.php" hash="5b0ec1ebe73e64b1c10cd036821deb4e"/><file name="Service.php" hash="e9d7280d375e3917a6b222da6f8dc8d1"/><file name="Session.php" hash="939f4dd80c193532422168068e3670b2"/><dir name="State"><file name="Jcb.php" hash="bc09bea61265195fed07b56334b4e465"/><file name="Mastercard.php" hash="65f2449e45865b451b0a5c08f405bf27"/><file name="Visa.php" hash="d27c247165853ab9995fe8874787cec1"/></dir><file name="StateAbstract.php" hash="a07849abad50e3904813643fb2e57d52"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Centinel"><file name="IndexController.php" hash="aa97d871be6215308dcb3d2973fb3f3f"/></dir></dir><file name="IndexController.php" hash="683e2aae21a7e65e97caeaa32af7291d"/></dir><dir name="etc"><file name="config.xml" hash="0c19be00fc21ecfe4a2145961024b8e7"/><file name="system.xml" hash="52052df926f875432acc5bb2345672a5"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Centinel.xml" hash="9715db6c2006854333940de409752e25"/></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><dir name="sales"><file name="centinel.js" hash="0d0d4610d5b94cac84a94d17cc9019fa"/></dir></dir></dir></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="a34b644c5d957779a890cb15c12ff17a"/><file name="start.phtml" hash="7b0b93864ab507f7bc4f1ce3e75b1f8f"/></dir><dir name="validation"><file name="form.phtml" hash="bff510bf825b8f035eae39514c061ba2"/></dir></dir></dir><dir name="layout"><file name="centinel.xml" hash="b2ed29dd8d809adc62d920fa6bc8a6cd"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="48266633b7cc79888746a6e215a91993"/><file name="start.phtml" hash="88b0735a527b685af293b8a99562e469"/></dir><file name="authentication.phtml" hash="fd9646f787de09b08eebeba75fa1269c"/><file name="logo.phtml" hash="55803993cec3af6f659b7529e8e76528"/></dir></dir><dir name="layout"><file name="centinel.xml" hash="89cd014042e539a36aa384b35702cec5"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Centinel.csv" hash="20f331c149ccf32faabdd406626805e0"/></dir></target><target name="magelib"><dir name="3Dsecure"><file name="CentinelClient.php" hash="e8459bd7d542e38058529e9bbb27ca25"/><file name="CentinelErrors.php" hash="e99aa9e865cc56beb2cf99d616ff0ceb"/><file name="XMLParser.php" hash="d089f3a81ac81378c889eee73a52f413"/></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="centinel"><file name="sc_learn_62x34.png" hash="7d6ec4b19f8eeb6baa2cddd5d4274f87"/><file name="v_activate_steps.gif" hash="005312b14c6aed41e8a47c4acaac7c1a"/><file name="vbv_ltbg_71x57.png" hash="324e5de7f6c75dc3cecb61646113ac41"/></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Compiler-1.9.4.0.xml b/var/package/Mage_Compiler-1.9.4.0.xml
deleted file mode 100644
index a9fb317..0000000
--- a/var/package/Mage_Compiler-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Compiler</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This module compiles all files of a Magento installation and creates a single include path to increase performance</summary>
-    <description>This module compiles all files of a Magento installation and creates a single include path to increase performance</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:07</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Compiler"><dir name="Block"><file name="Process.php" hash="41e18d0f4970541a185bf4460c23df3b"/></dir><dir name="Helper"><file name="Data.php" hash="0f022c4fa92031db88c3bb3d53577c6c"/></dir><dir name="Model"><file name="Process.php" hash="6c145b0f377f3226e48ae10f989632cc"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Compiler"><file name="ProcessController.php" hash="3f37cdb7bf83444821dec1117e673df2"/></dir></dir><file name="ProcessController.php" hash="375cee8ba1d2069e27d4604794856aa6"/></dir><dir name="etc"><file name="adminhtml.xml" hash="0e29017120ec1f3884bd59e8dfb06f12"/><file name="compilation.xml" hash="7f3dca4c1193a7635b9bd57e597a7ffd"/><file name="config.xml" hash="a766a350cabbeda305fcbfd58738e041"/></dir></dir></dir></target><target name="mage"><dir name="includes"><file name="config.php" hash="9ef6137dbf060ea48b1a976a08518976"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Compiler.xml" hash="2e87b9c6f4d39f0b8ecf21f3680d2df9"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="compiler.xml" hash="13c580b1937e895f1d6d905aba5a9a9c"/></dir><dir name="template"><dir name="compiler"><file name="process.phtml" hash="6e27c0103b9bf9bf1a2a4592160a9f8b"/></dir></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Compiler.csv" hash="caa1d67e6c508421a8c8c234ae204c5d"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Compiler-1.9.4.1.xml b/var/package/Mage_Compiler-1.9.4.1.xml
new file mode 100644
index 0000000..4bfe825
--- /dev/null
+++ b/var/package/Mage_Compiler-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Compiler</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This module compiles all files of a Magento installation and creates a single include path to increase performance</summary>
+    <description>This module compiles all files of a Magento installation and creates a single include path to increase performance</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:51</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Compiler"><dir name="Block"><file name="Process.php" hash="79cc3d9a2d244127b319875d052da4f6"/></dir><dir name="Helper"><file name="Data.php" hash="cd4cbd2162100486a8c990610627fbff"/></dir><dir name="Model"><file name="Process.php" hash="8e6c24f7292dc203b2bafe8201a57c14"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Compiler"><file name="ProcessController.php" hash="4bf432496465a488fefef18f308a5867"/></dir></dir><file name="ProcessController.php" hash="10870e0636c294e1ae6733ac332f6e6c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9d044840914fa8a941aa741ab75217e7"/><file name="compilation.xml" hash="878103b6f50bf2cc1f3075b60a8cccb5"/><file name="config.xml" hash="b2b7469ba9b92e9656d4c828feacdd0c"/></dir></dir></dir></target><target name="mage"><dir name="includes"><file name="config.php" hash="7a7b61cc43b0775e70fb9e556cbe2c37"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Compiler.xml" hash="f90a06b926ba6e34d37959842938089f"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="compiler.xml" hash="fcf972e9bc3e481a1a52f29763d89ea8"/></dir><dir name="template"><dir name="compiler"><file name="process.phtml" hash="5d5d9577753849bba49da416bcfc5e19"/></dir></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Compiler.csv" hash="caa1d67e6c508421a8c8c234ae204c5d"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Core_Adminhtml-1.9.4.0.xml b/var/package/Mage_Core_Adminhtml-1.9.4.0.xml
deleted file mode 100644
index 5aa23d7..0000000
--- a/var/package/Mage_Core_Adminhtml-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Core_Adminhtml</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Administration Panel</summary>
-    <description>Magento Administration Panel</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:07</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Adminhtml"><dir name="Block"><file name="Abstract.php" hash="8806fa4ecf7bf067bbf1fcd7f1823c2d"/><dir name="Api"><file name="Buttons.php" hash="314177e483ba9bfcda54a53204655552"/><file name="Editroles.php" hash="a67fc165250ada3054e77c7b2b744d5a"/><file name="Edituser.php" hash="a2ffedd09bf0cf135b22c6923ce3191e"/><dir name="Grid"><file name="Role.php" hash="74a101ea38940feb0305b7634727e0ad"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="6524240d05cad8f8596e469da9f5c46f"/></dir></dir><file name="Role.php" hash="a664b5c117989ac16ce1764d90cda9f8"/><file name="Roles.php" hash="f3460089fc5aa7ffa7397c5b29fbe6da"/><dir name="Tab"><file name="Roleinfo.php" hash="e56f4c8e096e824470ccccee9cf51c43"/><file name="Rolesedit.php" hash="55c4f22af226e719d8d2b5eac16f80a2"/><file name="Rolesusers.php" hash="8822621843ff9f3418e8e4caaa03a295"/><file name="Userroles.php" hash="ea1f5256d1a622c51633e72f96b11926"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="b7f5c52dcc1ce3282dadc3eb0634097f"/><dir name="Tab"><file name="Main.php" hash="14e9bc7497923208e006460246adf99e"/><file name="Roles.php" hash="104d49f856280f8fed5a0f578eb3ece1"/></dir><file name="Tabs.php" hash="0604ea459c83ebf74c1e6a9c07a8ac1f"/></dir><file name="Edit.php" hash="bb6065d8bcb146ba1a5b592a9bbbaf65"/><file name="Grid.php" hash="eadf6097acdca68b33d657fd2da5c0a2"/></dir><file name="User.php" hash="27b8a4e95ce9787cd7186978f86d4bdb"/><file name="Users.php" hash="1037a64678b2b8cd122928935c2da5ab"/></dir><dir name="Backup"><file name="Dialogs.php" hash="036a1bd12bd784b6f93899c39d06b072"/><file name="Grid.php" hash="4751549b8d085c91b4f8d423cd116290"/></dir><file name="Backup.php" hash="d1e3ad3ed2cf8075616c88a7297b7d1d"/><dir name="Cache"><file name="Additional.php" hash="5ec255f6146e03b9024c3c99ea34f90a"/><file name="Grid.php" hash="a0184efcd8d09b943cc18936ca232133"/><file name="Notifications.php" hash="4bff39aeefd4f298502f9e3c13fc7b4a"/></dir><file name="Cache.php" hash="3d1fb11560c2c74aff649fa784599d90"/><dir name="Catalog"><dir name="Category"><file name="Abstract.php" hash="c952be2913085f69488927b8bb6f2f66"/><dir name="Checkboxes"><file name="Tree.php" hash="42830b006c7739c14deb63a25507c58c"/></dir><dir name="Edit"><file name="Form.php" hash="fdef9a0013f663496d88219074ebb010"/></dir><file name="Edit.php" hash="74c11841cdbb8078921abbc770e66c4f"/><dir name="Helper"><file name="Image.php" hash="6ee023da9f4558dccec489aa6909592e"/><file name="Pricestep.php" hash="e5410530e4d352ebf811800319178f1e"/><dir name="Sortby"><file name="Available.php" hash="a1d1966c139c466daad8841e388d900e"/><file name="Default.php" hash="12a0a94ca2aa87fdbe555007d7ff1b37"/></dir></dir><dir name="Tab"><file name="Attributes.php" hash="27dc928629025a551037c718a49cdd0d"/><file name="Design.php" hash="37da8d7465aee6246ead6a5f115f8848"/><file name="General.php" hash="484c9431aae47436419f49cfeb0d1e44"/><file name="Product.php" hash="32f1ff555c8f7111312b49c7b1c4844d"/></dir><file name="Tabs.php" hash="83c70ffb9629c8b58d703880b998f631"/><file name="Tree.php" hash="1d0b70578389e31df91ef29656ebc5f7"/><dir name="Widget"><file name="Chooser.php" hash="af29b5edf4ffd47a08e4f04930de2322"/></dir></dir><dir name="Form"><dir name="Renderer"><dir name="Attribute"><file name="Urlkey.php" hash="ff69c8e2daa9e63d3053f8de8e433717"/></dir><dir name="Config"><file name="DateFieldsOrder.php" hash="f4aa2523db0ec199b675826a276d4eef"/><file name="YearRange.php" hash="19eb0dc5aac7008aa158c20593fe1f73"/></dir><dir name="Fieldset"><file name="Element.php" hash="fe445f4119b469427d0ddb82ef6d0a5d"/></dir></dir></dir><file name="Form.php" hash="cc0529c03910aae1a4f8864b208835aa"/><dir name="Helper"><dir name="Form"><dir name="Wysiwyg"><file name="Content.php" hash="ed2b992dbb3e35d2b53908f3ae61f3fe"/></dir><file name="Wysiwyg.php" hash="78e8a96aa71401732436742d422ba41b"/></dir></dir><dir name="Product"><dir name="Attribute"><dir name="Edit"><file name="Form.php" hash="5ab50a6f32d205a2fd6b01853c526d1f"/><dir name="Tab"><file name="Front.php" hash="3de471c33114ff3c4356776558a27093"/><file name="Main.php" hash="a9691fc5cf89a61e399c91ad478ee7dc"/><file name="Options.php" hash="1366c27c928649de43e5f60819a12f59"/><file name="System.php" hash="c4be263ded4c331c25dcb06bc8241121"/></dir><file name="Tabs.php" hash="32594f40561239d5739a05d6333d35d7"/></dir><file name="Edit.php" hash="8998b1ff611debb250c07675ebb25e1c"/><file name="Grid.php" hash="824acc4402594b5d668b0a2cc7693059"/><dir name="New"><dir name="Product"><file name="Attributes.php" hash="0d8df5753ec6395f6e040489fc924c53"/><file name="Created.php" hash="272b92f03dcb132bd93cbce18c4717e4"/></dir></dir><dir name="Set"><file name="Grid.php" hash="8235e7536fb95f457c7804bdb359e67e"/><dir name="Main"><file name="Formattribute.php" hash="72788cb0c35e83b16cd297c72816e271"/><file name="Formgroup.php" hash="1357da9d086b7cbea716beaeb4dae246"/><file name="Formset.php" hash="811159896ff795a3f0158e227534fecf"/><dir name="Tree"><file name="Attribute.php" hash="a0c77fed4a8649aa5fe6cfffc186edd2"/><file name="Group.php" hash="f94a1f39ee14d5abb5d8f44e2d97b700"/></dir></dir><file name="Main.php" hash="87425ca70751a94f82cbb131c043c10f"/><dir name="Toolbar"><file name="Add.php" hash="b6948be8c4e92b8ea10edce28dcef91c"/><dir name="Main"><file name="Filter.php" hash="764f4f5e7ed0c87e42f5d9f295ead025"/></dir><file name="Main.php" hash="8ac0042772c63c554242405a190924be"/></dir></dir></dir><file name="Attribute.php" hash="97a860d3c3875affd812362b8a1138dd"/><dir name="Composite"><file name="Configure.php" hash="536bb87840aceb2ad9b8351b8463f4cc"/><file name="Error.php" hash="6c3e478bbac4b301f5a0cf4073432c54"/><dir name="Fieldset"><file name="Configurable.php" hash="53c7bf96d856185b689a2f79514d33ae"/><file name="Grouped.php" hash="b53f2fe7e8686e8f5dfa9864bebf07ee"/><file name="Options.php" hash="2590d50c524e414fb9faaa2fb2dde011"/><file name="Qty.php" hash="2a00e29ed9077301533908d36ecfc770"/></dir><file name="Fieldset.php" hash="c10b07158433cf6139e498f6d220285c"/><dir name="Update"><file name="Result.php" hash="82ad1be2457016dc38a011c7e41e9b25"/></dir></dir><file name="Created.php" hash="5b1e14203080ccec46695956256e9e0c"/><dir name="Edit"><dir name="Action"><dir name="Attribute"><dir name="Tab"><file name="Attributes.php" hash="e7ec07231959a9f8b1021197e3b2b357"/><file name="Inventory.php" hash="7ef543269aa2349ce84f4e972405052d"/><file name="Websites.php" hash="4884477aeb158616d346b06f8cff3c6e"/></dir><file name="Tabs.php" hash="36ec4c5454d6a364028a1317f7de5f0d"/></dir><file name="Attribute.php" hash="b8e61c893d43d8ff7f44e01569292a37"/></dir><file name="Js.php" hash="62c4ec3a54f2e93abf767f332b2a3962"/><dir name="Tab"><dir name="Ajax"><file name="Serializer.php" hash="3b47cf7e093745798e144250c5162ae1"/></dir><dir name="Alerts"><file name="Price.php" hash="089e6bc761ed49c8ad2ec7ba26c7fb73"/><file name="Stock.php" hash="e06ce13d6445624469e8fd2206a29647"/></dir><file name="Alerts.php" hash="b61ffb81888eaa0316a81a604379e208"/><dir name="Attributes"><file name="Create.php" hash="3f7f954930e3e7b749ed292f309caa1c"/></dir><file name="Attributes.php" hash="d1bcd002acea03dca275a06f4cac16e4"/><file name="Categories.php" hash="40a692fe90176aabc59046e97654e401"/><file name="Crosssell.php" hash="664656ac9e319f86bfee33c97545a0f1"/><file name="Inventory.php" hash="64e56bcd189081003f4c395be263f6e2"/><dir name="Options"><file name="Option.php" hash="4582b6c3b2400202ed73a0930a40f8f2"/><dir name="Type"><file name="Abstract.php" hash="818f94de76f82a67d2471051d7442424"/><file name="Date.php" hash="39885b96f8723368ef77181a7b3fbf1c"/><file name="File.php" hash="0ab404bab696d9be91928566adabf3a6"/><file name="Select.php" hash="6a4d6248e19a61d9f5c7cac597dc719c"/><file name="Text.php" hash="096cc18189256a1e9f4a4e53806c4ea7"/></dir></dir><file name="Options.php" hash="9a7d5cb98581857bbe1d1e8ddb74ee7b"/><dir name="Price"><dir name="Group"><file name="Abstract.php" hash="e2ef8472cf860ec16800b34046922aa8"/></dir><file name="Group.php" hash="d16078959e29b11e60b1e76a82b506f9"/><file name="Recurring.php" hash="3d50b901f1d4f965dbc6cdb5eca5ff0a"/><file name="Tier.php" hash="aa66089b33d43ac4d7ad754e0ebd4b5f"/></dir><file name="Price.php" hash="17275003ff0c19185b1f722306b37031"/><file name="Related.php" hash="e72c8c2a39a4d3ae1c2968589fcbb1ff"/><file name="Reviews.php" hash="064f4b3853d3dad28f61b41082b027a9"/><file name="Settings.php" hash="e0950496755a9f8c0b9a55c9b54771ec"/><dir name="Super"><dir name="Config"><dir name="Grid"><dir name="Filter"><file name="Inventory.php" hash="10cbc7c845b97d17d9bd90e01a379ea6"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="ae009d6f1acb453fcee25b40ad240506"/><file name="Inventory.php" hash="99daa1ecdc5ecc2747c0bbb8c7112fb5"/></dir></dir><file name="Grid.php" hash="c98440cb58cc470c261f108841134c9b"/><file name="Simple.php" hash="1ff50725fd2958d6e20eb5713e6e854a"/></dir><file name="Config.php" hash="2e9e39a0472dca2b3f59966d11021f86"/><file name="Group.php" hash="1cd62c22d540ee8e40e0119a7a5cb059"/><file name="Settings.php" hash="7b20ee5f3b058b9736e35d723b348029"/></dir><dir name="Tag"><file name="Customer.php" hash="1199cdb139ad8201214fe7a0419c685c"/></dir><file name="Tag.php" hash="352bb1e1d536cab57b4280de2ce456b8"/><file name="Upsell.php" hash="2e9663a201e50de3bfe3cc292d9e9189"/><file name="Websites.php" hash="9e9cfc3b81e640725be5b6e02c9d3cfd"/></dir><dir name="Tabs"><file name="Configurable.php" hash="6085e32381fb2612ddea1a54a89e1caf"/><file name="Grouped.php" hash="87da69d6b67def224e86326b19cd6ac5"/></dir><file name="Tabs.php" hash="3fdbe6b1b94dfb0ccbc56d7ffa7f4326"/></dir><file name="Edit.php" hash="b501e75c51e8204b9baa954d61848569"/><dir name="Frontend"><dir name="Product"><file name="Watermark.php" hash="c81c187cb29b659a6aef01f1ab535713"/></dir></dir><file name="Grid.php" hash="0f561a7c6f0a9aba3994922216f8ad24"/><dir name="Helper"><dir name="Form"><file name="Apply.php" hash="0f1363899f7655b233e826a7215d5f4f"/><file name="Boolean.php" hash="93bf215159eb1308e315ad8141b50053"/><file name="Config.php" hash="b43b82224566766034373156e313de21"/><dir name="Gallery"><file name="Content.php" hash="fb36c29a35890b693cdd7ffb36b1dbd7"/></dir><file name="Gallery.php" hash="3bb08d8826aa08bbaf6f0e5d689a41ab"/><file name="Image.php" hash="5c0a06796c738b29738b8f45d1afd5e6"/><dir name="Msrp"><file name="Enabled.php" hash="8248490c5c3151787744e04462032b82"/><file name="Price.php" hash="38d46e644e7f0db3e5b893f27f49f525"/></dir><file name="Price.php" hash="f278a7db25a13a027ea25e78d746f322"/><file name="Weight.php" hash="4f0b58df8846b52df64109ca55b08faf"/></dir></dir><file name="Price.php" hash="740839608dd1244d32ef2ca26810898e"/><dir name="Widget"><dir name="Chooser"><file name="Container.php" hash="d4c30a3faa5c3f73707d30c0b7d687cf"/></dir><file name="Chooser.php" hash="fdbb886262f31e134031d77a8311b886"/></dir></dir><file name="Product.php" hash="7c844629bb172d2a510d8549d5fcfb38"/><dir name="Search"><dir name="Edit"><file name="Form.php" hash="19ff5e62cde4d4f75585a6bd3f980660"/></dir><file name="Edit.php" hash="75ca1935d14c89d7b077924a543c0f15"/><file name="Grid.php" hash="95e20704a061de4ec65c3b4c048202f8"/></dir><file name="Search.php" hash="d95b820a68dee749892a655714b75a16"/></dir><file name="Catalog.php" hash="ce5a2cf9a034e0a8926b84811c9ce707"/><dir name="Checkout"><dir name="Agreement"><dir name="Edit"><file name="Form.php" hash="2870329f50e032ca3be556c587835dc3"/></dir><file name="Edit.php" hash="7aa00b6829c6aaa42517159e03ba8050"/><file name="Grid.php" hash="a344b7faf6cb198868305a6d0be42430"/></dir><file name="Agreement.php" hash="127799b649c14d8040be957b67711f19"/><file name="Formkey.php" hash="ccf7cfaeeea137f9ff13aab29179b0b0"/></dir><dir name="Cms"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="ea5ca609d2e3df4e021f2cebb6b211ff"/></dir><file name="Edit.php" hash="4fbb998ae410ef1e4ee6d8090b61670a"/><file name="Grid.php" hash="c35edb4840d079cf660b8e2eab483044"/><dir name="Widget"><file name="Chooser.php" hash="8dc62a9dc661de869f69894f0d9807b1"/></dir></dir><file name="Block.php" hash="57712596a93b882e7cd7386bdc00f914"/><dir name="Page"><dir name="Edit"><file name="Form.php" hash="ed73c4aeaed92f0b8b804eafb9096763"/><dir name="Tab"><file name="Content.php" hash="8b0ff0d6694ecf4cb77aa407ebef3082"/><file name="Design.php" hash="2a6a997c15727a589982e858073ca71a"/><file name="Main.php" hash="13cd7cc038de4f5f7c160b6a12304512"/><file name="Meta.php" hash="3396c6a4d9bf9df78a4efe26a5f2057e"/></dir><file name="Tabs.php" hash="d7c653bc13f03ce9f38fb89d1c60097c"/></dir><file name="Edit.php" hash="413581f1521e0a3225bc30a1d5c9428b"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="82ee47503382870703952244e2293517"/></dir></dir><file name="Grid.php" hash="849ecd981f80b2b05a6fbcb402f93d14"/><dir name="Widget"><file name="Chooser.php" hash="e884ff798c9eef8364721ca9af87882f"/></dir></dir><file name="Page.php" hash="49cb99b5286dcd397e0af9e0b23250da"/><dir name="Wysiwyg"><dir name="Images"><dir name="Content"><file name="Files.php" hash="1163853c0068a0f6d227802fbe8dea70"/><file name="Newfolder.php" hash="e214bdce0908f034aebcb500080eaac8"/><file name="Uploader.php" hash="eb46366072c73eb7157bd539e3800405"/></dir><file name="Content.php" hash="c875dbec8d6ef0382538920d88b150a7"/><file name="Tree.php" hash="aa39816c696aaf7b681fd15034c0a731"/></dir></dir></dir><dir name="Customer"><dir name="Edit"><file name="Form.php" hash="0c289b4fd0a89bfec5a71772d3e6a453"/><dir name="Renderer"><file name="Adminpass.php" hash="32bf316dc52322a59510a83638bfb30c"/><dir name="Attribute"><file name="Group.php" hash="ea7c4d23b59371529440d060728c27d9"/></dir><file name="Newpass.php" hash="552b26b7d447881d577ceebdb594e015"/><file name="Region.php" hash="b3a5cf903c23e96d5387da1052943829"/></dir><dir name="Tab"><file name="Account.php" hash="cb80de35f033c6018df0aa07c5d58bfb"/><file name="Addresses.php" hash="c5ce493dd7d0f3ca64dedf6b46db1d6c"/><file name="Cart.php" hash="dbcd7a63f8a9d777014b7da117337709"/><file name="Carts.php" hash="760e68993751df9c568333bd13c40036"/><dir name="Newsletter"><dir name="Grid"><dir name="Filter"><file name="Status.php" hash="e32c86d186a0f9acd70344b4e1566c7b"/></dir><dir name="Renderer"><file name="Action.php" hash="0e431d80248283b2ae52707cbd397705"/><file name="Status.php" hash="1fe3941bc5f6f0736173e13bd059f1db"/></dir></dir><file name="Grid.php" hash="ec780b4c8ceaaa1f02ce48fbda58faeb"/></dir><file name="Newsletter.php" hash="202d74115632b72daa8f42d97a57b7a4"/><file name="Orders.php" hash="b651ce4f5c30c443b6a70b8e7b371d93"/><file name="Reviews.php" hash="0b6bbe5289881c0f5bd039ccef57dc9a"/><file name="Tag.php" hash="0764367a0636cb632b4103b95f487112"/><file name="Tags.php" hash="52c4a09334625c29534428b5af5c8d38"/><dir name="View"><file name="Accordion.php" hash="f81336d13723d8f527ec48c1ebdeb31a"/><file name="Cart.php" hash="f00d19890687bc12e83c27bbf2bdc329"/><dir name="Grid"><dir name="Renderer"><file name="Item.php" hash="19f6cf2f2d8e23b173e33b2b9d604258"/></dir></dir><file name="Orders.php" hash="23bb04733b29a2357b44e036653ee854"/><file name="Sales.php" hash="e11c52a84f4621d8e24a55596f03a05a"/><file name="Wishlist.php" hash="01601f4e626a08ab539a417396e3e616"/></dir><file name="View.php" hash="2a31077590dc4943008ba9d9ccbdf1b3"/><dir name="Wishlist"><dir name="Grid"><dir name="Renderer"><file name="Description.php" hash="e9ac1bf2699e79903cb6c811663dce32"/></dir></dir></dir><file name="Wishlist.php" hash="9a52b70a7788a3c425fb136978fc46c4"/></dir><file name="Tabs.php" hash="5fe3722dcb5d09048cc876d2c2a14d63"/></dir><file name="Edit.php" hash="42a26f8ed4e680031c6674d8731cb235"/><dir name="Form"><dir name="Element"><file name="Boolean.php" hash="4cbaac7ec7349ae54619ca89e459024e"/><file name="File.php" hash="7432ad033bd39dcec8b4584ddfb2aaab"/><file name="Image.php" hash="0e79379e17e64098679c4455f58deee3"/></dir></dir><dir name="Grid"><dir name="Filter"><file name="Country.php" hash="5f517b81692e7718e05fbc99ed7f84a6"/></dir><dir name="Renderer"><file name="Multiaction.php" hash="af4c89a70fbe4d26dc8db4279f97dbf0"/></dir></dir><file name="Grid.php" hash="06ba05f38c0b4a8883ead63482cb4ecf"/><dir name="Group"><dir name="Edit"><file name="Form.php" hash="0cadbc7ebb1df472f28c54dbb44fe5e6"/></dir><file name="Edit.php" hash="820b328a15292116341be27a3d829e72"/><file name="Grid.php" hash="5bb20efe160ad515ed3ae642ec6a397a"/></dir><file name="Group.php" hash="6ca9df8630e23750c0340f6c3639936b"/><dir name="Online"><file name="Filter.php" hash="25def0b452913c29fdada85b28cedcca"/><dir name="Grid"><dir name="Renderer"><file name="Ip.php" hash="b994acd83317e6d3a39950b7893f0a67"/><file name="Type.php" hash="16aa8fbdc1cdeb0bb3cc2bed78a0b878"/><file name="Url.php" hash="6d9181705db8e74742bb7e9490de76d1"/></dir></dir><file name="Grid.php" hash="3132fde935fcf5f91033d985c3c7dcd9"/></dir><file name="Online.php" hash="89bdbc6f33a15036792e717dfda4a4a0"/><dir name="Sales"><dir name="Order"><dir name="Address"><dir name="Form"><dir name="Renderer"><file name="Vat.php" hash="62836393b817252569217cec61e3584e"/></dir></dir></dir></dir></dir><dir name="System"><dir name="Config"><file name="Validatevat.php" hash="f905c4557329ce6802c8a8abc2d9fff3"/></dir></dir></dir><file name="Customer.php" hash="425fe36c6debba08b77538f26a5c1adf"/><dir name="Dashboard"><file name="Abstract.php" hash="d55265571d05fe5c6ec98d585838bd2e"/><file name="Bar.php" hash="7f89a11678c6787547cffe13fe7e4ae7"/><file name="Diagrams.php" hash="9c207f0bc1d304d761a80df2e88c4093"/><file name="Graph.php" hash="6deb593ae9e725e80d60e7f6b6bc4671"/><file name="Grid.php" hash="1fb286a315624cd1f055bbc03724a820"/><file name="Grids.php" hash="60f08bc998bab01615e814a1c960b6eb"/><dir name="Orders"><file name="Grid.php" hash="b475871f31c7cf78de7e57236f203f94"/></dir><file name="Sales.php" hash="24f1f6bdaeb1729d52faf720b72ae122"/><dir name="Searches"><file name="Last.php" hash="c171fc44097e31c7bc6575b328e55552"/><dir name="Renderer"><file name="Searchquery.php" hash="d9a796c5175fff8e1dfddf94f6f7bffc"/></dir><file name="Top.php" hash="436c2ff96aa9d9c44e5f3a4242f0fa95"/></dir><dir name="Tab"><file name="Amounts.php" hash="f28f8d6d84eab07f116592e855818181"/><dir name="Customers"><file name="Most.php" hash="943e9f0f6a332e2004154d7fdc860a71"/><file name="Newest.php" hash="4d5b87b861a60722148b9157d085ce91"/></dir><file name="Orders.php" hash="b7d58a1db078a8ab9f88988ee82516d0"/><dir name="Products"><file name="Ordered.php" hash="9fbb836a88175a252e1eed16855d7aa7"/><file name="Viewed.php" hash="21892723be536c455108696c030708c7"/></dir></dir><file name="Totals.php" hash="b35bf6bc86642181329d7c6a4063b0d6"/></dir><file name="Dashboard.php" hash="4330555661b77277854314fd963bfc0d"/><file name="Denied.php" hash="f18754e566f29562164e9f4f2154fb7e"/><dir name="Html"><file name="Date.php" hash="b867dbb838bb7b751c9ab4fadd0691d5"/><file name="Select.php" hash="b90d108fbdc632fecec28f588d3c4957"/></dir><dir name="Media"><file name="Editor.php" hash="904734bc8d1f1d535b8446b1cb7bc96e"/><file name="Uploader.php" hash="75fb544b5db702c425830692e3111891"/></dir><file name="Messages.php" hash="63b9051e067080a4484d3254509e2d32"/><dir name="Newsletter"><dir name="Problem"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="bfb315eba5ce6c24c43aa390f824a2c8"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="b6e6018adfb853dd8f972922467d01de"/></dir></dir><file name="Grid.php" hash="77c982c969880ccc4ec3b3279f890eab"/></dir><file name="Problem.php" hash="d7a5e625ada05d38e9411a54957e0cec"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="3a98c1bc08af3bcc66eabdeb1c9488b0"/></dir><file name="Edit.php" hash="eeadc81a388ca892c208e5543d2dc4b4"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="41b2bc208c4cf354065eb4ecc7e8c341"/></dir></dir><file name="Grid.php" hash="2dd9bdbee8a13adc9324de14902a9385"/><dir name="Preview"><file name="Form.php" hash="ec12b9117a9317db74cfc4a62b625ec3"/></dir><file name="Preview.php" hash="e33127ab0fc2ade9df1e5acfd251842c"/></dir><file name="Queue.php" hash="687a80234a6c6942500ce0e355b4bec7"/><dir name="Subscriber"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="f2b020b52cb5f5d27cc1df8379837db5"/><file name="Website.php" hash="cb5e07f6f075ba08702d08c6c149d995"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="85451acc8b0f56496a7259cd8dd76bc6"/></dir></dir><file name="Grid.php" hash="7260f65c291f4082d70978fdb45a3e12"/></dir><file name="Subscriber.php" hash="547980b120f86a0bdc71af6ea5e4b4df"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="f2b1549dd92e6883471640646cf3d5ee"/></dir><file name="Edit.php" hash="5d3fd5853c4e046b3752984fc6b459a6"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="2de17948babba3255185e824e0df2851"/><file name="Sender.php" hash="e0440c6f3f2af1c5b32ef17d41fc04ef"/></dir></dir><file name="Grid.php" hash="04c90d12653da962e4fac7b33f14594b"/><dir name="Preview"><file name="Form.php" hash="16aa35c3b2e48806625dcaba43c92bad"/></dir><file name="Preview.php" hash="09ed9ad8baa66d06a1fd6faa669717af"/></dir><file name="Template.php" hash="21d5eb58e09ac5096fd92600977fd431"/></dir><dir name="Notification"><file name="Baseurl.php" hash="dfdbc60d946f5666c3495190679cba42"/><file name="Curl.php" hash="2aeba6a2273f8f1e54d81c86ac535917"/><dir name="Grid"><dir name="Renderer"><file name="Actions.php" hash="99a94b2f0aae40f9c7ef88a665d45d67"/><file name="Notice.php" hash="fd90524ee4ae1d2bc16d31c71a532516"/><file name="Severity.php" hash="6745a90e7b990b7daa5618e00dc264c9"/></dir></dir><file name="Grid.php" hash="a18fbdf6a400a9fc1e3872cfea9518e1"/><file name="Inbox.php" hash="cf44b0a8760660ebd8a961a65773f14c"/><file name="Security.php" hash="af74cf2e1c7751d665a4375a0399a8f4"/><file name="Survey.php" hash="ec3650219b7d776c0e8026e3b7bd5ece"/><file name="Symlink.php" hash="6c427d602e5fca949d7813184a9b8b8a"/><file name="Toolbar.php" hash="08f588920aac56a603ea779b467489b2"/><file name="Window.php" hash="7bf40a4df88fc777eb2e2af91ef78043"/></dir><dir name="Page"><file name="Footer.php" hash="3246770f5c748b3a50476211edf75517"/><file name="Head.php" hash="874ebbe5de14ccdd458a6facbb4bd546"/><file name="Header.php" hash="c873bb0587722ff87379791184feac28"/><file name="Menu.php" hash="415744d581de429acd2fea5afe9ab0fa"/><file name="Notices.php" hash="316fd9052641e58b0d703ee36b4976a5"/></dir><file name="Page.php" hash="cb89a371f55974997804de0a61cd5c19"/><dir name="Permissions"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="fb8bb9a6a88d6366eb7bc0647203963a"/></dir><file name="Edit.php" hash="b09be0bc7a515f481e47ba4f563018ab"/><file name="Grid.php" hash="870323bc27cb8b5ec696b2603092b079"/></dir><file name="Block.php" hash="12e30bdf3fef18eb300b4c7bc40764a4"/><file name="Buttons.php" hash="32dd7dbce23d365e0a022bb3f294dd82"/><file name="Editroles.php" hash="09b493890c89039d4ce406b00be0fef6"/><file name="Edituser.php" hash="c855e11269a374c41edd871a19e6bfad"/><dir name="Grid"><file name="Role.php" hash="4524df7249ad6d3b164b5f0fbaf3f585"/><file name="User.php" hash="d0a4baae760877f7ac8587775087f925"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="33a129c9a6b5f2194496773ac7ab70ac"/></dir></dir><file name="Role.php" hash="2a13665d50a202158cc0590fced555d0"/><file name="Roles.php" hash="6bfcc3c0348274b0870b113f4736d260"/><dir name="Tab"><file name="Roleinfo.php" hash="403d663ef771f3611a0a2b50d46b3a4c"/><file name="Rolesedit.php" hash="225662e07a6ab6609c5bbd6f08cf6871"/><file name="Rolesusers.php" hash="8832cde896965e2b7bbca4638c8a9758"/><file name="Useredit.php" hash="e5e881c0790bfc3c6a2710c5fb8a0105"/><file name="Userroles.php" hash="57a5356934d115e47f563c5125848dd0"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="0c708883ce210d0a8b5b4d586a7cf06e"/><dir name="Tab"><file name="Main.php" hash="e6be40174f8206f0daac5d468316e4e3"/><file name="Roles.php" hash="64c25dec02a40da001b119a3dfa7b00e"/></dir><file name="Tabs.php" hash="f0da88dab2504dc3c6c0f5b86a53bbc5"/></dir><file name="Edit.php" hash="5b03bb8145164d560b1bdc8a269ac289"/><file name="Grid.php" hash="0b65eb7f5427cd22b346bfd87b503aca"/></dir><file name="User.php" hash="e5b81acde5072e754b5b28af7900ec03"/><file name="Usernroles.php" hash="6edb8570724b449437e59f067277ece9"/><file name="Users.php" hash="d597744c70b346f88dea87e87305942e"/><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="2026b495af14aa9a56935ba57498c1a3"/></dir><file name="Edit.php" hash="4298ed569a07d89bd75179a682d8c535"/><file name="Grid.php" hash="b019d3c19f49d30dd777d0bf311e4e43"/></dir><file name="Variable.php" hash="c894064b0ddd8ac81e92ab56363626a2"/></dir><dir name="Poll"><dir name="Answer"><dir name="Edit"><file name="Form.php" hash="382d5a97737db8c2b165f281d76f48ac"/></dir><file name="Edit.php" hash="63aed220b152cc116e59543729d73929"/></dir><dir name="Edit"><file name="Form.php" hash="cc568467e30577a1b9b9653d98392907"/><dir name="Tab"><dir name="Answers"><file name="Form.php" hash="27425239a41955cbcad44f5fad907bdf"/><file name="Grid.php" hash="9c52e51b0b0b1d2e1631790bc202a4f4"/><file name="List.php" hash="735a97e401819d79378fea03fb127d8a"/></dir><file name="Answers.php" hash="04540a47671baf275a8c1192197a15a1"/><file name="Form.php" hash="79c421116b0fc45445c5a8b0919a26a2"/></dir><file name="Tabs.php" hash="de583a3f18d5cbc2e1c250fecf7509db"/></dir><file name="Edit.php" hash="6f26bf3bc3d58f827958e2e3519c8c45"/><file name="Grid.php" hash="59be5ee15ed795e564c1c8a4397f81eb"/><file name="Poll.php" hash="9ccf39497025aba7d2ae8dfccbd5048f"/></dir><dir name="Promo"><dir name="Catalog"><dir name="Edit"><file name="Form.php" hash="99b4ccc6c993b3c6f785b90f867d3286"/><file name="Js.php" hash="3567b880caf3424119d21545467a0b6f"/><dir name="Tab"><file name="Actions.php" hash="639c36fe333c0b4193cdb5c858d244d7"/><file name="Conditions.php" hash="1dd1f6afcbc83cf24c8a4a57cd89e41a"/><file name="Main.php" hash="30be5eec578636204e4e2ac749c16fc9"/></dir><file name="Tabs.php" hash="ee13898b58f837d4a850213a450a6e19"/></dir><file name="Edit.php" hash="dc6c584c7b1bf07baceb80f9d9ccc251"/><file name="Grid.php" hash="3b3e748c0d9392fa1d22e851bd520ccd"/></dir><file name="Catalog.php" hash="9e83da3d00dfa31dd27beee92f629fbe"/><dir name="Quote"><dir name="Edit"><file name="Form.php" hash="a3ef7be928573c95300e3a686d109123"/><dir name="Tab"><file name="Actions.php" hash="af80c52b8840ac59e521cc184107f45b"/><file name="Conditions.php" hash="4e6013b559b2d106fa6823e5503b8a7b"/><dir name="Coupons"><file name="Form.php" hash="38a5ba623107f5359a63be333ecc8b52"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Used.php" hash="c10c900978716e683a88c74865e0bb9c"/></dir></dir></dir><file name="Grid.php" hash="6f12f7a7ac883537a91a868f8f046e8a"/></dir><file name="Coupons.php" hash="90eeb30e7bb308223d170325cfa82973"/><file name="Labels.php" hash="9149c4273f7724d18f6921d692399686"/><dir name="Main"><dir name="Renderer"><file name="Checkbox.php" hash="e24fd8ad3fcf1007293d9788db115ea6"/></dir></dir><file name="Main.php" hash="362533a6e487384930fbc9d31eb2c873"/></dir><file name="Tabs.php" hash="e8efb78f4bbcf33bc6b1f1475c8381a6"/></dir><file name="Edit.php" hash="0eed49127243c460ecf20717fc7c72f6"/><file name="Grid.php" hash="a981de2b2f84900d3aac8e5747d9e4b6"/></dir><file name="Quote.php" hash="cbdd154035e54141097f3f244ae5b698"/><dir name="Widget"><dir name="Chooser"><file name="Daterange.php" hash="817943af923130c019901eb371edd6fa"/><file name="Sku.php" hash="b94cf844cc52ef513213fdf36d4e2c31"/></dir><file name="Chooser.php" hash="85f891c66376974cacb1b94591f97fea"/></dir></dir><dir name="Rating"><dir name="Edit"><file name="Form.php" hash="85bb893fe11569f779e2a2002635cae7"/><dir name="Tab"><file name="Form.php" hash="f52e225c22a0cb338139511210bdf8cd"/><file name="Options.php" hash="d742244d9ede8bc8c1811958c8672940"/></dir><file name="Tabs.php" hash="fab29a2465c8f83d8229ed9a4e12a457"/></dir><file name="Edit.php" hash="57154b7f9692dc1b5fe294151ef7c4c6"/><file name="Grid.php" hash="af5b428dfd715c2488a50a8db6635ed8"/><file name="Rating.php" hash="2063e6bd12dd2154657cfc6a4fd38fae"/></dir><dir name="Report"><dir name="Config"><dir name="Form"><dir name="Field"><file name="MtdStart.php" hash="e8274e4f8675746412d39e424a212177"/><file name="YtdStart.php" hash="d8365453d33234dae3dbac4c4164ad40"/></dir></dir></dir><dir name="Customer"><dir name="Accounts"><file name="Grid.php" hash="4ee062a10a1fd6dd3250751e9387cb1c"/></dir><file name="Accounts.php" hash="1a1511fabb29de8780686d3e9e65a28a"/><dir name="Orders"><file name="Grid.php" hash="0656ce7c9cd7c61d1ed7a0d6356d3638"/></dir><file name="Orders.php" hash="c5d12fb3cb26d20e3de3b10ba69df1a6"/><dir name="Totals"><file name="Grid.php" hash="ff882af980ae3c8811b0aa7b5bea0a83"/></dir><file name="Totals.php" hash="8aa59ae89284d2145650c437279e2afa"/></dir><dir name="Filter"><file name="Form.php" hash="69cd30e782441d2c20e2f7d086b578a4"/></dir><dir name="Grid"><file name="Abstract.php" hash="1259838520e97e6f5e5a86142f960068"/><dir name="Column"><dir name="Renderer"><file name="Blanknumber.php" hash="99b1c0c07fa555fea0cddae25f6a888f"/><file name="Currency.php" hash="fe2d288dfb099ceb914baa95a5ee92ac"/><file name="Customer.php" hash="b1a5250946c49aa2e921c9abb30999a7"/><file name="Product.php" hash="a4ad3eacf672977d5fa6c5213c666b65"/></dir></dir><file name="Shopcart.php" hash="d990aa64540f38084994c55e16b66a36"/></dir><file name="Grid.php" hash="11b7bd61129d0b5f03b5bd26ada47fb8"/><dir name="Product"><dir name="Downloads"><file name="Grid.php" hash="b2c62eb8f8d6cd91686eb418731546aa"/><dir name="Renderer"><file name="Purchases.php" hash="81d96bd5944b7b723fbd69c6fe0fad34"/></dir></dir><file name="Downloads.php" hash="11e4f461607717faf3742492139d97ed"/><file name="Grid.php" hash="a3328280fbfdc1286dadd5695003d2f4"/><dir name="Lowstock"><file name="Grid.php" hash="49ea6e217dfd12742f9f4526fbcf6df5"/></dir><file name="Lowstock.php" hash="f7a0fda9bc65400bcb201ce8c57b4fea"/><dir name="Ordered"><file name="Grid.php" hash="fbe565a94ef00aa0713d3c0676b28455"/></dir><file name="Ordered.php" hash="d0d5a77d45cc05a1cc9d9c6184dce2d5"/><dir name="Sold"><file name="Grid.php" hash="06b8bb8d3fb23fe3fed95f9af6c26110"/></dir><file name="Sold.php" hash="dbc26917ddaf6bd398ec2fe38346a626"/><dir name="Viewed"><file name="Grid.php" hash="c8f127e3f7ba9c1f584a0c6fb6a08471"/></dir><file name="Viewed.php" hash="076655e8c23b29dfc968fd652c46e40c"/></dir><file name="Product.php" hash="6b7d0556f28ddf0816b5fa1723a818a5"/><dir name="Refresh"><dir name="Statistics"><file name="Grid.php" hash="7339559d1a5feb5a317d214026b59714"/></dir><file name="Statistics.php" hash="081553d681795450853d378022096aa4"/></dir><dir name="Review"><dir name="Customer"><file name="Grid.php" hash="9840725cb756a7bb302650784adf2848"/></dir><file name="Customer.php" hash="507272f138c912e8401773ebebfbf601"/><dir name="Detail"><file name="Grid.php" hash="835c153225918f2e3134f03d459528d5"/></dir><file name="Detail.php" hash="bbe8bb058d5edbd4880064ad03892932"/><dir name="Product"><file name="Grid.php" hash="27cb7517a1fb42e1466071023ddae3f5"/></dir><file name="Product.php" hash="6941c4daa613b5975ba3a9d897f7347a"/></dir><dir name="Sales"><dir name="Bestsellers"><file name="Grid.php" hash="b56131a4f69109a4163812880f70fc7e"/></dir><file name="Bestsellers.php" hash="1c7b5ac4ac82eaa2c76efada815ba43b"/><dir name="Coupons"><file name="Grid.php" hash="a25de7482812b4d9bd89713e75c4b540"/></dir><file name="Coupons.php" hash="dea9d22ce3a45989bff418452b474c95"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Date.php" hash="99724f69d6decef56c305e07c7e56add"/></dir></dir></dir><dir name="Invoiced"><file name="Grid.php" hash="1a23290dd7d7719b94287ee8556d1e94"/></dir><file name="Invoiced.php" hash="d213c1742bceb0e8760cf6c51f122c15"/><dir name="Refunded"><file name="Grid.php" hash="ebe3ac2ca0f2981e4fe6031f82ac4c60"/></dir><file name="Refunded.php" hash="27740811a81123285c6d78bb9f799576"/><dir name="Sales"><file name="Grid.php" hash="5c0dd665a3a92566c3b9ee9b170c095d"/></dir><file name="Sales.php" hash="011f528457f654222487ddc1db15e85b"/><dir name="Shipping"><file name="Grid.php" hash="ea48519fa084857ca4f44c967fe9d667"/></dir><file name="Shipping.php" hash="1cddda3d784b12525d836ac9a3357df0"/><dir name="Tax"><file name="Grid.php" hash="0a2340a418b896d8603f08d132f55b19"/></dir><file name="Tax.php" hash="fb277822cea2f0bb5b71c9d025d559f7"/></dir><dir name="Search"><file name="Grid.php" hash="407e420f3debfe639ae256e2d827b579"/></dir><file name="Search.php" hash="e9cb7352e3b233d5076926b67ae9f03b"/><dir name="Shopcart"><dir name="Abandoned"><file name="Grid.php" hash="932cab762e243101a7c3265dfa599c0c"/></dir><file name="Abandoned.php" hash="c933314669acd2fdbd63defd475d3984"/><dir name="Customer"><file name="Grid.php" hash="25089e52822291d522c42108810ab86f"/></dir><file name="Customer.php" hash="913294130b1a3dc25b0621df903bbd06"/><dir name="Product"><file name="Grid.php" hash="84d16caa0efd06af1d8cbca172e8992b"/></dir><file name="Product.php" hash="3f64b234f73486d662344cd9f52c4ae2"/></dir><dir name="Tag"><dir name="Customer"><dir name="Detail"><file name="Grid.php" hash="dd0c9252e4a70a0c3cb7e8e7c6c23639"/></dir><file name="Detail.php" hash="ebace1ece804b3c606020f8213f8b950"/><file name="Grid.php" hash="2260b6800e4c19ade24115f3f24fa907"/></dir><file name="Customer.php" hash="5ba6e846aababc182b25981aeb4c6f8e"/><dir name="Popular"><dir name="Detail"><file name="Grid.php" hash="818be0e011d29f75be00fa306b1b0c3d"/></dir><file name="Detail.php" hash="0ab400fc8641201ece75a65f1c93b809"/><file name="Grid.php" hash="ada614aaf421a6b35aee85a34d2d0d12"/></dir><file name="Popular.php" hash="54b7e0c887f64b16740869503de14a92"/><dir name="Product"><dir name="Detail"><file name="Grid.php" hash="7f1be567ae5d674f3875e1ba19e9c19d"/></dir><file name="Detail.php" hash="f0b90f22e066edbb5144b3a473ba074e"/><file name="Grid.php" hash="0dbc47e8afe260f1775f64f5abd5f284"/></dir><file name="Product.php" hash="a71f9d9003f52b69af346eff9143bc6c"/></dir><dir name="Wishlist"><file name="Grid.php" hash="0e63d4f557b29ee22ad74e25ab128bf1"/></dir><file name="Wishlist.php" hash="cbca56b25a8b586f64db6c91a538e029"/></dir><dir name="Review"><dir name="Add"><file name="Form.php" hash="912a68c3599baebbfd849d990a78ede3"/></dir><file name="Add.php" hash="c4ef9a8285531f848ef7ec85bd4b0865"/><dir name="Edit"><file name="Form.php" hash="aab9573c34402260a1b8abdb002bc703"/></dir><file name="Edit.php" hash="4bdfe952dff327bbde7c35d9956d8f6d"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="dae987db69eb9e6d7e0c6d3e3a4d0d2f"/></dir><dir name="Renderer"><file name="Type.php" hash="6e8026cd79021d31ee978b4ffafe30f0"/></dir></dir><file name="Grid.php" hash="5928d0b988c6dbbbaafd5c36efbd1b87"/><file name="Main.php" hash="4291581219eebb26a55d2c1b250171e2"/><dir name="Product"><file name="Grid.php" hash="eec163557bf71f8f22480bdd57a6c8a4"/></dir><dir name="Rating"><file name="Detailed.php" hash="e30faedc70008b47b14826e323947aea"/><file name="Summary.php" hash="2b8d5dc65e99660833e11b73344ce76e"/></dir></dir><dir name="Sales"><dir name="Creditmemo"><file name="Grid.php" hash="5717b8caec95d79d53baebf5665da23c"/></dir><file name="Creditmemo.php" hash="27fc256b67712baa22a6473e880681c7"/><dir name="Invoice"><file name="Grid.php" hash="bbca8c45b3055dab5327eb7e3f005bdf"/></dir><file name="Invoice.php" hash="f2a31a60dd248d1d023b82fe1ac14987"/><dir name="Items"><file name="Abstract.php" hash="467e9e7ca2f98b0051f3c8e361344439"/><dir name="Column"><file name="Default.php" hash="56d115ca0b116f68e404ef68807d20af"/><dir name="Name"><file name="Grouped.php" hash="4a2f8c476589e2b32af2ac01cafc96dd"/></dir><file name="Name.php" hash="c62de2bf8718a9c2ece2ce7e23e03bef"/><file name="Qty.php" hash="454a94edbe2c5b7a75f00737e170c3a0"/></dir><dir name="Renderer"><file name="Configurable.php" hash="28c70473cbe8350e442b54507dee18a1"/><file name="Default.php" hash="45fb1f4d18d3a3819459366afd873f94"/></dir></dir><dir name="Order"><file name="Abstract.php" hash="9968c36de59df2d73f7ab177ce99ad50"/><dir name="Address"><file name="Form.php" hash="c9f5836acbf4ff81427a9560722144f4"/></dir><file name="Address.php" hash="8b694ca709abe5f2dea49126dad372d2"/><dir name="Comments"><file name="View.php" hash="bd2304e9e8a63a912d132e93b5a121ee"/></dir><dir name="Create"><file name="Abstract.php" hash="ace23380dd4337893be6cd9f8fcc5edd"/><dir name="Billing"><file name="Address.php" hash="c7d6cdf4678e5d2f0961827501dea8a0"/><dir name="Method"><file name="Form.php" hash="729e963ab3ddf852c6aaeb4c374a701b"/></dir><file name="Method.php" hash="1cbda88628683510167d23bf158846ec"/></dir><file name="Comment.php" hash="107d8c6c1434f3e5ed365ae59e37ab52"/><dir name="Coupons"><file name="Form.php" hash="2dfc0a5002b07842e410ccf2710e610e"/></dir><file name="Coupons.php" hash="b9c757d33a7803b0415a9f0c213afb53"/><dir name="Customer"><file name="Grid.php" hash="5748a330e8dcc17699f3c6a1d3a589c4"/></dir><file name="Customer.php" hash="ea07e49bb04b3d7170ce2e5c42b5e85d"/><file name="Data.php" hash="8a086a74430cf27d5815f93b9c71071c"/><dir name="Form"><file name="Abstract.php" hash="994ad1483341a924d7a6c5d19a5e4726"/><file name="Account.php" hash="f14c220d593b0f06003bce684b140068"/><file name="Address.php" hash="87fc0f93e4be39fc0ba54f880490dcc4"/></dir><file name="Form.php" hash="e9879907839a7a810f58ed38e7ec4171"/><dir name="Giftmessage"><file name="Form.php" hash="98d63f507a64efaab99a500a9da71b86"/></dir><file name="Giftmessage.php" hash="2a3f37bf5c3723668344a3f7f2812267"/><file name="Header.php" hash="03f6dad30227f5d473400a7944e1a6d4"/><dir name="Items"><file name="Grid.php" hash="02bb5f83884bc84a82cea8902709e7f6"/></dir><file name="Items.php" hash="c29d6bd3003f80e1ea57b05141b09ea9"/><file name="Load.php" hash="f7a2aa5ea6bec7e254e873bcc82548eb"/><file name="Messages.php" hash="d87bea0103f77041cb81b75113675413"/><dir name="Newsletter"><file name="Form.php" hash="811887cae15aa522b1e358c3dc018507"/></dir><file name="Newsletter.php" hash="c0d9eff723feb880ed235a2a5b17abb5"/><dir name="Search"><dir name="Grid"><dir name="Renderer"><file name="Giftmessage.php" hash="7f9829c812972394931e019e2e96a90b"/><file name="Price.php" hash="ee6ce6908ae15c4407942a7d60fef978"/><file name="Product.php" hash="5d56f384c81931c32853f3d2bc5bb163"/><file name="Qty.php" hash="7611c0b8a7c2d1c7f129304348570ca2"/></dir></dir><file name="Grid.php" hash="649fc59c39244b2f974d15023caa47f1"/></dir><file name="Search.php" hash="e89f2e794055c5df0694a34c8e29ab60"/><dir name="Shipping"><file name="Address.php" hash="0ac0de15586744ec0bf5d671fc97e172"/><dir name="Method"><file name="Form.php" hash="ffb7b1b8af92e0020165271929d97684"/></dir><file name="Method.php" hash="621774bf02b03098d7681f9c81a2c5b1"/></dir><dir name="Sidebar"><file name="Abstract.php" hash="33c186eeb0dd61dc526a27ead10f280a"/><file name="Cart.php" hash="8203cb25f99eaf6fb607469872cd27b6"/><file name="Compared.php" hash="d2472fd4624fc3ba0a068537b5564bd9"/><file name="Pcompared.php" hash="50e6571e0b3a723f220cfc7c7fd3017a"/><file name="Pviewed.php" hash="f224ecc703e61de7704c720cbdb01742"/><file name="Reorder.php" hash="e30c333e309b362b99144de107caf2dd"/><file name="Viewed.php" hash="d188f15e1e330bb9cee987bb96139d47"/><file name="Wishlist.php" hash="3cfd84ed855acc1158825c4bac1eee07"/></dir><file name="Sidebar.php" hash="bb85cb56273718a438e470d3766102d8"/><dir name="Store"><file name="Select.php" hash="e568f34b8ee37902fd1ef5fceeeffa89"/></dir><file name="Store.php" hash="bd028b48bafff28a45141a8c213f7de7"/><dir name="Totals"><file name="Default.php" hash="0c06a5f6f9c9289fc0ec8e8f9bd38ab7"/><file name="Discount.php" hash="4b765ae9160306840358099712ca8f26"/><file name="Grandtotal.php" hash="0b140da78932cb339289247d737bef68"/><file name="Shipping.php" hash="2975332020d0faf31570e401f7431aa8"/><file name="Subtotal.php" hash="ef046c50436c16f9b71a9e13115bfae8"/><file name="Table.php" hash="10249cf6ca8666193e6c83994db02875"/><file name="Tax.php" hash="aaabef204e3c77f6acab7c5a02789c44"/></dir><file name="Totals.php" hash="703be91c809df96bc4e3f33a1a96e536"/></dir><file name="Create.php" hash="c1e4a9b052977322d863ac4bece32f62"/><dir name="Creditmemo"><dir name="Create"><file name="Adjustments.php" hash="89ab6b4a8002d8951b775059f6415d60"/><file name="Form.php" hash="cd6438633514cdf345d4c8a57f6a51aa"/><file name="Items.php" hash="a5ec6e06117c6858ef06d1ca25677597"/></dir><file name="Create.php" hash="c193123a808daf28acbc8793717ac6d3"/><file name="Totals.php" hash="c857b4b6cc5974c75e3a29eea2149009"/><dir name="View"><file name="Comments.php" hash="9135aa72b4bcbe7d3bb6013a2f04f016"/><file name="Form.php" hash="de15ef7c6f249fb9e4678a398011157e"/><file name="Items.php" hash="9a4e4ea401dcb83db60d1ca905d05640"/></dir><file name="View.php" hash="5682c3b6d957fffbe51f65638b6fae57"/></dir><file name="Grid.php" hash="332d48760a7984a6b00207543b88a4f7"/><dir name="Invoice"><dir name="Create"><file name="Form.php" hash="a6fb9792408416068988787f592374bd"/><file name="Items.php" hash="e97830b26af9f6f1bd1d141004ab7056"/><file name="Tracking.php" hash="8ea313eb2289113213c139295c4ea21e"/></dir><file name="Create.php" hash="df68552af456ece05b9d808479763178"/><file name="Totals.php" hash="ec44a68fb16b9222074f70b8392523bc"/><dir name="View"><file name="Comments.php" hash="1745fae306ac48cd9b60d7862253c263"/><file name="Form.php" hash="1cbcadc2e0a5f881c7916867115957c7"/><file name="Items.php" hash="bf1a848f21b8070e35e753ed50e7ddf8"/></dir><file name="View.php" hash="0508c53f38f6668267ff9c5e1e402847"/></dir><file name="Payment.php" hash="2f7d0a7edabb339ecf91426b9b67f204"/><dir name="Shipment"><dir name="Create"><file name="Form.php" hash="bdf8d97c42fd4225b4e7c50f41cb3a3d"/><file name="Items.php" hash="4dd1603a9ce555349c2a144b6448ff00"/><file name="Tracking.php" hash="ce1b2714096f0b2b4b64d020142ada9a"/></dir><file name="Create.php" hash="8a17f9a552ac4043c5ba695b5c2e7f28"/><dir name="Packaging"><file name="Grid.php" hash="c5dc315aa4a10b392647849647f8124f"/></dir><file name="Packaging.php" hash="4bbe680d38e5929c7196bbb26bac3350"/><dir name="Tracking"><file name="Info.php" hash="d1fc1232607baf4f133ec48ca0fae04a"/></dir><dir name="View"><file name="Comments.php" hash="12dfc224b8bd352eeb60d2b9b41a5c4f"/><file name="Form.php" hash="107bd71d65ca52e4fe59c148ff43d059"/><file name="Items.php" hash="0c2c02258238c04d35f8302f208dd5f6"/><file name="Tracking.php" hash="8d41c1e65ba0e3ec6945782957fcee9b"/></dir><file name="View.php" hash="dd4f42d11ffe1ea196bf1b82cd1f8ca2"/></dir><dir name="Status"><dir name="Assign"><file name="Form.php" hash="00cc48e6f0c3d2d8f5a9d276784dfa11"/></dir><file name="Assign.php" hash="9fb13f56dcfc8d5232fe57d729688837"/><dir name="Edit"><file name="Form.php" hash="e1e4a528c760069606a3288eefe9b53e"/></dir><file name="Edit.php" hash="878b0973508b56b3f373f8194cb70a07"/><file name="Grid.php" hash="f829cbd7178db37bf77b765af156f722"/><dir name="New"><file name="Form.php" hash="d0604be68b108b02af082bc7c65cace8"/></dir><file name="New.php" hash="29c01cd2f0e19af5e6250251b31267e9"/></dir><file name="Status.php" hash="6550dc33999e72773eab9478f52cc302"/><file name="Totalbar.php" hash="52aa0b423bcb1141c77b9458737b18c3"/><dir name="Totals"><file name="Item.php" hash="f43a219863c76c571205d832d0b43b45"/><file name="Tax.php" hash="184791b93aca13bd09ffb655f132ad01"/></dir><file name="Totals.php" hash="210db83b7c9a4c7cceb377b80f2a9c10"/><dir name="View"><file name="Form.php" hash="23d9c4ca41d10ae38b587c51450bc3e3"/><file name="Giftmessage.php" hash="42f341de5ae707b247a53424a1b67ed1"/><file name="History.php" hash="1d88d4967c4dc6b0d734e9e0aa4ac2d4"/><file name="Info.php" hash="d7ee83014d4bbab3a24e16d3f1d12eb7"/><dir name="Items"><dir name="Renderer"><file name="Default.php" hash="0a4e91ab3a575dc4e4bb02a74395d6b8"/></dir></dir><file name="Items.php" hash="c989206236501dc8b092d8d84e4f1d1a"/><file name="Messages.php" hash="4025d28ee095a9cd3f8ac60c1233f071"/><dir name="Tab"><file name="Creditmemos.php" hash="059adadd24b70299eccc487a536ab2c5"/><file name="History.php" hash="8e51c6f8901d81383fc8e3b937762f0e"/><file name="Info.php" hash="e2864c503f989daa5798cba16dde2a71"/><file name="Invoices.php" hash="0f308282d18b8193b98229f6b3058953"/><file name="Shipments.php" hash="ba3116e89be4121c316ee8ee87b0909b"/><file name="Transactions.php" hash="6cf7a8da63fbf6303692b0cb94799443"/></dir><file name="Tabs.php" hash="f13f47bc04d78d5c12b2ec834b00c680"/></dir><file name="View.php" hash="e118d98b266f83b7371f3bb2cb0495fc"/></dir><file name="Order.php" hash="7267a7a37d11673f68f0ee372cf3de7e"/><dir name="Reorder"><dir name="Renderer"><file name="Action.php" hash="3af81617dc8d3a5642079c2df2afc4ba"/></dir></dir><dir name="Shipment"><file name="Grid.php" hash="89b8634c717d62fe3b6487c15c8d107e"/></dir><file name="Shipment.php" hash="bf55854c2ea635e3a427a5031bba1125"/><file name="Totals.php" hash="0f2bb0aa24c61390e2727bf485214697"/><dir name="Transactions"><dir name="Child"><file name="Grid.php" hash="9b417be1aa074dc24de8680634ee2476"/></dir><dir name="Detail"><file name="Grid.php" hash="a42a03de4a8a788f02a845047c670db2"/></dir><file name="Detail.php" hash="86cca3beb4a511f8094cf5314a925468"/><file name="Grid.php" hash="da014699b42c2b4c1c81c17044d27da6"/></dir><file name="Transactions.php" hash="320be0527560fed342f9c811b8255bf9"/></dir><file name="Sales.php" hash="a1dc1bd628e8fedfa54aefac97bb41b4"/><dir name="Shipping"><dir name="Carrier"><dir name="Tablerate"><file name="Grid.php" hash="10e83ee8dde4582807a45d69f9acf679"/></dir></dir></dir><dir name="Sitemap"><dir name="Edit"><file name="Form.php" hash="b8d105362b3adf6c03d6a69d45bbc3a5"/></dir><file name="Edit.php" hash="e07b39397eb1286e1fcbc44139bc7e32"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="29bde8080647225153100af893c7a4ce"/><file name="Link.php" hash="fbc71a5ef95188f366fe84ab75516a1e"/><file name="Time.php" hash="a630f3e816cba54341ea826e0509be10"/></dir></dir><file name="Grid.php" hash="c02fabf9285882e6bb1b9395d38053ac"/></dir><file name="Sitemap.php" hash="50481db275cd12bbe56fcf5d8e78950b"/><dir name="Store"><dir name="Switcher"><dir name="Form"><dir name="Renderer"><dir name="Fieldset"><file name="Element.php" hash="c5251b386f061d7e76f9102870e48bb7"/></dir><file name="Fieldset.php" hash="28815718840b9cd9aa3a8f11dc704f75"/></dir></dir></dir><file name="Switcher.php" hash="4045caa8d0fa2303fbe04f26a9d6e1ef"/></dir><dir name="System"><dir name="Account"><dir name="Edit"><file name="Form.php" hash="99dd4d9afb439c78e66a74ea5b77a9e8"/></dir><file name="Edit.php" hash="d93d39b44e99f8c6f8a53fabeb8fe03c"/></dir><dir name="Cache"><file name="Edit.php" hash="3ed6b9c007cf377ff9f564ef281ec1fe"/><file name="Form.php" hash="8b387aa81ddff180e4c927b2fc9dbcd9"/></dir><dir name="Config"><file name="Dwstree.php" hash="949f0304d9a0c5c2a65cec4a491209a0"/><file name="Edit.php" hash="9fe688fa2b68a609bc8718838235da67"/><dir name="Form"><dir name="Field"><dir name="Array"><file name="Abstract.php" hash="3784a47ebc6bf8e201a94fb18bb25336"/></dir><file name="Datetime.php" hash="d9229f22e994bc820057e87cfec90598"/><file name="Export.php" hash="868fd289fe1c6f57ee6c2d056d1fccea"/><file name="File.php" hash="7d37626d158c4372bb3b7cc81f3a02d9"/><file name="Heading.php" hash="4ef6ca5626a72c022e3e8137596add5f"/><file name="Image.php" hash="22fca830060d1394a85da41db05964e0"/><file name="Import.php" hash="fbcca2bd1276efe49f513045592b2e45"/><file name="Notification.php" hash="1cdad5e7436b453245bcdd0489224628"/><file name="Regexceptions.php" hash="758807d54a62f6f61f611e767ec4ecf9"/><dir name="Select"><file name="Allowspecific.php" hash="ac58da8a22ee314eb89068718dbf4626"/><file name="Flatcatalog.php" hash="68c82c41e376b507816ce3ddb07e914a"/><file name="Flatproduct.php" hash="da237d35272d4dfe79fd5c83799205c6"/></dir></dir><file name="Field.php" hash="aea846b299b3399033354483361ee31f"/><dir name="Fieldset"><dir name="Modules"><file name="DisableOutput.php" hash="ce58e2732915fac2fb8936a79088c203"/></dir><dir name="Order"><file name="Statuses.php" hash="1316ef1399463d26d20611e802b998b4"/></dir></dir><file name="Fieldset.php" hash="b1cc5488a485e8c2397af2228dcfe0d6"/></dir><file name="Form.php" hash="e03e58aa776c049e11cc9856964593f1"/><file name="Switcher.php" hash="bd6f6c5dbf6eba1e0a936ac49942514e"/><dir name="System"><dir name="Storage"><dir name="Media"><file name="Synchronize.php" hash="411e489880f2a7d436823e46eb6c2030"/></dir></dir></dir><file name="Tabs.php" hash="6d01b907c1f3cb31132ab5c92902b56b"/></dir><dir name="Convert"><dir name="Gui"><dir name="Edit"><file name="Form.php" hash="51512ab6495c12ae7e521a0b220b5a18"/><dir name="Tab"><file name="Upload.php" hash="d193afda3f613e188d0515ecc19ba6fc"/><file name="View.php" hash="b599ad8fd48be28aab0995b125220b02"/><file name="Wizard.php" hash="b02afe7d66fee207a1f09d8812cf7a99"/></dir><file name="Tabs.php" hash="b9cc2ef30b98b610937b03fc02d8b497"/></dir><file name="Edit.php" hash="5e9488fca79a80b5234f5445e23a6e44"/><file name="Grid.php" hash="810689efe57896fb238e124faae811e9"/></dir><file name="Gui.php" hash="e089b93dd30284819d2d5d62d7d3b0d3"/><dir name="Profile"><dir name="Edit"><dir name="Filter"><file name="Action.php" hash="b7560fbdf0a5611d036ff11d2bbb51cd"/></dir><file name="Form.php" hash="3e3dd0fa111cb965b5752ae71d277c9d"/><dir name="Renderer"><file name="Action.php" hash="cd87651e0cb2e6ded77c76399783089d"/></dir><dir name="Tab"><file name="Edit.php" hash="1123d89a65d5a5aa17a8f23f6970de45"/><file name="History.php" hash="55f3d4c7b3701f990fa8195770dfefcc"/><file name="Run.php" hash="c4904951931aac62dcf658a47d81f40f"/></dir><file name="Tabs.php" hash="e1eb71d164447ccb5ed30d1c0b063895"/></dir><file name="Edit.php" hash="3e03e042fbe826d42fe3227f20f68e21"/><file name="Grid.php" hash="8b8d2d9532fbcc5669e306fe4f178cd5"/><file name="Run.php" hash="566d290a8b18f8d92f4c50ced8167774"/></dir><file name="Profile.php" hash="e98bc3dd91d4f33bb7066fbf16165afa"/></dir><dir name="Currency"><dir name="Edit"><file name="Form.php" hash="20b70301bec0b388197efc08843ae404"/><dir name="Tab"><file name="Main.php" hash="cb4ce996cedb2d09aeba5f7c301e0c77"/><file name="Rates.php" hash="20e20e6398fb25ce0aaabd296808f55c"/></dir><file name="Tabs.php" hash="9106b6dd6120dd32699b7c4d83ee275c"/></dir><dir name="Rate"><file name="Matrix.php" hash="6cae30f47d90546322f9f51feec24de7"/><file name="Services.php" hash="ac762568e16500cd45d3693cd45e73c4"/></dir></dir><file name="Currency.php" hash="c3cffe38d8d44a187ad756ccd7a930a9"/><dir name="Design"><dir name="Edit"><dir name="Tab"><file name="General.php" hash="6bbbf832832b30bbf63fc9d5c3bb2e50"/></dir><file name="Tabs.php" hash="c3d46a8b734ce44adf1afd9a78bad9be"/></dir><file name="Edit.php" hash="146be0ed03e144eb87aa89786f974786"/><file name="Grid.php" hash="41df1e7f4a7f1a310c934ac5c90bac99"/></dir><file name="Design.php" hash="63c84ac10dffefa4a60cb5a16ab2e9c6"/><dir name="Email"><dir name="Template"><dir name="Edit"><file name="Form.php" hash="ba60cf33870466147529540389a098fa"/></dir><file name="Edit.php" hash="fbff822e31d9fd4bfa74c21bd85c675a"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="06db8032ae98bcaf02dde31fda26ae20"/></dir><dir name="Renderer"><file name="Action.php" hash="977b2671b09737d77bb76efd8d1d140b"/><file name="Sender.php" hash="365125a25246d9c8698bfa6ee5e1df51"/><file name="Type.php" hash="7e587342637179a910cd521cb3f65d0a"/></dir></dir><file name="Grid.php" hash="0fb16af553465674f16de207b6a00a99"/><file name="Preview.php" hash="f71f27da9dde5eaf2683c98b8e7486bc"/></dir><file name="Template.php" hash="f961a2a3c8f6cb13aa8ed68be9d0ffb7"/></dir><dir name="Store"><dir name="Delete"><file name="Form.php" hash="86e76fd0c747b41a5611d16ef362da4f"/><file name="Group.php" hash="8a9875278ed5c2a1d7cbe2de0c8b5d3e"/><file name="Website.php" hash="02df4f06380e4b90bb36c44512f5f7fc"/></dir><file name="Delete.php" hash="bbf25320410cff2c1347ac4430b3b482"/><dir name="Edit"><file name="Form.php" hash="644b1a2848629900483e4f559d78a986"/></dir><file name="Edit.php" hash="1c26d15fa15443cbdaf7fa10d1c46595"/><dir name="Grid"><dir name="Render"><file name="Group.php" hash="d51172f385ad735d8edc971780ec3058"/><file name="Store.php" hash="56cc10240fdd3478e3d1062d72475360"/><file name="Website.php" hash="5f66c00e4522c40d5bf1b2d546224fe0"/></dir></dir><file name="Grid.php" hash="c75c238c07093f60b02ec4fa919fd7b7"/><file name="Store.php" hash="bc472fb0f06a390b255e9b3592d2ddfd"/><file name="Tree.php" hash="c23e3717d291a812964a9fb8ee916696"/></dir><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="d0d122ec389b0fd702287db9dc6763c1"/></dir><file name="Edit.php" hash="c604fffda2a18a7f112a68aa77baa4cb"/><file name="Grid.php" hash="7bab6ec5c65c3ed970df42674af1002f"/></dir><file name="Variable.php" hash="ce8ece090b8411742f92abc9edb3fdf9"/></dir><dir name="Tag"><dir name="Assigned"><file name="Grid.php" hash="289c2b672a9b03140c00aaf95cc09b5c"/></dir><dir name="Customer"><file name="Grid.php" hash="076b8a64dc03af267c456946d88dae9f"/></dir><file name="Customer.php" hash="5d0e98ae573372eeffa364b4f5e93eb4"/><dir name="Edit"><file name="Accordion.php" hash="3e633cddebf3f7c502d8d69b52b57092"/><file name="Assigned.php" hash="46657200625bbea8f17017cead2a8be4"/><file name="Form.php" hash="096d4192c6b03f86ec7113dc90b38ddb"/></dir><file name="Edit.php" hash="8138bcd7f37fb77365f1f19f813969ca"/><dir name="Grid"><file name="All.php" hash="03f5a39a97b773f8e30a3eb927cc0cf9"/><file name="Customers.php" hash="94dbb5abc8ae1dfa7ac16f4686810a7e"/><file name="Pending.php" hash="046f08f11632ab88da628d54ad428b91"/><file name="Products.php" hash="27039aeb2501fa5d6379524a52297bcb"/></dir><file name="Pending.php" hash="f9d75d43dcf71766ce2624f04fc7f9c3"/><dir name="Product"><file name="Grid.php" hash="74954d069ab71d4efbe262a1c4915684"/></dir><file name="Product.php" hash="d434e1282792816df00779a41b77c097"/><dir name="Store"><file name="Switcher.php" hash="5c832d5e5f1fb28ca6f8c5d250fd0f58"/></dir><dir name="Tag"><dir name="Edit"><file name="Form.php" hash="e3870d4338a56ddc333fadec6488624f"/></dir><file name="Edit.php" hash="3e9552841cb0486f1b07bca133e5cfc2"/><file name="Grid.php" hash="41e8a6118367c742b9180173e8daf02e"/></dir><file name="Tag.php" hash="6e74a75383b9ac5467cdfea6c6672f75"/></dir><file name="Tag.php" hash="dd0d9b1fe5544f616c0f47ac59657180"/><dir name="Tax"><dir name="Class"><dir name="Edit"><file name="Form.php" hash="c4a5a09202ec85a8a5217fb3dd1c9b38"/></dir><file name="Edit.php" hash="dec0c0a5429dd6277e6235f5446de4db"/><file name="Grid.php" hash="01a33ccb33459383a59f288e3242c2aa"/></dir><file name="Class.php" hash="a5c4e0fa6c3fae6e9a67e895a263462e"/><dir name="Rate"><file name="Form.php" hash="3c2e61a925169c6a4f4b2c49f0ddb863"/><dir name="Grid"><dir name="Renderer"><file name="Country.php" hash="ab49dfe7ae7318f2cd4c19f428ff65b3"/><file name="Data.php" hash="ee564a26a28e6c672dc70283b8727156"/></dir></dir><file name="Grid.php" hash="4311cef68b093dd21a464444bb04f182"/><file name="ImportExport.php" hash="51749ab5623e4499e50e534836a571e0"/><dir name="Title"><file name="Fieldset.php" hash="e1d2275ed3ef0683fc2576fa5e4faf57"/></dir><file name="Title.php" hash="4aab833771581272d1ba200432ea00bd"/><dir name="Toolbar"><file name="Add.php" hash="cab32f30562274448ccc28d8d278c037"/><file name="Save.php" hash="97907b0978b7665d45cd8a75acda4b40"/></dir></dir><dir name="Rule"><dir name="Edit"><file name="Form.php" hash="d3117202c01e13c77630fe521b520431"/></dir><file name="Edit.php" hash="075f674a17a8822f20b0d2e7d51ea788"/><file name="Grid.php" hash="d52779e77fc997d22937255d0c6aad1d"/></dir><file name="Rule.php" hash="9312e570058a660557588246e50f1628"/></dir><file name="Template.php" hash="048e4d58a8abf8e3a4c8f5677cf6def7"/><dir name="Text"><file name="List.php" hash="41726f17baf4ba05ceaa79953a0bd611"/></dir><dir name="Urlrewrite"><dir name="Category"><file name="Tree.php" hash="1e01061dac93dcc890e36246ae60b758"/></dir><dir name="Edit"><file name="Form.php" hash="3d703104e5d5e0dc7c2dbd8bdcbba50c"/></dir><file name="Edit.php" hash="abebcb24862a597d023dc47e55e06175"/><file name="Grid.php" hash="951283f25d355557d77ff3fc232c30ca"/><file name="Link.php" hash="a082c052dd2d63e8b47b452090ad7752"/><dir name="Product"><file name="Grid.php" hash="c21688b10e691b43d3c2be26e33068b4"/></dir><file name="Selector.php" hash="42efc1c2c979c7234684da85d0c5f4bc"/></dir><file name="Urlrewrite.php" hash="f6bed2492f4348c239a56b93c2c8cd3e"/><dir name="Widget"><dir name="Accordion"><file name="Item.php" hash="1ac375fb0ad1148f1a3486f1c7dad763"/></dir><file name="Accordion.php" hash="fa8c5ee4d9a67c62860c7995a2f5facd"/><file name="Breadcrumbs.php" hash="f2b60b95e58b36adeb63552424ec00b8"/><file name="Button.php" hash="6dfb5f9a54fcab22606043bdd04d461c"/><file name="Container.php" hash="701d273ac0551c92a87451631ec94cf1"/><dir name="Form"><file name="Container.php" hash="2647161b6a37509a84fc08bff6ce23de"/><dir name="Element"><file name="Dependence.php" hash="12bb49d958b0121ea0bdf6cd3b47a66a"/><file name="Gallery.php" hash="1a9b799b5f8b060be9775a01d7626799"/></dir><file name="Element.php" hash="f0b4276a0c30ecd0f89362c138667690"/><dir name="Renderer"><file name="Element.php" hash="29d1418f521ddb89e24943921c76c4bd"/><dir name="Fieldset"><file name="Element.php" hash="b419b410919759ab61f58dbd86212a2d"/></dir><file name="Fieldset.php" hash="de6bc5059042f678be9014401c1140d8"/></dir></dir><file name="Form.php" hash="8e07b8961c116fdfa109f548c0963b73"/><dir name="Grid"><file name="Block.php" hash="d3415dd6d043edcb8236bcb202a93bdc"/><dir name="Column"><dir name="Filter"><file name="Abstract.php" hash="b99f0dbfe4f3685d8609c3e5e62e2a23"/><file name="Checkbox.php" hash="41eb6bbe5bd4bea08725ade2b9bc254d"/><file name="Country.php" hash="23f713e16b15e7b2b1e8b8202b6aab22"/><file name="Date.php" hash="c143657c6b6b7ebe15abe233e5523918"/><file name="Datetime.php" hash="0b5ec21288cb134916b2a55c07fba169"/><file name="Interface.php" hash="f8709f395b919353186d3a28b2427d12"/><file name="Massaction.php" hash="b0d958db2d2f897510813a0b418e0319"/><file name="Price.php" hash="9d948fa21d31cb67e65a27b60706892a"/><file name="Radio.php" hash="fd316ceb4e867d192ef45382019c54a1"/><file name="Range.php" hash="aa954a9524813a18e450671de7be2a35"/><file name="Select.php" hash="312ac65d14fe5808b94cf01693e73683"/><file name="Store.php" hash="c479999fdd7f63e62a4a2ed7a8b7e85f"/><file name="Text.php" hash="498b987ce2efc08c96c9daf982c7ad93"/><file name="Theme.php" hash="f2f91007375d651411cbfb5d9d31f5d6"/></dir><dir name="Renderer"><file name="Abstract.php" hash="0877927202ba8cb3c007f1e998846c38"/><file name="Action.php" hash="c693f237ebf99daa9d0847253904dce2"/><file name="Checkbox.php" hash="9ffcfeb3859943bf8e21e5ed901f7eb6"/><file name="Concat.php" hash="a0f3dba0a2f719b9d231f5fd6112e9de"/><file name="Country.php" hash="c3ce0bcd5d39be75574ce3014b50874f"/><file name="Currency.php" hash="5381176d3cdfe77c2948bf5b534f402d"/><file name="Date.php" hash="dd112ba85cb251c4ce4acefebcc6d77e"/><file name="Datetime.php" hash="44037bdde740944a80b5d7c67b085155"/><file name="Input.php" hash="c3ca64db8371066aa2313e9d5ae9a2fe"/><file name="Interface.php" hash="9fec60d6ae235d4f050a48f8891397f0"/><file name="Ip.php" hash="a3bc5003397174eee0c4580e522ee5ba"/><file name="Longtext.php" hash="a42d8268677431d06f23b18b73ff0484"/><file name="Massaction.php" hash="48780753058340dcb7d2ad0799886d32"/><file name="Number.php" hash="da8225e2a1282a1966c46e7ac87d61aa"/><file name="Options.php" hash="15ee3eef0f1be48f83e543fd4fddb10d"/><file name="Price.php" hash="e695c582e86897a2b71c8796eb45e370"/><file name="Radio.php" hash="1784e361f47d188c995f7349ee425854"/><file name="Select.php" hash="7445e830f03632a9d4dda2021a3d1cf2"/><file name="Store.php" hash="a29e258b9963d847cffe16577223ee1c"/><file name="Text.php" hash="2f297552e7f0749c75efde13500a75f9"/><file name="Theme.php" hash="282f1e4dcd4833515de87ab0393f6b9b"/><file name="Wrapline.php" hash="2bdb2a2d417fc7d405ee911c40c4b578"/></dir></dir><file name="Column.php" hash="5f37c1b21f74a74aafa9179e95fbfe12"/><file name="Container.php" hash="58fc2e07119b5e4145fefcc4f749118a"/><dir name="Massaction"><file name="Abstract.php" hash="e3394fca7a58c1eddb6188076165c32f"/><dir name="Item"><dir name="Additional"><file name="Default.php" hash="6879cf65e66b360f2163f250e4a3562c"/><file name="Interface.php" hash="04db948fdb1ad2ae5243674869f24b5f"/></dir></dir><file name="Item.php" hash="d6541c34b3d94aece64cf57478569330"/></dir><file name="Massaction.php" hash="0649c03624c79c444cf054ce49d08ba3"/><file name="Serializer.php" hash="cd93824ccd3b24bdb97636cec9bd6013"/></dir><file name="Grid.php" hash="542b30e8c9d360df1160e520137b1a3e"/><dir name="Tab"><file name="Interface.php" hash="61ac6f75ef55994b9409212b7c068fbe"/></dir><file name="Tabs.php" hash="bf410f1dcd6ec5792599d8513eb65e0e"/><file name="Tree.php" hash="8fcf0d8894270461592a1b996a3a1e22"/><dir name="View"><file name="Container.php" hash="48702822606edbc1752eaf8797e2fdb7"/></dir></dir><file name="Widget.php" hash="decb2e463a8f908e4e43245698a6f614"/></dir><dir name="Controller"><file name="Action.php" hash="3ba8923155131f165de4b24cab8b1f34"/><dir name="Report"><file name="Abstract.php" hash="93735d32568b1f392b5fa4a10937392d"/></dir><dir name="Rss"><file name="Abstract.php" hash="b06747180f1212b557f862b729fb4217"/></dir><dir name="Sales"><file name="Creditmemo.php" hash="af189622ec813cf6949cf892dcf6125a"/><file name="Invoice.php" hash="bc00214eeb245421bda96153aafaf19d"/><file name="Shipment.php" hash="5f5cac08a0dfec54a7c4c7039b0e4074"/></dir></dir><file name="Exception.php" hash="44207ed4e9b5d888465e3ec342951647"/><dir name="Helper"><file name="Addresses.php" hash="5efa1e819fa6b6b3276491b040d77283"/><dir name="Catalog"><dir name="Product"><file name="Composite.php" hash="372f822324ef3743ebdaa85a95c68eb2"/><dir name="Edit"><dir name="Action"><file name="Attribute.php" hash="95045d72c50603435d4bb8f7155deb36"/></dir></dir></dir></dir><file name="Catalog.php" hash="e952f09baa412d512b078d855b9f4209"/><dir name="Dashboard"><file name="Abstract.php" hash="30093b0860aabc91f5536fd4804a8a99"/><file name="Data.php" hash="e427b0c5ec57baf11297906ed754b0a4"/><file name="Order.php" hash="103df9c0158567427030a687d228d1f4"/></dir><file name="Data.php" hash="e6d9960369cb287adbaf16cc224f7b15"/><dir name="Help"><file name="Mapping.php" hash="ab759adbe2f9e3187c94c212d4747abe"/></dir><file name="Js.php" hash="82fd6176dd872e8bfa46a4943e6636d1"/><dir name="Media"><file name="Js.php" hash="a7c77ea8858c7a35a545c6f3ae883147"/></dir><file name="Rss.php" hash="a9a4d7bdd91e9d10560205da8ffeacfc"/><file name="Sales.php" hash="8b6034ee70156b8824960f25cacaa4e4"/></dir><dir name="Model"><dir name="Config"><file name="Data.php" hash="4c4206478a3a5b7065481a359dff797e"/></dir><file name="Config.php" hash="2363b4cc646330ce48602ec95cf20dd0"/><dir name="Customer"><dir name="Renderer"><file name="Region.php" hash="e64f33d24ce1acb1fccaf089082930e5"/></dir></dir><dir name="Email"><file name="Template.php" hash="79bfb7dcd80fbb41fecd493c298e2868"/></dir><file name="Extension.php" hash="05c31b0713d19ce57c2b4d05dd9a18f7"/><dir name="Giftmessage"><file name="Save.php" hash="2849a3df15792e773ee0236a353e0692"/></dir><dir name="LayoutUpdate"><file name="Validator.php" hash="1a9e0082789f21e4d205ee5e1af8f5ed"/></dir><dir name="Newsletter"><dir name="Renderer"><file name="Text.php" hash="36fa1832ba5ee4a5f2f86290cda582f1"/></dir></dir><file name="Observer.php" hash="8101ea47383903954f922bcac3050022"/><dir name="Report"><file name="Item.php" hash="249bc4d6c2fe209b5ea8f3872ba04f04"/></dir><dir name="Sales"><dir name="Order"><file name="Create.php" hash="c91499f785f4f39191f978de174b1722"/><file name="Random.php" hash="b40e6c27f9283f934d4f655839126740"/></dir><file name="Order.php" hash="0b7e17e6569bf6dd8c8d26374143b2f2"/></dir><dir name="Search"><file name="Catalog.php" hash="0b11e59e0c4950dfe25e90b0bfe11829"/><file name="Customer.php" hash="5e9563a1ae7abc810c1621305a2903f0"/><file name="Order.php" hash="055f3e4100dd905f559c60a5be7f703c"/></dir><dir name="Session"><file name="Quote.php" hash="ba05387fc32960d10cb0e45286a0447f"/></dir><file name="Session.php" hash="a543f20db68121a0906bebec3ad957dd"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Admin"><file name="Custom.php" hash="9a72fab9ce9caa8ef04cf76993160b3e"/><file name="Custompath.php" hash="8ed95aff9688c352ed5def2cc7216375"/><file name="Observer.php" hash="aabc9c2fc39b41823f62c2eebd2544af"/><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="fa69226978a7cc41f139c5efb1da14a7"/></dir></dir><file name="Usecustom.php" hash="52e66d90f8d2aec0c183c5d58457cea6"/><file name="Usecustompath.php" hash="c5f888363c830e0e3546f6826465bce0"/><file name="Usesecretkey.php" hash="8dc5317f4ab19d2265fa1a6b4b69addb"/></dir><file name="Baseurl.php" hash="d883ba04c5294208ca5f739dc4a40567"/><file name="Cache.php" hash="217a5687dd3286d9c9b3cf58f2a35830"/><dir name="Catalog"><dir name="Inventory"><file name="Managestock.php" hash="14a89ee0b26f3dc5b4aff4090eadda51"/></dir><dir name="Search"><file name="Type.php" hash="e923c27c02f96e7915510b6fab3ff6fc"/></dir></dir><file name="Category.php" hash="f944e70e5a075e9f65219f9b37bcceb4"/><file name="Cookie.php" hash="beecbc456b5bcb505cacaecf28fc006a"/><dir name="Currency"><file name="Abstract.php" hash="1fc00525e31cda957aade1c6aeee2338"/><file name="Allow.php" hash="a2c5c466f9b413a072a7976e2fe8b967"/><file name="Base.php" hash="55deb651b2ebd1c0eeaadcc3030847df"/><file name="Cron.php" hash="e223ac8233823981444109ac69ace335"/><file name="Default.php" hash="1220941f500c43c66c9f429ab95a5ac6"/></dir><dir name="Customer"><dir name="Address"><file name="Street.php" hash="2e20de0df187cd66849517466dc3f503"/></dir><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="c73debbe5529ce484eee2a6664764dcf"/></dir></dir><dir name="Show"><file name="Address.php" hash="38b00bdf10d963fbf5be9a0302406861"/><file name="Customer.php" hash="01d91dd5d8eb028c717f319dde677ff2"/></dir></dir><file name="Datashare.php" hash="4bef7e9f6e915c869b7bb3e468415b19"/><dir name="Design"><file name="Exception.php" hash="1b418434347b54e91ea11a94fd07ed74"/><file name="Package.php" hash="6fad5ac9269998768a13ebf7c8f28b90"/></dir><dir name="Email"><file name="Address.php" hash="3ae26dc5453b9cab12263b65f83c2373"/><file name="Logo.php" hash="b4b055cddcbc6f93fa43af8a88421c52"/><file name="Sender.php" hash="d4a0fb1773ca96fa86526799495c1bd5"/></dir><file name="Encrypted.php" hash="a5e3bc1539ffbddcf6ee650bb753c978"/><file name="File.php" hash="f269d665f3a8c7b735ba8e8d63672d31"/><file name="Filename.php" hash="70979f965510f26276c850fce788eea7"/><dir name="Image"><file name="Favicon.php" hash="19d8f4d5d67d9a17ff836fe335d16f34"/><file name="Pdf.php" hash="73076a7f18b04d75c2fc4977687c4137"/></dir><file name="Image.php" hash="eb5e3b2a99384b679d28a5ecb65bcc89"/><dir name="Layer"><file name="Children.php" hash="7f15e3acc71388478f5fe0368c88b497"/></dir><dir name="Locale"><file name="Timezone.php" hash="2a26d9f5e3338e4f0f8e3af45832e940"/></dir><file name="Locale.php" hash="0fec654a0ada04afe93fa53959108a29"/><dir name="Log"><file name="Cron.php" hash="0f3ca3e8ab5ed5bd5346e3b8178367d8"/></dir><dir name="Price"><file name="Scope.php" hash="21f54c017337fec999765785ee93adb8"/></dir><dir name="Product"><dir name="Alert"><file name="Cron.php" hash="fbe701dca5435bca0298b3594efdd397"/></dir></dir><file name="Secure.php" hash="75f06d5e3930f731d1810ecf4040fa6d"/><dir name="Seo"><file name="Product.php" hash="eacb28940d8f1943ddd0bc6a5c6c98bf"/></dir><dir name="Serialized"><file name="Array.php" hash="465549589b59f486e1a2b1610e8c51f8"/></dir><file name="Serialized.php" hash="c60d1f2514fb51c45eb4583581b2ef2a"/><dir name="Shipping"><file name="Tablerate.php" hash="b3b3bd3ee066e48345883bc8c7284b3d"/></dir><dir name="Sitemap"><file name="Cron.php" hash="cd84f70fb65f34de1d7bb105b1d70914"/></dir><file name="Sitemap.php" hash="6fbef301ebe14e2c91eeef01f44f7d9a"/><dir name="Storage"><dir name="Media"><file name="Database.php" hash="9b9502d9ec58868fa6b83e5fc79d5ca3"/></dir></dir><file name="Store.php" hash="aca8ee0d6c7e407ec55570cc18ff272b"/><file name="Symlink.php" hash="9a15c42ff3c5353ed55f5137b8c3e796"/><file name="Translate.php" hash="0a9f0eadbdf8223c9fd630d59a48f1ce"/><dir name="Web"><dir name="Secure"><file name="Offloaderheader.php" hash="21d6657417a1e98b1dbd50cd3c965894"/></dir></dir></dir><dir name="Clone"><dir name="Media"><file name="Image.php" hash="3ac1b8c7a8f63980de8bf747394272c0"/></dir></dir><dir name="Source"><dir name="Admin"><file name="Page.php" hash="2dcd8a52513a711883876224ee6c5e64"/></dir><file name="Allregion.php" hash="1fbac9de5b026fd601b86fdc0e5cd58d"/><dir name="Catalog"><file name="GridPerPage.php" hash="02a52c0d61285b60c32d5681a973289b"/><file name="ListMode.php" hash="0346d08fd7779d3e706cc20a14a39091"/><file name="ListPerPage.php" hash="b9d11b022b805d53a35f3c5be95b9bd1"/><file name="ListSort.php" hash="59aca29e311b6f4cd73a3fdafa32835c"/><dir name="Search"><file name="Type.php" hash="55d156c930a534251dab32395757e997"/></dir><file name="TimeFormat.php" hash="e78f4a50376da5f4bb0d55ecb63324c5"/></dir><file name="Category.php" hash="d310a3a31ba0f8c63b023dd8c7f1fcc8"/><file name="Checktype.php" hash="e523e27f8adab92bc27d85edb7cef249"/><dir name="Cms"><file name="Page.php" hash="d3aeae3a5594dca7bd16b10ad89e55ef"/><dir name="Wysiwyg"><file name="Enabled.php" hash="dc15aa7402520623ff7a993d04a82e7a"/></dir></dir><dir name="Country"><file name="Full.php" hash="48122c72c4eb34afe1471a74e78dc3fb"/></dir><file name="Country.php" hash="1f5754ff1b70ca47a601ec9d6b6221f9"/><dir name="Cron"><file name="Frequency.php" hash="a5175f4b297eb2e465f457c76292cfab"/></dir><dir name="Currency"><file name="Service.php" hash="9804a1f449d3773a0b0071484620217f"/></dir><file name="Currency.php" hash="fbb2930a737860ccb3636136ffe1db4f"/><dir name="Customer"><dir name="Address"><file name="Type.php" hash="aee20f87bab8d750bfc597346ca72eba"/></dir><file name="Forgotpassword.php" hash="2445b9c83a9f6e55be856106c85cd3fd"/><dir name="Group"><file name="Multiselect.php" hash="8e1d29c961825cda6e8865db042e100b"/></dir><file name="Group.php" hash="1e53c280a342b4cae999d831b8ddd412"/></dir><dir name="Date"><file name="Short.php" hash="8b278bb72c56c244210a3ece4c3054c7"/></dir><dir name="Design"><file name="Package.php" hash="baaaecb855ab9c7d44126082c831e18f"/><file name="Robots.php" hash="a2e8c8e61692be022b41524e35415bbc"/></dir><dir name="Dev"><file name="Dbautoup.php" hash="4b1941d1d306dc6af2be43ca1bfdefb4"/></dir><dir name="Email"><file name="Identity.php" hash="64bc2e8b4d778a6d8e20558330d2f7b6"/><file name="Method.php" hash="473ca797528be3d9e133527597f54f05"/><file name="Smtpauth.php" hash="0f6270d9b19fbb06f6d5a3cc4b3a2a68"/><file name="Template.php" hash="b29b38261dd91671497cb8663b0853b7"/></dir><file name="Enabledisable.php" hash="81a7d243afb7a7ae4127325b6d2cb108"/><file name="Frequency.php" hash="575e6895daf761d17ee4bab4906243bb"/><file name="Language.php" hash="7fa90774ae2df6b2e431b8ed01c9b911"/><dir name="Locale"><file name="Country.php" hash="aba15c361ac56c3cd2adff69a5b45ac8"/><dir name="Currency"><file name="All.php" hash="e3f7e6c5a6d52a6bc85b40523a35db6c"/></dir><file name="Currency.php" hash="0a9b47da3e0bd3c9f277b54d8d3808c8"/><file name="Timezone.php" hash="51cc07904fd1608929f11e5b85835081"/><file name="Weekdaycodes.php" hash="a5cf00ad125276e4fd3f86242d7c042d"/><file name="Weekdays.php" hash="fe0043fa190b1f10528b8c9d56139d47"/></dir><file name="Locale.php" hash="724b6cd609273d70290113043a27a91e"/><file name="Nooptreq.php" hash="1f7970e10a3ad304da21fee21c0950a9"/><dir name="Notification"><file name="Frequency.php" hash="7c80b49e84d43ce34794043c8dd15109"/></dir><dir name="Order"><dir name="Status"><file name="New.php" hash="7bcab1d9d7a8b7793ae8da948bf23648"/><file name="Newprocessing.php" hash="e8075d23d12f396b8e0428894af86a2b"/><file name="Processing.php" hash="fd497df34e5ac49d4d62048ade815327"/></dir><file name="Status.php" hash="25d6948207ca120b11b3651ff644535a"/></dir><dir name="Payment"><file name="Allmethods.php" hash="4629ac4f9088842d403525d176690dfa"/><file name="Allowedmethods.php" hash="96675da1c82b3e146cd392f3a1bb0784"/><file name="Allspecificcountries.php" hash="d14af35b787aeaf3f2633f4d66304ce7"/><file name="Cctype.php" hash="62612bd003831821a1602d4ce49b1e9a"/></dir><dir name="Price"><file name="Scope.php" hash="1356d00f77d0fa6dbdb90a0d974285e7"/><file name="Step.php" hash="1dab2a57491b2839ac7716ef88b7cdc7"/></dir><dir name="Product"><dir name="Options"><file name="Price.php" hash="a0c84ce8ba978ef630156959e0b5dc03"/><file name="Type.php" hash="c20c44dbf8063c885e388de0eb2ad17b"/></dir><file name="Thumbnail.php" hash="46491c9be5ecd85337b33b51b26d3de8"/></dir><dir name="Reports"><file name="Scope.php" hash="c6bfc67c88d84f4b30adb94f83bba1e2"/></dir><dir name="Security"><file name="Domainpolicy.php" hash="7631bf64d39e1b68bf05d0cb76a01abc"/></dir><dir name="Shipping"><file name="Allmethods.php" hash="ab9885dde13694d5065544c0edc456bb"/><file name="Allowedmethods.php" hash="40913be5db1f2ec9e239eb4927926bc7"/><file name="Allspecificcountries.php" hash="5242e43b0c2f4907c5dccd05492ae57a"/><file name="Flatrate.php" hash="f5613b3d84039ce90a30fc928a0d8202"/><file name="Tablerate.php" hash="afdeebe2642b148d9e90e9e622096ad8"/><file name="Taxclass.php" hash="0f45581cf3adda47ff3889f0a1727df4"/></dir><dir name="Storage"><dir name="Media"><file name="Database.php" hash="d96400c2e2ced0dd3008ccaf364757d4"/><file name="Storage.php" hash="16e591b972f4b3841cbcf1ce885790d4"/></dir></dir><file name="Store.php" hash="10232c48d66e2644549735eb4606145e"/><dir name="Tax"><dir name="Apply"><file name="On.php" hash="bdb39dce24184d09d50b5e35cef6f060"/></dir><file name="Basedon.php" hash="592c6788bd5390f4ad4826a38487600d"/><file name="Catalog.php" hash="e9b90621307905f9452faaccb13b0cb4"/></dir><dir name="Watermark"><file name="Position.php" hash="d3e2d17de2b2d57534aca4f79f055102"/></dir><dir name="Web"><file name="Protocol.php" hash="1dea95ca27e52decdbd8a338dc8d2762"/><file name="Redirect.php" hash="7ba5f78ac4f044216f3b9aceb808b9ba"/></dir><file name="Website.php" hash="96665c120351a344ec3fdd8a6598fa4c"/><file name="Yesno.php" hash="600ed8f96c7eba056e21612547377b6d"/><file name="Yesnocustom.php" hash="42e39a4459cce6aba6eeb83a76ce540d"/></dir></dir><file name="Store.php" hash="cb173d714c1ec6e7e5ff5d7c90ff4689"/></dir><file name="Url.php" hash="310cc90a9fd659ef641fbc2267080df3"/></dir><dir name="controllers"><file name="AjaxController.php" hash="5a7b3797e9ef2ca0097c83fe868a1d09"/><dir name="Api"><file name="RoleController.php" hash="ebe531ce21f3d9b30a0678f81fabeb47"/><file name="UserController.php" hash="c934a1d0da97db4b20d3b989d34c5eb0"/></dir><file name="CacheController.php" hash="2d17c0b6e2f6c18c2d247c29f230c0af"/><dir name="Catalog"><dir name="Category"><file name="WidgetController.php" hash="8b35918f9a2a3d9c7129baad74e12086"/></dir><file name="CategoryController.php" hash="0a9de0f30a4a37149cd6a19f99812aa2"/><dir name="Product"><dir name="Action"><file name="AttributeController.php" hash="b85ad6500bf470aee94b456189fcd8eb"/></dir><file name="AttributeController.php" hash="09f95f07fa0b6f98e686b8c0d27015a4"/><file name="DatafeedsController.php" hash="6cfd6e07d7e6fd7bda424e9106791bc8"/><file name="GalleryController.php" hash="fd148c927b5922e1f168c7fdcff7a128"/><file name="GroupController.php" hash="a0fb677802ae528c6b9bbf1bfe2c9109"/><file name="ReviewController.php" hash="a6b3116e4bcb42a6119782f6638dd217"/><file name="SetController.php" hash="c0b759fee4fd5a39f2d6550f73506b1c"/><file name="WidgetController.php" hash="ccacb960146224f12e3439fb8d97a1f1"/></dir><file name="ProductController.php" hash="328ad1b8dccec2bc429b10b74d738738"/><file name="SearchController.php" hash="daea0f73460b35816d90afba238563c9"/></dir><file name="CatalogController.php" hash="7fb997bbd75d5d4e97f51c5605a7e5f0"/><dir name="Checkout"><file name="AgreementController.php" hash="4ac302738f4aa364651c58a1a57e70fb"/></dir><dir name="Cms"><dir name="Block"><file name="WidgetController.php" hash="6fe67533f2254d868ab074d71ebd877c"/></dir><file name="BlockController.php" hash="4784c52d57f9e2554f2da44704809071"/><dir name="Page"><file name="WidgetController.php" hash="539881fe06abf63fd2c185f71c6b71f1"/></dir><file name="PageController.php" hash="3d7454e5afc07d7c722e0f34e76b7d9b"/><dir name="Wysiwyg"><file name="ImagesController.php" hash="fdc9fc35ed49619bb784acd1867f3d05"/></dir><file name="WysiwygController.php" hash="6873086a0cfbc59ffe9ba56a9dd78927"/></dir><dir name="Customer"><dir name="Cart"><dir name="Product"><dir name="Composite"><file name="CartController.php" hash="d596bbc829a10f20a379ffaf63ef65f2"/></dir></dir></dir><file name="ConfigController.php" hash="e67ab7bac05f8eb96cf158b25540ee03"/><file name="GroupController.php" hash="6dd2c74c9a5f637b07f8bb2dd862e57e"/><file name="OnlineController.php" hash="ef4965523714e1e78fa9919f7101ce27"/><dir name="System"><dir name="Config"><file name="ValidatevatController.php" hash="552587306f03e52da672b74f3026d869"/></dir></dir><dir name="Wishlist"><dir name="Product"><dir name="Composite"><file name="WishlistController.php" hash="7de9d8c532581e4f0672f489e4a79f15"/></dir></dir></dir></dir><file name="CustomerController.php" hash="0c4f66abdcea9c6d9b7f440d78edc5c5"/><file name="DashboardController.php" hash="cb1ba21fa9317cc15ca1b814e90de69a"/><file name="IndexController.php" hash="bb7b651d76c8a875428f3c7911cf94c7"/><file name="JsonController.php" hash="0ca170d1505a2a4fb59af02408361f2d"/><dir name="Media"><file name="EditorController.php" hash="a2302405c906005930299086871fa603"/><file name="UploaderController.php" hash="3fa26d34f883159eabf0d2d1ff2c1a2c"/></dir><dir name="Newsletter"><file name="ProblemController.php" hash="a172b61ad356aabaa4b256608be0e594"/><file name="QueueController.php" hash="e420ddab5547b9df574c5139f5b9f836"/><file name="SubscriberController.php" hash="2388c51a7ff508cbce6179b011d177c4"/><file name="TemplateController.php" hash="b3e2fa20241263496b8eaa2b7266c7f2"/></dir><file name="NotificationController.php" hash="976071f7083b095a328e5622eee442cc"/><dir name="Permissions"><file name="BlockController.php" hash="2608dd88b73bc04f96fe70e076c7da51"/><file name="RoleController.php" hash="019952509d4dae9fafd3fa1024af27f1"/><file name="UserController.php" hash="e899f2277f578cbae0fa0e812e710996"/><file name="VariableController.php" hash="d01073a431417791526ad818b4371493"/></dir><dir name="Poll"><file name="AnswerController.php" hash="7376ba3ba1ebf8e7a18e5a03286e9f60"/></dir><file name="PollController.php" hash="c6d10f8210ea4d04fe311c7671e6d1a4"/><dir name="Promo"><file name="CatalogController.php" hash="5eb839a68d088fc7025f02a1a0001a47"/><file name="QuoteController.php" hash="226f6f88feda67f894caab6332f9d206"/><file name="WidgetController.php" hash="7cf2e09f792a292900207bd082e1aeac"/></dir><file name="PromoController.php" hash="e30837333c4c67d8165007aa2feab35b"/><file name="RatingController.php" hash="edaa7a0e1a01f826aa268ae40a46945f"/><dir name="Report"><file name="CustomerController.php" hash="31b219ae4ba50f4231c4cb45b9feabbd"/><file name="ProductController.php" hash="ab4e8d0060b1c77d08c4db7973b8b376"/><file name="ReviewController.php" hash="460aaa889e3ec75932cf01de98be083c"/><file name="SalesController.php" hash="378fc9ffcaf9477a2f6a85a7fab449b2"/><file name="ShopcartController.php" hash="22390ff4c733f3a3b9671b009d76ddd2"/><file name="StatisticsController.php" hash="5d30167b6686d1ff8f10da6ef6ff5833"/><file name="TagController.php" hash="195c825b6d52f786752d2264210df4ab"/></dir><file name="ReportController.php" hash="bc571493b15f2aeddbbc8b5fc9756a20"/><dir name="Rss"><file name="CatalogController.php" hash="e455ca6991a22325abf3a8b81570c237"/><file name="OrderController.php" hash="ad9f3e5b18868092ba0ae2c2a7fd59ea"/></dir><dir name="Sales"><dir name="Billing"><file name="AgreementController.php" hash="9171c69e6ebe23335ec9f06f24ab53f4"/></dir><file name="CreditmemoController.php" hash="b6facb6394f9ffb6b8007396702243f5"/><file name="InvoiceController.php" hash="3ee8a06cf0fb4328e2dd29f7a681c7eb"/><dir name="Order"><file name="CreateController.php" hash="e604a188139e556fee16e67a8d7ca68f"/><file name="CreditmemoController.php" hash="4187e62788a9f3159cea9d59b3543cf6"/><file name="EditController.php" hash="2eca9986b069dedf221126f5fd02e706"/><file name="InvoiceController.php" hash="a74dc269179ba77c8685254adf24b2ad"/><file name="ShipmentController.php" hash="1736e79b4f69023b576fe9196b81b1dd"/><file name="StatusController.php" hash="336fa850f4d08f34ba23957a0ac51bf4"/><dir name="View"><file name="GiftmessageController.php" hash="14b10af7a53b27f709dda510855c61cf"/></dir></dir><file name="OrderController.php" hash="0664c0fe82684bd4e6d30f9bfdec6693"/><dir name="Recurring"><file name="ProfileController.php" hash="0a1ef81ae9c69e4b8a7d4bdc3b474b64"/></dir><file name="ShipmentController.php" hash="f77a07dd2aaffdb419b128dcd7a43ff5"/><file name="TransactionsController.php" hash="ff60fb56c197aa26edb66d09dc485d97"/></dir><file name="SalesController.php" hash="c491e545c8b8333953489a787cdf2312"/><file name="SitemapController.php" hash="2d46ec6584606ff5327e51f819ec3eb9"/><file name="SurveyController.php" hash="22851083d8c816676d22d45ad652c609"/><dir name="System"><file name="AccountController.php" hash="dc2449b19bc120ada582b010a65bf244"/><file name="BackupController.php" hash="27e291a12b51a5fb0055cc4cd9c16634"/><file name="CacheController.php" hash="6e3c92ae2fb7f8dd70e7913d04733530"/><dir name="Config"><dir name="System"><file name="StorageController.php" hash="adb18b1a46d36eb7e3b76aec6e23724a"/></dir></dir><file name="ConfigController.php" hash="430e0be3cf04c2675ef8677aecfb3864"/><dir name="Convert"><file name="GuiController.php" hash="02f545c596531dafa55d5a0f03898271"/><file name="ProfileController.php" hash="c2e94de74c9dd4fb980bd8bda1abf0e0"/></dir><file name="CurrencyController.php" hash="47f3d181cd6c7d376196cb174c40ae4f"/><file name="DesignController.php" hash="ca36818c226ec2f9e9026ab5199e1fd9"/><dir name="Email"><file name="TemplateController.php" hash="482681d27a4f62dc03377abe8ac96518"/></dir><file name="StoreController.php" hash="b81f6c51aa31f996916ed2d229a9e293"/><file name="VariableController.php" hash="bb26c6bde2237af3075522df35f9f16c"/></dir><file name="SystemController.php" hash="df9e8a4ca6fdda1873fc9140500dd305"/><file name="TagController.php" hash="b7094e346feb452ff4f2edffd88c5664"/><dir name="Tax"><dir name="Class"><file name="CustomerController.php" hash="44181464b9076b6efb12d42c503cb754"/><file name="ProductController.php" hash="af1043ce13870b6930d619d65d02da54"/></dir><file name="ClassController.php" hash="599c1e9515eceeb6327a13240afb5e35"/><file name="RateController.php" hash="613f78cd5df1b03a1c98fd3a6ba74657"/><file name="RuleController.php" hash="4e9877e2fa290b25f206549f7f7f1389"/></dir><file name="TaxController.php" hash="ba5cef021e3bee1f5aa6600fdbe3da2f"/><file name="UrlrewriteController.php" hash="2509696e2d596e38acadf0c9946afb3e"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c9e5ea72c70800629306e7f1eccced0b"/><file name="config.xml" hash="390cf42cfcadeb4947031ad469906b76"/><file name="jstranslator.xml" hash="0c888565406549cc72904a636ffdcd63"/></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Adminhtml.csv" hash="6b21dbb385419c62dd4a3c61c9bf64fc"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.17</min><max>1.51.1.17</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_LinLibertineFont</name><channel>community</channel><min>2.8.14.17</min><max>2.8.14.17</max></package><package><name>Lib_Js_TinyMCE</name><channel>community</channel><min>3.5.11.16</min><max>3.5.11.16</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Core_Adminhtml-1.9.4.1.xml b/var/package/Mage_Core_Adminhtml-1.9.4.1.xml
new file mode 100644
index 0000000..9683ef3
--- /dev/null
+++ b/var/package/Mage_Core_Adminhtml-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Core_Adminhtml</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Administration Panel</summary>
+    <description>Magento Administration Panel</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:51</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Adminhtml"><dir name="Block"><file name="Abstract.php" hash="1d12544ff9a4179ec26ea38df2f705a1"/><dir name="Api"><file name="Buttons.php" hash="2bfed92fbddff63dc671c27b5d75ce93"/><file name="Editroles.php" hash="a1d4db198e2e99ecc9afa2f058b30e71"/><file name="Edituser.php" hash="1585e1dd89f71aed9d84c704cf9945f9"/><dir name="Grid"><file name="Role.php" hash="979c32b3dea09126c937e588d7ec0c0a"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="5fab40b01ca6d75c853417f6f182243f"/></dir></dir><file name="Role.php" hash="c6d7bd3e76b94c4f4df8ba70d8f87cbc"/><file name="Roles.php" hash="1f9b226104fc7015d6a752b12c95f5d8"/><dir name="Tab"><file name="Roleinfo.php" hash="068f8a4c1914a134ace5faa00094cf31"/><file name="Rolesedit.php" hash="29b4cbd98c0ca82453f02b4627a95c0c"/><file name="Rolesusers.php" hash="767b7483660096254eb486f5d2be927b"/><file name="Userroles.php" hash="03cc0352d61d676a30662564a5ce839f"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e797303af20e9b4c72de379330fdd76c"/><dir name="Tab"><file name="Main.php" hash="b6c71ac2f96d87c0d0a586258e9301d4"/><file name="Roles.php" hash="2817cb16b57964c029cdc991061168fb"/></dir><file name="Tabs.php" hash="83b36d6858b78b3ef1ef56102e733ece"/></dir><file name="Edit.php" hash="742b1c24fa349177cc5379f7c0eb5d0f"/><file name="Grid.php" hash="3a58107458d582950e14cfa51513077e"/></dir><file name="User.php" hash="adf9a33ed18d3c60e9ffc284f98ff6dd"/><file name="Users.php" hash="4d3ccf7be3cc39c720fa032abb0af6aa"/></dir><dir name="Backup"><file name="Dialogs.php" hash="468b3514651887904849a6e9f7d81e8c"/><file name="Grid.php" hash="d7a48a3580321c5a502950255b7965dc"/></dir><file name="Backup.php" hash="25b24ec94e7fc2b5c04b694b884597a8"/><dir name="Cache"><file name="Additional.php" hash="140342a012f58cb93e0ac7d82d02b53f"/><file name="Grid.php" hash="d6eb94996a6dd177f09a95525ceeeee4"/><file name="Notifications.php" hash="18205ad9e6a0b21ee467dcc789d19864"/></dir><file name="Cache.php" hash="2eba478582fb0d66d6732f21fd95c715"/><dir name="Catalog"><dir name="Category"><file name="Abstract.php" hash="b4d5029756e0c8e8de149156a8cde6ab"/><dir name="Checkboxes"><file name="Tree.php" hash="a30396e16cad9fc4a3d924fc81587f51"/></dir><dir name="Edit"><file name="Form.php" hash="a0cff1b2848881be054ed580ea0492ab"/></dir><file name="Edit.php" hash="28f749e9c1bf2066878b9cc7f4c44a71"/><dir name="Helper"><file name="Image.php" hash="97826fd95b6704961f976c3755ff63f3"/><file name="Pricestep.php" hash="0fbb5ec65a9fd2c13b17d9054116e0ec"/><dir name="Sortby"><file name="Available.php" hash="3baa0f9586e319e5be5ec7f1d77318f4"/><file name="Default.php" hash="8d2654ee619e84385a78b8f077b95817"/></dir></dir><dir name="Tab"><file name="Attributes.php" hash="8c37ae6f103e435d176713614cfc2732"/><file name="Design.php" hash="758a748b925e1bc5977b2c422eff7629"/><file name="General.php" hash="19f6ba72a075162228fe7606729944fa"/><file name="Product.php" hash="d18af8055e288e6537226a03f9f4f14d"/></dir><file name="Tabs.php" hash="84c926a493661a0a34fd409e20d96d10"/><file name="Tree.php" hash="4874a7a762c32f84d87c84ea63ca838c"/><dir name="Widget"><file name="Chooser.php" hash="4a8fa415e03bad3b179987b859eb8c27"/></dir></dir><dir name="Form"><dir name="Renderer"><dir name="Attribute"><file name="Urlkey.php" hash="ff7e37b0d7aa89165cae9fa598028c8a"/></dir><dir name="Config"><file name="DateFieldsOrder.php" hash="325392687355326b76a6d6b4d714958f"/><file name="YearRange.php" hash="81fc92362f8322bfe7cd478c8407744c"/></dir><dir name="Fieldset"><file name="Element.php" hash="9eed80102cc6a7e281e208aa86e99ab5"/></dir></dir></dir><file name="Form.php" hash="25150307aaef45477c387305f5e4f68f"/><dir name="Helper"><dir name="Form"><dir name="Wysiwyg"><file name="Content.php" hash="171b45a02d0f5bf62bde1358ac5e7a2a"/></dir><file name="Wysiwyg.php" hash="d3ce33132bc4220ec9b10b90f1769ac9"/></dir></dir><dir name="Product"><dir name="Attribute"><dir name="Edit"><file name="Form.php" hash="cdf3e0c7a1ec95b04888c84a1f778ebc"/><dir name="Tab"><file name="Front.php" hash="8f55cbf6f064086aadbbe74866acc26f"/><file name="Main.php" hash="4e8e7760214a3e176fd8eabbcd6a9e86"/><file name="Options.php" hash="f39e935918e8e668d5a8c54527c78232"/><file name="System.php" hash="e04ed3d2db33f456af71ad202dd78bbd"/></dir><file name="Tabs.php" hash="d9f123df155992923a370d2b5bee265e"/></dir><file name="Edit.php" hash="e53f99431ac23771abe61d4b0bfc406d"/><file name="Grid.php" hash="6ca85f95807da51938179cb20394f977"/><dir name="New"><dir name="Product"><file name="Attributes.php" hash="e84f1a4d60c284ae8849880d989c0afc"/><file name="Created.php" hash="71dfab2069f92429c1b08d50fa8145ef"/></dir></dir><dir name="Set"><file name="Grid.php" hash="f2fc5d5670e5817b2cf1cc9d26d726cb"/><dir name="Main"><file name="Formattribute.php" hash="0b1e150657f35428872d92bcc20fcec9"/><file name="Formgroup.php" hash="6ee05aa130ec4e0d26853d973185f4cc"/><file name="Formset.php" hash="203488f4962df9e69bbe67be46ad486b"/><dir name="Tree"><file name="Attribute.php" hash="85ed149d0074c657697be04bb69f2520"/><file name="Group.php" hash="bae5d15420a2b086b3710c8eb79bb99c"/></dir></dir><file name="Main.php" hash="307a3b737e4bcd2e5550e54407ebf658"/><dir name="Toolbar"><file name="Add.php" hash="16612d7c0e6efc62ae75142a6bf3cd64"/><dir name="Main"><file name="Filter.php" hash="c6eecdaacbcc665868f4a1e2114f6224"/></dir><file name="Main.php" hash="45d9726e9a6845a7911146586de27e25"/></dir></dir></dir><file name="Attribute.php" hash="35bda03c081d6583355e84b2a652aebc"/><dir name="Composite"><file name="Configure.php" hash="b67bd03a727caab2d99cbec59eb6c15a"/><file name="Error.php" hash="a11b9e86c20d87c7881e6c10821c651d"/><dir name="Fieldset"><file name="Configurable.php" hash="b66dc415373b803e75cacc0fe302f865"/><file name="Grouped.php" hash="a886ae59748a6bd05712599d9e36f59d"/><file name="Options.php" hash="6e3c0d7be774973bb7c14bc3aaf16e63"/><file name="Qty.php" hash="9475558d479812c1255f3459233dc92f"/></dir><file name="Fieldset.php" hash="f11d5ce88b7c2b2b10df891dfdffcdb7"/><dir name="Update"><file name="Result.php" hash="04d1f852a68190de43d0a7875db17722"/></dir></dir><file name="Created.php" hash="b47f62987dd532eb78540fb1ae149482"/><dir name="Edit"><dir name="Action"><dir name="Attribute"><dir name="Tab"><file name="Attributes.php" hash="c28f819e42ee059b0e0807f8c073c7e6"/><file name="Inventory.php" hash="28b622520b546658b1ce1201b4ab07cf"/><file name="Websites.php" hash="d122b9fead07ce717b812866c46adcf4"/></dir><file name="Tabs.php" hash="ee4ac2b9077429db8832401b2ebcc4ae"/></dir><file name="Attribute.php" hash="0ca8963be70c599d760e6f34520e1ca1"/></dir><file name="Js.php" hash="e261073dc1e135d7287c48a3ac6024fe"/><dir name="Tab"><dir name="Ajax"><file name="Serializer.php" hash="407bce164538ebb2699a4f630919f544"/></dir><dir name="Alerts"><file name="Price.php" hash="61d24a11322b7334f9d9159b0d54a270"/><file name="Stock.php" hash="39f246d0007135c96569cc0f677e8200"/></dir><file name="Alerts.php" hash="71877f70f839bc3311400a8b0f74ad1c"/><dir name="Attributes"><file name="Create.php" hash="abd39e94d61a77f718a447d16a00a911"/></dir><file name="Attributes.php" hash="452ab3f3424dc9693e4f1cb3f8f0bd84"/><file name="Categories.php" hash="96e5cb356bb207156dad4ca8fd953239"/><file name="Crosssell.php" hash="3fb1a2644748deac0667915369a125b4"/><file name="Inventory.php" hash="f6dc9b47afa451a07fcaee2bee4b4c90"/><dir name="Options"><file name="Option.php" hash="b1f8e3381c100602006315d01fdfae9b"/><dir name="Type"><file name="Abstract.php" hash="03e4e1f2a23529b61d9cd6b2356048f3"/><file name="Date.php" hash="486db1c7e03c9009933622a04f93b4b1"/><file name="File.php" hash="bdc8a288f3612adc368a1eec9555ea60"/><file name="Select.php" hash="73477e9768fae45a4d53b074d23760a5"/><file name="Text.php" hash="2171a4e312504df88008d4bcda2d7e4b"/></dir></dir><file name="Options.php" hash="a62eb8c69acc3164765a2a58380d4eed"/><dir name="Price"><dir name="Group"><file name="Abstract.php" hash="7fcb2806533cf4005992cd5f6aba2c93"/></dir><file name="Group.php" hash="1861d97732bdee01154cc39c3bf4b345"/><file name="Recurring.php" hash="4a03f89a26555b68be76e630de5347c6"/><file name="Tier.php" hash="f214bc620608440dc393092faf045094"/></dir><file name="Price.php" hash="fa49ddddedc8937e9db216713dc50742"/><file name="Related.php" hash="58139c20fb9deffb1b28aa7d4081be30"/><file name="Reviews.php" hash="89efeb2d1d07e92aea33e26b0c91b0ac"/><file name="Settings.php" hash="be4f8669f07a1a1951b1ecacd9fc328b"/><dir name="Super"><dir name="Config"><dir name="Grid"><dir name="Filter"><file name="Inventory.php" hash="02c8d622fdb61b9c4dbacca7a7b2cfdc"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="9ee83d276e1f9e851450ef377f1051a9"/><file name="Inventory.php" hash="2c305eed32d570d0743b2ded6ff77c40"/></dir></dir><file name="Grid.php" hash="9080fb1a0e252b37f6424ae05ac23fe9"/><file name="Simple.php" hash="4f4c795463b3bf7e302210163b85b4e8"/></dir><file name="Config.php" hash="9d21bfac241042373e81b36b7cd81fa9"/><file name="Group.php" hash="96d08a2ea0ff1fea50370f3741d6d1de"/><file name="Settings.php" hash="199168163f1340c262863bbfdcac7361"/></dir><dir name="Tag"><file name="Customer.php" hash="d1bc2fff71591e0938f7897a9d5e7435"/></dir><file name="Tag.php" hash="5a9a5345a8820830974f7701e42157f8"/><file name="Upsell.php" hash="78025ebd67d64b038b4d7a4082b99b2d"/><file name="Websites.php" hash="69d0d1aa6951622e378ec284e968bca5"/></dir><dir name="Tabs"><file name="Configurable.php" hash="a9b9ff4f7e7c8e76b6eb63a1022e5298"/><file name="Grouped.php" hash="4b0d7e5766e03b7ec4e13892cce63e35"/></dir><file name="Tabs.php" hash="990c3877e7ac14972c42b1615b6d2f61"/></dir><file name="Edit.php" hash="a77985102f5bc9500d8d999bdb640aa8"/><dir name="Frontend"><dir name="Product"><file name="Watermark.php" hash="c8fdddc408ff23b4a2e0cc9940452532"/></dir></dir><file name="Grid.php" hash="4415c85c4c6cfe9ebad25dbb4a570a7d"/><dir name="Helper"><dir name="Form"><file name="Apply.php" hash="ebdec21e1d86ebb91f61f05235b02c0d"/><file name="Boolean.php" hash="b3790b5b035c6d68c7478cb9362dd196"/><file name="Config.php" hash="0c59e94f97e820a46bb5f21e548363d2"/><dir name="Gallery"><file name="Content.php" hash="4ed8b17993adda5daccaec874cf516d2"/></dir><file name="Gallery.php" hash="cad37730c4c135877ce4467a7d01176b"/><file name="Image.php" hash="6241be43f381a5a0821f4dcab824f8eb"/><dir name="Msrp"><file name="Enabled.php" hash="a44f68cbf40a6c4b8d730349e5dea567"/><file name="Price.php" hash="c8fe461530d7de62b64a4f0d5d313d21"/></dir><file name="Price.php" hash="eee51e79b5c100190b1ac01090cb8ac4"/><file name="Weight.php" hash="0c7bf1ab444bd1af1d7fdbd7bcbfe828"/></dir></dir><file name="Price.php" hash="63b3d5a6a44de5108c06a15a58166d7f"/><dir name="Widget"><dir name="Chooser"><file name="Container.php" hash="162b5430206fdb7dcaa404ce8f122660"/></dir><file name="Chooser.php" hash="a13ab5cc27f3b108c83da378799c7845"/></dir></dir><file name="Product.php" hash="6221f39a3224f6c5ab50d0c906dfc6f8"/><dir name="Search"><dir name="Edit"><file name="Form.php" hash="a42b407c9a9f47092df32f565297b3b6"/></dir><file name="Edit.php" hash="bdb5ad67da655778ffacd912a07df423"/><file name="Grid.php" hash="f3ebd37ea9b57148d2f233f4d6d132b0"/></dir><file name="Search.php" hash="96a2febc55af4f9a3445def312b2f4d1"/></dir><file name="Catalog.php" hash="28eb5e6b2060460cc0308a9115ce4874"/><dir name="Checkout"><dir name="Agreement"><dir name="Edit"><file name="Form.php" hash="9151175340c1cf3787cbff6f52d31895"/></dir><file name="Edit.php" hash="64f603054370f2a77077249828a7bd6e"/><file name="Grid.php" hash="c56ef0e787a8d2f2555663e950f17fd1"/></dir><file name="Agreement.php" hash="ef6402bcc1e58c9b1598c8dc606b977d"/><file name="Formkey.php" hash="33506381a0bc723b94bd4635fc1fc555"/></dir><dir name="Cms"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="a9a37434f2f77967cb1d71dc725cc2f0"/></dir><file name="Edit.php" hash="dce0c8f690bdd9f5f0a7f781e15bb8da"/><file name="Grid.php" hash="8535d143498e9361d46364210f40aa60"/><dir name="Widget"><file name="Chooser.php" hash="55b9d76cbb369cdb0263a53f964fc564"/></dir></dir><file name="Block.php" hash="3f6f0192cd2a00850d9af6f3e825c3fd"/><dir name="Page"><dir name="Edit"><file name="Form.php" hash="31930639349c990f654e48fb7691a36f"/><dir name="Tab"><file name="Content.php" hash="e4e99ec295b2bb66cac94dd13410c0ab"/><file name="Design.php" hash="5545e1f1b1b716fff48325c364d795b3"/><file name="Main.php" hash="c1204a5bb8cb4bec6b7cb957374863d7"/><file name="Meta.php" hash="71472514e5e64d34807485bd9d4a12fe"/></dir><file name="Tabs.php" hash="6028f105ec1c60a4a41379fa41fef0f0"/></dir><file name="Edit.php" hash="283dd2ba93961f05baafa9ae641e99e2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="b69a369f078299372a0dc2684ddbba87"/></dir></dir><file name="Grid.php" hash="d2580f2a2a20a80ebf446191da59d9bf"/><dir name="Widget"><file name="Chooser.php" hash="3861c825efbae550f7c5b874a832973a"/></dir></dir><file name="Page.php" hash="44c1d2c7672727bcb5f617f4895e067a"/><dir name="Wysiwyg"><dir name="Images"><dir name="Content"><file name="Files.php" hash="dfe9b5f9cc1e88b7a92c89cae607ca56"/><file name="Newfolder.php" hash="abf8f9db9780ae6d4795c323225abb24"/><file name="Uploader.php" hash="c90b036837f00ee86c18d5e03cf56c56"/></dir><file name="Content.php" hash="18332e1d078c402dfd6db5b97c1f33d5"/><file name="Tree.php" hash="cabff9304c30720fe46e55e9f97fa6bd"/></dir></dir></dir><dir name="Customer"><dir name="Edit"><file name="Form.php" hash="88a9be8c62c08488c6f827d6e265b969"/><dir name="Renderer"><file name="Adminpass.php" hash="360c3517de650b9ec57a7f4f6730fcf8"/><dir name="Attribute"><file name="Group.php" hash="3161a779443b4944aed44ed266212aa9"/></dir><file name="Newpass.php" hash="445763b68a969eaae5ad2b780304d845"/><file name="Region.php" hash="e042b4f141569c7bb2ca7c309cd78c8f"/></dir><dir name="Tab"><file name="Account.php" hash="c3b7b882e2d87695d8f204d57ff2ffcc"/><file name="Addresses.php" hash="6be0f07b01c229f200ca47723c991567"/><file name="Cart.php" hash="6dbd28473e97889cbb12d799f992e84b"/><file name="Carts.php" hash="b487cfbfa014ecac68c1772b8dcafbb9"/><dir name="Newsletter"><dir name="Grid"><dir name="Filter"><file name="Status.php" hash="b75c661699fab3163db9b05484f184a6"/></dir><dir name="Renderer"><file name="Action.php" hash="83f1619271d589cf2f98266eb2b298b1"/><file name="Status.php" hash="12cc0385800c2654faca3e1b3191a36b"/></dir></dir><file name="Grid.php" hash="e6bfbaab166055bc97ca6a430fc24f57"/></dir><file name="Newsletter.php" hash="0b4a34626577789ab75efea769dcaa7d"/><file name="Orders.php" hash="61aac0bcd2a87580599e1cd4d0bb2e51"/><file name="Reviews.php" hash="31efe9289ff7e87eff54c179c24dba6f"/><file name="Tag.php" hash="5b1b636cae3e66210eba1bc6a3e39c36"/><file name="Tags.php" hash="f90b0d2468019f8dbaea8c576936b547"/><dir name="View"><file name="Accordion.php" hash="81facad941d92464a28f6fd5614fb608"/><file name="Cart.php" hash="8d9b2b37138a6fd89b983c7f270b03ae"/><dir name="Grid"><dir name="Renderer"><file name="Item.php" hash="f2d36c6018a1975b0f9d983adfe245ee"/></dir></dir><file name="Orders.php" hash="fed6b2896c91e422e69f1a600ec8d9cc"/><file name="Sales.php" hash="b731082a6fc2dfa9b3fe8a5d6bf309e8"/><file name="Wishlist.php" hash="961d8c040d2292cb7197c89e63b144a3"/></dir><file name="View.php" hash="f96caeaa728561efb18187444b7b0685"/><dir name="Wishlist"><dir name="Grid"><dir name="Renderer"><file name="Description.php" hash="f53f9167df22e37e68faca9d2ce333bb"/></dir></dir></dir><file name="Wishlist.php" hash="10461d6a242274497dd19094c022df58"/></dir><file name="Tabs.php" hash="3ded30ea877555bff0ca42610af96bfa"/></dir><file name="Edit.php" hash="5ea2cb0668eec0f0c7146ba39960a715"/><dir name="Form"><dir name="Element"><file name="Boolean.php" hash="fc6a5684ed07f3f41e4c06e7344d908c"/><file name="File.php" hash="4eb0ff4d329073aad2265381c01a0f0c"/><file name="Image.php" hash="2de933a0ef21a707e21381dbe2419b22"/></dir></dir><dir name="Grid"><dir name="Filter"><file name="Country.php" hash="0f1bc3cfad87222867e25a52cd605172"/></dir><dir name="Renderer"><file name="Multiaction.php" hash="4efa42b2e04948a2f64e85309c85cb1d"/></dir></dir><file name="Grid.php" hash="c3bb6f389beb5e149f919fc69c6627e9"/><dir name="Group"><dir name="Edit"><file name="Form.php" hash="e6fea58502cdea637c0157ea59f16c0f"/></dir><file name="Edit.php" hash="d2f99b544dc8b14184f2e9f6cce51d1a"/><file name="Grid.php" hash="12c7160547939438100ef7ae261ac225"/></dir><file name="Group.php" hash="eaec4acad81f69ff1a27a54122610050"/><dir name="Online"><file name="Filter.php" hash="ffe20662f60e0b779c926abe5ff6d971"/><dir name="Grid"><dir name="Renderer"><file name="Ip.php" hash="61400fedbbe4636ffb8a5bc1c6e75490"/><file name="Type.php" hash="150f363f91d9fb883f44b5dba8b141eb"/><file name="Url.php" hash="26161955ae6ad2c9d54d86ca20915b59"/></dir></dir><file name="Grid.php" hash="1eacff4ddfd493f6c221e0f165bab92b"/></dir><file name="Online.php" hash="089a608976c37ba29631514fd95365ca"/><dir name="Sales"><dir name="Order"><dir name="Address"><dir name="Form"><dir name="Renderer"><file name="Vat.php" hash="673cd679f9d5d7a8eb49968dfdff866f"/></dir></dir></dir></dir></dir><dir name="System"><dir name="Config"><file name="Validatevat.php" hash="6c44b4cf2a4532dfef9f33a40d527f40"/></dir></dir></dir><file name="Customer.php" hash="0bd1275ae095c7f5b48d0dafd013cce0"/><dir name="Dashboard"><file name="Abstract.php" hash="e9b622f22beaede0e7d097444be1f744"/><file name="Bar.php" hash="55433f04b2b15053d07f6b6d80ca6e8e"/><file name="Diagrams.php" hash="15341f9925a159eca333fed855d569f1"/><file name="Graph.php" hash="f20a65054e9186820dc0527092f7b30f"/><file name="Grid.php" hash="9468ed7c5da000af3cd3354dbcfbe3e9"/><file name="Grids.php" hash="2235cdd24831e25fad2aaac38789ecc7"/><dir name="Orders"><file name="Grid.php" hash="f92d2a66236995ae2e3951c54b24c436"/></dir><file name="Sales.php" hash="f3365fc3d801700304cee4aa373e9ce9"/><dir name="Searches"><file name="Last.php" hash="9bb819e172cbea12c16e4cda910f24b0"/><dir name="Renderer"><file name="Searchquery.php" hash="01e38618ae9218a3ad748a0a8d22fc7a"/></dir><file name="Top.php" hash="e9db73d797a14f1494e152ebf7269f72"/></dir><dir name="Tab"><file name="Amounts.php" hash="de998abe0165fb810473b79a1f1bc52b"/><dir name="Customers"><file name="Most.php" hash="a95156aa6735fffae2e592b17833cda6"/><file name="Newest.php" hash="d59d800b48df42ae85c886c76e9cd840"/></dir><file name="Orders.php" hash="95dc17af38b3fe3ad4be51fd191e6b52"/><dir name="Products"><file name="Ordered.php" hash="1ecba3f7f07991aabd7be7b185c71894"/><file name="Viewed.php" hash="3d68267acd0253df57f17deff5408d19"/></dir></dir><file name="Totals.php" hash="3dd71832f902929b1a06defb8b2e4887"/></dir><file name="Dashboard.php" hash="3fca911a8afb8417625a04318171f6a5"/><file name="Denied.php" hash="55a2dc1b2b2839eece570dd602ee040a"/><dir name="Html"><file name="Date.php" hash="147063fc866d415b9376a07fbee91a8d"/><file name="Select.php" hash="48b825c9be24ec326febf95f5c9449fc"/></dir><dir name="Media"><file name="Editor.php" hash="6e1604888e79ece680f2764aa2a7dd39"/><file name="Uploader.php" hash="0c0851fbef753a9b982d225b498c7fd9"/></dir><file name="Messages.php" hash="917f968f40fde4c6d94b639deed48bdb"/><dir name="Newsletter"><dir name="Problem"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="a3ee987724942adc84bfe94f8c6139ed"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="b1a2993d634b5db32a8140c18f673868"/></dir></dir><file name="Grid.php" hash="7159ed12e2b23ddfa9061061f5e9fd54"/></dir><file name="Problem.php" hash="0ee1f8f1267589d18f0ad4b3356ae886"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="dfdf35631ee8819a94119def8e936d2d"/></dir><file name="Edit.php" hash="b9de2cb9df47de6d328fb3ebe079e85f"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="25d234ab87104931892193f5c2ff307a"/></dir></dir><file name="Grid.php" hash="f193f8d007edbe4ee0ef0f496de1bb01"/><dir name="Preview"><file name="Form.php" hash="e4f8a2f7926bc6459b427d082a9bfd1b"/></dir><file name="Preview.php" hash="f51c6a0924a89de4776b659bdc1e69cd"/></dir><file name="Queue.php" hash="b24837a0549af04763b22fac18f900c1"/><dir name="Subscriber"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="81d31d0057e780de4ddd38beab5bac38"/><file name="Website.php" hash="18a46ee8a8cbef2af8da175d84fcfb8c"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="7889c89f8832a14518e3329ffc81e657"/></dir></dir><file name="Grid.php" hash="372b9dee90b9f94802f8f9248e131eaa"/></dir><file name="Subscriber.php" hash="5d02591f5d99b9a034d35274546b2cfe"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="239143579f0958e949bb9a7d1215c947"/></dir><file name="Edit.php" hash="a8f026033bff8c435c5a90ea9684c55d"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="af0f7297d0de92d7e0ca2eb97b4b195e"/><file name="Sender.php" hash="cc7e96026bf1a720199994ac121ec236"/></dir></dir><file name="Grid.php" hash="8adf36fa829d54964b79c902c35cc4b5"/><dir name="Preview"><file name="Form.php" hash="3aae730608509c2de996e87f33535bdc"/></dir><file name="Preview.php" hash="ad20db0f12048a51d398f71ba2880768"/></dir><file name="Template.php" hash="52e9a3e5ba6a48950bec070e7108de08"/></dir><dir name="Notification"><file name="Baseurl.php" hash="f465f0f939bacf140e17e2a73c68f648"/><file name="Curl.php" hash="5562dffe8f544de14477d633c58d11a5"/><dir name="Grid"><dir name="Renderer"><file name="Actions.php" hash="8a92a77ba89231ce3875212b265feb2f"/><file name="Notice.php" hash="d9d8f4a5657ac3ea69460beb094fab44"/><file name="Severity.php" hash="49a1c0f2b3e3dac83ea17bc415700737"/></dir></dir><file name="Grid.php" hash="b69968b2ffc329bd0d04e6e92cf3c389"/><file name="Inbox.php" hash="cf88df1189b59b5d80e3d80f5c5b5ee2"/><file name="Security.php" hash="a9bf2769b39a9fea4a4ee3ef3d1d9e30"/><file name="Survey.php" hash="1e212b6d13543cd10be01e2b15d60aa6"/><file name="Symlink.php" hash="9666c29f2f3fe03eaf4eaf9ffde45ef4"/><file name="Toolbar.php" hash="a32fa374fd13357033a99c4e41328ed7"/><file name="Window.php" hash="ae90e32783c39946ae4dc1bea9f8ca93"/></dir><dir name="Page"><file name="Footer.php" hash="d1a4e2acaf969095729041c182ca097e"/><file name="Head.php" hash="fe8b20f2fc855b15eab3ebae500b6c4d"/><file name="Header.php" hash="4043dddbd522d15fcbf30fa6b905941d"/><file name="Menu.php" hash="93fc054fa2e6052f07897cd941adb515"/><file name="Notices.php" hash="7298bcaba60c7a5433cccc0ef8fb4869"/></dir><file name="Page.php" hash="79ff758d432530488292c1d04d45be3f"/><dir name="Permissions"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="250070fd2e5ff2b561696484204f1b26"/></dir><file name="Edit.php" hash="84137babee7bfaf5d74ec8d1abe7bc94"/><file name="Grid.php" hash="2af86b670dfa0daafa87c68549248c42"/></dir><file name="Block.php" hash="ba75e154ab0dacea1a496f5dddff3ee5"/><file name="Buttons.php" hash="cc95103c467e1690fa1a3af947d41934"/><file name="Editroles.php" hash="7000bd2a967324d4d8f59d9fba69e994"/><file name="Edituser.php" hash="37fd49b06155831e001aa72616c59334"/><dir name="Grid"><file name="Role.php" hash="e664e65f34a4a2388646dbc1593f2459"/><file name="User.php" hash="ff6e1722cf7d2dfabbc81714030e0900"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="d4c1d8bd47dcef72be788628e4691b75"/></dir></dir><file name="Role.php" hash="af24afd4eb11f6285219e4b0f49ea70d"/><file name="Roles.php" hash="97918d7e78298f17f35d7443d5bd0397"/><dir name="Tab"><file name="Roleinfo.php" hash="d3d1b327c9ee471c97b8c811024df0f5"/><file name="Rolesedit.php" hash="94acaaef7675950120a511958a16e3fe"/><file name="Rolesusers.php" hash="1162dcc0461c5d27aa79632950888a48"/><file name="Useredit.php" hash="d299e6842fe7c46578c54e0987c79429"/><file name="Userroles.php" hash="99621d6b7b827435b75ebdd609b9b558"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e56981d6fca4121ddc406e8c4888191d"/><dir name="Tab"><file name="Main.php" hash="14a3fc3b16f5834c34840ec6af6fe852"/><file name="Roles.php" hash="39263f8d830d709a68c1d3ddb3c5023c"/></dir><file name="Tabs.php" hash="dec4daa38e5951c969353b03f2d651e6"/></dir><file name="Edit.php" hash="bb570d5036d34531b46fd29c813f9234"/><file name="Grid.php" hash="66f37feace5315656052e355cf1030d7"/></dir><file name="User.php" hash="e566d45d3baba405d9c8d464c0face4c"/><file name="Usernroles.php" hash="5db4ffc12fef23f814dd5402e74e738f"/><file name="Users.php" hash="ee78f2adc119a2fc2ffe8a89ceebd57b"/><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="c386f51bfb9ce0bd67f6f85750bca473"/></dir><file name="Edit.php" hash="9cebf0be6ab18ef6682bae2c95ec316f"/><file name="Grid.php" hash="6768cd076848b08656653fac8c9304dc"/></dir><file name="Variable.php" hash="854436ed296fa61143eaad2012e00be2"/></dir><dir name="Poll"><dir name="Answer"><dir name="Edit"><file name="Form.php" hash="d1d567516ad5d195f58118d74a3c9485"/></dir><file name="Edit.php" hash="ea60da414febac398ad8a5f7e960a4d4"/></dir><dir name="Edit"><file name="Form.php" hash="f49681920874b6306db0b84bcddf29fb"/><dir name="Tab"><dir name="Answers"><file name="Form.php" hash="e4352cb54881242eeb76e16d3d0d57bf"/><file name="Grid.php" hash="72fe16bf15a5afba06165e359dafb80e"/><file name="List.php" hash="2689aa93a8757a2c622930cc30578fe6"/></dir><file name="Answers.php" hash="16b63468731527503a41202fa1210462"/><file name="Form.php" hash="fb78e237210fc3aaacafa7a260e08aaf"/></dir><file name="Tabs.php" hash="5d78bfe8c000e5dc45436bafa25d3006"/></dir><file name="Edit.php" hash="cf70265c9750388d2cdd235c5a92696a"/><file name="Grid.php" hash="37e4d5a930b9f642f3b5a98edcd667cd"/><file name="Poll.php" hash="438e44affda9859ccc07067d873e6640"/></dir><dir name="Promo"><dir name="Catalog"><dir name="Edit"><file name="Form.php" hash="8a71206ef66c7370119b4f2b348edabe"/><file name="Js.php" hash="0489e9289d574d351faf222342f3e5c2"/><dir name="Tab"><file name="Actions.php" hash="756556f16aae2e7d5099dd9ac0d6c3d9"/><file name="Conditions.php" hash="9fc57c4ed418a0cec1bd2006983d57bf"/><file name="Main.php" hash="068a51f801b94b4fdd7f2352f838c2ef"/></dir><file name="Tabs.php" hash="98c91073906792a0c6296fb83a7ab330"/></dir><file name="Edit.php" hash="99dbb202deb0b9f05801a63e42d31b0d"/><file name="Grid.php" hash="22be7c2ac5741cbe5d060c89cfd39f49"/></dir><file name="Catalog.php" hash="1ae39c43c5f75785edf1c5324a4290fc"/><dir name="Quote"><dir name="Edit"><file name="Form.php" hash="4a8463187cb19e25ea975cc2ed11d664"/><dir name="Tab"><file name="Actions.php" hash="ed58616f357944eb2f73a28f7efc1e39"/><file name="Conditions.php" hash="7febefb8d3f16e24e2bd3fa260135955"/><dir name="Coupons"><file name="Form.php" hash="d98e35ad0a8920bfbd3ef6c71978859f"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Used.php" hash="226bef3f5347cf5f87223f15602fcb58"/></dir></dir></dir><file name="Grid.php" hash="b8f3bb64730a0ad22621d4de28e4934a"/></dir><file name="Coupons.php" hash="6b15976a6d1f15012490237346d6057f"/><file name="Labels.php" hash="0374ba4e22cb6afe418cd0a2a85020cc"/><dir name="Main"><dir name="Renderer"><file name="Checkbox.php" hash="18855aea907c954a5475117a205635ea"/></dir></dir><file name="Main.php" hash="2bdacfbe90630bdd2ee8f23a66b64dd3"/></dir><file name="Tabs.php" hash="1bd68564db436b417f488bac6e097758"/></dir><file name="Edit.php" hash="8ce5af06e914dae03f0886ea05866af2"/><file name="Grid.php" hash="2a5f9302cce1fb40f796cc592299a524"/></dir><file name="Quote.php" hash="13e7c6d67080c994fb2a1cc59404406c"/><dir name="Widget"><dir name="Chooser"><file name="Daterange.php" hash="70bf48e3059b5118e63343e17948229d"/><file name="Sku.php" hash="2f0b0875caa8efd274aa26efa2334fe8"/></dir><file name="Chooser.php" hash="7db7b478b3c1b1595c483b4268aecdc4"/></dir></dir><dir name="Rating"><dir name="Edit"><file name="Form.php" hash="e21a9307f72c2026b066d7557ce9c57f"/><dir name="Tab"><file name="Form.php" hash="d7d970cc0d7d9dd10d7a03e808a8aed4"/><file name="Options.php" hash="106e1377ecef0876c9bd2542335c6435"/></dir><file name="Tabs.php" hash="f9210a4da76b60fc6446f5cb7addccad"/></dir><file name="Edit.php" hash="c72a2464231e82c381f94454562eebbc"/><file name="Grid.php" hash="eb80f7c545a4a0071addfe7f015da33c"/><file name="Rating.php" hash="39bb6e11d3bae43bfb4d35169ee4e41b"/></dir><dir name="Report"><dir name="Config"><dir name="Form"><dir name="Field"><file name="MtdStart.php" hash="a924ee763c18e3ed80b87d748f282cb2"/><file name="YtdStart.php" hash="cdb5ef1ce2da5813d13fe8f72a7079f7"/></dir></dir></dir><dir name="Customer"><dir name="Accounts"><file name="Grid.php" hash="125f58e5a98c21f5c7f41af2f18e1ba5"/></dir><file name="Accounts.php" hash="ba03c8be6d24be78a3348205d7b1c59b"/><dir name="Orders"><file name="Grid.php" hash="3b6c90bf0a2d500f55c37c463476e022"/></dir><file name="Orders.php" hash="b2bcb3c005b9d3b5e79640eb56b3085c"/><dir name="Totals"><file name="Grid.php" hash="53a10e918398bb631825e0834fffcfd8"/></dir><file name="Totals.php" hash="d6922f6143aeb8edc9b420afed078929"/></dir><dir name="Filter"><file name="Form.php" hash="d5b993228db6ed19ef0db663fe9e7815"/></dir><dir name="Grid"><file name="Abstract.php" hash="33f0615bff06d6080788293420ae1e03"/><dir name="Column"><dir name="Renderer"><file name="Blanknumber.php" hash="264f57bbe36d99209dbe4a459c860c9a"/><file name="Currency.php" hash="e6f4db3f02df326305086b0fb4a0af56"/><file name="Customer.php" hash="9347c243bfbe02bbf19b86e1eec157e6"/><file name="Product.php" hash="f9addb0013529e496f972c221f32ad40"/></dir></dir><file name="Shopcart.php" hash="897da04c70099203dc40de8f5c75706c"/></dir><file name="Grid.php" hash="7f61478562abc700c6e845e3a5f6dd63"/><dir name="Product"><dir name="Downloads"><file name="Grid.php" hash="09b580cf3a9b12333b637671c3d6a977"/><dir name="Renderer"><file name="Purchases.php" hash="31ebc48790ea8d1796aff7a0a26a98b0"/></dir></dir><file name="Downloads.php" hash="2601b484b6ec5f115f2c134b3ed56c6c"/><file name="Grid.php" hash="9739764d528da1173b74476aeaa90343"/><dir name="Lowstock"><file name="Grid.php" hash="d0cc3ec79ae288d3480dfeeb49396c0d"/></dir><file name="Lowstock.php" hash="606e6f1affec1d43c4a2d2169a0c2219"/><dir name="Ordered"><file name="Grid.php" hash="654181d62c7cc2623e3f97ab10e86d26"/></dir><file name="Ordered.php" hash="a16dad58467e0e2226a414dbfc4c00b0"/><dir name="Sold"><file name="Grid.php" hash="1966a5e024bca07b470fbd397c872be3"/></dir><file name="Sold.php" hash="7a6e7b04579774dadc2be4047b3ae258"/><dir name="Viewed"><file name="Grid.php" hash="b1d1e9daae03ff525976ef8bc1241688"/></dir><file name="Viewed.php" hash="44359a7eb23f239951867a192ffb73a6"/></dir><file name="Product.php" hash="b12b9b84f824c934beb2aa12f65047e3"/><dir name="Refresh"><dir name="Statistics"><file name="Grid.php" hash="464179727ceb08e438e264b02ab15883"/></dir><file name="Statistics.php" hash="c481a493b5a1bcacfc6667e1e3375ae5"/></dir><dir name="Review"><dir name="Customer"><file name="Grid.php" hash="eaeb6261c45a8a129afc019a40571971"/></dir><file name="Customer.php" hash="df0464f31e9650434fbe505d2b5d6fc6"/><dir name="Detail"><file name="Grid.php" hash="48a704b1a6307f9997d1c401e071a188"/></dir><file name="Detail.php" hash="e92d6d12ad04061df9a012d4d2427b6e"/><dir name="Product"><file name="Grid.php" hash="49466f8a9c3731ea13ae75b354da2388"/></dir><file name="Product.php" hash="36570e05c5e34a57de894ae2ce35157f"/></dir><dir name="Sales"><dir name="Bestsellers"><file name="Grid.php" hash="29dbb485598a8d96cbdfb9876d189443"/></dir><file name="Bestsellers.php" hash="dece62b23890be79025bce175a8873ad"/><dir name="Coupons"><file name="Grid.php" hash="2aa7f3681c09b4d48f3d9d17d71f5a99"/></dir><file name="Coupons.php" hash="231ae689b8b1369b863751203f5f6e56"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Date.php" hash="57689030e9f44bd0253341acc821f4e4"/></dir></dir></dir><dir name="Invoiced"><file name="Grid.php" hash="490362b3d8b9474ded06a9af9176222c"/></dir><file name="Invoiced.php" hash="cad6ff9f84bd43374ca9b1f47fa5265c"/><dir name="Refunded"><file name="Grid.php" hash="104056775346b260c39b570e2c29c77b"/></dir><file name="Refunded.php" hash="53cf2c3212b5414a8448e53d327d739b"/><dir name="Sales"><file name="Grid.php" hash="1771f104565bc2a606cbcf662b5a6f95"/></dir><file name="Sales.php" hash="b564b60052182d9d7989c810250c1525"/><dir name="Shipping"><file name="Grid.php" hash="179ac71bc9e787df09c2d697d844fd50"/></dir><file name="Shipping.php" hash="c7650cc6c9ad2e168856e6bdbfd60d31"/><dir name="Tax"><file name="Grid.php" hash="13f4fce239c6834032118bbb95a85746"/></dir><file name="Tax.php" hash="03bb6ddb944a0f6cb818b8cb765ba928"/></dir><dir name="Search"><file name="Grid.php" hash="db8fb084a7392cffb50c8988b255048d"/></dir><file name="Search.php" hash="3d903ea0062a23a38afdb6257277ef69"/><dir name="Shopcart"><dir name="Abandoned"><file name="Grid.php" hash="11bfeff5565ac8391cbe21ad8dbc634e"/></dir><file name="Abandoned.php" hash="6c275144d3c233203b915836a99b9256"/><dir name="Customer"><file name="Grid.php" hash="33f38ff6795ca48a865be1ba8c1b626b"/></dir><file name="Customer.php" hash="46176721eeaf6b1d13cbd2ee4aac9c32"/><dir name="Product"><file name="Grid.php" hash="9863a30d2c53906b3a650bc4944fb60d"/></dir><file name="Product.php" hash="8db7478a73364dbe0f6b743eb796eeb4"/></dir><dir name="Tag"><dir name="Customer"><dir name="Detail"><file name="Grid.php" hash="e7ae098944aaede6d0e634ec58d7b1ba"/></dir><file name="Detail.php" hash="6c1d2a0744e3c1e47bd0d0b4e7f94896"/><file name="Grid.php" hash="38856f03efc67f4a26af2172a1af3a0a"/></dir><file name="Customer.php" hash="46ff79f5e4a9f582bce155b0f7b8ae1f"/><dir name="Popular"><dir name="Detail"><file name="Grid.php" hash="b03fc43b10d29d5a398b73cd1c2dbea3"/></dir><file name="Detail.php" hash="27d0cbb728aac205394a42c1ab85c5c4"/><file name="Grid.php" hash="d18cf3969a7adad625b60b28941a7270"/></dir><file name="Popular.php" hash="bb4e3f5e49419d3c8eda46df6aaa4f70"/><dir name="Product"><dir name="Detail"><file name="Grid.php" hash="b1450dab9226d4a9b2e84c1ce6cf6e5c"/></dir><file name="Detail.php" hash="5e836c4da0c50d12e616d5b6a129acea"/><file name="Grid.php" hash="ab880e5c3a6cc0b4e3efb3933e42b1c1"/></dir><file name="Product.php" hash="622c74aba260ccb80b7cd0466b254740"/></dir><dir name="Wishlist"><file name="Grid.php" hash="30c6507df24b9530e52d9abf2d72db92"/></dir><file name="Wishlist.php" hash="29c55462d5a7ba74bf944920ba32b88e"/></dir><dir name="Review"><dir name="Add"><file name="Form.php" hash="afaad3889588d19e78c5358ca31053bf"/></dir><file name="Add.php" hash="bed0d84fbce29827765e870bff16db74"/><dir name="Edit"><file name="Form.php" hash="d94544827780e99378670555538e6b12"/></dir><file name="Edit.php" hash="5131aae643eb8061ce598c127cff9fa4"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="7768070f8509625a9a2cc0178fbb42a2"/></dir><dir name="Renderer"><file name="Type.php" hash="a5871202c5a258f69c23fd938d840062"/></dir></dir><file name="Grid.php" hash="973b7c8444c20e7c6cd2fb3b5bee8320"/><file name="Main.php" hash="486e69de5935dc1233cb6272437d90cd"/><dir name="Product"><file name="Grid.php" hash="045dbe8bfe4482d83b8a1d41622908bd"/></dir><dir name="Rating"><file name="Detailed.php" hash="086e949db4cb03112b61ef64fa4f7c28"/><file name="Summary.php" hash="bed407f557d7f647e62f53a0afd67f0e"/></dir></dir><dir name="Sales"><dir name="Creditmemo"><file name="Grid.php" hash="9cc7ca73c39a2eb2f9ccd663443d9a11"/></dir><file name="Creditmemo.php" hash="7077674f1b98929a1746a2e0a2205c36"/><dir name="Invoice"><file name="Grid.php" hash="d71c2db826d77e3cb9fd025e39d0a97c"/></dir><file name="Invoice.php" hash="6433788709a2896617beba8246c69024"/><dir name="Items"><file name="Abstract.php" hash="d250e9f03e6ba5df3f5575ac3d669c86"/><dir name="Column"><file name="Default.php" hash="e59a6699310b93569c5769e59c448e8d"/><dir name="Name"><file name="Grouped.php" hash="73fabc3f2ef4e076b7a44da3ec74232e"/></dir><file name="Name.php" hash="93365a10779ab90b16cb70aa7cb76f77"/><file name="Qty.php" hash="fd55983a3475987721b675907117e114"/></dir><dir name="Renderer"><file name="Configurable.php" hash="4f21e2b3302da7ae358538833d511241"/><file name="Default.php" hash="e2538c0044a3f905ecc11060a8e4c4d1"/></dir></dir><dir name="Order"><file name="Abstract.php" hash="45739bf1bea027fe45a88d5fb74bc1c4"/><dir name="Address"><file name="Form.php" hash="82c5e9cea0dc8b5c9f975751dba3202a"/></dir><file name="Address.php" hash="5223e26b8bf7b30acdaedddf211eea56"/><dir name="Comments"><file name="View.php" hash="039130ef6c6a23a631f4d96029671e90"/></dir><dir name="Create"><file name="Abstract.php" hash="ec59e0b6e9acd1a548555f9c6799ef6f"/><dir name="Billing"><file name="Address.php" hash="0df1e25bb08dad32e2bfb8a0f9a167ad"/><dir name="Method"><file name="Form.php" hash="a2bb4ecb917e3a761412193d5b742c6f"/></dir><file name="Method.php" hash="199760457b7473e0467d8c214ed11dae"/></dir><file name="Comment.php" hash="6e5f5722608c3338627724fdb4586632"/><dir name="Coupons"><file name="Form.php" hash="69d16bbe72563d8521e6e5c43abd3917"/></dir><file name="Coupons.php" hash="c01e37e722548e4a1a7ea157d71d48b8"/><dir name="Customer"><file name="Grid.php" hash="42df68f6d1fa8156711d8cf3b7cb2987"/></dir><file name="Customer.php" hash="b1cdeeee9cd91ac572963f0290230054"/><file name="Data.php" hash="a53aa485b2e4608e5523efbac2ba510e"/><dir name="Form"><file name="Abstract.php" hash="8342b7df4b622a5c5109ca720be19e76"/><file name="Account.php" hash="bf0f8022c18fec7c2ff2f0467cdbb2bd"/><file name="Address.php" hash="2652debcdd91d9a68eb12f3d14953146"/></dir><file name="Form.php" hash="37cce5735e6474c8f7a318cfea2bcb85"/><dir name="Giftmessage"><file name="Form.php" hash="e6ff0f1c7094056a3659b2fb34f2f6f4"/></dir><file name="Giftmessage.php" hash="5e4419f5ecb48733015043167176cccd"/><file name="Header.php" hash="94f8aede089e59bc3cfcc9383e83cc94"/><dir name="Items"><file name="Grid.php" hash="c59b6769d698d9dc758a1d3fbf8b1480"/></dir><file name="Items.php" hash="d70ba8b7eaa08b74fdf180a19066d542"/><file name="Load.php" hash="edeee2ea6deb6fc3751088d80e5dec6d"/><file name="Messages.php" hash="52bfb9f025f9d872f4eb33366957fc6d"/><dir name="Newsletter"><file name="Form.php" hash="c690ca5f1dd244de31d6b72232f9eea6"/></dir><file name="Newsletter.php" hash="8b2bee63e50417114d5dbce7fc71cd6c"/><dir name="Search"><dir name="Grid"><dir name="Renderer"><file name="Giftmessage.php" hash="04e63b8afe6cbd37db3129f4e8c699ab"/><file name="Price.php" hash="5281d1c8a312ca741d58d14fbe3deced"/><file name="Product.php" hash="0b76bf90a8f2d5cdbd4b18fb16b2eaeb"/><file name="Qty.php" hash="54cee680adfc48caf551e4a8cb2fdec0"/></dir></dir><file name="Grid.php" hash="fa13dba8c6b9700b46f29aede759923d"/></dir><file name="Search.php" hash="fa316633bbf0f02bb4d2baa6468b67c5"/><dir name="Shipping"><file name="Address.php" hash="644215db3b8a9085255f789305f5381a"/><dir name="Method"><file name="Form.php" hash="08be11adb3b48c77c52a4df4e5e66a26"/></dir><file name="Method.php" hash="61ea096b05b007410b26237b5dac302c"/></dir><dir name="Sidebar"><file name="Abstract.php" hash="f5b8c9e2b61f4f0efea22f739a196d88"/><file name="Cart.php" hash="c784182a9c3558519fd56a968a19deb6"/><file name="Compared.php" hash="b844720f38bb949d43a32dc773b15da7"/><file name="Pcompared.php" hash="8ebcbb054c9f682c0c2e10d206ad94bf"/><file name="Pviewed.php" hash="bbc071c18335ae066a5aefab212a07d4"/><file name="Reorder.php" hash="e09f2c7ee365800730e50e8d95cd6cb3"/><file name="Viewed.php" hash="8e2b366150e6802afdec9685d65ff409"/><file name="Wishlist.php" hash="daf7e737f3141d392d83e387a3ad6fd5"/></dir><file name="Sidebar.php" hash="5aadf67f34a30f866cc04cb8ef00f1ab"/><dir name="Store"><file name="Select.php" hash="58494c02e8b891e02250cebcdd60362c"/></dir><file name="Store.php" hash="52ed6a59d9094d816a28ab1e01352588"/><dir name="Totals"><file name="Default.php" hash="87c47abc5ae14e81b6e51726085b790c"/><file name="Discount.php" hash="333db7abe6b23ea11f6a4babad105817"/><file name="Grandtotal.php" hash="bf2e0c7eeecf93046d19881d27eb626d"/><file name="Shipping.php" hash="644e308ae7d0d73ab849225dfcdc2cd3"/><file name="Subtotal.php" hash="629e99987933be9751e043fc485a420e"/><file name="Table.php" hash="06c746d4bf94f0d9b2a102da6548b6ae"/><file name="Tax.php" hash="4e92963bcb4172c5877542c7e061da98"/></dir><file name="Totals.php" hash="95ef4744840cb78571bfe7e4f8dd397c"/></dir><file name="Create.php" hash="e8b2a62d41a7968f5b25ddce7d9b45cf"/><dir name="Creditmemo"><dir name="Create"><file name="Adjustments.php" hash="32d1fe6ba59c5490be8f8cf1a4292616"/><file name="Form.php" hash="761e40421c230555e96f10159985fb83"/><file name="Items.php" hash="71e02814cd463899e34002ca04774338"/></dir><file name="Create.php" hash="bc2bf938b2dde5b09bd71cd8192a04e1"/><file name="Totals.php" hash="88425527934940def2f62e07c8376174"/><dir name="View"><file name="Comments.php" hash="02a18178e6ce9a20b8220531b602fe86"/><file name="Form.php" hash="369deccfac5176136831e3a4c2c8f386"/><file name="Items.php" hash="ffe3820202c8615cc98e6b10f966d93d"/></dir><file name="View.php" hash="e7a412b2d713bf9da23f38c9eacdfd18"/></dir><file name="Grid.php" hash="2c4ae6a5eb2199ddba27c56cc74bd141"/><dir name="Invoice"><dir name="Create"><file name="Form.php" hash="0bb4ca3c8652753a67265fa508e024ae"/><file name="Items.php" hash="b331e20e32951de332b145322da16c6a"/><file name="Tracking.php" hash="176fce657283fe3ab46a978880f37e4e"/></dir><file name="Create.php" hash="d8f4edc6611556d11bec056520979148"/><file name="Totals.php" hash="89ea1b4adccd1527742ef3a635f3e768"/><dir name="View"><file name="Comments.php" hash="231315629330662ac0d4ecfc4b94b956"/><file name="Form.php" hash="fae7a3587b2e65750b78453c202eba62"/><file name="Items.php" hash="e4b7bf50b026c03e5bc6077a41b73ec0"/></dir><file name="View.php" hash="e11d21463b5a54d766bd7156c4b77300"/></dir><file name="Payment.php" hash="bf73b8efb03db49e7981917f58e1999e"/><dir name="Shipment"><dir name="Create"><file name="Form.php" hash="19d7ab1eab9a39680ebb0babc4f889f1"/><file name="Items.php" hash="4d7604a86a11dc60212460a91860eb35"/><file name="Tracking.php" hash="e15d81cff93fad63f6fe9dc4b0936872"/></dir><file name="Create.php" hash="e1eaf308de67d85cebde2bcdfac55ee4"/><dir name="Packaging"><file name="Grid.php" hash="708e82d58d7de322ab128c79d690810c"/></dir><file name="Packaging.php" hash="95b1a24a1177c96a0ba0a3994e07f7f4"/><dir name="Tracking"><file name="Info.php" hash="1e9e750fbc5b8dc0eda1300a4fb943ce"/></dir><dir name="View"><file name="Comments.php" hash="3ded55f91490c01aa222a64eb40a9515"/><file name="Form.php" hash="4434a74139f4cb9845feee89840c58f5"/><file name="Items.php" hash="ecff7af6d51846f9be730666df5144fb"/><file name="Tracking.php" hash="d7eb5eb9ccd5fa455e7e734a57956fcc"/></dir><file name="View.php" hash="ece7ff35488a5ef159d67579270f7ec2"/></dir><dir name="Status"><dir name="Assign"><file name="Form.php" hash="9b4e30d3fc1a42c7a6792f22a769852c"/></dir><file name="Assign.php" hash="348bf62626f5a27a803bcca48f20be2d"/><dir name="Edit"><file name="Form.php" hash="17fce0de94d4ad003b94e7c201b46427"/></dir><file name="Edit.php" hash="02492e82607134bf42f0e07a4ee4920d"/><file name="Grid.php" hash="52d5bfd055d4c8fefe78840014442d4a"/><dir name="New"><file name="Form.php" hash="aafe74d46855d19aec5938d4f1391a11"/></dir><file name="New.php" hash="f7256daa0364107d4fab1ac3608138c7"/></dir><file name="Status.php" hash="a9678b586a0e1c0ab78e8c253badf901"/><file name="Totalbar.php" hash="942e16a2630b93ae9d9bf4108896cb84"/><dir name="Totals"><file name="Item.php" hash="b96cedf974257076ea4de13f1ad555e3"/><file name="Tax.php" hash="45e0955cd679c47e17df955dbc9f3145"/></dir><file name="Totals.php" hash="3e21f4a401e6db9a90886f3198b33858"/><dir name="View"><file name="Form.php" hash="0de281fce53e6ce5b974c4750e487a06"/><file name="Giftmessage.php" hash="d72e07778f70449e525bc42cee5b5d1b"/><file name="History.php" hash="5a08d199d187a98156f1510c6a0fb209"/><file name="Info.php" hash="9211aaa0e8640093595a8df1ec7c6a9a"/><dir name="Items"><dir name="Renderer"><file name="Default.php" hash="e27e98952b037349c5ed44bb5d128cff"/></dir></dir><file name="Items.php" hash="b3956ac7700aa0db02a50506f944aabd"/><file name="Messages.php" hash="84d48df928eb3207d26d3d5b48ce4897"/><dir name="Tab"><file name="Creditmemos.php" hash="06b931ce1dfd688af78e108a890a51ef"/><file name="History.php" hash="9e94bfc713c545507825a9de373d367e"/><file name="Info.php" hash="10390772fe22959257922236601cb23d"/><file name="Invoices.php" hash="62d3958b62be9d3143d9955fca3775a7"/><file name="Shipments.php" hash="783fc711e7aa66954429dd618d893c8b"/><file name="Transactions.php" hash="24aec6ab4d074a51f832fe7c3306ceab"/></dir><file name="Tabs.php" hash="5a80c1873ef2d212436e79ba3365fcba"/></dir><file name="View.php" hash="13eb259102e63ccd15e577449c166579"/></dir><file name="Order.php" hash="867a3d05a32de0ff1951a61495263663"/><dir name="Reorder"><dir name="Renderer"><file name="Action.php" hash="4ade6495da0d4c7861d76d0feebf0754"/></dir></dir><dir name="Shipment"><file name="Grid.php" hash="9a56f8e66e9702d613efb45d82e25f84"/></dir><file name="Shipment.php" hash="2e4802c132a7b74b7624b5d8eca65852"/><file name="Totals.php" hash="af26a6ae487a2c19212f27dcc203d754"/><dir name="Transactions"><dir name="Child"><file name="Grid.php" hash="422f95a665f1402a96df6dd41e48c625"/></dir><dir name="Detail"><file name="Grid.php" hash="ac07bd664ec30c7cd9cc776dd91df9a7"/></dir><file name="Detail.php" hash="466d909abf726e521ebf4a26ea30634d"/><file name="Grid.php" hash="d1b68ce93f6c0d26982ec6af6b40b722"/></dir><file name="Transactions.php" hash="759dc094205d6f50e306ee8895a8e1c1"/></dir><file name="Sales.php" hash="85e41bd256030dc381bf41937229b2c8"/><dir name="Shipping"><dir name="Carrier"><dir name="Tablerate"><file name="Grid.php" hash="215ad38165d867ae249379a4aa14df0f"/></dir></dir></dir><dir name="Sitemap"><dir name="Edit"><file name="Form.php" hash="9298d64b4d901d31349e814185114c17"/></dir><file name="Edit.php" hash="f32576c26bbe22bcdcb0d0e906b501d2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="049bafed18d2a6fc243f321e2e5f910b"/><file name="Link.php" hash="860fc688a2e32b4748995803ac626e2e"/><file name="Time.php" hash="8f7abc65d6b76ab7afe860ab973f0f1b"/></dir></dir><file name="Grid.php" hash="7fcaa769f080c3af1a7ac6ba05acf035"/></dir><file name="Sitemap.php" hash="0eb9104cbb4a1083a08c2f80e06a3655"/><dir name="Store"><dir name="Switcher"><dir name="Form"><dir name="Renderer"><dir name="Fieldset"><file name="Element.php" hash="178f45f348a82528daa1512ad6398914"/></dir><file name="Fieldset.php" hash="4da413d2e88f9e9327a8f9f3d49c5206"/></dir></dir></dir><file name="Switcher.php" hash="abdfb8b0b9d50e1d26bf670c7cc52d04"/></dir><dir name="System"><dir name="Account"><dir name="Edit"><file name="Form.php" hash="724d0ef86dc2c8c6162211a9ab014898"/></dir><file name="Edit.php" hash="1c0133fdd5deb83b037f59e5e81d147b"/></dir><dir name="Cache"><file name="Edit.php" hash="c460241a6e8b297afdd79869b00ff3ed"/><file name="Form.php" hash="9e04a6ffa820d5226c59fa5b18c20711"/></dir><dir name="Config"><file name="Dwstree.php" hash="9dc81b84d226f9488df3191857731a63"/><file name="Edit.php" hash="62a74fc635fbbc827eca2a4fea3f063b"/><dir name="Form"><dir name="Field"><dir name="Array"><file name="Abstract.php" hash="2d7e1f8baf6b40cf99eabee0bf6ee026"/></dir><file name="Datetime.php" hash="9dcfda6124cf0f25dba073b32826b610"/><file name="Export.php" hash="608bf1d1cfd31f10ebf78da291884ac5"/><file name="File.php" hash="3e31f49c77e40d674ca3f3db948c93c6"/><file name="Heading.php" hash="1cf79e6c2edd686b11be095bd5d4268f"/><file name="Image.php" hash="fe9ffa0ad2172d26a9684dcc7cb00a4a"/><file name="Import.php" hash="d291487bc5eb16f732f5e41884b498d4"/><file name="Notification.php" hash="062c73fd8066aff6b5f9650f97a71fa9"/><file name="Regexceptions.php" hash="4373b8ee96f0cc0d7a7dcfcf228b6b49"/><dir name="Select"><file name="Allowspecific.php" hash="0ef107ae4c63c0e016908359bf69a0f9"/><file name="Flatcatalog.php" hash="a246011eedf68f0cd42bbc73c71de0c2"/><file name="Flatproduct.php" hash="4f3784430bd835136e33988cc4bc3a84"/></dir></dir><file name="Field.php" hash="4f8d09202ed37588f4cf00923e14dfc2"/><dir name="Fieldset"><dir name="Modules"><file name="DisableOutput.php" hash="e302059fa3248cc48e520b4cc1554799"/></dir><dir name="Order"><file name="Statuses.php" hash="39de6497e1e23218883690ebc1c211d6"/></dir></dir><file name="Fieldset.php" hash="cc88cdd430c4a2d1036797f53d001adf"/></dir><file name="Form.php" hash="a4a4dfcbdf301c3c580e177713a7717e"/><file name="Switcher.php" hash="47be4380f93f25f25c08f7a9489c4a53"/><dir name="System"><dir name="Storage"><dir name="Media"><file name="Synchronize.php" hash="3ba97d2aeae4e2b987533a688769ba3f"/></dir></dir></dir><file name="Tabs.php" hash="7a76ed4c223c359a3a6a08c33d0d2650"/></dir><dir name="Convert"><dir name="Gui"><dir name="Edit"><file name="Form.php" hash="34a1d852071e8a668f9a918233934ef5"/><dir name="Tab"><file name="Upload.php" hash="066c77626c21cd66040bdbf6b7166f65"/><file name="View.php" hash="69b9e0b0604d36be0f2c5813252a3c58"/><file name="Wizard.php" hash="238c81cd7d8005aa5880d9a19d4e4db7"/></dir><file name="Tabs.php" hash="6522c80d035883c2281e1e909369f2c3"/></dir><file name="Edit.php" hash="d19f3f451824a9cc61ad4ce2f43e363f"/><file name="Grid.php" hash="d9b48baef0ed72de626ac7f436200047"/></dir><file name="Gui.php" hash="4350827a669efe856906d9ab68b6e385"/><dir name="Profile"><dir name="Edit"><dir name="Filter"><file name="Action.php" hash="bde22deee315064248611ed6b2ad16ab"/></dir><file name="Form.php" hash="4a2e8ed06a8d59c0c2100d0ed7c53a63"/><dir name="Renderer"><file name="Action.php" hash="8c9b0e1db555843b1c83a492c3abd778"/></dir><dir name="Tab"><file name="Edit.php" hash="69cd410e98c0786054a0b79e8b7ce271"/><file name="History.php" hash="2c5916e829b695ef6a70de18b00cbd4e"/><file name="Run.php" hash="931a4d60bf3a8617e7ffa6897ca4433e"/></dir><file name="Tabs.php" hash="73fd658cee413fc7188d164621bdd0a2"/></dir><file name="Edit.php" hash="b36ff98cebc8065a3adc2761061b47e2"/><file name="Grid.php" hash="9398722801c514cfc9dce17de92da075"/><file name="Run.php" hash="69c6338a4f4c3a0798c4c8aa4e3b579a"/></dir><file name="Profile.php" hash="3e3d88171cb6bd5f5e65de243f7ca0bc"/></dir><dir name="Currency"><dir name="Edit"><file name="Form.php" hash="2aa4d9904e2605aef4518e673543c2d5"/><dir name="Tab"><file name="Main.php" hash="25aaab5e589d6188c1b5c518e83a1e8e"/><file name="Rates.php" hash="a00b269f40e627cfce099601de20a91f"/></dir><file name="Tabs.php" hash="5e83f641504801a639f8328b03e13b3a"/></dir><dir name="Rate"><file name="Matrix.php" hash="57b842fd652808ba57af02beba73eed9"/><file name="Services.php" hash="d627271f20ed93d2b8e21ed3f92da34e"/></dir></dir><file name="Currency.php" hash="e8c5e50cfd955cae70566f634e73955f"/><dir name="Design"><dir name="Edit"><dir name="Tab"><file name="General.php" hash="d9401ff15ad83db694e9a675a8b79930"/></dir><file name="Tabs.php" hash="ca472f52eeed68ee4cfc7c2e11fe40ba"/></dir><file name="Edit.php" hash="cb2793aae1f1928305a810504025ac25"/><file name="Grid.php" hash="ecb9e5c60a2662eb67072da076b9f8e7"/></dir><file name="Design.php" hash="8d2e0a9860c04659ac9bb5b00a8d36e4"/><dir name="Email"><dir name="Template"><dir name="Edit"><file name="Form.php" hash="4047d7b28bb1012fe744352cff61e5f1"/></dir><file name="Edit.php" hash="d41764fc3f30dc19e94b3fac784ea5a5"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="3a65e0cb2c719ce6cdcbffe7a8d39f0f"/></dir><dir name="Renderer"><file name="Action.php" hash="57385d1912ed259f426016c3c672efb2"/><file name="Sender.php" hash="a66f1b1e1640834752075fa9a25bfaa5"/><file name="Type.php" hash="149b001b475f99f68a8adb4121ad1a0f"/></dir></dir><file name="Grid.php" hash="299c926a54231aca1fda3218a57b98f1"/><file name="Preview.php" hash="838ca945ed5df147d2d95cb65f638057"/></dir><file name="Template.php" hash="070f119a1cf4cec9086dbf3622884659"/></dir><dir name="Store"><dir name="Delete"><file name="Form.php" hash="1b12724f41ddc9804df3b1adc6aaf3b4"/><file name="Group.php" hash="a98de1773de879fe1802c191eb3dcb47"/><file name="Website.php" hash="712be69f55e4eb7497d00503f90dfa62"/></dir><file name="Delete.php" hash="950ce6a762483f6a9bc170ebe05c2cee"/><dir name="Edit"><file name="Form.php" hash="ff454cbc44bac6db7fe60cee729a65bb"/></dir><file name="Edit.php" hash="f934328a7507894c6ac16220e4fbaf21"/><dir name="Grid"><dir name="Render"><file name="Group.php" hash="a646b1e1c09442a6cd35b7ade3d1c58b"/><file name="Store.php" hash="af46fe92709138edaa34b7879f706b21"/><file name="Website.php" hash="2d9611dd6962917458dc27f1d0316547"/></dir></dir><file name="Grid.php" hash="aae919b8ddc65ed826860c12ee490818"/><file name="Store.php" hash="b9dce08fb5186579db7c0a2f141ebb0e"/><file name="Tree.php" hash="83f34a90883f0b5564542578827e9573"/></dir><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="afe3ac35fcc2392f59bbf6149edeac43"/></dir><file name="Edit.php" hash="925d823e86aaf0e826634293d7215f00"/><file name="Grid.php" hash="4b7ea75f0c7c529adc1e46d1558bf99c"/></dir><file name="Variable.php" hash="8e26f5d1efad4bae053f03be0f610080"/></dir><dir name="Tag"><dir name="Assigned"><file name="Grid.php" hash="6fa9719638788074f2fe3e6c6f4ecdda"/></dir><dir name="Customer"><file name="Grid.php" hash="a69779f7f5b3fd4b5468a2987f4d5cb5"/></dir><file name="Customer.php" hash="fac677a42c59f5b7c0db6ae3e41a28a5"/><dir name="Edit"><file name="Accordion.php" hash="c09b6c3363882b5f4ca602206e20bdd4"/><file name="Assigned.php" hash="c581c8584f80bce4b4edf844f2d799de"/><file name="Form.php" hash="969c221079de8c9389d192015fc1b363"/></dir><file name="Edit.php" hash="c3c5820f753a002280969f08684adf2c"/><dir name="Grid"><file name="All.php" hash="244719441585726e8832ec01aa28489a"/><file name="Customers.php" hash="024dc8c415e729da49c4c6f7efea6224"/><file name="Pending.php" hash="b31394982859de98ff2286e92c55e5c8"/><file name="Products.php" hash="2bc99ba096bf8c4b2c86e950972a4982"/></dir><file name="Pending.php" hash="f34333f6bd655698aeb7300560c2dfbc"/><dir name="Product"><file name="Grid.php" hash="9f48afaacded433fc2ab57aa44a324ba"/></dir><file name="Product.php" hash="e6662e0fa5c8aef9d635e0bc0335e5ce"/><dir name="Store"><file name="Switcher.php" hash="7ba7c60103ea6392fc3e084bd7f0c356"/></dir><dir name="Tag"><dir name="Edit"><file name="Form.php" hash="c2fd548e26992867848bbeaa57fd025c"/></dir><file name="Edit.php" hash="26d55cbf55b3f3d277211dcfad794b06"/><file name="Grid.php" hash="98b5ca760618f3b79f6c8fdc88ae4e18"/></dir><file name="Tag.php" hash="3d27c57ce9b27289afed85ac471ab0ef"/></dir><file name="Tag.php" hash="5c2b86b81776c7ec3b2330855d2131cf"/><dir name="Tax"><dir name="Class"><dir name="Edit"><file name="Form.php" hash="c73474e1fc6a2fc4c0b9f711a7d184b5"/></dir><file name="Edit.php" hash="114a8bb193e2997625dce40dc511df51"/><file name="Grid.php" hash="4221025a57309a6a5d22fa8182339fc7"/></dir><file name="Class.php" hash="358ecb085cbf35c3bf9b86aab272e649"/><dir name="Rate"><file name="Form.php" hash="735b3fcccc099415edc49f14a9af7930"/><dir name="Grid"><dir name="Renderer"><file name="Country.php" hash="bd524126080e5ad5ed76d9248088bca1"/><file name="Data.php" hash="ffb41b73434fd919d306b80f7401314f"/></dir></dir><file name="Grid.php" hash="bf204ae63b3141dda2c7b94cb23a9671"/><file name="ImportExport.php" hash="a9cb8e94f63288d5a29c0c869d08147e"/><dir name="Title"><file name="Fieldset.php" hash="e72758c8f41e5194766181af24dcd262"/></dir><file name="Title.php" hash="a0cdd4e6d31a66bdabc019a226a20a2e"/><dir name="Toolbar"><file name="Add.php" hash="6aca1ecf71403052514123d02cd4f63c"/><file name="Save.php" hash="d30485a1be9d7a6b98470eac448a21d3"/></dir></dir><dir name="Rule"><dir name="Edit"><file name="Form.php" hash="05f178eb2ea1a3a9f43a16ae80f9055e"/></dir><file name="Edit.php" hash="470b4b4dfe09841c7a1fe4d892b17aa3"/><file name="Grid.php" hash="b30e13cbf1bb1c9fd92b7a285a6422a8"/></dir><file name="Rule.php" hash="28c4e8a83882aafe18d4343de91830be"/></dir><file name="Template.php" hash="65e2a243ea8ccafb068eec480cb8264a"/><dir name="Text"><file name="List.php" hash="5b923aafef84752e8274560dde17b89c"/></dir><dir name="Urlrewrite"><dir name="Category"><file name="Tree.php" hash="bce8f4744813be70932966b5948dd779"/></dir><dir name="Edit"><file name="Form.php" hash="f3c8420dce816fea6c2220933c2176fd"/></dir><file name="Edit.php" hash="0dc9b099d51583d6bb77931db9dee2a5"/><file name="Grid.php" hash="6e12625945f32cd3d3c4cfc34e5e3da0"/><file name="Link.php" hash="0311e1099bc46104d3af6b2ad234f257"/><dir name="Product"><file name="Grid.php" hash="b353f6dffd20c5255b7910e2e9860632"/></dir><file name="Selector.php" hash="abfe917849402fda943214cb238d9f7c"/></dir><file name="Urlrewrite.php" hash="96f5cc86bb6657cb7671fb8d40e8dda8"/><dir name="Widget"><dir name="Accordion"><file name="Item.php" hash="862b7ac1ae6da1ff3396d7eaa6476fc7"/></dir><file name="Accordion.php" hash="2bfd91842c44da9c2d928ee59d99d424"/><file name="Breadcrumbs.php" hash="f2e9c982e431beef24e9531ea282a65b"/><file name="Button.php" hash="e41efda16c0c57798b0c92329e8449bd"/><file name="Container.php" hash="519866b42615db90c75f953abface41d"/><dir name="Form"><file name="Container.php" hash="1e11d0757aa1b79dd549630a39b59196"/><dir name="Element"><file name="Dependence.php" hash="0bd48ed91f763b4cee92b7def6c1e0ec"/><file name="Gallery.php" hash="9bd81ae35f97f0c8865ba4065d727a99"/></dir><file name="Element.php" hash="2de7b0945e2fdab89265ffec97dac5ae"/><dir name="Renderer"><file name="Element.php" hash="1337caa569089562b6fc3fcb84fd30d4"/><dir name="Fieldset"><file name="Element.php" hash="1bdbf1b7b6f9b7f00e7954c5bf62380d"/></dir><file name="Fieldset.php" hash="3c5376aebd05abd599f989f02623203c"/></dir></dir><file name="Form.php" hash="f15c69923ae2f35b3bc98b0243c9cbc1"/><dir name="Grid"><file name="Block.php" hash="b1d3f1e3b1f35b26291a6986dc700756"/><dir name="Column"><dir name="Filter"><file name="Abstract.php" hash="9ec8d38af2e0a97aca97bd840338dbad"/><file name="Checkbox.php" hash="0c8d8bc032276d22d8a23b1cb5cb4ee3"/><file name="Country.php" hash="5c41e9bc49b829817fc6c6e0b3bb1301"/><file name="Date.php" hash="4d432d04c21e356ada833fedb11a8d32"/><file name="Datetime.php" hash="8b4e170ce510dff4672f566a0c6006d8"/><file name="Interface.php" hash="ecb2182f785bab42bce0aab1e9aeffb5"/><file name="Massaction.php" hash="be4a354269953c27b5651307a00b356e"/><file name="Price.php" hash="f7ef1bda31e33231ac8349172a22c885"/><file name="Radio.php" hash="5f60bbeba611df2280756e89e3edaf4d"/><file name="Range.php" hash="e3671131adcae3b8191b0ee12fc4479b"/><file name="Select.php" hash="bf0b958af6c17cf87acce2139594007e"/><file name="Store.php" hash="9e3391cef3d7e6b571ddb0ff1ce31e95"/><file name="Text.php" hash="decc14e17a7efe47df5627d6266d82eb"/><file name="Theme.php" hash="a2c1c6b7e7531ab123a59dbae9edfa82"/></dir><dir name="Renderer"><file name="Abstract.php" hash="2b97d78c9cb1f594c785b7b35297638c"/><file name="Action.php" hash="9af11dec7785235d252a4ed4be6f615d"/><file name="Checkbox.php" hash="c75ff15abb158fc0739592af7ea7422c"/><file name="Concat.php" hash="0c98188f755ed33c3099b0e4a290a22e"/><file name="Country.php" hash="282ed653192f3e0967454a500b1d6c55"/><file name="Currency.php" hash="88f51735c3b03ed176d8f4e9f4fb68f3"/><file name="Date.php" hash="7b36c06c450f56de09a2a0e2e2003080"/><file name="Datetime.php" hash="1b0a1a0a77fe3503dec6bb89846e97fc"/><file name="Input.php" hash="54efcf346dcaefd0421d0fdfb3d35c31"/><file name="Interface.php" hash="064fb4d2541597d669b9d18f2f39cc1d"/><file name="Ip.php" hash="135fceb308bfae5a72e723efba31efdd"/><file name="Longtext.php" hash="512f23de2d3c820889b3d87afda9599f"/><file name="Massaction.php" hash="05fd267920703792920e5346e7ca0fb1"/><file name="Number.php" hash="1bcfc1fa0ce52b58757204c0d119f868"/><file name="Options.php" hash="66ed26d285706fe39a0022294972bf5e"/><file name="Price.php" hash="801e02cf3a66f89c02e9c90b925b81b5"/><file name="Radio.php" hash="762d232eda0a59fd4db6d570ae6a11cb"/><file name="Select.php" hash="3d0acd16d0323ef3d114a7aca647330c"/><file name="Store.php" hash="edada7e10d9635a8592dd76135f0f33c"/><file name="Text.php" hash="f08ff907545ff447f429214a5760ab8b"/><file name="Theme.php" hash="8e2ba7495c4161f44e1899d74b6f9f8a"/><file name="Wrapline.php" hash="3a7edf01eb91fd42305bf256d93531e7"/></dir></dir><file name="Column.php" hash="d04226c35fde4b31769656cdfff8cfe9"/><file name="Container.php" hash="7efc13b32c9d7c9f235c0194b9814f11"/><dir name="Massaction"><file name="Abstract.php" hash="04c79067f07388582101ce565644344b"/><dir name="Item"><dir name="Additional"><file name="Default.php" hash="53e9468b19a71f8e44920a0a0a39ea17"/><file name="Interface.php" hash="0b995f29e3c068cdffbdc93dc4d965e8"/></dir></dir><file name="Item.php" hash="f9da9045c7c77e625ba312d065dedb26"/></dir><file name="Massaction.php" hash="1e4b83485d7f0b556c88a5898c40e516"/><file name="Serializer.php" hash="7e2185abd12832c169fd42e89caade33"/></dir><file name="Grid.php" hash="6ac41f9c52e6fdc3fe7f01037f9aed2e"/><dir name="Tab"><file name="Interface.php" hash="094aaa32090cbcf7865c0641a1e2baa9"/></dir><file name="Tabs.php" hash="c09d2afbbcb4bfd78462723bb6972e6b"/><file name="Tree.php" hash="4ee77de449208f8bb2f1c4ee4656ab90"/><dir name="View"><file name="Container.php" hash="973b7b77e228a28bcff88520a3bbf43e"/></dir></dir><file name="Widget.php" hash="670978a7c059808e49191ad21d42cab6"/></dir><dir name="Controller"><file name="Action.php" hash="ea2630204852617ff41e4e1f948ede68"/><dir name="Report"><file name="Abstract.php" hash="c9dadae96c4f5bb9443167a5e4c0ac58"/></dir><dir name="Rss"><file name="Abstract.php" hash="5b04702be27869ce7af05581c6ac473a"/></dir><dir name="Sales"><file name="Creditmemo.php" hash="9baf9dd1d7003e5919acd7fd8be3c8de"/><file name="Invoice.php" hash="e18f2e1dbf17f766c3aa6a30d1b8b330"/><file name="Shipment.php" hash="4f115f033c90b1f0f05244c87892174d"/></dir></dir><file name="Exception.php" hash="1bf87284314f84a2e9dddbc6aa02d929"/><dir name="Helper"><file name="Addresses.php" hash="94dea4d61e921f74e574a13f35fa526f"/><dir name="Catalog"><dir name="Product"><file name="Composite.php" hash="5ebb5be492e23577a083518cdc4ebbb7"/><dir name="Edit"><dir name="Action"><file name="Attribute.php" hash="8fa9acfe18c721e80c067ff290fb4423"/></dir></dir></dir></dir><file name="Catalog.php" hash="7c43ea78a71e27be4c9e9275930d4c49"/><dir name="Dashboard"><file name="Abstract.php" hash="c2d2e0f8fe77177016afd7195e0c7bfb"/><file name="Data.php" hash="0cd9341123775b408eb2d870cbb6b152"/><file name="Order.php" hash="4ae6c3d63a209d9031aff5e3f69ff01c"/></dir><file name="Data.php" hash="abe5fffa5546a517c1ca60a201ace9c1"/><dir name="Help"><file name="Mapping.php" hash="4c5d3127d193a1f2c37e6d3af9eeb7e7"/></dir><file name="Js.php" hash="72316dae9a20494eb546340cbc838730"/><dir name="Media"><file name="Js.php" hash="94b127033b3975f6063cfb201aaa7210"/></dir><file name="Rss.php" hash="0ec2e6fc3c0f3a36207665a5440493b6"/><file name="Sales.php" hash="3c04f74983d4c7142c781cd89df71d12"/></dir><dir name="Model"><dir name="Config"><file name="Data.php" hash="d687ffbbc02a98cba695382e4894dedc"/></dir><file name="Config.php" hash="5830b87d46656f515b6d3fd6e1ac52c6"/><dir name="Customer"><dir name="Renderer"><file name="Region.php" hash="6b0653f92868441704b4dc8c990707de"/></dir></dir><dir name="Email"><file name="PathValidator.php" hash="28d73ea32531762160b56571a7946d98"/><file name="Template.php" hash="bcf8708d5b38c13fb750bb7f54d92258"/></dir><file name="Extension.php" hash="d38d90a931c22ad4210fc88f9007ea38"/><dir name="Giftmessage"><file name="Save.php" hash="f96d2f3f24b9509f6094417d66843c4f"/></dir><dir name="LayoutUpdate"><file name="Validator.php" hash="511832527843ff905055bd0092295fa6"/></dir><dir name="Newsletter"><dir name="Renderer"><file name="Text.php" hash="5580b8c1af8552494f0a356c58bd38c1"/></dir></dir><file name="Observer.php" hash="2600edcd9b2ed84d8eef48bfe3137f77"/><dir name="Report"><file name="Item.php" hash="89d084e5c5bf665524c2605b6828f2d4"/></dir><dir name="Sales"><dir name="Order"><file name="Create.php" hash="f19d6d9aa7e79dfa8b3a2a8c95649cf4"/><file name="Random.php" hash="fe59bc31d04b4069dae013662a928355"/></dir><file name="Order.php" hash="be50cd145aa949efe0dbb8907ca2c66d"/></dir><dir name="Search"><file name="Catalog.php" hash="5d9a903fe56bca27c094929acc8807b9"/><file name="Customer.php" hash="c2b8935fcf7aef9bd4cc10be40e465a8"/><file name="Order.php" hash="958a0e0b7e7ebf02fe067fda4b8823a2"/></dir><dir name="Session"><file name="Quote.php" hash="41b0bd0c9fb61cc8130a413a09a2d79f"/></dir><file name="Session.php" hash="85361ee383f9c79986bbec474b8a1f3f"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Admin"><file name="Custom.php" hash="2e046894406289aa907ae0035e46b1c8"/><file name="Custompath.php" hash="ead8d3a1df593bd69890ea79bd9b3829"/><file name="Observer.php" hash="cf571f4c0de3b6360a0efb9515a0bfe2"/><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="a86613c9c07371cf3fac211fb19d6f24"/></dir></dir><file name="Usecustom.php" hash="fff1bebb0e91904cb26c63df391a1235"/><file name="Usecustompath.php" hash="fc23817391f632789cf63c822f57dd71"/><file name="Usesecretkey.php" hash="e21072aee647c809471f6e2893298cdb"/></dir><file name="Baseurl.php" hash="304bd2df6d53224b7bf31b39c40190ad"/><file name="Cache.php" hash="f1936cb90a793bda1b6a35255edd96b3"/><dir name="Catalog"><dir name="Inventory"><file name="Managestock.php" hash="e5944356c0ff4dd9741690152719d3ea"/></dir><dir name="Search"><file name="Type.php" hash="7a6f20cd3be131670abf8b99566e60da"/></dir></dir><file name="Category.php" hash="fbda292baa5daaacb284a8fe715bfe9b"/><file name="Cookie.php" hash="81a5b71978c0ed23e1fa8b291c23306a"/><dir name="Currency"><file name="Abstract.php" hash="37d41ca094ad7a593ed70abe124d5ec6"/><file name="Allow.php" hash="68bd67c886ba2000f395c55c816a9b46"/><file name="Base.php" hash="af6b18eee844e76f329d4c51e933d4fa"/><file name="Cron.php" hash="17eb00bccbd61beca4581acf7416f022"/><file name="Default.php" hash="bee4b5c43f2f3e36db81043e1a4e38f0"/></dir><dir name="Customer"><dir name="Address"><file name="Street.php" hash="206e706118ee6655401b9b42c61f8506"/></dir><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="5abc0ac6ea5ea85848797706e06e99d9"/></dir></dir><dir name="Show"><file name="Address.php" hash="feeec998fd621ea03edf460fea1634bc"/><file name="Customer.php" hash="e61f0a53ee55ced4ac33c2ac0221370f"/></dir></dir><file name="Datashare.php" hash="25913fe52b59a4bd39e46c4428854c12"/><dir name="Design"><file name="Exception.php" hash="68565707472fe642dd4b7a40e2d0b925"/><file name="Package.php" hash="93e0526fcc2c9bad6826c18a36fb2ad5"/></dir><dir name="Email"><file name="Address.php" hash="421366b7e3a6b4c0244fbc6188d11f92"/><file name="Logo.php" hash="33b719f143c2903cee686388d3d060e7"/><file name="Sender.php" hash="79b079bd76cbea2d998738859784ab5e"/></dir><file name="Encrypted.php" hash="84b385dd684b85612707b4fa9db51ad0"/><file name="File.php" hash="f42cccdb5023090f46ae2607532e5368"/><file name="Filename.php" hash="96f867e0997f10d83febcfcba0004e52"/><file name="Gatewayurl.php" hash="dff96ccdae32aaff1d2535a1e7157a3e"/><dir name="Image"><file name="Favicon.php" hash="bcf45a7d93048d325b0f7f4ad1cf0eb2"/><file name="Pdf.php" hash="355ffa084fa7bac2f97436743f097f60"/></dir><file name="Image.php" hash="3ef32a5d2650336e8cbfc4093c54f221"/><dir name="Layer"><file name="Children.php" hash="7c2edbbd89dba4e5c46ca7332ac2ab2f"/></dir><dir name="Locale"><file name="Timezone.php" hash="4876cce3ad44db1787c159706166b597"/></dir><file name="Locale.php" hash="c36f4de4e2340ffa1c2d360d2e917443"/><dir name="Log"><file name="Cron.php" hash="0960c63fb46cdbc57554d68d01129032"/></dir><dir name="Price"><file name="Scope.php" hash="6e8849ccddcd5195481bb44ba194f543"/></dir><dir name="Product"><dir name="Alert"><file name="Cron.php" hash="536cae440b551a5c8b52988bd41dd679"/></dir></dir><file name="Protected.php" hash="824f1696606927d8b43da42477bad8a4"/><file name="Secure.php" hash="a036733f115c60ff74d92cf9e142ba60"/><dir name="Seo"><file name="Product.php" hash="28f4ed01035ff820777cc6ced55f3d87"/></dir><dir name="Serialized"><file name="Array.php" hash="d68727325451f37b3bc8a631bd87984e"/></dir><file name="Serialized.php" hash="df3b2f9a6d931bc5262960ad2c68b822"/><dir name="Shipping"><file name="Tablerate.php" hash="91656cfd86831cd8a26a5e57f3475edc"/></dir><dir name="Sitemap"><file name="Cron.php" hash="cb06d56d24023876fa771022d6ecbb2a"/></dir><file name="Sitemap.php" hash="c74a82773ad66c1495d24817a47c4c96"/><dir name="Storage"><dir name="Media"><file name="Database.php" hash="6923e70725113267e3deeba1cfb6da9c"/></dir></dir><file name="Store.php" hash="6e79f5835127803c134b82b3c4961d78"/><file name="Symlink.php" hash="95b9d98e178f4b8f927680b0791b631a"/><file name="Translate.php" hash="b6b6241975ad904fcb6dad072ba94ce5"/><dir name="Web"><dir name="Secure"><file name="Offloaderheader.php" hash="724df1bd4f97398e50223342ec786f4d"/></dir></dir></dir><dir name="Clone"><dir name="Media"><file name="Image.php" hash="5578699345bb7524f1fb182e442653d0"/></dir></dir><dir name="Source"><dir name="Admin"><file name="Page.php" hash="42d6d50d365de5f67652e34e9840b4a8"/></dir><file name="Allregion.php" hash="d797110c372e988ff1a6e49d08ce4b88"/><dir name="Catalog"><file name="GridPerPage.php" hash="34c1553061fc5ff78eebde96a405bfa5"/><file name="ListMode.php" hash="04af817c1308371fcff319df9d1657f2"/><file name="ListPerPage.php" hash="ecb52706a68b4f173d6841fd697aa27b"/><file name="ListSort.php" hash="b79668ebc442a45cbffd7b7d3bd5d596"/><dir name="Search"><file name="Type.php" hash="f1b3abe3363b407f0d227843f70e8e2f"/></dir><file name="TimeFormat.php" hash="52b6b587880e91136d62c9d00a0b9163"/></dir><file name="Category.php" hash="919d4a332eb1253e37eacd987a93dda6"/><file name="Checktype.php" hash="19755a1389a9f8cae1f4aa6461881f26"/><dir name="Cms"><file name="Page.php" hash="dff5ebe6df33c59bafbee5cf6743b244"/><dir name="Wysiwyg"><file name="Enabled.php" hash="7131f228f3b3d4200af27a9268a858c5"/></dir></dir><dir name="Country"><file name="Full.php" hash="fb170bf789af8e5473b8c8bc0815760d"/></dir><file name="Country.php" hash="03f0ce0aa5bcbbcf7f4166a5ef538ad6"/><dir name="Cron"><file name="Frequency.php" hash="f696f381b430183990d02c8842816373"/></dir><dir name="Currency"><file name="Service.php" hash="ba5b791f1f54723cd4f230e867b1fd83"/></dir><file name="Currency.php" hash="7a62eaf4aea976f5980ce25ff84966a4"/><dir name="Customer"><dir name="Address"><file name="Type.php" hash="50e978ba85a6b055bd286f1546bdc82e"/></dir><file name="Forgotpassword.php" hash="1173581eb58ff0233680da25f0dba5a0"/><dir name="Group"><file name="Multiselect.php" hash="262832009eab525d249b1549c8a2b966"/></dir><file name="Group.php" hash="516d462794a85a4f55a0b0b924f6a4a8"/></dir><dir name="Date"><file name="Short.php" hash="0ecb55ea74e7f0635cf9656bd4a79f56"/></dir><dir name="Design"><file name="Package.php" hash="92b1341793a9470fa4868f08ed054768"/><file name="Robots.php" hash="932beab930045a12398cec1af767edad"/></dir><dir name="Dev"><file name="Dbautoup.php" hash="b6466ce08c8de924d7d73302a1c4e395"/></dir><dir name="Email"><file name="Identity.php" hash="f7cf7b723bbc82a236adca740249e12b"/><file name="Method.php" hash="28d64e5cfed2865385d38c60a6d59c3f"/><file name="Smtpauth.php" hash="1379a68f7463a688da3559a56c0c62ef"/><file name="Template.php" hash="546603ce87c833f85c2886fa78c4da3f"/></dir><file name="Enabledisable.php" hash="e4ba4eefa3c92dcd4f6088df73e852b5"/><file name="Frequency.php" hash="b45cac5c61aa1c76f02354fa354c2e59"/><file name="Language.php" hash="cf4973e113cf46bf582ba866b0c84bd6"/><dir name="Locale"><file name="Country.php" hash="3f5882e3e02a1cfceb94e44dec5154a9"/><dir name="Currency"><file name="All.php" hash="f17029b7a993196608692c62074d357f"/></dir><file name="Currency.php" hash="e65f20d6b8dcc9b92eecc3773288b29a"/><file name="Timezone.php" hash="8a91c04de34b595b523b2744bafad7e8"/><file name="Weekdaycodes.php" hash="2dcb2f68f9676e7757511cfc52fae914"/><file name="Weekdays.php" hash="fd1c10e7451311bda4439bce1aaa4889"/></dir><file name="Locale.php" hash="7c1997cc0bd57c0e19a3049d2602ff16"/><file name="Nooptreq.php" hash="129aa8240d6dcf7610cf5aebce742014"/><dir name="Notification"><file name="Frequency.php" hash="992ad115d486c15b4e49d1c713c5fbe5"/></dir><dir name="Order"><dir name="Status"><file name="New.php" hash="b13e716a54aafb4debe2e39f862d1a6b"/><file name="Newprocessing.php" hash="98351a23d0cfc885f6ae955bc8497a79"/><file name="Processing.php" hash="463d61baa271f0be702d99496a9cc474"/></dir><file name="Status.php" hash="d51560e7f3996d42858d2234c71a46d3"/></dir><dir name="Payment"><file name="Allmethods.php" hash="bb56b4469058373f44333efbda871155"/><file name="Allowedmethods.php" hash="1c3df6f913320f5863c6ce5a895ab038"/><file name="Allspecificcountries.php" hash="e033d3d9881675523f824b520ed0c6e5"/><file name="Cctype.php" hash="bd508e1461321c62a8bc13d8009fcb40"/></dir><dir name="Price"><file name="Scope.php" hash="67a80549b00e35bb3cb2e1e1e5a19b82"/><file name="Step.php" hash="4f3c8edc0c9ffaaa2e1c876cdc4a1f12"/></dir><dir name="Product"><dir name="Options"><file name="Price.php" hash="675c24d90116fe01ca667b7c282ee480"/><file name="Type.php" hash="5e5b7e26c1582a5ec4414b9e8d234521"/></dir><file name="Thumbnail.php" hash="3055686e20099ff6e89291834a2adace"/></dir><dir name="Reports"><file name="Scope.php" hash="069a3499c4298db920ba405fa11c0ea4"/></dir><dir name="Security"><file name="Domainpolicy.php" hash="8077bae576aa62e2be69321140bb0177"/></dir><dir name="Shipping"><file name="Allmethods.php" hash="f1b6cc6e499d22ad0d09f12126a57ae7"/><file name="Allowedmethods.php" hash="cde3eb6702c5b55d004e6798294304dd"/><file name="Allspecificcountries.php" hash="b9ddf5a44b9f7b04295384365fe09103"/><file name="Flatrate.php" hash="c881e1fd1f4ae6c5d5e5195a7726fd4d"/><file name="Tablerate.php" hash="5b089f80b770d155ce1ce130904f6cd0"/><file name="Taxclass.php" hash="e3995dd47b8356e54438aa5172d4c53f"/></dir><dir name="Storage"><dir name="Media"><file name="Database.php" hash="168fa52133880bdd0a5b9940bd5eb419"/><file name="Storage.php" hash="0f9612972aad64996f79b073f6aa51ed"/></dir></dir><file name="Store.php" hash="58122ea3b33c37ec9ea19a7bcf52ec48"/><dir name="Tax"><dir name="Apply"><file name="On.php" hash="9895d966f0a3594f146e2143a75d9164"/></dir><file name="Basedon.php" hash="a439e01f07d6485c890e02630f98a758"/><file name="Catalog.php" hash="2fe2fdda4bcc8b445fe48c009342e642"/></dir><dir name="Watermark"><file name="Position.php" hash="2c04100eb63d9e8cbf3c88085fd2f996"/></dir><dir name="Web"><file name="Protocol.php" hash="df2fbf74d4e484c19a2813b3b9eb2b22"/><file name="Redirect.php" hash="182130c27530d8c8fd9f19a00cdc3b8a"/></dir><file name="Website.php" hash="29e00fba750aa9fed121702446994918"/><file name="Yesno.php" hash="3e3d9290c8a907608b9d5a58028b338d"/><file name="Yesnocustom.php" hash="8a5bc93d4c803e3fa20df139869096bc"/></dir></dir><file name="Store.php" hash="fd2a829b6c24413772706d9f74a227ca"/></dir><file name="Url.php" hash="9099e82b420afdd2b332029423541671"/></dir><dir name="controllers"><file name="AjaxController.php" hash="21aa2331850549a0d56a0f34e126672d"/><dir name="Api"><file name="RoleController.php" hash="dd71ee700489808549abbda71255d9b4"/><file name="UserController.php" hash="ada4455c4277dd842949e1d8393a945d"/></dir><file name="CacheController.php" hash="82ffba0759bca1498d810db6cbdbae9f"/><dir name="Catalog"><dir name="Category"><file name="WidgetController.php" hash="d7274f61d984ca38d10f3f89abdaa38b"/></dir><file name="CategoryController.php" hash="c52faa77117d63bad16a2fcf08203cd8"/><dir name="Product"><dir name="Action"><file name="AttributeController.php" hash="f85caaa4837b6e123d3f595cb7ff0cea"/></dir><file name="AttributeController.php" hash="3805ddafadbf0c58f4225bc61ea87412"/><file name="DatafeedsController.php" hash="b6f1fb27951ccc158ebf1e27b0be9f65"/><file name="GalleryController.php" hash="2bf4baf9369aadbc9357117b48d08a11"/><file name="GroupController.php" hash="08c4d556258752769c14a8da3e8360a6"/><file name="ReviewController.php" hash="9b0e7354ca4f68e60598ee57a04a7175"/><file name="SetController.php" hash="052505c1fac2a67a21f04451bfaf212b"/><file name="WidgetController.php" hash="ab47a3fd2d409fa3590aa1ff866e0515"/></dir><file name="ProductController.php" hash="4f293523f888ccb2df82374a36e2e8c6"/><file name="SearchController.php" hash="8f0be8ea2dda17161f44a244e7721b65"/></dir><file name="CatalogController.php" hash="247369a9fa2674f1660c92f630b7343a"/><dir name="Checkout"><file name="AgreementController.php" hash="8ac0324efd3a81443d32f36178c815ea"/></dir><dir name="Cms"><dir name="Block"><file name="WidgetController.php" hash="45aad6354caa2b7a5608a14d8b86a6ce"/></dir><file name="BlockController.php" hash="117f2f823bd437abf534f2fc4200c50f"/><dir name="Page"><file name="WidgetController.php" hash="27e2d88da95bf627dc94e2eb4c62f7bb"/></dir><file name="PageController.php" hash="f68ee1a38644bceec232f23c961aa9cc"/><dir name="Wysiwyg"><file name="ImagesController.php" hash="0002d34d5a20602f947029710c003e94"/></dir><file name="WysiwygController.php" hash="52937e9d1c6c2e60abf4f6f4e506ea3e"/></dir><dir name="Customer"><dir name="Cart"><dir name="Product"><dir name="Composite"><file name="CartController.php" hash="00aec88f5179e17aaa2cb32410d4e627"/></dir></dir></dir><file name="ConfigController.php" hash="75fc248de6217cec3dc7115a6d3c7871"/><file name="GroupController.php" hash="300e16d47af15dfdc72d3a72d6a8b425"/><file name="OnlineController.php" hash="c582c470171c6f22930874ace2212fbb"/><dir name="System"><dir name="Config"><file name="ValidatevatController.php" hash="9ec588e2864cf7584f86e7ea03ef859b"/></dir></dir><dir name="Wishlist"><dir name="Product"><dir name="Composite"><file name="WishlistController.php" hash="312e61c120d15fa6b9beff8d013669a5"/></dir></dir></dir></dir><file name="CustomerController.php" hash="840b12a524c3c4ddcbb33a84eec8e5c0"/><file name="DashboardController.php" hash="cccdc39d1b4256bc6d3fdc3f312b469c"/><file name="IndexController.php" hash="93d25be27f7172e4b91be4e29b1667d5"/><file name="JsonController.php" hash="2a0884d78d11507f5ca8617ab60a65fb"/><dir name="Media"><file name="EditorController.php" hash="08217fbb9baea7eadf7e1c2fa9d37ed0"/><file name="UploaderController.php" hash="5a3f8a7627dce0832bf279ee0bb29aec"/></dir><dir name="Newsletter"><file name="ProblemController.php" hash="666980a1414023c417422a9354854ca7"/><file name="QueueController.php" hash="84615826588fd8d919efce2d5f261953"/><file name="SubscriberController.php" hash="012dfabbe5188395de3d4934db9d8f1f"/><file name="TemplateController.php" hash="ea1674e2d186bddad77aaa693dd51047"/></dir><file name="NotificationController.php" hash="d7a410e9d20a264e4d9515b1a86f7d30"/><dir name="Permissions"><file name="BlockController.php" hash="185535dffd66b8d8ef1068019eb3eff8"/><file name="RoleController.php" hash="9606953d4410722d615ac816820fa340"/><file name="UserController.php" hash="50f7bdedd11f5682e275bc2139461ca6"/><file name="VariableController.php" hash="c92ad3f6d684b0766cd43d3a31f4c1fa"/></dir><dir name="Poll"><file name="AnswerController.php" hash="9287852777f2b860e531374d94e45157"/></dir><file name="PollController.php" hash="b430f477bc4bfb01ccaf060ea4ffdf99"/><dir name="Promo"><file name="CatalogController.php" hash="c8fdcea935fe0c754f27644e0e78e07f"/><file name="QuoteController.php" hash="b28ffe79f88fb1a6d01aad9c80ae72fe"/><file name="WidgetController.php" hash="d91c5d5958237820bcfa78c89cac16c2"/></dir><file name="PromoController.php" hash="ed7e53ece75726b7a31e675748540a84"/><file name="RatingController.php" hash="315660eb3bda08558a3f609a5596d7c2"/><dir name="Report"><file name="CustomerController.php" hash="9f5dfc9f1f6ed652d59c420b5c069502"/><file name="ProductController.php" hash="0c615feb915eb56af10fc75c00feb0c3"/><file name="ReviewController.php" hash="7da2ab6db4eae2bfdf9ecccd3c87e7f5"/><file name="SalesController.php" hash="d1c582fa4d0df0af89b528012fee1c2b"/><file name="ShopcartController.php" hash="525c2321b21e62a3c1f686d62559c01b"/><file name="StatisticsController.php" hash="91a77e722297e68b0ad1ba54ad359b2a"/><file name="TagController.php" hash="3c1aec074c4eb53d14f77f549339dbfd"/></dir><file name="ReportController.php" hash="63feec302514efa918d1a80f8f7e9cca"/><dir name="Rss"><file name="CatalogController.php" hash="c007de3af2772afd0af741b3be6c8a79"/><file name="OrderController.php" hash="608bc4c2de1d4785ffec32805c10368c"/></dir><dir name="Sales"><dir name="Billing"><file name="AgreementController.php" hash="2da3d500f2049c5ece840fbbfca9647d"/></dir><file name="CreditmemoController.php" hash="2d688eee9da7ccfcefaf9788def48b1a"/><file name="InvoiceController.php" hash="19a9445cabc5f9059d6e550b8f58b873"/><dir name="Order"><file name="CreateController.php" hash="bdf67443df772d984dc1c51135ae1199"/><file name="CreditmemoController.php" hash="4445b5dc62da541f2f847beb0d1bbaec"/><file name="EditController.php" hash="0b7c20984714ac732162c98bf89850fc"/><file name="InvoiceController.php" hash="1f1a90c7f42c23debcf804b1be6defff"/><file name="ShipmentController.php" hash="fbf45e3a33640447a07b66744f9c1346"/><file name="StatusController.php" hash="39ea9de1b69ab854ddc481948281d94a"/><dir name="View"><file name="GiftmessageController.php" hash="99aa2e8b8abc4e517817d4a206f66994"/></dir></dir><file name="OrderController.php" hash="6d237944b46c4cda0a259371732ef925"/><dir name="Recurring"><file name="ProfileController.php" hash="9cb710bd52e9a0ffe2e3f7471a7344f0"/></dir><file name="ShipmentController.php" hash="fd91d81711fc1dff84ab77ead90cbe42"/><file name="TransactionsController.php" hash="2804baa76fb26d4ef1bb52b4657623a2"/></dir><file name="SalesController.php" hash="0af897e1b6c86b1a333ade2d42c7132f"/><file name="SitemapController.php" hash="b5b322f6be561056e015130fefaadfcf"/><file name="SurveyController.php" hash="1f472bbf45c9b2c5b0871da68a64747d"/><dir name="System"><file name="AccountController.php" hash="065a0d935e4eb62882fb1c0e581509b0"/><file name="BackupController.php" hash="a978f19979f623f2db52a4cd2521461b"/><file name="CacheController.php" hash="75ddb06e7d3aa12d387bad621b5a69f8"/><dir name="Config"><dir name="System"><file name="StorageController.php" hash="07f6a5f5ad1ace3aa724902656de99cf"/></dir></dir><file name="ConfigController.php" hash="35ff2d7f2282dd7983f832d215dc4257"/><dir name="Convert"><file name="GuiController.php" hash="9c3a90e18ad3b405779df0dc3b32f3a0"/><file name="ProfileController.php" hash="535281019f5bb6e456f7dee19952ff29"/></dir><file name="CurrencyController.php" hash="51394cd2c6721baa9f9a88c6a5d10377"/><file name="DesignController.php" hash="47108670fb51eb5a66d626e9a48a816c"/><dir name="Email"><file name="TemplateController.php" hash="2d5834d5c3559158a7222759d5bd0706"/></dir><file name="StoreController.php" hash="2b0bb94e5c7a359e9109bc5e038ef621"/><file name="VariableController.php" hash="4399817273fe7e92bd3e7aebcd3c23ad"/></dir><file name="SystemController.php" hash="968204b11a8efb93c13ff3a36ea3aa0a"/><file name="TagController.php" hash="b427319c9cc848023e2894ff98cf6e77"/><dir name="Tax"><dir name="Class"><file name="CustomerController.php" hash="e11693950ace13f570c97f46110d671b"/><file name="ProductController.php" hash="ff329c1879ae3ba19b3cbc2d20f4d93e"/></dir><file name="ClassController.php" hash="f30d45900d180019a6e2f2d9d5edad9e"/><file name="RateController.php" hash="bba20ae7c52d95d3f6add60eb7785388"/><file name="RuleController.php" hash="6a24cb90bec2d0878c23530593ff50e5"/></dir><file name="TaxController.php" hash="2bcb2c6c6164bc91a14711f13808ceda"/><file name="UrlrewriteController.php" hash="8728bfac026517f44f522deafc102c78"/></dir><dir name="etc"><file name="adminhtml.xml" hash="eacc179395f301ba856c22b7ae75d4b1"/><file name="config.xml" hash="cee3689bb30fbde7f0b28a519cb004a6"/><file name="jstranslator.xml" hash="bc2b74495321e4a736d063e9ddc71693"/></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Adminhtml.csv" hash="b65baff79fbf0ae5e5945ce1e2ff975b"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.18</min><max>1.51.1.18</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_LinLibertineFont</name><channel>community</channel><min>2.8.14.18</min><max>2.8.14.18</max></package><package><name>Lib_Js_TinyMCE</name><channel>community</channel><min>3.5.11.17</min><max>3.5.11.17</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Core_Modules-1.9.4.0.xml b/var/package/Mage_Core_Modules-1.9.4.0.xml
deleted file mode 100644
index 93e58cf..0000000
--- a/var/package/Mage_Core_Modules-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Core_Modules</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Collection of Magento Core Modules</summary>
-    <description>Collection of Magento Core Modules</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:08</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Admin"><dir name="Helper"><file name="Block.php" hash="caa2d50273d135454432a82279a11568"/><file name="Data.php" hash="a1e30b8cff30b64d0071e3fc0d4d747c"/><dir name="Rules"><file name="Fallback.php" hash="5482131732670d135c93815ccda8c06f"/></dir><file name="Variable.php" hash="fae16e7d6ff7c120b7f4ef6382c00286"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="a59d50ca3b29cc9a624261da4dbe9c1b"/><file name="Time.php" hash="7192ead0d21ba20bfe1790f5e2aff34b"/></dir><file name="Resource.php" hash="0839068c44eddb3b3748236642bf84e7"/><dir name="Role"><file name="Generic.php" hash="21c78892191682d198ebeb3a4995db8c"/><file name="Group.php" hash="538b9f77a4c75aa1060a52f611abaf1a"/><file name="Registry.php" hash="a24c7a642f46edd6c2d4c7675c0c84f1"/><file name="User.php" hash="46d3710d79d3640420f58a262fbeffd4"/></dir><file name="Role.php" hash="943df3fdcf2f2c819b804203762c405b"/></dir><file name="Acl.php" hash="54433cdf323e543e1867c2549ece2146"/><file name="Block.php" hash="6f4be02782162b7139294394fb2004ef"/><file name="Config.php" hash="a3bcd071ae1f775d2e1501a7a4f9822b"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="9b07c8d517462b6204a83d90acd16756"/></dir><file name="Role.php" hash="8b294821cf814a143d850198f4c43152"/></dir><file name="Acl.php" hash="6cc39341f37e79af75598f6cac080928"/><dir name="Permissions"><file name="Collection.php" hash="adefccfe4c00a5107351e4db77640acb"/></dir><dir name="Role"><file name="Collection.php" hash="d932179a37015862d102e9bad94f3bbf"/></dir><file name="Role.php" hash="f9e310b9e3866e9b444e914275a7874e"/><dir name="Roles"><file name="Collection.php" hash="dfc8f612252f1290b2159451fe4e9436"/><dir name="User"><file name="Collection.php" hash="4e7b8bf1992f866fe90e3ddf5b0c6461"/></dir></dir><file name="Roles.php" hash="983a8d78acc8b0497aac971d41aca7ad"/><dir name="Rules"><file name="Collection.php" hash="a8dbbe361030637cfb8302a9b00d1679"/></dir><file name="Rules.php" hash="28114cde294f6cc6e145b46ec725c72f"/><dir name="User"><file name="Collection.php" hash="57f200bf02f6ea105ceb61e8fe46e756"/></dir><file name="User.php" hash="55f3f78be0507543391cbc8e540c6b7b"/></dir><file name="Observer.php" hash="81cc930f29d4344171630cb7ea4a1edd"/><file name="Redirectpolicy.php" hash="b646df71602dbe82e7ab1782fbd84133"/><dir name="Resource"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="1926e0a7c8bf8940f70e26e3c2dd70ae"/></dir><file name="Role.php" hash="be13385eb722b00b08ee72c333f3c948"/></dir><file name="Acl.php" hash="f24de22c611f36f6fc7be3ac20c46695"/><dir name="Block"><file name="Collection.php" hash="718324e3f2d4c5d48c056bc6fda734de"/></dir><file name="Block.php" hash="5035beb7d68f54ffd191e1f7b8884421"/><dir name="Permissions"><file name="Collection.php" hash="cad5501e6d14ab6e7422881c2bd0529a"/></dir><dir name="Role"><file name="Collection.php" hash="daa545d25e2b93754fd2f7b5eac63795"/></dir><file name="Role.php" hash="f464a8b332d285af1bd80248fb18400c"/><dir name="Roles"><file name="Collection.php" hash="8ccb0a88f2091d75721a52c3b12757a3"/><dir name="User"><file name="Collection.php" hash="0f674723bb96b168ace8a02a1cca0186"/></dir></dir><file name="Roles.php" hash="8cc80a0c8b61fe74fb736ce8dfcac4c7"/><dir name="Rules"><file name="Collection.php" hash="fdc5f99600a5fbd7dba4fae947895689"/></dir><file name="Rules.php" hash="7d29a42a640f540fb93fcd74d5736670"/><dir name="User"><file name="Collection.php" hash="4ce53e45a26d3e054bb88df76471de9b"/></dir><file name="User.php" hash="d83993d485d972470d74e3bbef5129ef"/><dir name="Variable"><file name="Collection.php" hash="a6e4c9520ae8814e22a86126263a8123"/></dir><file name="Variable.php" hash="d552d6a33a00e83583c2c9b958fc57e9"/></dir><file name="Role.php" hash="427f7e03d269ad1dc23a4173621c6d3a"/><file name="Roles.php" hash="b83f289438abb74f56f1912877f53f1c"/><file name="Rules.php" hash="489fdb5eae36676cc780ef79bd0b3f2c"/><file name="Session.php" hash="2028c3c98afd35568fb8d3cc4f134581"/><file name="User.php" hash="c0acee16404bf6cb02f161ef3b77d7ee"/><file name="Variable.php" hash="7d47e44adeea80a3497965d4ac43a11c"/></dir><dir name="data"><dir name="admin_setup"><file name="data-install-1.6.0.0.php" hash="0c513c2cfa2157991f25ced0078a0a28"/></dir></dir><dir name="etc"><file name="config.xml" hash="e46e6daf902ff5fa67e29aeb7822dc25"/></dir><dir name="sql"><dir name="admin_setup"><file name="install-1.6.0.0.php" hash="980f7a261260766a99bb1c2168ee9ee8"/><file name="mysql4-install-0.7.0.php" hash="3ac4123cb71f013d2ad470dea9d30810"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="72634f2eb3a48eeceaea8c5996628e58"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0b41c60e4309ab58b185475035690803"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="a6e086154afbf0e78ebda93b8df1e6e5"/><file name="upgrade-1.6.0.0-1.6.1.0.php" hash="aa06fe4ff87c19621f325a7eb7ef74af"/><file name="upgrade-1.6.1.0-1.6.1.1.php" hash="b09feaaa0526ef59693920d6eda5bc70"/><file name="upgrade-1.6.1.1-1.6.1.2.php" hash="6b79418a832f51d1f9c28c5ce748322a"/></dir></dir></dir><dir name="AdminNotification"><dir name="Helper"><file name="Data.php" hash="df042bc27f5d78373840d635b65b602c"/></dir><dir name="Model"><file name="Feed.php" hash="db188fd3c854c92ab2f2fd18e3aeef56"/><file name="Inbox.php" hash="3f3e76c94db42f21e2213e87f347650b"/><dir name="Mysql4"><dir name="Inbox"><file name="Collection.php" hash="5d92840cb8289659edf2bea39c9506e5"/></dir><file name="Inbox.php" hash="efbb324a01db989b7abe345a7e2a0603"/></dir><file name="Observer.php" hash="b4ed5e01e17ab5d02af5dbf62fd6b99f"/><dir name="Resource"><dir name="Inbox"><file name="Collection.php" hash="161c59fda876ddb47af017f3d3688e92"/></dir><file name="Inbox.php" hash="c88b47b782cfcdf0752568434b29fd4a"/></dir><file name="Survey.php" hash="1b099509ff57f10c585295f95b1bdbf6"/></dir><dir name="etc"><file name="adminhtml.xml" hash="8306afc5cbf075e597ea182abbbad3bf"/><file name="config.xml" hash="93e0e7500211acff718572a494b1ff1d"/><file name="system.xml" hash="5022df69821d874a52f57c9073cebb27"/></dir><dir name="sql"><dir name="adminnotification_setup"><file name="install-1.6.0.0.php" hash="cf2dd6c652424ef76d06f74c89b66a7b"/><file name="mysql4-install-1.0.0.php" hash="f0ae881e7787a929c476dd20798eab98"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="d2c80d03e0f86c9b8825f033c23b6d01"/></dir></dir></dir><dir name="Api"><dir name="Controller"><file name="Action.php" hash="6c3628b0ac300a4cd89b98eda8d09c26"/></dir><file name="Exception.php" hash="f1c37ee004e19d1bd0d89feee1cb8399"/><dir name="Helper"><file name="Data.php" hash="0ef5815133c5d83c063356a3e0da3daa"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="c2a37bf362c2a7b2b7541bdfaecec197"/><file name="Time.php" hash="c914e7c3bdfd6a9db3520a09092042c7"/></dir><file name="Resource.php" hash="c73618e1e22cd9e536ac70743cdd2540"/><dir name="Role"><file name="Generic.php" hash="fb84e9243f5b0b259550ac04d78f3f14"/><file name="Group.php" hash="8767858e21f6f122daf9e9613aa46daf"/><file name="Registry.php" hash="86e7d446f72e86958fd31fd0529a89ff"/><file name="User.php" hash="c469eff3b9a049abfffa2713efae214f"/></dir><file name="Role.php" hash="d96b56ede53505c56b58b0f38135823e"/></dir><file name="Acl.php" hash="939deaca14b67306b767e389187590e6"/><file name="Config.php" hash="bb1e22bcb0fb28ad2588f6c2b2a60e31"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="32fe974a16a7b48f1894d2679b84e1a2"/></dir><file name="Role.php" hash="e5e0771ac8010362fa549c6e7daa7e30"/></dir><file name="Acl.php" hash="70c0aeedb1fb6ab524ab2794686e2901"/><dir name="Permissions"><file name="Collection.php" hash="4cd6e1648ef9de08aac8cd601f0e6dc7"/></dir><dir name="Role"><file name="Collection.php" hash="be4910ba32a9a2523441b0e94055cb96"/></dir><file name="Role.php" hash="ac94438d85b8e1fe7dd54ea5b6e63ae3"/><dir name="Roles"><file name="Collection.php" hash="18e2d6868811a2ca964bc8b6bd114976"/><dir name="User"><file name="Collection.php" hash="747d7d19d70c23540b3fd2597700eea8"/></dir></dir><file name="Roles.php" hash="49c8bf80cce95a6144ab436e3325fa0f"/><dir name="Rules"><file name="Collection.php" hash="9074b80fdbe0064239f630923205116a"/></dir><file name="Rules.php" hash="428cd0c12e6fd67e9c8034c7ac916020"/><dir name="User"><file name="Collection.php" hash="a5528fbfb43795975f632684de0a1e9b"/></dir><file name="User.php" hash="ffa15689d0d3be22d1dd833854c9918e"/></dir><dir name="Resource"><file name="Abstract.php" hash="f651d503d44050750e347dea6c4eb2a1"/><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="8cebb1abdaa3a0047515c8f293024185"/></dir><file name="Role.php" hash="89d84c7acc34e89db2ce8da6549cb309"/></dir><file name="Acl.php" hash="68367d41c8cddb578356dd3e954b4e05"/><dir name="Permissions"><file name="Collection.php" hash="8f0a8da938b11ae2f807a8cea8ed90fb"/></dir><dir name="Role"><file name="Collection.php" hash="4b0f67fd9f8b98d6290d89637b8d316e"/></dir><file name="Role.php" hash="fb845fb504654a9d77d589f9375cec0c"/><dir name="Roles"><file name="Collection.php" hash="107712d451f49d5117b0ca501993e725"/><dir name="User"><file name="Collection.php" hash="dd46a32c262b6f614e06c137e966b444"/></dir></dir><file name="Roles.php" hash="601e50dd0dcee557e210dc58d8a6cefa"/><dir name="Rules"><file name="Collection.php" hash="71e01b2d03324b5cca1febb062c16b82"/></dir><file name="Rules.php" hash="8bc2f8599ff63bace0f881b7dbad38d4"/><dir name="User"><file name="Collection.php" hash="af7f66ac98385c12eb69eec621091b7c"/></dir><file name="User.php" hash="4e00711e498dbad779d00e44abdadafb"/></dir><file name="Role.php" hash="ae0c28bdc096f4a02a24bacffbe43e4c"/><file name="Roles.php" hash="fa40e03fd2fb95ad6d180006b372a000"/><file name="Rules.php" hash="19025dc7e78b47f7bfab247abbf3dfab"/><dir name="Server"><dir name="Adapter"><file name="Interface.php" hash="5a2b192b023481b9334867830f7fc138"/><file name="Soap.php" hash="ea07c3bad993021d2b30901ad5277691"/><file name="Xmlrpc.php" hash="89630ebb23280c22955d32834dd428e7"/></dir><dir name="Handler"><file name="Abstract.php" hash="958f6fb48098d3f5593be13444b6271d"/></dir><file name="Handler.php" hash="15041baa52a1f7378c923a7fe19ddbf9"/><dir name="V2"><dir name="Adapter"><file name="Soap.php" hash="b40c707f4d69a59570142e416eae6ea6"/></dir><file name="Handler.php" hash="645b2e4ab2515e5ad8ad88d7513cbba9"/></dir><dir name="Wsi"><dir name="Adapter"><file name="Soap.php" hash="e04892f8ee83aa2236240f7f674beebe"/></dir><file name="Handler.php" hash="c8287d2c89cb6135104bda851f977489"/></dir></dir><file name="Server.php" hash="9be34054f5a0c93688ddfd9f052169b7"/><file name="Session.php" hash="8a290c5d23e5caba85adbc5748ddee85"/><file name="User.php" hash="15f64d4cc591f61fbf227ba25c3a1485"/><dir name="Wsdl"><dir name="Config"><file name="Base.php" hash="5c284d7e8e13f59f4b4f8b275d191452"/><file name="Element.php" hash="e42b6b1c30064f8a53f0fb199d77e5cb"/></dir><file name="Config.php" hash="fca16130d0fc928d68c4307fc7fc4886"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="0d50721374b168478c75084b9e0aa784"/><file name="SoapController.php" hash="caaba72fa28c829c358566baefeccbaf"/><dir name="V2"><file name="SoapController.php" hash="7bf9b20009581e5ec0cee7fba29fae6d"/></dir><file name="XmlrpcController.php" hash="757a12d58d3c89c92c25767d78bb8ba5"/></dir><dir name="etc"><file name="adminhtml.xml" hash="57ae0b2026085976e92bc10a4bfe0aab"/><file name="api.xml" hash="338887365fd87a21806a14089685d4cb"/><file name="config.xml" hash="abee7d9e23f6d7d2684eaa5b517f21f7"/><file name="system.xml" hash="f48c397a9a8ae46ec06bd051cfa38626"/><file name="wsdl.xml" hash="f0db676b04733b38f310355bb44bc3cb"/><file name="wsdl2.xml" hash="7d527421ba4b63a8a812ab6b1095891d"/><file name="wsi.xml" hash="9fb1700cf935a26e7fada90a07fae7fe"/></dir><dir name="sql"><dir name="api_setup"><file name="install-1.6.0.0.php" hash="09e011980354c86266cdf9d63a5af8cd"/><file name="mysql4-install-0.7.0.php" hash="4cb547e0f089626e582767db0ec8ee90"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6aba64817491a0d6a75bf672ac4cab44"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="193d3c806f3f6f9c8b9d78695856ae3d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="8e4802513a90731e5d70d1882b38b806"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="f7b95ac048305ed05d040e3f21c495b4"/></dir></dir></dir><dir name="Api2"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><file name="Buttons.php" hash="e57b2cca67185e3cd213f8a0f8b85f40"/><dir name="Edit"><file name="Form.php" hash="c8d355c13150048b44adbb7890807182"/></dir><file name="Edit.php" hash="f16b5c8886a820c2e6aa98bd4aa4d643"/><file name="Grid.php" hash="86ba4658fb06045763abb8c7a06b15a4"/><dir name="Tab"><file name="Resource.php" hash="3239ed35e6d73f4d99f3aebc6cb15df2"/></dir><file name="Tabs.php" hash="505fd3e313888bf6841b8419de4a36b9"/></dir><file name="Attribute.php" hash="0dd6ead429d30891593ef5dd46694fd8"/><dir name="Permissions"><dir name="User"><dir name="Edit"><dir name="Tab"><file name="Roles.php" hash="fae6fda77fa35cb811e343db83ab538f"/></dir></dir></dir></dir><dir name="Roles"><file name="Buttons.php" hash="99d83abfae8d8c391c2f1ec74cacf783"/><file name="Grid.php" hash="34d4de009fe78255533328d5d9948e24"/><dir name="Tab"><file name="Info.php" hash="b580103e0eb426629d6abab30bcbbbf8"/><file name="Resources.php" hash="a9cb4685233d34c84fb44b0fcc79df4f"/><file name="Users.php" hash="dd1412f767dd45ba5ca2766095cec422"/></dir><file name="Tabs.php" hash="d60717cf367b7fb6bbb0ae11dba22c0a"/></dir><file name="Roles.php" hash="1d276329e5a50560e6e2f2b32ec29285"/></dir></dir><file name="Exception.php" hash="f4ced7d9dfb82edfdeb2c7d0b5ce2768"/><dir name="Helper"><file name="Data.php" hash="8975105793473a87063e164aea84feaa"/></dir><dir name="Model"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Operation.php" hash="7772c8a909faec7391ce93fe91e077df"/><file name="ResourcePermission.php" hash="7980da3c1b5f522349a63f43938e37a1"/></dir><file name="Attribute.php" hash="af82dddf8646031fdae39a58dfa307df"/></dir><file name="Filter.php" hash="5109370c1a4adc8bc1f6b276f50868ae"/><dir name="Global"><file name="Role.php" hash="ae97b45a46e8770005e419678fa8ebf9"/><dir name="Rule"><file name="Permission.php" hash="8de779f299484181680195e87387fc88"/><file name="Privilege.php" hash="d90ec9b7324de863e74e6f13b3dfcde3"/><file name="ResourcePermission.php" hash="48f8373c47060c8c01358500d4548d5e"/><file name="Tree.php" hash="9a49b87115c274c87198a612fac101ff"/></dir><file name="Rule.php" hash="321434a2a494b8b519df55c0554b99e2"/></dir><file name="Global.php" hash="7819e08f4116c8c5a26af3a5a7f8a5fc"/><file name="PermissionInterface.php" hash="cabcf2514da2259366f1f68767937646"/></dir><file name="Acl.php" hash="8168df9324f44b487637330fe94e5b45"/><dir name="Auth"><dir name="Adapter"><file name="Abstract.php" hash="fa725f5d2bc74776393ab577da5213e0"/><file name="Oauth.php" hash="dafe7bb6be6ebb9648dd8d013c68f924"/></dir><file name="Adapter.php" hash="872d0216ee0446972dc2d486ff0d7bd4"/><dir name="User"><file name="Abstract.php" hash="81117cecf3a752eb7bf0ba689a4c0528"/><file name="Admin.php" hash="02230ffbbe56609a244dcb4f531a5739"/><file name="Customer.php" hash="0023067ca016f00f011204ffe6a346d2"/><file name="Guest.php" hash="e57dd3245a2a09a2755a1ade2cf1a788"/></dir><file name="User.php" hash="2b22b00fbd482e569f7e01c6ee4f1e74"/></dir><file name="Auth.php" hash="665a2694ec0fc6e233767d05ddc7b0f5"/><file name="Config.php" hash="ed2cdc8b2c092280a58cee2ec8ab9e2e"/><file name="Dispatcher.php" hash="30da396e02ddb880a36fcae44b3f4ffb"/><file name="Multicall.php" hash="c82b0b041e8b71685658ce9939d9f537"/><file name="Observer.php" hash="23b35ca3a5c0de9419bff1b50b98ef64"/><dir name="Renderer"><file name="Interface.php" hash="d9bd0c2d19c4f216ca1495ac30987233"/><file name="Json.php" hash="76b25110de667ee1c5f76c93fb242565"/><file name="Query.php" hash="5ef975348f915590b5fba1ff5a5a4958"/><dir name="Xml"><file name="Writer.php" hash="03bcf955bf8cb14b2143647161949357"/></dir><file name="Xml.php" hash="92504e9d4da46b51835e029882cdbe0b"/></dir><file name="Renderer.php" hash="6802baf80fe73e306e2361054a7b4687"/><dir name="Request"><file name="Internal.php" hash="ed73acd6aa487d4d55ddb073cc92a54f"/><dir name="Interpreter"><file name="Interface.php" hash="bd8eea102f6fdd48da627dad533b87b9"/><file name="Json.php" hash="28ae2899eaeb54f13a10424ad0bd2222"/><file name="Query.php" hash="dbdc8defdc20549dde842a6f30b05926"/><file name="Xml.php" hash="ce5d93d53da641b1f92514b2490b5c40"/></dir><file name="Interpreter.php" hash="c983432ec6ab8ab19061e2895b0b12ee"/></dir><file name="Request.php" hash="52ce6e5ed8b67e92242c89358c0ff61f"/><dir name="Resource"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Collection.php" hash="c5c3f91562564872857a90de8f6e6eb1"/></dir><file name="Attribute.php" hash="4b31a1a4c3923d393607c65c363cb74a"/></dir><dir name="Global"><dir name="Role"><file name="Collection.php" hash="c8cdd0443473ccdef524bbc9d0ee5faf"/></dir><file name="Role.php" hash="d512859354a0f3a68482c0b5b724200f"/><dir name="Rule"><file name="Collection.php" hash="199861b7d7ac3a114a9a3acd7b3b6bdc"/></dir><file name="Rule.php" hash="027b4342ef354ae654b95d3ad67d052a"/></dir></dir><file name="Setup.php" hash="06271b676d7740c82d9b87cab3f9c7cb"/><dir name="Validator"><file name="Eav.php" hash="f8eca8dadc2a2b16b01c523bf18a1fe9"/><file name="Fields.php" hash="9afa037fbf7489ea9042eb6955083b0d"/></dir><file name="Validator.php" hash="dc081ab02438cd20f95540a9a9552b30"/></dir><file name="Resource.php" hash="2de527731797b00eee24128ea7dadcb6"/><file name="Response.php" hash="03b815e352a2e39648c1836a28106519"/><dir name="Route"><file name="Abstract.php" hash="ad6970f5b98a7d2c8b7f6686d3e5e50e"/><file name="ApiType.php" hash="5bd38d66efe6a96558778c22cbd3cf25"/><file name="Interface.php" hash="635382ad0b407c35a551832250c79ab7"/><file name="Rest.php" hash="a1524cd462cb860fbb586e999a6a3dc7"/></dir><file name="Router.php" hash="26b93184e98020f9266225c0654cc011"/><file name="Server.php" hash="636ebda89a840623c4ec3c783c2c0581"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Api2"><file name="AttributeController.php" hash="e7c9a4ff55b6bfde147b4562cf9d6867"/><file name="RoleController.php" hash="a281f68c3d40ead23d29a5a761c27036"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="120807e3d576ab501e5a289d97e25978"/><file name="config.xml" hash="692bf96f7375cb891461e67f1e3e2ee1"/></dir><dir name="sql"><dir name="api2_setup"><file name="install-1.0.0.0.php" hash="ed93a6c9c5d36b8c9e552c1b75cb8c2d"/></dir></dir></dir><dir name="Authorizenet"><dir name="Block"><dir name="Directpost"><file name="Form.php" hash="e69a1ed465822af82fcca19b6232296e"/><file name="Iframe.php" hash="d175239ccdac988fe85d3ac55552d060"/></dir></dir><dir name="Helper"><file name="Admin.php" hash="73abd68b846923ba6841d0f16bb68ac3"/><file name="Data.php" hash="57de952e77147fe84c0ac75701b055a1"/></dir><dir name="Model"><dir name="Directpost"><file name="Observer.php" hash="49b71dfe98c71e0704f503fc6b1ee200"/><file name="Request.php" hash="373852a6d6a4b2d204d2105748a3d0e4"/><file name="Response.php" hash="d671a881c1241f1bbb173babbcf082b0"/><file name="Session.php" hash="9ed74b4f3bd8694cb4e9512748cff581"/></dir><file name="Directpost.php" hash="f68182cb174048294a2069ad5f19c510"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Authorizenet"><dir name="Directpost"><file name="PaymentController.php" hash="58a391e6780c02cbb6e96629406b70d5"/></dir></dir></dir><dir name="Directpost"><file name="PaymentController.php" hash="68655a8dec57f412c6c1c75472310385"/></dir></dir><dir name="etc"><file name="config.xml" hash="e5b53414e308a72beb5964c9e52bb891"/><file name="system.xml" hash="ffc68b24656677cc1f4191332a59a90f"/></dir></dir><dir name="Backup"><file name="Exception.php" hash="aef32492db8e2e178a6f19dd60ec44b2"/><dir name="Helper"><file name="Data.php" hash="0f9eb22500eecf1541ffae88a455ebbf"/></dir><dir name="Model"><file name="Backup.php" hash="b9f82ae285c4d1537dcde437da930445"/><dir name="Config"><dir name="Backend"><file name="Cron.php" hash="e55dc0f8d625f820247117fa8340a7c2"/></dir><dir name="Source"><file name="Type.php" hash="b717810ab4fdae54653a5a2fbc7ea83f"/></dir></dir><file name="Db.php" hash="8e4071a663d5c9c56ccdefe6f11f202a"/><dir name="Fs"><file name="Collection.php" hash="12b97f06d9bf26f826f06c0eea7409fc"/></dir><dir name="Mysql4"><file name="Db.php" hash="9d8151ac0ee8a690f82250ca69af7d21"/></dir><file name="Observer.php" hash="863ee663b43f6d2034d485df551e8408"/><dir name="Resource"><file name="Db.php" hash="16989c6a7a852e56e0fc163e28ea7579"/><dir name="Helper"><file name="Mysql4.php" hash="5871dac4d9b3224d5a1ad47095346d11"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="43b323c1e0b322d4a01a0a27e6c235c6"/><file name="config.xml" hash="668b53e3184cbdf3fc15250286b53c4d"/><file name="system.xml" hash="903010312af10460e9eef9cd2936f816"/></dir></dir><dir name="Bundle"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Bundle.php" hash="9f4002ed90b9e2a53dc20e71151acda8"/><dir name="Options"><dir name="Type"><file name="Checkbox.php" hash="96f52f78dc7a09bdb427c8ee52b65d23"/><file name="Multi.php" hash="3722af33a4e0dbb000091073426fb096"/><file name="Radio.php" hash="2d5e65660d87f101cb7cece0b11ae040"/><file name="Select.php" hash="b649193e763687ee21b24869a8339133"/></dir></dir></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Attributes"><file name="Extend.php" hash="5af45e344d7369bbf96c509da09306db"/><file name="Special.php" hash="af9f401061ebb00a733af4bb305bc5ee"/></dir><file name="Attributes.php" hash="fbfb5661ef64a6f9e30054208b760ae5"/><dir name="Bundle"><dir name="Option"><dir name="Search"><file name="Grid.php" hash="89d6f93c59a52af2cf56950665054b7c"/></dir><file name="Search.php" hash="9fa52e06eb3f75a425d5402116ce47e0"/><file name="Selection.php" hash="8f70becf362c369b2f6bcb8c3378763c"/></dir><file name="Option.php" hash="4eb61a0f38c5d7ebf82a58ee985bc28f"/></dir><file name="Bundle.php" hash="3c8a140d681c43aa707dadf3891178b4"/></dir><file name="Tabs.php" hash="51e04fa4277ae8461e947fa11bb6f3df"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="b9ed58833e99ba225f7e06a5c770447b"/></dir><dir name="View"><dir name="Items"><file name="Renderer.php" hash="a6b39e26ae9800313883689ac88ace9e"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><dir name="List"><file name="Partof.php" hash="0626bb248d0bfc65fbfabe1afa6fca63"/></dir><file name="Price.php" hash="c2fb9faa87455332faa3e860d35e938a"/><dir name="View"><dir name="Type"><dir name="Bundle"><dir name="Option"><file name="Checkbox.php" hash="cb772c2e417713caf2f9fa98b0a32d4c"/><file name="Multi.php" hash="e143ea304896f9f9e4b1d257d87260b3"/><file name="Radio.php" hash="f12ee7d486847ca528183856e07c5174"/><file name="Select.php" hash="fe4ac96fab3ff577861643ed565e330c"/></dir><file name="Option.php" hash="f85c1a9ff47d44591680f5e65aada7f6"/></dir><file name="Bundle.php" hash="a31d887cea522b42895561f80c0fb535"/></dir></dir><file name="View.php" hash="a91000e3d040ad4db6c9b2709ce77af0"/></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="5a7bb36644dfc43964eea9aabf815825"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="1cfbb62968ad39b38626233a30901805"/></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="f3db3dce8aa1d5d8bf31cc0767708c47"/></dir></dir><file name="Data.php" hash="a504909d004a1d701008aed90be4d3bd"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Bundle.php" hash="7ca532d3cebc8c69213d8f9f407cf190"/></dir></dir><dir name="Mysql4"><file name="Bundle.php" hash="e3b32c7f32917f53ac37e3636f903868"/><dir name="Indexer"><file name="Price.php" hash="9b1ff395e4dd949d3d335f165c36276a"/><file name="Stock.php" hash="1f2616a3a7410536206b7808d5007eb2"/></dir><dir name="Option"><file name="Collection.php" hash="f9c4648e7460f9a5f7b2551b7fc9f746"/></dir><file name="Option.php" hash="f5e970a9a7f208a92726761804dc7551"/><dir name="Price"><file name="Index.php" hash="203756cdc4713e771e0a7a05a892d544"/></dir><dir name="Selection"><file name="Collection.php" hash="45ab88a71e63861349fcbfad333a5d03"/></dir><file name="Selection.php" hash="91af51ec66d9c5d965977743ea871d40"/></dir><file name="Observer.php" hash="28e69ae14ca167303063cf0b82acbb16"/><file name="Option.php" hash="e8e875976ecb9f67244c0759415a5c90"/><dir name="Price"><file name="Index.php" hash="04a040260f89de6d07b49b40c8242434"/></dir><dir name="Product"><dir name="Attribute"><dir name="Source"><dir name="Price"><file name="View.php" hash="ef62864559ecc464e984df4d8d6dd264"/></dir></dir></dir><file name="Price.php" hash="08be1b25c01a1afb9b6fe2f60210c04a"/><file name="Type.php" hash="c3ac88d57ee7bca0fe7f6f7a4a11c46a"/></dir><dir name="Resource"><file name="Bundle.php" hash="bdba9059fb28a4cd03ef8ff63c9f57a2"/><dir name="Indexer"><file name="Price.php" hash="2128077c360503bbdad7cea6d0c055bc"/><file name="Stock.php" hash="b8c3dbf508ccaebda2ff5e6187dc3b82"/></dir><dir name="Option"><file name="Collection.php" hash="c25e5bda5dd2f5d53084a836be9c2e6c"/></dir><file name="Option.php" hash="c4d9d237f6c0a481b6ab26d3c3e0fd7e"/><dir name="Price"><file name="Index.php" hash="362d1e90ca755bd15888781e6834a54b"/></dir><dir name="Selection"><file name="Collection.php" hash="7066e059b329afdc3c78f581ace99f86"/></dir><file name="Selection.php" hash="843e5b865eccaba72cd30f39559ee1ba"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="77d8b0578aae73f0d15a9fca4ee61c4c"/><file name="Creditmemo.php" hash="8c526bf1db150d294d3f7895529db53a"/><file name="Invoice.php" hash="646cca8fdb8fedc83dcd9c29ea40ed8d"/><file name="Shipment.php" hash="cbc9cf391fe7f28ad74462eb09d49dca"/></dir></dir></dir></dir><file name="Selection.php" hash="6f30a4943f5092f5495ff7b37eb191ab"/><dir name="Source"><dir name="Option"><dir name="Selection"><dir name="Price"><file name="Type.php" hash="c654f9f6bf71f078160d4a34641e051c"/></dir></dir><file name="Type.php" hash="ed911131f87e6574bccdf4253565c1da"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Bundle"><dir name="Product"><file name="EditController.php" hash="0eaa6bfbaaaff740bbda5b3a135fe2ab"/></dir><file name="SelectionController.php" hash="f0884d1f147a752bd8e6f509189882d2"/></dir></dir><dir name="Product"><file name="EditController.php" hash="0255f1bdfac6e3fe6a740bdcf4a1a9d3"/></dir><file name="SelectionController.php" hash="ac354d6e6c719b3bc3fd03471b6c418c"/></dir><dir name="data"><dir name="bundle_setup"><file name="data-install-1.6.0.0.php" hash="51f712340a2a28e9da1e7b72bdab97c0"/></dir></dir><dir name="etc"><file name="config.xml" hash="93215a0503d700dca5f2e13f7223bded"/></dir><dir name="sql"><dir name="bundle_setup"><file name="install-1.6.0.0.php" hash="a1cfca05b83d498cb152e03b90dbe70f"/><file name="mysql4-data-upgrade-0.1.13-0.1.14.php" hash="ed4ad4a2e94719374e7425a6a1405583"/><file name="mysql4-install-0.1.0.php" hash="999ed121f79a34042f49c3b3d2b08aeb"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="2b177adfaf3ef71fac894b17d6183145"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="6a9d04d83024f3284f5cff880e54936c"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="459d1215e6cef3708c88a3f9e813094c"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="7dc6038bc99f2ae1222e11fc3cfb6765"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="ca59841ba6210240fcc85959743255df"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="717da80d58087bee6a40d313cba86d0e"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="b7bd7f7f9e7a8cddfba8f6fb4ea37353"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="9971b39c34daf8797596b4cdbbcaf3f4"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="35e56f2170462bc56c108eab708dccb4"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="a0208cfa774d98b0331ed9812c93c205"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="01b9bf1ed81e71b6e7c53ae35cb31f3e"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="0edea46d0d166eb6fad7acc3dc586048"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="194078628aff605dd856189c02e8053c"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="69349ff72fe2b1ef99db0b08da589cc9"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="a96e843cf78d277cc933940fa0d1d7d2"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="83d9e00ff228d78b44e6d56d754b3b53"/></dir></dir></dir><dir name="Captcha"><dir name="Block"><dir name="Captcha"><file name="Zend.php" hash="9e650dca067fab58be1817aae23f97f9"/></dir><file name="Captcha.php" hash="c88c6aff85e912f8018af95c830a52ec"/></dir><dir name="Helper"><file name="Data.php" hash="cca9932fc8cebcc419deaa08f82f632e"/></dir><dir name="Model"><dir name="Config"><file name="Font.php" hash="f6855855204af49b27021a07dc4997f5"/><dir name="Form"><file name="Abstract.php" hash="aed06b20ca537c8001e8a652628cb6b1"/><file name="Backend.php" hash="ad0061b6efb7b52a774c0b92fbf97d49"/><file name="Frontend.php" hash="f889118ab152231b826b2b8c347a9193"/></dir><file name="Mode.php" hash="83cbb2e35c76da541767eca87eec22d3"/></dir><file name="Interface.php" hash="d098c44cd60168ba7659c826a7a92cda"/><file name="Observer.php" hash="699da0e3ccf56f580f2407e2626d6593"/><dir name="Resource"><file name="Log.php" hash="f8095dd5be1d14a799fe8c7dc3746a22"/></dir><file name="Zend.php" hash="5390ae9b64f9c725ee1419ec5259bb57"/></dir><dir name="controllers"><dir name="Adminhtml"><file name="RefreshController.php" hash="85a78cd9706548cdd2d0bea07a9d68d5"/></dir><file name="RefreshController.php" hash="1c13db5d690d5818476b9ece2a906e79"/></dir><dir name="etc"><file name="config.xml" hash="83239b8a32eeb80562c2953be588c3b7"/><file name="system.xml" hash="045798ed80f08456fa4bde6538115200"/></dir><dir name="sql"><dir name="captcha_setup"><file name="install-1.7.0.0.0.php" hash="79b8836dc21b7e5bf7da7c077f3d84fa"/></dir></dir></dir><dir name="Catalog"><dir name="Block"><file name="Breadcrumbs.php" hash="dff5d9fb1b553e501f75c88030d744cb"/><dir name="Category"><file name="View.php" hash="59d72d523c2748a5c2a08cc2c3f5c0cd"/><dir name="Widget"><file name="Link.php" hash="87d7738143ee4e40e863c5e67a8f6bdb"/></dir></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="d605f8ef9809fb47302d175a539c5d94"/><file name="Attribute.php" hash="698725af0c0341607dbbd914f95630f5"/><file name="Category.php" hash="70b91e71c41ca3518fa935d4ab645c34"/><file name="Decimal.php" hash="ad2c34e653da950d13944da5a4d3c00b"/><file name="Price.php" hash="6226b66128b6748bdf2a42b9edf04345"/></dir><file name="State.php" hash="2200cf8e1fbe736cca46ad217ea37988"/><file name="View.php" hash="bb5bedfaa2f986ac88a6ee4b2b932da5"/></dir><file name="Navigation.php" hash="01f02f9f5aea7d8086afdb806f2508b5"/><dir name="Product"><file name="Abstract.php" hash="b3de11057a65efa46ca5f85a00cf77a5"/><dir name="Compare"><file name="Abstract.php" hash="eb1dd4aab523921a65e273881836b70f"/><file name="List.php" hash="aeff8054c24559dc325f7d2f0351c875"/><file name="Sidebar.php" hash="a62ecd9ff51fdc71bdbfe5fe60c3af92"/></dir><file name="Gallery.php" hash="af6d5c6eadc817482bf6dce6c57c95f4"/><dir name="List"><file name="Crosssell.php" hash="b5b416cb2af25edf53cebf62a74758c0"/><file name="Promotion.php" hash="b76409fdf26b11c07f9363733dd37fa9"/><file name="Random.php" hash="1086668ebc995d636f5ade64c67c4669"/><file name="Related.php" hash="9f4aae52a6a5a20f2b04f67238444820"/><file name="Toolbar.php" hash="792a5c55e1af817370b163022fdab038"/><file name="Upsell.php" hash="d2760b9e9144964a536a778ffc9eb996"/></dir><file name="List.php" hash="7d3419df76b9e532fd7945e2579bf630"/><file name="New.php" hash="ca34053438dca273450f23902124bbe3"/><dir name="Price"><file name="Template.php" hash="c070ad6804ae31e33b4b0f75c3081ef3"/></dir><file name="Price.php" hash="5ba3147f9d6edc765a459eaae5ca2fc6"/><file name="Send.php" hash="fad4ac95aa668d13335ee67173f992e4"/><dir name="View"><file name="Abstract.php" hash="02afc973fe15d2b186148522dde4253e"/><file name="Additional.php" hash="fd23972777ae7f22166c8637b4452f48"/><file name="Attributes.php" hash="418505496533f47cfdb552653478ec64"/><file name="Description.php" hash="3933e86b723ee0eeccb8d0e15c35cdb2"/><file name="Media.php" hash="c67ad24d870bc3fbac46b6c034262d0e"/><dir name="Options"><file name="Abstract.php" hash="673200ae6c98005daccc0bb45f557590"/><dir name="Type"><file name="Date.php" hash="23e971c82349012b2674f53cf78b21ae"/><file name="Default.php" hash="45df1b4c1f76c7c3f0c6b161a2364a32"/><file name="File.php" hash="27916e714ab9663e3c6559e9fc5be771"/><file name="Select.php" hash="f361ede3f754ca9471cc51fdd3f5d872"/><file name="Text.php" hash="b1693b780ff9bbcfffaad43771fcf8eb"/></dir></dir><file name="Options.php" hash="f544353c1c28e13adb5ffda0c2809253"/><file name="Price.php" hash="2931561be062a5c174868d6da75d5ee1"/><file name="Tabs.php" hash="5308f17a3c09fa7ebe810f6131588dba"/><dir name="Type"><file name="Configurable.php" hash="1d101337ffe557e3565bfcc29fefeae0"/><file name="Grouped.php" hash="e5914c1612836ac7e4beb4ffd4be3edb"/><file name="Simple.php" hash="407e6a940c8f2904aaa89f49e4bf28e7"/><file name="Virtual.php" hash="6ca0c8c536343b13424ad1722c22d1cd"/></dir></dir><file name="View.php" hash="35973636c7800bde04ed8fed69bb8b87"/><dir name="Widget"><dir name="Html"><file name="Pager.php" hash="3c025a4ade4383a2936ad5aa7bb39894"/></dir><file name="Link.php" hash="24341cfdad66bd4f4c41aa30fe977372"/><file name="New.php" hash="cdc5ab6e5ae7c3d1622830123852bd17"/></dir></dir><file name="Product.php" hash="c3016a548c94c5067a9971da0d7d7e20"/><dir name="Seo"><dir name="Sitemap"><file name="Abstract.php" hash="45bdaf82409349f8e6f511be3f4dd011"/><file name="Category.php" hash="af055f9f149c46feb59fae19e5ccedb7"/><file name="Product.php" hash="015b16562aaa16931affccc8dd71f1ba"/><dir name="Tree"><file name="Category.php" hash="7a3f8afcfc448f7d71dd42c1d4925432"/><file name="Pager.php" hash="de260e14c195ddb1aeb736dcf8cf2383"/></dir></dir></dir><dir name="Widget"><file name="Link.php" hash="7a86f0e03c53f2bb1e9252141c9020d3"/></dir></dir><file name="Exception.php" hash="0179104ce5022bcc5512e962d431bba2"/><dir name="Helper"><dir name="Category"><file name="Flat.php" hash="e403f3fea684f4b40a6a8e131a715304"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="7d6c19e3883d3bbd99de969bdeb3c0e4"/></dir><file name="Rewrite.php" hash="f20dafaabe85500b298989e37f1ca0ab"/></dir></dir><file name="Category.php" hash="bdc769946270dfdbe696f3b7e6dd4fa6"/><file name="Data.php" hash="51c9b79ee40eea71e548dc2f1fc05eab"/><dir name="Flat"><file name="Abstract.php" hash="fdbb21698a8fbe8db7603c4355b73a51"/></dir><file name="Image.php" hash="4434f405f3a2f2200a94cd90ad50b10e"/><file name="Map.php" hash="1686e6ed32f6b5dbeb5a597288254652"/><file name="Output.php" hash="489484164b5e7ba9372b186988de082c"/><dir name="Product"><file name="Compare.php" hash="0766ebc34366d772617632e8da5d7671"/><dir name="Configuration"><file name="Interface.php" hash="001b92f52823ecc5777807f986b4c0dd"/></dir><file name="Configuration.php" hash="cc9c25e19e2af63d782ad96bff298a02"/><file name="Flat.php" hash="f6c0e965a8bdc23d95f236c6006f32a0"/><file name="Options.php" hash="c8fc172f2eefd0804d5e4753ddae00c4"/><dir name="Type"><file name="Composite.php" hash="22568c93e4fdb14ac1b49ccfd977641c"/></dir><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="364322afee5e385f7d3294436fd7f493"/></dir><file name="Rewrite.php" hash="623588d9ff88a376b8b736bfb1f98b76"/></dir><file name="Url.php" hash="f2d6d9473153c84a406c7960d944018a"/><file name="View.php" hash="aeab098bc4a82af3ac33f1670dcfb15d"/></dir><file name="Product.php" hash="8f74cd3e74940bc977b37d2e5f33b5c3"/></dir><dir name="Model"><file name="Abstract.php" hash="5399d56b627d1a675cd3cadd8aaa768f"/><dir name="Api"><file name="Resource.php" hash="5d342b70a49b19b2747e7a03c85095af"/></dir><dir name="Api2"><dir name="Product"><dir name="Category"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="cad9ef1517173f0f00ff569be0b981bf"/></dir><dir name="Customer"><file name="V1.php" hash="a108c6bb33433839a3694c425cf92d69"/></dir><dir name="Guest"><file name="V1.php" hash="3ce11e40688705dca640b1186f414453"/></dir></dir><file name="Rest.php" hash="ac416fbef617af536dff5bbcbbdd61d0"/></dir><file name="Category.php" hash="bedb76db707efccaa3c53ef7fe602aa5"/><dir name="Image"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="312ff9a8f0b3842c76e82f0c8723023c"/></dir><dir name="Customer"><file name="V1.php" hash="2a73ed3ae72e037d4e107216fcb66576"/></dir><dir name="Guest"><file name="V1.php" hash="01f2136a7a27329bcec67560c069cc3f"/></dir></dir><file name="Rest.php" hash="0a64e319ac196c15d3af58f2a74efe48"/><dir name="Validator"><file name="Image.php" hash="c3d9e939bfdc90d9f2309fede3d61eaf"/></dir></dir><file name="Image.php" hash="b36d59fa96a06f1225de7ce226b32a7f"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="a9aa9dab5be83186e1a4d88f55fb2513"/></dir><dir name="Customer"><file name="V1.php" hash="7e330764edf3b2ed1e581e49c2de3315"/></dir><dir name="Guest"><file name="V1.php" hash="4285c2ba5ca5b228d1f0f8039655e34e"/></dir></dir><file name="Rest.php" hash="2c1d36d5174b420d031697b672afa8fd"/><dir name="Validator"><file name="Product.php" hash="3d774220754452726072f51246e113c0"/></dir><dir name="Website"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="54aaaf767c93cebbcc4c30d768b460cc"/></dir></dir><file name="Rest.php" hash="41088bbc5eb642ee779e30f2cbe13415"/><dir name="Validator"><dir name="Admin"><file name="Website.php" hash="49bfed6811464d93eafdad36d358f472"/></dir></dir></dir><file name="Website.php" hash="c85d0759a2a89efffe85dac4318b6472"/></dir><file name="Product.php" hash="8ebe91dc817724fe0d4502d8de5cdd03"/></dir><dir name="Attribute"><dir name="Backend"><file name="Customlayoutupdate.php" hash="1906499bafc1edd37e26f3959055427f"/><dir name="Urlkey"><file name="Abstract.php" hash="4e84559fa09f5dd3dc701c1cd3defe89"/></dir></dir></dir><dir name="Category"><dir name="Api"><file name="V2.php" hash="74d409f156cafc8d1eae110782228867"/></dir><file name="Api.php" hash="26d34123ccb312221f7b8e720be39c64"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="06af4c1245b1450021cc52bbce2a8864"/></dir><file name="Api.php" hash="f116285d1ea2de3e22cfa76d380ec7ae"/><dir name="Backend"><file name="Image.php" hash="88de246cf8a346d336e6d30b0f453910"/><file name="Sortby.php" hash="2d1b48beda0699587b1eff7d9eb18f8d"/><file name="Urlkey.php" hash="469c1883e70ebfcc3f6e2a18b927d760"/></dir><dir name="Source"><file name="Layout.php" hash="38316f42324a3227e27e753d2d17f015"/><file name="Mode.php" hash="29a887a321b5f1cb199d859b33ad89aa"/><file name="Page.php" hash="d8f1fb0693fa613b87cad674832a7cae"/><file name="Sortby.php" hash="f95940ed9bd96805d9d099a111557b08"/></dir></dir><dir name="Indexer"><file name="Flat.php" hash="3a8aed45dd42d6c5e89b4cfc24ab0a11"/><file name="Product.php" hash="7c332ea93f25e4d0586d94c00c3f83a5"/></dir><file name="Url.php" hash="03204ac658d9c3548a1e0111a3ed6a7f"/></dir><file name="Category.php" hash="0ab3203b113fb38341a6972b08357929"/><file name="Config.php" hash="960943c9b90cd595356b1f439932751e"/><dir name="Convert"><dir name="Adapter"><file name="Catalog.php" hash="e2d7a1b5016c9c937a5f940e8bd4a9dd"/><file name="Product.php" hash="2249eb2cc4c64504ec0ffbff80bb6a6d"/></dir><dir name="Parser"><file name="Product.php" hash="bf4f3af184dbb2dfb6b553d960cabe4c"/></dir></dir><file name="Convert.php" hash="f8711c86e2936d74b793321d0b3398ba"/><file name="Design.php" hash="0788ad594384e78dc18211e541a97985"/><dir name="Entity"><file name="Attribute.php" hash="967d705a4b89a92d41fae1b4518fbd12"/><dir name="Product"><dir name="Attribute"><dir name="Design"><dir name="Options"><file name="Container.php" hash="0c06ba7586010a01e30aebfdc0e5aa7b"/></dir></dir><dir name="Frontend"><file name="Image.php" hash="b1eb392c46c0d0e31fd4ceec82d91677"/></dir></dir></dir></dir><file name="Factory.php" hash="37199b8fa6933b87e8bf9e6643fd0862"/><file name="Index.php" hash="4f7bb172ee1334e510fecbce52373c51"/><dir name="Indexer"><file name="Url.php" hash="ac4a5bb7efeba1fe9313d220f6249ded"/></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="6d339963bab9940293e0f42782022e1f"/><file name="Attribute.php" hash="187f66e483e8654d5decf4abae8fcee8"/><file name="Category.php" hash="fc0b6dc472326743f30439fa3801fa85"/><file name="Decimal.php" hash="35d10ab83c9fdae952affaa48b043817"/><file name="Item.php" hash="c11edf35238a31aa492dfc8ed6aa327a"/><dir name="Price"><file name="Algorithm.php" hash="394ee3039156f05cb153bc87d55b1fc8"/></dir><file name="Price.php" hash="2ca517a1a54e992cbf167b970ff52e03"/></dir><file name="State.php" hash="077f09092c1414b4d8a73653db81dd00"/></dir><file name="Layer.php" hash="0d2ac9d06fcd6688beb4a07d0045da65"/><file name="Observer.php" hash="c5146dfd5fc5a556aa4f5d77b38d65b1"/><dir name="Product"><file name="Action.php" hash="c5148e1d47094a363250e732815082b0"/><dir name="Api"><file name="V2.php" hash="f6920d64fb2ddb9afb784dc70e888186"/></dir><file name="Api.php" hash="38f7c365b6938803956d8d5384effc68"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="b496a0f7d27095451fbcf9ccfc7ce32f"/></dir><file name="Api.php" hash="14a858bcac11c35ceef2500538830f91"/><dir name="Backend"><file name="Boolean.php" hash="229e9a7fb8d2e15d1fdeb8181445ebe0"/><dir name="Groupprice"><file name="Abstract.php" hash="d35b8dd3ff94f32d03d974ac33fde2f9"/></dir><file name="Groupprice.php" hash="e13ab416436949702144be98a8c94e9d"/><file name="Media.php" hash="5b643b94d167bcd3cbb8dde5623246e0"/><file name="Msrp.php" hash="fe63bc9e0d65dc3d1237eb2078923d76"/><file name="Price.php" hash="ff52da1f8a92a9c4271b4ad435801856"/><file name="Recurring.php" hash="f8e58b745661650d28892373ec982f90"/><file name="Sku.php" hash="46cfd45e115daa320b751e857ba9e8b7"/><dir name="Startdate"><file name="Specialprice.php" hash="cdcf2668c93fa5035b76aa15ef88fffc"/></dir><file name="Startdate.php" hash="b9a4b229fe15ba352db8ec9a04291691"/><file name="Tierprice.php" hash="1ac4294d92e3d250159564751335d6e2"/><file name="Urlkey.php" hash="004afee828cc01704b31919349eb1851"/></dir><dir name="Frontend"><file name="Image.php" hash="386d33679a77c37895bda511517c17ff"/></dir><file name="Group.php" hash="2a129a217055568d0958af302a1a5d2d"/><dir name="Media"><dir name="Api"><file name="V2.php" hash="9e5969b4b8530e57ee00ac55280cd2f8"/></dir><file name="Api.php" hash="a5ef7461fb59e7e6b2ef5f3d8ba42d49"/></dir><dir name="Set"><dir name="Api"><file name="V2.php" hash="ec27f9bd23529e40243196b006ddfdfc"/></dir><file name="Api.php" hash="44d60e0fef24f0d1b6fa369353d8c1e0"/></dir><dir name="Source"><file name="Boolean.php" hash="8188d6e83cc0d2d16fc4876d228c2475"/><file name="Countryofmanufacture.php" hash="b5ab8824ea10fbce4088c050fbcf67f6"/><file name="Inputtype.php" hash="e8b344c662a099b7cbe3bb1d0ae312c4"/><file name="Layout.php" hash="ecd67bb233e6aa0b188f446d5962f8ff"/><dir name="Msrp"><dir name="Type"><file name="Enabled.php" hash="874a11135465a502bbbf62cd58461556"/><file name="Price.php" hash="f3dbe7528b070894c617dc982f33f348"/></dir><file name="Type.php" hash="1d30a1e90e79d90af028202e5bd622c6"/></dir></dir><dir name="Tierprice"><dir name="Api"><file name="V2.php" hash="db92cf6602484be811da52fd5cda27a2"/></dir><file name="Api.php" hash="623e710a8cde8e495fff36009a6c2ff6"/></dir></dir><dir name="Compare"><file name="Item.php" hash="5a0b8c6dbd3e554d23d7edde6dc7664c"/><file name="List.php" hash="3ccac75f80eb97e5e7ed05ccfb4a8e80"/></dir><dir name="Condition"><file name="Interface.php" hash="3d1e83608560f21fcd94ca45a979b41c"/></dir><file name="Condition.php" hash="25a0cd54440afbf3ad8d915e88f10a4f"/><dir name="Configuration"><dir name="Item"><file name="Interface.php" hash="e7d838c6995cf062706f3aff8343390e"/><dir name="Option"><file name="Interface.php" hash="4a73836aad7135383a37250e6bfca517"/></dir><file name="Option.php" hash="f0dcacab62c5bf1c693c1abbd9352098"/></dir></dir><dir name="Flat"><file name="Flag.php" hash="dbfc46eefe47f08ab90de7b9729e6c72"/><file name="Indexer.php" hash="30f815a8c6c39c49954fe75e4b519f01"/><file name="Observer.php" hash="41e970922615897d150f92612196c764"/></dir><file name="Image.php" hash="a18f0d17efe6d01ec6ef1cce06960ccc"/><dir name="Indexer"><file name="Eav.php" hash="7618ab5d273a835fdebcd05aa146dae0"/><file name="Flat.php" hash="dbb5aa4c06b3353d1957b876d2c40167"/><file name="Price.php" hash="97c4e703f62475e3358865f12d811e28"/></dir><dir name="Link"><dir name="Api"><file name="V2.php" hash="6c70e65f2586fc28f09384f349244457"/></dir><file name="Api.php" hash="ad3458914b4ada1b1cfad8944c7eb9d9"/></dir><file name="Link.php" hash="4397ebb8e0e755273b84849c2bad05c8"/><dir name="Media"><file name="Config.php" hash="7f730c523323b820493066b116e160d0"/></dir><dir name="Option"><dir name="Api"><file name="V2.php" hash="e2e337f444291e17e84e813f34b5e686"/></dir><file name="Api.php" hash="8a56eb1b5c9c7990c9df368cc562805e"/><file name="Observer.php" hash="13cf958417156e721339f05893ba8aae"/><dir name="Type"><file name="Date.php" hash="e4d7596b3f4dbf962383d87d85dc154e"/><file name="Default.php" hash="ba662f4493c2e6a966ba6e2720b88b71"/><file name="File.php" hash="056f59762babcd043f3455f5abecf6c3"/><file name="Select.php" hash="281ed0e1384dbf4dc18ff9638ccdc68c"/><file name="Text.php" hash="cdff8cdce60d340e95e5d2d4a28baee8"/></dir><dir name="Value"><dir name="Api"><file name="V2.php" hash="f478fc9cad96b446af48597122d85664"/></dir><file name="Api.php" hash="afdb12fc5e3e52e4e8ac687b05f5b4f7"/></dir><file name="Value.php" hash="a63d01e87928ca3bb65229145dc1efd4"/></dir><file name="Option.php" hash="2d4d937648d019311a2a72a6ef1dc174"/><file name="Status.php" hash="ced8970f86fdccb17c830b80b12b33fb"/><dir name="Type"><file name="Abstract.php" hash="cd675bf61affc80c7410a38dbae08eb0"/><dir name="Api"><file name="V2.php" hash="7c9c9c80f446a59897f25e60672fb2ec"/></dir><file name="Api.php" hash="8ebd7e0d437a70645a0cf80e9834069f"/><dir name="Configurable"><file name="Attribute.php" hash="c8f8d57c9a3804c408b9e261beb3eefc"/><file name="Price.php" hash="cf7daffcb252267d1e502273e28a305e"/></dir><file name="Configurable.php" hash="42ad7a5df7ef6a527bb5b14588aacf42"/><dir name="Grouped"><file name="Price.php" hash="28eaf519153d5db1b79028b120a48bd4"/></dir><file name="Grouped.php" hash="9553d7467f1167744ea3f3d57a81c1d8"/><file name="Price.php" hash="2a757a8c1268c07ae43c4d3c1eba45f9"/><file name="Simple.php" hash="bc8aa458ff494d4475511cad48a866a9"/><file name="Virtual.php" hash="82c8912508ac48b7dd3dc55706c3c528"/></dir><file name="Type.php" hash="8c919879f58180f42da96db9303bafbd"/><file name="Url.php" hash="29b50e89e08b81a3b0fb00c3833dfc3c"/><file name="Visibility.php" hash="8c6dd0f045c26492e5a082086d18aa9b"/><file name="Website.php" hash="56c6082ede65a6764a892c35f235a579"/></dir><file name="Product.php" hash="eb003077225ab3b612e15ed46dbb871f"/><dir name="Resource"><file name="Abstract.php" hash="c78fb80b238aa93bffd770da2634077b"/><file name="Attribute.php" hash="083fbabafa2f9b2b93be9c32febe9c9a"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="16bb20412710d7a2a9ecf1d499942be1"/><dir name="Frontend"><file name="Image.php" hash="a3f01f4cdb9d581b7005fff83e1b7b73"/></dir><dir name="Source"><file name="Layout.php" hash="b528859d861098e5ab7ce183cd878c7a"/><file name="Mode.php" hash="268e61822290de0bf2cd59be33766d86"/><file name="Page.php" hash="675cf0b87655fff869bfc1f8d45d9e38"/></dir></dir><file name="Collection.php" hash="6b7ef3804ad45381b0164b967f595aca"/><dir name="Flat"><file name="Collection.php" hash="b4c7a90acb2d41d0be620c4994025926"/></dir><file name="Flat.php" hash="fa589f1153b9eeaf0b2311671152adb1"/><dir name="Indexer"><file name="Product.php" hash="7c573ac7e1d0be9d510d3cabae9d7c77"/></dir><file name="Tree.php" hash="2a160b88ab1aded63dc37040ee843a00"/></dir><file name="Category.php" hash="3c079ade2f2bf38e9423ef47e8d9a456"/><dir name="Collection"><file name="Abstract.php" hash="19c6f3250eb34e02648885695bb72a10"/></dir><file name="Config.php" hash="56b4be1960a399cca1f6e3a5413cdfc8"/><dir name="Eav"><file name="Attribute.php" hash="0553b24b137b571fe5adaf6f7079eae8"/><dir name="Mysql4"><file name="Abstract.php" hash="77bf8d831649cbd4cb22c6e38e1e6cbd"/><file name="Attribute.php" hash="ce29fde69b75dbfa76ee59395c27ef46"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="16fd9fb1c0a9e3f7f0a3da630f8b5f5d"/><dir name="Frontend"><file name="Image.php" hash="7b1efd69b7068f6269e5963fcb0f2421"/></dir><dir name="Source"><file name="Layout.php" hash="5902b8ec96fdabbfba22d12147a1f9f8"/><file name="Mode.php" hash="d298a9b154606d73977448afd409cf14"/><file name="Page.php" hash="2a0d8a3d458f6ad47fab99709c575b83"/></dir></dir><file name="Collection.php" hash="1e919121af88496fd3c9e12204d984b5"/><dir name="Flat"><file name="Collection.php" hash="3b6493ded5a4b074074984210c083900"/></dir><file name="Flat.php" hash="c6310cc6f9b3ad85fa543fcdb59f0ebf"/><dir name="Indexer"><file name="Product.php" hash="7cfc40ac2f41452ad477c6ead974d440"/></dir><file name="Tree.php" hash="e12a81ba27afb2c5044283bcb2ca9580"/></dir><file name="Category.php" hash="9f2f641cb0de686c995718288a4c1b2e"/><dir name="Collection"><file name="Abstract.php" hash="80eac3b59973421b48c8ff0082227f4d"/></dir><file name="Config.php" hash="26650f9818fca47b48c4654acee00a41"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="2fe32b4753d30dfc5de743e512c2fe69"/><file name="Decimal.php" hash="72e4695e08258a882ef36b2b2ef25a2e"/><file name="Price.php" hash="e3fe65ace9436eb406c68796cd21bf93"/></dir></dir><dir name="Product"><file name="Action.php" hash="5227ea6c0ce4484b4bf997bce9cd37cf"/><dir name="Attribute"><dir name="Backend"><file name="Image.php" hash="c3b5adfd873cb29c60c3ac18e2bd7bf3"/><file name="Media.php" hash="f05b409ffa13b07ce7f387925aba5c35"/><file name="Tierprice.php" hash="9ea320310cf7f210d0e5f61e3fd5a622"/><file name="Urlkey.php" hash="22b92b8efd3a9a92bcc4477ed07b8c77"/></dir><file name="Collection.php" hash="656272a27a7d0fb7bb7783fabe7ed4ba"/><dir name="Frontend"><file name="Image.php" hash="6e1bb32214d33789802cad5224b31d0d"/><file name="Tierprice.php" hash="7aa313df344f028150607d3715069fef"/></dir></dir><file name="Collection.php" hash="bca3f22426b03396a8b99ce4c886b086"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="9013f3daaea7e9a6fec6ac018c97fc7f"/></dir><file name="Item.php" hash="d85209d65afb97ce19ea977d74b414ae"/></dir><dir name="Flat"><file name="Indexer.php" hash="86dae654289b2146c4d2fcfd15c313c7"/></dir><file name="Flat.php" hash="c6c46472a572248707522cdf977a0369"/><dir name="Indexer"><file name="Abstract.php" hash="e2469fe950d76f10da8a811e688abd3f"/><dir name="Eav"><file name="Abstract.php" hash="7d6704efe0e95a3ef525e85bcafb3983"/><file name="Decimal.php" hash="34c9b97c8bf1b2821e7cd3c4b6eb7dbe"/><file name="Source.php" hash="fb4544e261a3ec415aeb420255f5a70a"/></dir><file name="Eav.php" hash="d9c748945123a47685db1fb255ee0264"/><dir name="Price"><file name="Configurable.php" hash="6555f812507f36d3139b2406bf2691b0"/><file name="Default.php" hash="ef2e3327c73efd98120b7b10ffed1cbd"/><file name="Grouped.php" hash="8823446108436d3bf360bca5b75e0bb5"/><file name="Interface.php" hash="3466a545d21ee82855f1caf2c2e04a24"/></dir><file name="Price.php" hash="c042288cbde8958279292469e7ef977f"/></dir><dir name="Link"><file name="Collection.php" hash="3f1dedead3fc806ab616edbea689d08d"/><dir name="Product"><file name="Collection.php" hash="e742fe4505d1f9b66e605f638f70d064"/></dir></dir><file name="Link.php" hash="9a8426299e8ececb93eba31c4651f511"/><dir name="Option"><file name="Collection.php" hash="6f94b6f180f1261cfd97a48319f0b267"/><dir name="Value"><file name="Collection.php" hash="64d49df810c454e57dc352af45e79db4"/></dir><file name="Value.php" hash="98d0ac8c28fcd7b73b0300e2bd03e038"/></dir><file name="Option.php" hash="a5fe5fef0022403ce04d3f6d8f5d66b8"/><file name="Relation.php" hash="7528ce5262e287b5ac4570c39cecdd80"/><file name="Status.php" hash="1d85dfd645199aff01697f9075ea69ec"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="11bb638081b4749458946e1448d9ca10"/></dir><file name="Attribute.php" hash="0ac0ea517b292148c8847bfd30baefcc"/><dir name="Product"><file name="Collection.php" hash="c3ba64bb9367830b6870195e46ec1cc9"/></dir></dir><file name="Configurable.php" hash="330a459b1686b6ae6f19563f32ffdb8d"/></dir><file name="Website.php" hash="ab17bc81707fd31b1eb6b4985e0382f5"/></dir><file name="Product.php" hash="5db16fca9860bf397d035b5dba87507d"/><dir name="Sendfriend"><file name="Collection.php" hash="41e24179196d884a89d8fcb7c292e964"/></dir><file name="Sendfriend.php" hash="dafac33cd5a9ad0f0bd1503e17f1e693"/><file name="Setup.php" hash="d8a92cc2f3f802f3943911fdafcb3362"/><file name="Url.php" hash="f06beb416bb905d70d1350a4fb6fbddc"/></dir></dir><dir name="Helper"><file name="Mysql4.php" hash="bddc88c4de81e944e3bbf35fdd4363ed"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="beef208a673d4acbd9afbccc639ad200"/><file name="Decimal.php" hash="469556abeb7e15eef17b5ea3353894f5"/><file name="Price.php" hash="0eb1fde29b2098ac20a7e2ad548adabe"/></dir></dir><dir name="Product"><file name="Action.php" hash="3faf7b08a790efd350e9f992d24221ab"/><dir name="Attribute"><dir name="Backend"><dir name="Groupprice"><file name="Abstract.php" hash="0c44439c5413141510ae5a094928cf68"/></dir><file name="Groupprice.php" hash="f3d29b2f169cbd0a8fe24d39c8710a7e"/><file name="Image.php" hash="33034e003246bdaa3732444289385724"/><file name="Media.php" hash="d8f212a3d6ca27c4392b700f66dae802"/><file name="Tierprice.php" hash="a2cbaacb0ac840adfe9646db31ed855a"/><file name="Urlkey.php" hash="2262eb9b8c6db5b7fbbcda8535976a30"/></dir><file name="Collection.php" hash="a73b5a17c24744e95ac32d1f97f3cab7"/><dir name="Frontend"><file name="Image.php" hash="139229526616ebdef9fb27aca81db6c0"/><file name="Tierprice.php" hash="5d4ceecd198819c7ba458b7f28622f5b"/></dir></dir><file name="Collection.php" hash="28c8c814e1c9545eafcb848dc5d00384"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="948e5a8ff1ea4dc486a19b2229ffc8a3"/></dir><file name="Item.php" hash="9d2d9c3902a8985e140598169e670e65"/></dir><dir name="Flat"><file name="Indexer.php" hash="00c53d98e3a205e3d2c97d7d03835012"/></dir><file name="Flat.php" hash="7a2c7d7711c9c598b4a04ba436160617"/><dir name="Indexer"><file name="Abstract.php" hash="21126ba16f5f2ca4db63897f9a559f43"/><dir name="Eav"><file name="Abstract.php" hash="d37eae3cc381710ec7abad80571ec52a"/><file name="Decimal.php" hash="0372d92275a05c07cd5715cbde92c06e"/><file name="Source.php" hash="b4edfcd21fb7974a08bf195bdbd8b560"/></dir><file name="Eav.php" hash="f579a7e70b13ec272eacc6b8f6850e6d"/><dir name="Price"><file name="Configurable.php" hash="8ec53532373b5e8c2326041d71d7b1e9"/><file name="Default.php" hash="6e04e9071bd8bb74bbefa54ad3cb8dc0"/><file name="Grouped.php" hash="d044889afe733ecedcca6c03777142a3"/><file name="Interface.php" hash="021e40baacd8bee14d34678eaa6cbda7"/></dir><file name="Price.php" hash="d1eccd5ff490dd96d27bfedfa4ad3f4e"/></dir><dir name="Link"><file name="Collection.php" hash="c58cdd3a4bb7439b8e0f01d2c23deb4e"/><dir name="Product"><file name="Collection.php" hash="7fe7daecdb0738f726c89a1a9b4ab5fb"/></dir></dir><file name="Link.php" hash="f6315829fc96747e5cfcc1f7cb920024"/><dir name="Option"><file name="Collection.php" hash="411f7f3d3d4ff31128a35e8012fe6f2c"/><dir name="Value"><file name="Collection.php" hash="faa70f0e1340def77f28676f33c117d0"/></dir><file name="Value.php" hash="9a2eb3f77bed40339874df0d7735aa48"/></dir><file name="Option.php" hash="e9ce26ccbe023f25ffcd0cd6119913d6"/><file name="Relation.php" hash="29a7c4f5416dbfb510f10e1e5ca7b307"/><file name="Status.php" hash="babd4c22ef0706906e5a17cfa3ae2451"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="f2d589d068f6e3252d8d3e1c27971d59"/></dir><file name="Attribute.php" hash="733bd1f4d46246a5c6cab4afacd12d66"/><dir name="Product"><file name="Collection.php" hash="7c74e62a50f7062fc67343224aff59d9"/></dir></dir><file name="Configurable.php" hash="c1e2764cc282e227c9cc90e664adc57c"/></dir><file name="Website.php" hash="24eabf1dac8102c0a172522c41edf63d"/></dir><file name="Product.php" hash="07048cb76beb23b3eaad5c8dfe200111"/><file name="Setup.php" hash="a07f84365233d9e247508ca1d52fb8fc"/><file name="Url.php" hash="7f392dc6284e61e239c0e1dfdf463688"/></dir><file name="Session.php" hash="85dc8d88009120a351c2cdf2e59ddd23"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Catalog"><dir name="Category"><file name="Flat.php" hash="d6a167189578f6729a8464a5b00c889f"/></dir><dir name="Product"><file name="Flat.php" hash="29d00096aab5c387fe09d53914599a50"/></dir><dir name="Url"><dir name="Rewrite"><file name="Suffix.php" hash="3c096e44cb311bff7b8827be26d9a7a9"/></dir></dir></dir></dir></dir></dir><dir name="Template"><file name="Filter.php" hash="873a8a3731ed4d71b18ecee89a8389f1"/></dir><file name="Url.php" hash="cb7fdd0608ab6ef7b6ded81966ae7c50"/></dir><dir name="controllers"><file name="CategoryController.php" hash="1a90cc9dd1b10853972d8c4859309078"/><file name="IndexController.php" hash="e015ae60fb19f872e6ccce968f5f5517"/><dir name="Product"><file name="CompareController.php" hash="9625bc3c8663dcfd52f8c20ee4ec9e71"/></dir><file name="ProductController.php" hash="2e1746bb7cccec9146b0d0430be78b81"/><dir name="Seo"><file name="SitemapController.php" hash="8faa57ee67d67ebc07f3c7d7c2ff6701"/></dir></dir><dir name="data"><dir name="catalog_setup"><file name="data-install-1.6.0.0.php" hash="0911877b0f5f7f75153e647632144053"/><file name="data-upgrade-1.6.0.0.12-1.6.0.0.13.php" hash="7408d9bebec81bac8cfaa82d2246bc61"/><file name="data-upgrade-1.6.0.0.13-1.6.0.0.14.php" hash="f6d063b376d8239af71933169aada7e3"/><file name="data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php" hash="3ea878479e551944714ac2b22c0ee96c"/><file name="data-upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="69a1c10da60ed0aaaf76686f1510494c"/><file name="data-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="5f1f3a491473a2e60afe18e9bb3ec319"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="cc8126ed44039f3578a18e8408190bda"/><file name="api.xml" hash="d784a8b268ef8848061df57fa4190625"/><file name="api2.xml" hash="2ea1ea69a6bfd1efaffb00c8f5cc6022"/><file name="config.xml" hash="98ad8521c9b08aaeab31fbda617e0c26"/><file name="convert.xml" hash="9cc9a49a719e66e2bd8dd229d6886f3a"/><file name="system.xml" hash="c85941108a3321424e46c07f258c6ca2"/><file name="widget.xml" hash="63d9a69bdeffb96fd652f832e93b4dea"/><file name="wsdl.xml" hash="fa198392d766134085b3c2ec1be4a0e9"/><file name="wsi.xml" hash="0acfd65c613ccb83404317500078a85d"/></dir><dir name="sql"><dir name="catalog_setup"><file name="install-1.6.0.0.php" hash="d3d83b26127ce996b341e4d67fb4b2ca"/><file name="mysql4-data-upgrade-0.7.57-0.7.58.php" hash="e77b598a1c7080a97e2d066530bc4780"/><file name="mysql4-data-upgrade-0.7.63-0.7.64.php" hash="b5443e86cc381622e7bbb4128732f5fa"/><file name="mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="dafb3fd3c8ff721f9c2bdb2cb8e03332"/><file name="mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php" hash="8052bc5216e4f035f32bb806727ff3dd"/><file name="mysql4-install-0.7.0.php" hash="c2ecf9ab172739266247748be75aef25"/><file name="mysql4-install-1.4.0.0.0.php" hash="d3faa8bc8f7c294a6953087776bd9456"/><file name="mysql4-upgrade-0.6.40-0.7.0.php" hash="1a4fb3cab768f3aa36023818c89af55f"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ac13e51cb31dda3ecab2597beb51bc8c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="3806192600b523969eef31c5a18a03c3"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="a3f49edb28d84c59fe9ca7837dcea688"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="71021c0648afc8b71256e66f41ff40e3"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="d03a980c274d1f676db2eefa856eeecc"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="b4287cf3624eae49641148ffbef8de5b"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="ae46ab3bacd5e00907f115a45764db05"/><file name="mysql4-upgrade-0.7.16-0.7.17.php" hash="71021c0648afc8b71256e66f41ff40e3"/><file name="mysql4-upgrade-0.7.17-0.7.18.php" hash="981e85d7a3413309de30374f910deb9d"/><file name="mysql4-upgrade-0.7.18-0.7.19.php" hash="55b76609304d873314a15330948ae957"/><file name="mysql4-upgrade-0.7.19-0.7.20.php" hash="a3f49edb28d84c59fe9ca7837dcea688"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="aa675f723b60582fde073c690a42ebb6"/><file name="mysql4-upgrade-0.7.20-0.7.21.php" hash="e8f620a5a054b991489c48860ba10221"/><file name="mysql4-upgrade-0.7.21-0.7.22.php" hash="556cfef21109c164e2e41eb485637eff"/><file name="mysql4-upgrade-0.7.22-0.7.23.php" hash="f2cd9fd2ff63f12e8399a5d7e4e62c18"/><file name="mysql4-upgrade-0.7.23-0.7.24.php" hash="3bb145d699f3c5a6db4c5f32233e2e93"/><file name="mysql4-upgrade-0.7.24-0.7.25.php" hash="bf5b8bee4bd3d1e4ebc687a2dc2c3b30"/><file name="mysql4-upgrade-0.7.25-0.7.26.php" hash="bf5b8bee4bd3d1e4ebc687a2dc2c3b30"/><file name="mysql4-upgrade-0.7.26-0.7.27.php" hash="88908e44653f5001778a2c215d2334a2"/><file name="mysql4-upgrade-0.7.27-0.7.28.php" hash="18c56edc18cb2d26b4fee1602031a8b0"/><file name="mysql4-upgrade-0.7.28-0.7.29.php" hash="82e449ada8ef2dd3f772f672ac9c8f4f"/><file name="mysql4-upgrade-0.7.29-0.7.30.php" hash="19993f5d8b5061d548402dd1ced2511a"/><file name="mysql4-upgrade-0.7.30-0.7.31.php" hash="ce6e9a220b1f47a449b1da768b481362"/><file name="mysql4-upgrade-0.7.31-0.7.32.php" hash="1f95d965cdd2ef8e0701c36d9a6d81ad"/><file name="mysql4-upgrade-0.7.32-0.7.33.php" hash="a3a0bb1853557a46d94ba9717e17c21c"/><file name="mysql4-upgrade-0.7.33-0.7.34.php" hash="1b317292156c19786d0c7891a8b6c94c"/><file name="mysql4-upgrade-0.7.34-0.7.35.php" hash="ae2f124dc9859240b3e5ce1a5ab0f79f"/><file name="mysql4-upgrade-0.7.35-0.7.36.php" hash="7b5b00ab8ec63b5fd02d8fa65cadf1b9"/><file name="mysql4-upgrade-0.7.36-0.7.37.php" hash="cb86e22aa7fd8996725dcd06935dff86"/><file name="mysql4-upgrade-0.7.37-0.7.38.php" hash="97a399efa3aa04df7dc63b395c2580ee"/><file name="mysql4-upgrade-0.7.38-0.7.39.php" hash="fb4444e6f5e32ef7dfca18a41e68ac50"/><file name="mysql4-upgrade-0.7.39-0.7.40.php" hash="bdde08b163e8c6a309637611ab6ebb06"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b6f41c583a739161c2255da179ac2bd7"/><file name="mysql4-upgrade-0.7.40-0.7.41.php" hash="d2e40907a7c8182999b4fd4b05aa54a7"/><file name="mysql4-upgrade-0.7.41-0.7.42.php" hash="827225fc74e03e78dd9394881330eb5e"/><file name="mysql4-upgrade-0.7.43-0.7.44.php" hash="95b7e4a01611587a57ae1c8421b0683d"/><file name="mysql4-upgrade-0.7.44-0.7.45.php" hash="6d9ee0c7fb4bd68452f1d82743005ef7"/><file name="mysql4-upgrade-0.7.45-0.7.46.php" hash="0fc03ee03ae2ffa5be0e718d3b5481c3"/><file name="mysql4-upgrade-0.7.46-0.7.47.php" hash="db9d37ff3ad447df8969dcf82b9bfdf6"/><file name="mysql4-upgrade-0.7.47-0.7.48.php" hash="f2ba617765373d640b78c409feec30f6"/><file name="mysql4-upgrade-0.7.48-0.7.49.php" hash="0eab9338782973dc63bec3ea582b8a5e"/><file name="mysql4-upgrade-0.7.49-0.7.50.php" hash="d85f9f9b9bcae12794b6bf6370d94644"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="3cee2cef6e32abe440cccdadd671f932"/><file name="mysql4-upgrade-0.7.50-0.7.51.php" hash="e55d842ef8a8437553644cf25cfcb9c9"/><file name="mysql4-upgrade-0.7.51-0.7.52.php" hash="0bfafab7de0664a4178de76f3890daf9"/><file name="mysql4-upgrade-0.7.52-0.7.53.php" hash="29533cc9df23e68747399c8263731477"/><file name="mysql4-upgrade-0.7.53-0.7.54.php" hash="d22c9a89e63753b14a8a7f1688a3526d"/><file name="mysql4-upgrade-0.7.54-0.7.55.php" hash="0dc3e2a1902cb6b14e9b7055ab570799"/><file name="mysql4-upgrade-0.7.55-0.7.56.php" hash="60753837cd5d60361534cbb0225a3454"/><file name="mysql4-upgrade-0.7.56-0.7.57.php" hash="170c670d3d72f70148e4d6c08342d235"/><file name="mysql4-upgrade-0.7.57-0.7.58.php" hash="12e12c08e28702e44fafd0028c1b849f"/><file name="mysql4-upgrade-0.7.58-0.7.59.php" hash="051192900951ee98fc951b5cc6aa9483"/><file name="mysql4-upgrade-0.7.59-0.7.60.php" hash="55fc783cb0f0729167ff5fd2e0a1dd57"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="a3f49edb28d84c59fe9ca7837dcea688"/><file name="mysql4-upgrade-0.7.60-0.7.61.php" hash="b895f5353751e0188c753acf337818ec"/><file name="mysql4-upgrade-0.7.61-0.7.62.php" hash="7a5c16a58337826b6d99039b8afaf5fd"/><file name="mysql4-upgrade-0.7.62-0.7.63.php" hash="a5191a21d2a025b70a4c9b3262300da6"/><file name="mysql4-upgrade-0.7.63-0.7.64.php" hash="996bd2a70e9038fad8394f45d0eff9f6"/><file name="mysql4-upgrade-0.7.64-0.7.65.php" hash="010c4eea30beaa065d1978cc9c75858f"/><file name="mysql4-upgrade-0.7.65-0.7.66.php" hash="31937181e9cb258de9ac045166cf2e36"/><file name="mysql4-upgrade-0.7.66-0.7.67.php" hash="965f4ea3f8a2a3462b2643e6aba90d65"/><file name="mysql4-upgrade-0.7.67-0.7.68.php" hash="64799f0acc85d3dd4f38d329e5af0aab"/><file name="mysql4-upgrade-0.7.68-0.7.69.php" hash="a77cf62660a94679202d0afcfe5c377c"/><file name="mysql4-upgrade-0.7.69-0.7.70.php" hash="27b1fb809c832ba02a1ee11408733fdc"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="6101295efd5f3f08f01a25736ec5e4f2"/><file name="mysql4-upgrade-0.7.70-0.7.71.php" hash="fd9597fd643c92bf0fca4d47dc12d774"/><file name="mysql4-upgrade-0.7.71-0.7.72.php" hash="9cd8144308f5164ced498a58cee7338a"/><file name="mysql4-upgrade-0.7.72-0.7.73.php" hash="2bb63d43241c32344f04ba08ec779b9c"/><file name="mysql4-upgrade-0.7.73-1.4.0.0.0.php" hash="a7ac06f492342ad7aa7a793c2b777f16"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="5da5b75ea047b1650baf789cd8ca5b4a"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="4eb5719eaeb28af0b58a5eb55b782c0c"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="77631a576880ed0c95bae492b0ec43c9"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="64bccc23fe9b77f2baab984f8cd9a4f0"/><file name="mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="9e71f44020268215ce0442be5390ad0a"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="98320c3efea02f3cdc48b736f062af25"/><file name="mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="769851d021ea071c5472a688a7ec27a9"/><file name="mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php" hash="85a2d3ea3b5b01559306595127f10108"/><file name="mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php" hash="31ac945d49fe496eb1b9bc097dee6809"/><file name="mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php" hash="af36774824c34c2e4607deb6c7a4cd8a"/><file name="mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php" hash="db18c11c5cb8a2629e1a542509eca131"/><file name="mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php" hash="3f279db6d9bc87e9da98805465ea58f0"/><file name="mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php" hash="273d8e4e1ae2746e546a206d62e43820"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="9ecd093559741748ace7a4cfd5b88f11"/><file name="mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php" hash="efaf7fd6da74170c570c8a318ae21e35"/><file name="mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php" hash="9fbbbc917f61035c2660f3506f81ab0d"/><file name="mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php" hash="5d060e7f034fce20260a77318207a5e5"/><file name="mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php" hash="601f0a64fded0b691d4e5cee1d4605f1"/><file name="mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php" hash="ef6456951f48c49a2c8655371dfc3882"/><file name="mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php" hash="6e28c9a7f29d0f4e84a2e288be34a0d2"/><file name="mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php" hash="e81a3dad476185e2d34b8a8f4e17aed9"/><file name="mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php" hash="a48503aadadba707cc96a39f344b3e87"/><file name="mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="2cfb7b7f14ef594bc4d09768cceff672"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="445490fc8158fd0ef7cd83c27ba93743"/><file name="mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php" hash="2a428605b7c8ddf194eccd4f40b57627"/><file name="mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php" hash="7d8e65edb87932c9a03c1e037e15c217"/><file name="mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php" hash="70e5a99b44286483ded586c2c77609ae"/><file name="mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php" hash="8dfca4d13fedcd3927800ce3abb3adcb"/><file name="mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php" hash="c452a59ae39426cf10bf2dd296363fa8"/><file name="mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php" hash="9ce0c5ae8cf94b5b2aaf29934d77ff94"/><file name="mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php" hash="a0b70d350522db088260ad4ec2c6fb6f"/><file name="mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php" hash="bceac8cc99838b2eb12609af7fa4d289"/><file name="mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php" hash="a183832b91182bc1d76a001f33fa2c91"/><file name="mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php" hash="d22ec63695cf1d6c6d73a45a423b1560"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="07ce9770be5a2c649589ae390077d11f"/><file name="mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php" hash="ea749610e40e90c9614314964b64a396"/><file name="mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php" hash="38846d1d51038070a2733c032c157970"/><file name="mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php" hash="9b31f4b214dbb5230c29d83cace9fba7"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="d1c7df345f9d59660a45ae79c4aa159c"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="34c9a15dbd4b6c0b765c2730022f8c1a"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="10547a76c65573fa3dbe2a2c8d683817"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="c4895fa8b5b66db9a98cc765116b54ca"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="dfdc909dbc50f6e4556b3f350bb31cf9"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="262c663c9367c7404f63608ff545cd72"/><file name="mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="26fd60835af8537cdcaecfc86776b4c5"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="a407effa970d70d0c38e8f8a3c1190b5"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="683a300cf2c2b65967804b1ba86b6247"/><file name="upgrade-1.6.0.0.10-1.6.0.0.11.php" hash="be8d5e4b7ef6f6d698837e7d7d038468"/><file name="upgrade-1.6.0.0.11-1.6.0.0.12.php" hash="5f27bb2394ca437ccc6eafacda319c26"/><file name="upgrade-1.6.0.0.14-1.6.0.0.15.php" hash="5a64b192dfb43b5b6068a36c750f666d"/><file name="upgrade-1.6.0.0.15-1.6.0.0.18.php" hash="6713ad3a3e1279840570d09be596ad8d"/><file name="upgrade-1.6.0.0.18-1.6.0.0.19.php" hash="2b9ff26ac0a03b7b06d11e5da20a36fd"/><file name="upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php" hash="3b43f2365ac8a0cc69128b42ef55a552"/><file name="upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php" hash="0c50b1fe993a9c96ebfc1195cec2d9ef"/><file name="upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php" hash="8bf92dde7ab583472cf41e3aa3bc7854"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="977b5802c56f3995d1e3f350bc560840"/><file name="upgrade-1.6.0.0.3-1.6.0.0.4.php" hash="5fb5d4f3f47671b5b9de7bc189420df6"/><file name="upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="2fb8b3607046c292040810e74a07f4e0"/><file name="upgrade-1.6.0.0.5-1.6.0.0.6.php" hash="48946c60f1c39c90f12423af8fd9ab4a"/><file name="upgrade-1.6.0.0.6-1.6.0.0.7.php" hash="d902f18b3d77ceb531870db665dd6a5f"/><file name="upgrade-1.6.0.0.7-1.6.0.0.8.php" hash="1954af67d8f5ce325f211a062e607185"/><file name="upgrade-1.6.0.0.9-1.6.0.0.10.php" hash="8bea76f4be2e8a15b414fe85200e0146"/></dir></dir></dir><dir name="CatalogIndex"><dir name="Model"><file name="Aggregation.php" hash="d8af150f1f31f8eeb374b372112c7bd6"/><file name="Attribute.php" hash="e7fc5f65b7150d29466cf72e660499a3"/><dir name="Catalog"><dir name="Index"><file name="Flag.php" hash="f9994f4bfa80c140a5dc3c7d56f354eb"/><dir name="Kill"><file name="Flag.php" hash="aadfadde5165ee0d52c48b171eabdba9"/></dir></dir></dir><dir name="Data"><file name="Abstract.php" hash="1ad82e249c4503cdf441957c7b455b57"/><file name="Configurable.php" hash="ba79b0a91e7250057b67ac0d83604534"/><file name="Grouped.php" hash="5914fe1730fe66b4b9f5f3127a4f422a"/><file name="Simple.php" hash="7f58b8c4463fe055fe99427fdfd4cb1f"/><file name="Virtual.php" hash="383cf1b8a7936cdedc1f37b2966fd687"/></dir><dir name="Indexer"><file name="Abstract.php" hash="3f4d1948c963b9295eb9d74cadad19bb"/><file name="Eav.php" hash="f48fda3c09788e64982acd730859a681"/><file name="Interface.php" hash="17198f0e5b2db1597e934a7fc87df8ba"/><file name="Minimalprice.php" hash="6083e851bd5987d52b783f7534dfe54b"/><file name="Price.php" hash="f3f374ff229ed0e4275e3d75801152b5"/><file name="Tierprice.php" hash="80e587f773db5240db32eea1fbf0eb02"/></dir><file name="Indexer.php" hash="ea8f414c384e223f7066f40a1825da58"/><dir name="Mysql4"><file name="Abstract.php" hash="d31a3c0e2196eed9b5803f7f3dcbadcb"/><file name="Aggregation.php" hash="1e2bd5dbd163b5d380de7042caa476af"/><file name="Attribute.php" hash="5432abbb2508b9e035a3e281fedc9a32"/><dir name="Data"><file name="Abstract.php" hash="e923a9926a1f067de21d8d1f401545db"/><file name="Configurable.php" hash="3de1676d25c734ecd245c7bf878f73aa"/><file name="Grouped.php" hash="c68cd41d33583c508227e85cf60976b9"/></dir><dir name="Indexer"><file name="Abstract.php" hash="af322c8d3d112ecde8ca776a0018e664"/><file name="Eav.php" hash="a12a21ca3b5d071c70da3ccf3ba594be"/><file name="Minimalprice.php" hash="00922c6b3c641c559eca64383bb77769"/><file name="Price.php" hash="36d9a8cc30d851f144db2687ab2f403a"/></dir><file name="Indexer.php" hash="638fe575e181ee6c68c4bfbc988c24e5"/><file name="Price.php" hash="88052475d8f04c300c6fae7b09d319e8"/><file name="Retreiver.php" hash="8f05bd5edb9b7a6ff19bea9f844dfbc6"/><file name="Setup.php" hash="1fbb2d9be694eadc61f2d1d83a0309d5"/></dir><file name="Observer.php" hash="8047d191d20f391728e223f9fc8e311d"/><file name="Price.php" hash="a195a56776dc8633fefaf4bf95cf7da8"/><dir name="Resource"><file name="Abstract.php" hash="55c819cd20eb177370d0d7c9a53a3174"/><file name="Aggregation.php" hash="67dc7625e3715466d02be700f5af432a"/><file name="Attribute.php" hash="9771e6b7750db77ada5437c299f0c097"/><dir name="Data"><file name="Abstract.php" hash="81f481e13bff2c1516442eef052ae670"/><file name="Configurable.php" hash="1c28a438bee1ab045dae5831d2d9514a"/><file name="Grouped.php" hash="ae6f6724480661972838fb5a5495addd"/></dir><dir name="Indexer"><file name="Abstract.php" hash="192816c1dfa15625f02ec3b24bdd6950"/><file name="Eav.php" hash="e2c4848e82adfe4e1a36084aed6e1276"/><file name="Minimalprice.php" hash="d09967b2fc0f04afbf7109a1fbce2851"/><file name="Price.php" hash="e950948c90f03beeb93e8351b6e095e3"/></dir><file name="Indexer.php" hash="cf50fc45c5da409e70e1496b395c2934"/><file name="Price.php" hash="2383523c21df945fc7c6a1d335f2f27a"/><file name="Retreiver.php" hash="70598ae252e98fb6f89cab93469bba01"/><file name="Setup.php" hash="2a69b5d885631ea810158a4909329a9e"/></dir><file name="Retreiver.php" hash="cbec9f6f58e97c37f191d310a1eff230"/></dir><dir name="etc"><file name="config.xml" hash="50ff66b4fc9b312bc89626503b3cd348"/></dir><dir name="sql"><dir name="catalogindex_setup"><file name="install-1.6.0.0.php" hash="cf8f185eee27560f80f39a914b5c3c82"/><file name="mysql4-install-0.7.0.php" hash="58a76cfbf513042d9241684681c6b079"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="d0aa67bf065bb707fe2abab0425caf6d"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c9148eaec8f5380d769b2b34ffb18084"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b2710d3bef49d9fd256c6ae9c871be05"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="bb820f1d177b543937070e00fb4b1845"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="29314bf0698771534cab5eb548402ca1"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="24cbd4a5b74266bcfbade17ef5f8ada4"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="7b2a5ed488381396236020a21579aeb1"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="af7837b7a4a1824e87c9f0f1645dd33c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="d68c3505c7b47de51e4fe56a6cbd791e"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="8d8b05c8e5df2bf84b586816ac1b13d3"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="3870bb2755fbb8547c7d7862f869c7b1"/></dir></dir></dir><dir name="CatalogInventory"><dir name="Block"><dir name="Adminhtml"><dir name="Form"><dir name="Field"><file name="Customergroup.php" hash="a1bc58f2f084c1f648e56e3b9da4fc7c"/><file name="Minsaleqty.php" hash="70ad8c04e28efb204fc106207c33aeeb"/></dir></dir></dir><file name="Qtyincrements.php" hash="b261f945d395df544101b9aefbeef6ad"/><dir name="Stockqty"><file name="Abstract.php" hash="e24fe678792bd0418688654445adabcc"/><file name="Composite.php" hash="7e64a2096cf31e8403a8ef2f059f0f9b"/><file name="Default.php" hash="89e5d0814a90450ccd11b8505c74a0e9"/><dir name="Type"><file name="Configurable.php" hash="cbffc0a8607f8ace1240b22f8d989fcb"/><file name="Grouped.php" hash="ab6c2c5e76f4d4bf3355b0a63cde0493"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="dead0e2fb29574261d5b5d315e356e05"/><file name="Minsaleqty.php" hash="838420acee2dd3a5acb6001ef5382494"/></dir><dir name="Model"><dir name="Api2"><dir name="Stock"><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="97562c6058565fe06b265442414811f0"/></dir></dir><file name="Rest.php" hash="76b2a33c938950385b8201e3df6b090d"/><dir name="Validator"><file name="Item.php" hash="1b0cfbaed0d9ba8f83b02fc32185de6b"/></dir></dir><file name="Item.php" hash="cbca2f7f7afcf55b105e90a0673ce262"/></dir></dir><dir name="Indexer"><file name="Stock.php" hash="c0984aedb09efd73fe70a489761e6ae1"/></dir><dir name="Mysql4"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="31fa6e10d95ed91f2cd36ec49087eb47"/><file name="Default.php" hash="3a95a221685f00b7bb1d75715e6955fc"/><file name="Grouped.php" hash="f0014ec4bb9d18b18ad8fe076777ac64"/><file name="Interface.php" hash="dd5e3abc59defff34dae52e7ade0541d"/></dir><file name="Stock.php" hash="6f0903cd0b2ab90b43d58d6343a81f8a"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="f782cd8443b68f42c9b9f1040bf23637"/></dir><file name="Item.php" hash="d78fcc6b999ef32713e1e3a40c74d127"/><file name="Status.php" hash="b771b21943d3dbf935125ba221fde479"/></dir><file name="Stock.php" hash="f459ba26acf3bc5c48d28d94ddf9bacf"/></dir><file name="Observer.php" hash="cf0787c14b69f8a331548a2d6ed341ce"/><dir name="Resource"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="99b85c19436fd2cb1bb639c234507903"/><file name="Default.php" hash="d3b5e2ef640c5b1ddd51d1d384ac7a23"/><file name="Grouped.php" hash="373135e46cfb49c9ac161cdf4542e216"/><file name="Interface.php" hash="21633d6d7270d2f27a6a3e43aa4e3718"/></dir><file name="Stock.php" hash="006bd7c6552ba58f3f5c6f4d2b02b801"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="ac116ab6c146546acfe59331b2652a21"/></dir><file name="Item.php" hash="7aa6d956789b642696f070490bb886ab"/><file name="Status.php" hash="5069f9b3d81cc2653932563e972a3a1c"/></dir><file name="Stock.php" hash="75a6f191034e6b3cd459198f5200846a"/></dir><dir name="Source"><file name="Backorders.php" hash="dd5a2e4f5efb98cc3ea16b8b7e9ec555"/><file name="Stock.php" hash="bf73ca9c63cda414afd2b2a1217ddd97"/></dir><dir name="Stock"><dir name="Item"><dir name="Api"><file name="V2.php" hash="ff859921c2c7b1ee05aebe08d30fb197"/></dir><file name="Api.php" hash="47b8ff35afcf3619b439f064b2290e64"/></dir><file name="Item.php" hash="8bd5d30e4c56b9bb9553e8c2a50b1254"/><file name="Status.php" hash="d95989bb579fc09fe4de165589a32eb2"/></dir><file name="Stock.php" hash="16f67a9361cee9a7147ddb739d401a98"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Minqty.php" hash="d9831c57b177371b4df7dcc296c842d7"/><file name="Minsaleqty.php" hash="b09b9183f94e35e2c01bf076e4a73dbe"/><file name="Qtyincrements.php" hash="048f74672f457990537be44d98b9315f"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="7e7bf9fcaf608e7655e2fadb729b12c5"/><file name="api.xml" hash="0568837d13dc040aa49b41ab4dff808a"/><file name="api2.xml" hash="bd3260899f9b9486db208d765a24e8d1"/><file name="config.xml" hash="014f7fe202259a429541ca3128f13940"/><file name="system.xml" hash="3d995e44a4426e9bf2df71c86b53f2df"/><file name="wsdl.xml" hash="cfad5924eb32b8fb7ccf79309e5966df"/><file name="wsi.xml" hash="ec7bdd8cb2bc5dd12c0a4d865fe3d313"/></dir><dir name="sql"><dir name="cataloginventory_setup"><file name="install-1.6.0.0.php" hash="f27e471805eddff1bf82df8107f3f974"/><file name="mysql4-install-0.7.0.php" hash="6ba7aa64d910b36a119e6a4ccab4f1d9"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5a9307e341725852439334f7d5e2816f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="28fcfff6687a76578474774b791ede4d"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="3c038bcc6fd8d8a377833995c8e57188"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ccd6337d78f140a84b40a3aa34d594f8"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="1f84078a74c0b69b25627921ba46d9a6"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="594dda2c42f64420af520403b0ad280d"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="fd73a003742f3e2568de9e4b1cbaab59"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="8129f7ce45e56324a5ecd7e5bc65e039"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="b72a6c90993bc3285473ac430078e2b6"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="aa090c910f467d017f647bf9bed33f85"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="f07d18a7750209513b5e30acd4d0b372"/></dir></dir></dir><dir name="CatalogRule"><dir name="Helper"><file name="Data.php" hash="f114ddae5cdaf5bb9062fbc0525a65a4"/></dir><dir name="Model"><dir name="Action"><dir name="Index"><dir name="Refresh"><file name="Row.php" hash="cf9ea839eac7052dd9016baa261571e9"/></dir><file name="Refresh.php" hash="6988a0c4ef21306a3fc3f9bf5a3c26b2"/></dir></dir><file name="Flag.php" hash="89da7917e6cdfb0d297190251ebf4169"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="98dc46b90d3d123138e2ceca984e1a16"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="082fee76f3ec35c9e6574848aaee5148"/></dir><file name="Price.php" hash="df79ff85fd019caec3a0e3c00deabee6"/></dir></dir><file name="Rule.php" hash="e6cccfd2c15365dd7fadd0cb7d3e11c5"/></dir><file name="Observer.php" hash="0a085d9342bd1781dfc1c94dff083539"/><dir name="Resource"><dir name="Rule"><file name="Collection.php" hash="44c60a399686f678146b4030cc178cb1"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="be34144ee4fc34011eedcadcc023d5a2"/></dir><file name="Price.php" hash="db97799a10e708a7ce51ee5aed4b3290"/></dir></dir><file name="Rule.php" hash="d3ef4a4ff9876be7c747e181e827f8dc"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="8597f6e2ba5196887db9182bb4a16877"/><file name="Product.php" hash="37363ef9f7e28a4e4895586f99526e95"/></dir><dir name="Condition"><file name="Combine.php" hash="585427b59b5c3a2cd2940ab7812e6901"/><file name="Product.php" hash="00fd7823a5edca69180b03533896150d"/></dir><dir name="Product"><file name="Price.php" hash="60226e4a64afc637de9c77f5591b425c"/></dir></dir><file name="Rule.php" hash="d004ff0a9cd62a4e06f4a9f7cd88369e"/></dir><dir name="etc"><file name="adminhtml.xml" hash="73016378f9ba7645398de6357859d1c1"/><file name="config.xml" hash="322f34e65bdf4e2bd7356f24cc2bf3e3"/></dir><dir name="sql"><dir name="catalogrule_setup"><file name="install-1.6.0.0.php" hash="f99c00bb678a800719c5d4c412a49170"/><file name="mysql4-install-0.7.0.php" hash="b357df1aa63143f7ed1fc4c1c2d4a1a0"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="adc3ad486f6a80fe863b9d44df345d1e"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f005bc366de60f96a1505055d817a5e8"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="20435e11621f0306884a64005286c0e3"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="4936b71df8df089c274f2dc5f2c8821e"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="1a238cedfd2b80d5ea30879c53ce8e43"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="cd4c75cd9a21b6d9cd3f0e5a799815f5"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="c918bb2d58138ed34576b591521d8ef6"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="f082bd75ebca7b25f64f07df9a099db8"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="ab2e1f2440c969df314517be519f64a2"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="8edc824dd64b606a204ee9fe1c610a91"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="02a57c0410a008a9be02f9f6a7b54de2"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="4e0c6fab17fb8551c47322c6765341f5"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="dc42862c395434103f7fa6bdca290164"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="73f0ee67893eee7948cb9f48242e88a9"/></dir></dir></dir><dir name="CatalogSearch"><dir name="Block"><dir name="Advanced"><file name="Form.php" hash="c4c1713e4bbdc16cb0ee850aaedc3cad"/><file name="Result.php" hash="310fc695dcbfcbceb35119312ec66b5f"/></dir><file name="Autocomplete.php" hash="e202dd4bbef904236e7cd062fba11705"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="2dc8cf868e549f09695c8332163933d8"/></dir></dir><file name="Layer.php" hash="68ff0d6b3a774c4dee71a63db303fe49"/><file name="Result.php" hash="7fa721871ca0ddae2f8170b5c995997e"/><file name="Term.php" hash="cb1b28a95c749bf853631e1a4b1777c9"/></dir><dir name="Helper"><file name="Data.php" hash="07929ff5bf2897db21b8d941e2f6827c"/></dir><dir name="Model"><file name="Advanced.php" hash="28c2238611b6a6839870720ed3a4e9d0"/><dir name="Fulltext"><file name="Observer.php" hash="db616d623addda792285431dba58d592"/></dir><file name="Fulltext.php" hash="c2214a9c614551ac8a73e25e7ba08909"/><dir name="Indexer"><file name="Fulltext.php" hash="110dfc244cc187d62a803ff6daa33cec"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="2bad10ccda4b15a38b22d4bd149d1e71"/></dir></dir><file name="Layer.php" hash="404dcaa87375d9170e81e4c3e04f0cf5"/><dir name="Mysql4"><dir name="Advanced"><file name="Collection.php" hash="aa03f1339b7ebc61d4be24edcd74ce10"/></dir><file name="Advanced.php" hash="945e86183ddabab0dc939e7c8dbe36fa"/><dir name="Fulltext"><file name="Collection.php" hash="967735a54331b0f7675ea682d876eb09"/><file name="Engine.php" hash="ae74f610dfd3278c86757304357b096a"/></dir><file name="Fulltext.php" hash="e8b8165e231a1a47e354550156023a7b"/><dir name="Indexer"><file name="Fulltext.php" hash="f3895c8928c0729144fcb543341e0933"/></dir><dir name="Query"><file name="Collection.php" hash="80795ac59424f9343ec3579cd3afaf5f"/></dir><file name="Query.php" hash="eca5a8fed6561e2bf1f503a5e3894bd9"/><dir name="Search"><file name="Collection.php" hash="0c8336671fa586fbbbf45cfc011fdb79"/></dir></dir><file name="Query.php" hash="0ec47e6cfa90f303cc0aeeaf4242dec1"/><dir name="Resource"><dir name="Advanced"><file name="Collection.php" hash="5a35a25c346410403155657d9c794b80"/></dir><file name="Advanced.php" hash="3d8c2a496f2adff90f97ea7b27bd7093"/><dir name="Fulltext"><file name="Collection.php" hash="aa2f7ad37c1f328d4a858af5224161d1"/><file name="Engine.php" hash="2922f0eab7a7157a62ece349ffad4656"/></dir><file name="Fulltext.php" hash="b10421b49c01934e25a0b5b89423a286"/><dir name="Helper"><file name="Mysql4.php" hash="1cb52148ea9f147443142802a5ccac8e"/></dir><dir name="Indexer"><file name="Fulltext.php" hash="6d6c52c0bb00ac1a4ff0283f1ffc135e"/></dir><dir name="Query"><file name="Collection.php" hash="1f36d427babb22a0f610cd217bd88729"/></dir><file name="Query.php" hash="e0960c2bb8fae4146fd06f4c97967053"/><dir name="Search"><file name="Collection.php" hash="3bac930ad9b9fbdbcf18e85083741e1f"/></dir></dir><file name="Session.php" hash="3b64d6f7dcd2bd9ae5c0c5347887529d"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Sitemap.php" hash="f8a202c12c4eec2c3a07ef7b462f69e5"/></dir></dir></dir></dir><dir name="controllers"><file name="AdvancedController.php" hash="bb536922f21c24c1ae0b12744300f807"/><file name="AjaxController.php" hash="b5addc862bb4c8d3f768e314e52ec9a6"/><file name="ResultController.php" hash="221e519f7985eb066d64792862fc59b2"/><file name="TermController.php" hash="22420488e648e5f852fb7df4120cc884"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ab94dc4bbf1312308549b7d3999452ee"/><file name="config.xml" hash="8b374762e2c06a24be57da998c87fcc7"/><file name="system.xml" hash="a2fcb985b8b881b78d27010897c13870"/></dir><dir name="sql"><dir name="catalogsearch_setup"><file name="install-1.6.0.0.php" hash="a2b0d197a9e45e8ba6ec6fdb199888d6"/><file name="mysql4-install-0.7.0.php" hash="712a386cbbd394efe749e5194370fca2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f1298524c0e8389799244f065e097a0d"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="83e4a715af4d5690b58dc4dbad3006f9"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="392ccdab42485cea7426beea3288792e"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="4186e84dd5d4b4be4e78b3f9428f78b9"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="27d10ec3e6a9e8ab6fb2e6fc7cd45e0d"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="c36dec0d08b86b36cceeafda534321a0"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e0610cececc06f7d0d96a82ddb648344"/><file name="upgrade-1.6.0.0-1.8.2.0.php" hash="3f43aa1f65cc87f92d7e19b4c180ca21"/></dir></dir></dir><dir name="Checkout"><dir name="Block"><file name="Agreements.php" hash="01835129ca84c8a6f56097b06636fd5d"/><dir name="Cart"><file name="Abstract.php" hash="872be8c057c924ca191ba0537f5b0794"/><file name="Coupon.php" hash="1fceac167119d3c42af64a6e7c8a71a2"/><file name="Crosssell.php" hash="13dbf998a15118ea5b56f3bc7841c560"/><dir name="Item"><file name="Configure.php" hash="842993ebdfeb50a0c26ae19fc6997997"/><dir name="Renderer"><file name="Configurable.php" hash="0c2e3530214b12cb21c736248dea8803"/><file name="Grouped.php" hash="67625b5ec0559494f73cc2ae19ee8347"/></dir><file name="Renderer.php" hash="5b5b9830a510c0967bf27da2912d36fe"/></dir><file name="Minicart.php" hash="1a542fc17951851fab4caf179db2bc55"/><file name="Shipping.php" hash="6fc8fe017f2373cb29628c113d1bb1b8"/><file name="Sidebar.php" hash="b9ce6dc90840fb4e522025e6a2417817"/><file name="Totals.php" hash="3acc1369b38f6f51075219698d03345f"/></dir><file name="Cart.php" hash="90530b2ceef673632d7198950523d896"/><file name="Links.php" hash="46de6b3a0fc7ae8a1ae381bb74bd0d00"/><dir name="Multishipping"><file name="Abstract.php" hash="e341425a398ff768c34a65230682ba6a"/><dir name="Address"><file name="Select.php" hash="1793fb3a0ea7e43a1cdcd9b755bd39b0"/></dir><file name="Addresses.php" hash="8759f8cc535172f9b8d9ee5356780fba"/><dir name="Billing"><file name="Items.php" hash="53b44cedd1239aa341c6eafe08d48fe5"/></dir><file name="Billing.php" hash="ad98a619f72678d071839ed955915fb8"/><file name="Link.php" hash="94c157e952a32362e76b712197a59c66"/><file name="Overview.php" hash="ca306b397661c6123c131e5e535bb261"/><dir name="Payment"><file name="Info.php" hash="08ef96244b3ebca5d7732ee56cf5c263"/></dir><file name="Shipping.php" hash="f705bb50a314ebbaeb3083dec924e448"/><file name="State.php" hash="334ee0b3c9545fd5e581f4ef63330092"/><file name="Success.php" hash="5b83ad214e1b0384cb1c871528995e90"/></dir><dir name="Onepage"><file name="Abstract.php" hash="4b39037994dfe61e2cfc7bef63448cce"/><file name="Billing.php" hash="ba0a71fa042248952a74636202652680"/><file name="Failure.php" hash="9106efb1dccccfc80f5d307b134c7448"/><file name="Link.php" hash="bd368ed291976634c9c52f33cd5f6809"/><file name="Login.php" hash="7857bc45c6226a8229b83f562679a5fe"/><dir name="Payment"><file name="Info.php" hash="ac4a991b0a6d05048ca2db14d246509a"/><file name="Methods.php" hash="8265cc80ed4910af39b6e1f74e78c5ed"/></dir><file name="Payment.php" hash="bc88e1014705d486be1e33d094f2ac49"/><file name="Progress.php" hash="20d530cb1867ed769bb8cec8052afe4b"/><dir name="Review"><file name="Info.php" hash="b061baa6f8d251c64b9cab27a94c9127"/></dir><file name="Review.php" hash="7dcf5f69495112c22a13088025e91845"/><dir name="Shipping"><dir name="Method"><file name="Additional.php" hash="482c7aced91da476fcc7940ba2422aa4"/><file name="Available.php" hash="ac975fe58100c7187c7ad41efee2f3c6"/></dir><file name="Method.php" hash="9635ce02ff9e552c6ca316ee87e3e41d"/></dir><file name="Shipping.php" hash="80b9583f205de49524da89d391acb084"/><file name="Success.php" hash="0885c2795f13c50f57e69bce8d085b41"/></dir><file name="Onepage.php" hash="5cf1c1c0489e8f9a1f0012e2b9595752"/><file name="Success.php" hash="e8018a6b54cded2365d186c663cd4968"/><dir name="Total"><file name="Default.php" hash="66dc9076a8ce6931fdc699db167ba92b"/><file name="Nominal.php" hash="cabb2ac2a88ba346625b9247a3a71a08"/><file name="Tax.php" hash="6f154ed6626155404969501946c71344"/></dir></dir><dir name="Controller"><file name="Action.php" hash="2140565efbed00f9adf27760f44b2f84"/></dir><file name="Exception.php" hash="5ec650bdcb9d71f0b5fc348fc2758f19"/><dir name="Helper"><file name="Cart.php" hash="5baa4a7803d841df763d75c3301b8deb"/><file name="Data.php" hash="f4dc9af9742b7842867ed99c2e83772f"/><file name="Url.php" hash="16a0c1a51531c77e47d59d3d1c626c18"/></dir><dir name="Model"><file name="Agreement.php" hash="b580e9f9103423b901ab91f5310770b6"/><dir name="Api"><dir name="Resource"><file name="Customer.php" hash="025742b119d655c84df990522df5d48b"/><file name="Product.php" hash="a0ff764a225e34426528bed282710d51"/></dir><file name="Resource.php" hash="6bae9a50adf01bf17a8026ae5ea16e15"/></dir><dir name="Cart"><dir name="Api"><file name="V2.php" hash="ca951fb2730c2a3b8a25aba1e48bf669"/></dir><file name="Api.php" hash="64362c38ea6adb5569300c9302c6150b"/><dir name="Coupon"><dir name="Api"><file name="V2.php" hash="9147be382a0f3e670b935e854d21149b"/></dir><file name="Api.php" hash="7281c3d83022812980530277d988b9df"/></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="24f3b7eb8dea09b6fddb7785078768f8"/></dir><file name="Api.php" hash="80552ab2df6b4a666c5026894e6b7fdc"/></dir><file name="Interface.php" hash="a18f87449ec50d3759620e08f7b209de"/><dir name="Payment"><dir name="Api"><file name="V2.php" hash="84aa5a5f31a36cdd0ec87a2120b9fcea"/></dir><file name="Api.php" hash="505b707924d3510781922693db5705e5"/></dir><dir name="Product"><dir name="Api"><file name="V2.php" hash="52d7e0631effa6573f2e7cb9f499c34b"/></dir><file name="Api.php" hash="b205126d26bcfef83c42c5c004336e58"/></dir><dir name="Shipping"><dir name="Api"><file name="V2.php" hash="0ca7ed3c830a45b6e0a22ed412f48fd1"/></dir><file name="Api.php" hash="e9af22352df7284f040dad6a9a5ec241"/></dir></dir><file name="Cart.php" hash="78a88f2b65cfbf9f83b75316b62dce3f"/><dir name="Config"><dir name="Source"><dir name="Cart"><file name="Summary.php" hash="8e54e142a018e30c2a6263d734091ed4"/></dir></dir></dir><dir name="Mysql4"><dir name="Agreement"><file name="Collection.php" hash="a5d2e187861d7a47e33a1f8dfe568799"/></dir><file name="Agreement.php" hash="8fd16cd1119f012cdc66ce0101f7cd72"/><file name="Cart.php" hash="68a293fb22cdedf7fd4c49d4d01cc577"/><file name="Setup.php" hash="0818088b40ef0aacf85e35bd10822a8f"/></dir><file name="Observer.php" hash="95c74ef6d46a2421855f991659c7dc23"/><dir name="Resource"><dir name="Agreement"><file name="Collection.php" hash="70390a18d13f12efd292c76228d29034"/></dir><file name="Agreement.php" hash="7f20980118952614f5714c1f4153b92c"/><file name="Cart.php" hash="ce89a605fd599477cac950d59d41f4fd"/><file name="Setup.php" hash="813ccb7e69f00a31c143037af7662e3f"/></dir><file name="Session.php" hash="0375614ce3144681b02f37bc25a414bf"/><dir name="Type"><file name="Abstract.php" hash="df92eaf8fd8e69285de36aa2aa4110f4"/><dir name="Multishipping"><file name="State.php" hash="48e6080608d05fc6dc7284b635040e76"/></dir><file name="Multishipping.php" hash="05e6c897750305c65f21ac527cb6f064"/><file name="Onepage.php" hash="bb170775e5417ee7b4f87fee907f4bbe"/></dir></dir><dir name="controllers"><file name="CartController.php" hash="fccbfdf52d77e2c706d1cb4e99e7445e"/><file name="IndexController.php" hash="835b0dbd4fac4b76a274d7299cbd3c00"/><dir name="Multishipping"><file name="AddressController.php" hash="c9c93e7093db346806c9f79d8f5b52d6"/></dir><file name="MultishippingController.php" hash="301ea50309f4b0f007e44465dc0cc4c0"/><file name="OnepageController.php" hash="60fc66d4af696cda774a99b8159f75a1"/></dir><dir name="etc"><file name="adminhtml.xml" hash="72fa6908b80f63b891ab5ac9e60a74ad"/><file name="api.xml" hash="07869dd7ea9e838ae3ab12df67816a2d"/><file name="config.xml" hash="1a3aa782c78fa35897769c97763089d6"/><file name="jstranslator.xml" hash="e7d071b767fb4269f62d5b33dd241f80"/><file name="system.xml" hash="3226cfa047ceb033fdab8ba223f01fd9"/><file name="wsdl.xml" hash="9a10e25803e84713f5031a168dd0c624"/><file name="wsi.xml" hash="2567bee4ef18e1b426c700ce66c3bcb1"/></dir><dir name="sql"><dir name="checkout_setup"><file name="install-1.6.0.0.php" hash="8023f1dce251f1376c3ba9a15262d1e5"/><file name="mysql4-install-0.9.1.php" hash="121a29cd5d6fac478e0e7c8cc0ae4e0e"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="caf108e5f9ad2c1cbcd6dd4512405bc0"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="8b7187ee19e04e5722522ee204df4bbe"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="2fe9fb1f351f24f255e01578acdf5e20"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="c86e236086ee30581d8ab81d5be6d8bc"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="d5eb44438a47c217307b567b5d5b3cda"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="1647b99f4ca60de0ca2caabae08b1cc2"/></dir></dir></dir><dir name="Cms"><dir name="Block"><file name="Block.php" hash="2026d5e3ec9868f3a565d461e2781185"/><file name="Page.php" hash="8a942685ce32d526fb633b05d61e633d"/><dir name="Widget"><file name="Block.php" hash="87384c28f0fcf94ff4cdb894d94c3bd9"/><dir name="Page"><file name="Link.php" hash="62d09bfafc2eee9d3df946a8348e5434"/></dir></dir></dir><dir name="Controller"><file name="Router.php" hash="5dd259a31fbbb1d93d37479585d98adb"/></dir><dir name="Helper"><file name="Data.php" hash="5b401887c9b6ea30b87faa3383e32676"/><file name="Page.php" hash="9dbd6afbf7f7fc1020ab6bf2e5308de1"/><dir name="Wysiwyg"><file name="Images.php" hash="9d37c7df55870372c67ef614c87e7012"/></dir></dir><dir name="Model"><dir name="Adminhtml"><dir name="Template"><file name="Filter.php" hash="4b8f25b0d6a794d041807fee31d4cf92"/></dir></dir><file name="Block.php" hash="83d40f33b021463bc4bb0eb1d56f40ac"/><dir name="Mysql4"><dir name="Block"><file name="Collection.php" hash="0ce095dbc704bf96a03b58cc34bcee38"/></dir><file name="Block.php" hash="e58e789de65a1d0b1e3200f308a326a3"/><dir name="Page"><file name="Collection.php" hash="1b0ab33ca1731ea0317355b4cd26a80f"/><file name="Service.php" hash="a36048e18e769374bffd794b01aeb5c8"/></dir><file name="Page.php" hash="79becb04a45a36b58361057380cb63a2"/></dir><file name="Observer.php" hash="56af81a9637530097458c997fa6d7a70"/><file name="Page.php" hash="3b60c996d092d36d0df2381f072bc828"/><dir name="Resource"><dir name="Block"><file name="Collection.php" hash="094cbc78f457b943183bd62986ade660"/></dir><file name="Block.php" hash="1a984c70b61e3c501a791919595b51d4"/><dir name="Page"><file name="Collection.php" hash="fb752a9e5941720852132c2526ac4ac5"/><file name="Service.php" hash="031c3b36bd9327c264c94a5ace150fde"/></dir><file name="Page.php" hash="de4319cd668bb83608932ba3d608fbd5"/></dir><dir name="Template"><file name="Filter.php" hash="21286b1ddb5e180223905d9a2930cd2b"/></dir><dir name="Wysiwyg"><file name="Config.php" hash="d8d910e5a4c480f6d93184f107989b2e"/><dir name="Images"><dir name="Storage"><file name="Collection.php" hash="fe8a17645ea1a2e5ea23f31ac2f34251"/></dir><file name="Storage.php" hash="a094d259b85527d5bd3fbdd9c70c14f1"/></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="22073687a4879efcae896723ba6901c7"/><file name="PageController.php" hash="1c0eee5022af77ad35fa6387823a7b7c"/></dir><dir name="data"><dir name="cms_setup"><file name="data-install-1.6.0.0.php" hash="98ffdd112d54cd7d8bf0baa9fb42a497"/><file name="data-upgrade-1.6.0.0.0-1.6.0.0.1.php" hash="cf1aa0ef419605b9041c511f1df6b30c"/><file name="data-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="d34ef38bbe7c6454609549735924cacc"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="26cfaa3305365414a7bbcb212ba6676e"/><file name="config.xml" hash="5ee4baa239fe2f016bd366e002d08406"/><file name="system.xml" hash="f96d55ee55ec88d17ab1fd129fd15526"/><file name="widget.xml" hash="19daa63e98d6adf9bf7a8743ebcfec60"/></dir><dir name="sql"><dir name="cms_setup"><file name="install-1.6.0.0.php" hash="036832fd0187d0c97a386e02548e4b7e"/><file name="mysql4-install-0.7.0.php" hash="eba8ab5a1a3b17a4efaee22ee36e2303"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="43ca4351a1f90c5b6d15b160140fec4e"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c1e07029aea48f5efea912da751d3364"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="3c0b96adf71c6548a7d060aa2887f7bd"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="df2dd2e5fb88662ec3aeef3ca66cb683"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="94959b92163ebeb21ee267b056f9fffe"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="33c5082df30fe56f5b52cb3e3ba33f5e"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="80036501cd1d3673b29025791bad936f"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="5a7f7d8801adb61b7f40742f14fcc5c0"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="9296cf6a7bf311e21d38f78b7a4382f5"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="bbd1d797b5efcd9d700e4172475fe96e"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="3673999c0fb91684094cbe9360dec2fc"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7eb82690d68c916e310cbb3afa3ce612"/></dir></dir></dir><dir name="ConfigurableSwatches"><dir name="Block"><dir name="Catalog"><dir name="Layer"><dir name="State"><file name="Swatch.php" hash="5870932d0398e31209b38592e0f2a1de"/></dir></dir><dir name="Media"><dir name="Js"><file name="Abstract.php" hash="ac0376fb546b2b5466fc265db805500e"/><file name="List.php" hash="32c3e7a38a8464b96d36e6bf9bf70e10"/><file name="Product.php" hash="b4110492547aac402ab6299a24312c3a"/></dir></dir><dir name="Product"><dir name="List"><file name="Price.php" hash="3f5bfebd086a4a15766a92f5033711e7"/></dir><dir name="View"><dir name="Type"><dir name="Configurable"><file name="Swatches.php" hash="f6bbfd51d4c3cfa820120323e39e37d9"/></dir></dir></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="b8ba8a4a2f67ce5ad3ad68be3fa8c669"/><dir name="List"><file name="Price.php" hash="6bd1fe6fe96ffd70d0056ae40a8d94ee"/></dir><file name="Mediafallback.php" hash="3b05c50121fee8862a6632aadea056d0"/><file name="Productimg.php" hash="ec85544a4cd10b89e4cb11bec7f3cd68"/><file name="Productlist.php" hash="3f04a102b5456a7d51b45c53b435dbf9"/><file name="Swatchdimensions.php" hash="e2ff093ff96ef0c759095bdc46964d52"/></dir><dir name="Model"><file name="Observer.php" hash="152d660d8b152d089cbd3bdb9b288be7"/><dir name="Resource"><dir name="Catalog"><dir name="Product"><dir name="Attribute"><dir name="Super"><file name="Collection.php" hash="537866e74b606cef3c8254a1bba6a288"/></dir></dir><dir name="Type"><dir name="Configurable"><dir name="Product"><file name="Collection.php" hash="00671910ae721b7e4b0c5fd65bd3f6b6"/></dir></dir><file name="Configurable.php" hash="d602e5e25165db00445513598b15ca19"/></dir></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><dir name="Catalog"><dir name="Product"><dir name="Configattribute"><file name="Select.php" hash="2d9fa3692840f71216f7753ab92121aa"/></dir><file name="Configattribute.php" hash="0d540fa0f5d44d102c7f48469b208a97"/></dir></dir></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="8e694ee9e63658cf427583a0048b4298"/><file name="config.xml" hash="985c7d9dc014951dacbc8e087103bc50"/><file name="jstranslator.xml" hash="f2648cac1386d4ba4c1b5a8d699f66c2"/><file name="system.xml" hash="04c114ed08e34c9d258a900101f6423d"/></dir></dir><dir name="Connect"><dir name="Block"><dir name="Adminhtml"><dir name="Extension"><dir name="Custom"><dir name="Edit"><file name="Form.php" hash="e26414f64cedd1321ba8da2cc225ed19"/><dir name="Tab"><file name="Abstract.php" hash="dbd67c2564728e893753dd3dde4f6e0b"/><file name="Authors.php" hash="cd6621452faba0be529c8eda1fee984c"/><file name="Contents.php" hash="3c8132774831b661b0f47daa178cd2e8"/><file name="Depends.php" hash="9e380c2f0dde7c4a6586a3425d02cc72"/><file name="Grid.php" hash="2bc4b16f7dd704fbdef92fe506771ad9"/><file name="Load.php" hash="5763af2594d2e4761d05c2095afbdf7e"/><file name="Local.php" hash="051aafb1da88da0d4a20fac4e26a63f1"/><file name="Package.php" hash="0a3a063eb7a3d2deec9c58a10e8da807"/><file name="Release.php" hash="edfb87af6df90f33a3645bcc47a9630b"/></dir><file name="Tabs.php" hash="eaadde7d25104b25c86f6fc15be1072a"/></dir><file name="Edit.php" hash="77160823c353eec4ead9b1a91533de65"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="8f4525f02dbd792bca739def1a54c66b"/></dir><dir name="Model"><dir name="Extension"><file name="Collection.php" hash="e3edca7adb4900df4959dc0672842790"/></dir><file name="Extension.php" hash="eb7923ef67622eeba1fa0e13f77ab095"/><file name="Session.php" hash="b3668a4540c2ac629c3897ec494d8b4f"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Extension"><file name="CustomController.php" hash="aa399d37bc97765d0003b9f64f1107d2"/><file name="LocalController.php" hash="d51c4ca3b11eb15ec4bedb3d06361385"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="81c78906e15656a7a38c602e48bf39d6"/><file name="config.xml" hash="9c7adf5d5c9381d03a47ec8a4c0f1dd7"/></dir></dir><dir name="Contacts"><dir name="Helper"><file name="Data.php" hash="5b94241f71c741c1f1ec214614dddf0f"/></dir><dir name="Model"><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="8e3b0397091a6e8ec8d46957fd413aa9"/></dir></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="228964505f71cabc33ff172c01337f07"/></dir><dir name="etc"><file name="adminhtml.xml" hash="6a077dd2f29239e1bd4d6f157047e3e0"/><file name="config.xml" hash="8c70aedd3e5f207e3a60aa96f2a2fdf5"/><file name="system.xml" hash="464371ade06413d71129ddf133c8138f"/></dir><dir name="sql"><dir name="contacts_setup"><file name="install-1.6.0.0.php" hash="4523d0df619c528b9fe09c217b1403fe"/><file name="mysql4-install-0.7.1.php" hash="5177d23b10f5c4f13c71611ccf498bc1"/><file name="mysql4-install-0.8.0.php" hash="75c9bc4e6b64ff6b66e5e38e8356ca13"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="329bc2138e3c827cbdc0e43e0ce2eab9"/></dir></dir></dir><dir name="Core"><dir name="Block"><file name="Abstract.php" hash="a4758c091f367ef85d0c6b4629fc1a34"/><file name="Flush.php" hash="1c81f1f58c42f8be5de5c18de7930004"/><dir name="Html"><file name="Calendar.php" hash="5a93eb0c181d3856b43b9427eb1fa2c7"/><file name="Date.php" hash="5e258063e63e9a671fcc62652a035b42"/><file name="Link.php" hash="91bc4e1065dba61f08d7ae10c82d05b9"/><file name="Select.php" hash="d5a535fd18cbb27e602f8ba5337a4d2f"/></dir><file name="Messages.php" hash="e7083c054bbdae836dad9a475dd872a0"/><file name="Profiler.php" hash="5c6fb9ba6ecaf6b6d63c36f3fb8aa3ad"/><dir name="Store"><file name="Switcher.php" hash="9739aed5c6f4102b74f4cbaa04f82d26"/></dir><dir name="Template"><file name="Facade.php" hash="7922ee4c04286ce3eb98059cadb267dd"/><file name="Smarty.php" hash="2ee2ff23f9699c3e5344d0cdad0a8682"/><file name="Zend.php" hash="8502425e486ee06d7990cf59e6c352ed"/></dir><file name="Template.php" hash="74ae08a5f164504e178563f3cb472717"/><dir name="Text"><dir name="List"><file name="Item.php" hash="78507c198e651856f6eb0b1de165d018"/><file name="Link.php" hash="ebe9462234b8e722dbb78d9c69733ea2"/></dir><file name="List.php" hash="56072cf10a5747c38a953322d8b9df1f"/><dir name="Tag"><dir name="Css"><file name="Admin.php" hash="84cc0d77b7246ec4057eb79e055fb8fb"/></dir><file name="Css.php" hash="edadd3969bfe2c3aeada707b3c2b3088"/><file name="Debug.php" hash="dbc940a9871b56c0c88248bfda2c3694"/><file name="Js.php" hash="2ed1784cb60e4278660f9aab1ab0cc8e"/><file name="Meta.php" hash="a571e8f423426d0a26eb64243f290a64"/></dir><file name="Tag.php" hash="482ad79a266f5892cf522c92e76fc9cf"/></dir><file name="Text.php" hash="ec7485a26b1b035ecb008fc39b637148"/></dir><dir name="Controller"><dir name="Front"><file name="Action.php" hash="9e79d3d56b4da2478017d92b78ed9398"/><file name="Router.php" hash="4f8912333744827c28d814ef62851699"/></dir><dir name="Request"><file name="Http.php" hash="d634129e9ed625819159358d4793ed11"/></dir><dir name="Response"><file name="Http.php" hash="ff98a825b04f4159bd56f60e129b6dc3"/></dir><dir name="Varien"><file name="Action.php" hash="0de4286af825455c29e455ff6a561304"/><file name="Exception.php" hash="323d91b1c5020d2f0f8e70923dfee51f"/><file name="Front.php" hash="6f29f0475c5eff2eb93f6e89b5e0c7cf"/><dir name="Router"><file name="Abstract.php" hash="e7d162ad38982815fe1e3be8d4b91e0e"/><file name="Admin.php" hash="90039dea8a57f01308861db0ada6b237"/><file name="Default.php" hash="28e45c061f48ffea9b2ed93658194456"/><file name="Standard.php" hash="8e46f8bd97db4693976a80e9f98db675"/></dir></dir></dir><file name="Exception.php" hash="a6a9dea6b1f59cba29564e44acc7bd88"/><dir name="Helper"><file name="Abstract.php" hash="be419d2ae92967b64101d8476c6e1b3a"/><file name="Array.php" hash="c2789f63f05681b449f7a6ccef2b1369"/><file name="Cookie.php" hash="de1f32bc6d23d9b1d79af8c3c17c2aaa"/><file name="Data.php" hash="f0bd7ca4b96912ee637d63fc7865f873"/><dir name="File"><dir name="Storage"><file name="Database.php" hash="70c2d3685fe216a9dfe47ce46d6d1121"/></dir><file name="Storage.php" hash="fec468db62c90dce4f84c1fecf4d904e"/></dir><file name="Hint.php" hash="bc7c4d51b8494323f9722f44384c4331"/><file name="Http.php" hash="c601ef1dc4b63f02651b78d7303bc231"/><file name="Js.php" hash="129ca78b4a4be5a0ad419fe668c847e4"/><file name="String.php" hash="e501986df9fef06fc8823dc3a45f975f"/><file name="Translate.php" hash="ddf28a39448666179aa0971c39e2d3a8"/><file name="UnserializeArray.php" hash="08bae1b3464e662df323a50c592a4a6b"/><dir name="Url"><file name="Rewrite.php" hash="7f6fcc21fc757de6784057e1747afac5"/></dir><file name="Url.php" hash="c894c0a3eacd745355468bdc1301fbdd"/></dir><dir name="Model"><file name="Abstract.php" hash="3f4befe189872445b531739b1346f9e0"/><dir name="App"><file name="Area.php" hash="48ae85f39015edd9e79ee189e9ebda2f"/><file name="Emulation.php" hash="4056aeb1d1db4398ee9d7f322e524b11"/></dir><file name="App.php" hash="6b0e193af8cdb2d74eb28ca98259cc88"/><file name="Cache.php" hash="1e0b6cac7b114332ec0a20cf6b53c4dc"/><file name="Calculator.php" hash="04b04f608cc3b4caf76d8f927b930b0f"/><dir name="Config"><file name="Base.php" hash="50ed2b4e270db833ee91c21d35986c65"/><file name="Data.php" hash="663eb167c35391f77caf53c07347d7cb"/><file name="Element.php" hash="830513274ce2e355317f0cd80b5cae96"/><file name="Options.php" hash="bf6e7351c30e291fcf28bfda7b73c9e7"/><file name="System.php" hash="dd0497c8e28c365b5b5f22c6b591a118"/></dir><file name="Config.php" hash="ccd5ec20ff7e8685dac7cbdd453ff280"/><file name="Convert.php" hash="7061bd4dfc8a68e3ee8bd97edb40ae37"/><file name="Cookie.php" hash="34ef9b7ad40572763d2c1dc298f9a49e"/><file name="Date.php" hash="55b340e0ea366ed6d73dc1d1527be844"/><dir name="Design"><file name="Config.php" hash="cc7204a98d3ab882e8910a99e280ed4c"/><file name="Fallback.php" hash="c2304f13391a3f18f17441f6ebc327cb"/><file name="Package.php" hash="11bf73f2ff2e0528aa06811a4e9f90c8"/><dir name="Source"><file name="Apply.php" hash="340087f0619d7666ab5737479a563876"/><file name="Design.php" hash="d712c236572a3891af359ec8b3e4e89a"/></dir></dir><file name="Design.php" hash="bc0cc433586f176a2016de5bea4ab66b"/><file name="Domainpolicy.php" hash="8ed8dcd059fdfdf2218fb458c3b44763"/><dir name="Email"><file name="Info.php" hash="3a1152c569ba371366c876ce09580ebc"/><file name="Queue.php" hash="5d5d01ffe9aa4d3592cf663ecf25142e"/><dir name="Template"><file name="Abstract.php" hash="11305d196235edfbd986e6a10ffb0d39"/><file name="Filter.php" hash="17b3201f056acaa8e0f8b112db52561e"/><file name="Mailer.php" hash="cd7fbc1e3be6945446d3d2386c7e8e24"/></dir><file name="Template.php" hash="58917615766c5e3238bf2debc539210f"/><file name="Transport.php" hash="dee3f7b1dac344ee7ce6908eb7acec3b"/></dir><file name="Email.php" hash="3a6a3ee260169b333be8bd75dcd945c7"/><file name="Encryption.php" hash="0f21e842fddf683bb1a0c0de4e4ea8ef"/><file name="Factory.php" hash="3c63a62a08dd427aca268d6abe4a52b3"/><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="eead16bc8a93b7eb0fa96cccada9570c"/><dir name="Database"><file name="Abstract.php" hash="43838858cc42d70897c99b45195e4933"/></dir><file name="Database.php" hash="3d8c5c9c3c4c7db04223cc50cdef1283"/><dir name="Directory"><file name="Database.php" hash="572d4f449cb211963eb5b1864d80e1cd"/></dir><file name="File.php" hash="564a477c9a19e138cb0f9a87cdaec6f9"/><file name="Flag.php" hash="f7c9c910b8998b2d797276769838efce"/></dir><file name="Storage.php" hash="eb25e64a06a12a866b1d9e7c9f111a62"/><file name="Uploader.php" hash="d91a08273557273378beab0a6f9fb60d"/><dir name="Validator"><file name="AvailablePath.php" hash="51c35fa5e4ece45893f88ebba52529d4"/><file name="Image.php" hash="dbd45c9eea5f9d061917e3938abea16f"/><file name="NotProtectedExtension.php" hash="68e1493daf2ced574367115c92556640"/></dir></dir><file name="Flag.php" hash="12f33ffabeae1142bd5bd12bc25de002"/><dir name="Input"><dir name="Filter"><file name="MaliciousCode.php" hash="49d2e9a0dbcc0c8e220628885bab6640"/></dir><file name="Filter.php" hash="5fd5d9338ca0082ff98912c3eb9359c8"/></dir><file name="Language.php" hash="8fddf850daf6897171bb6ba4c6f15789"/><dir name="Layout"><file name="Data.php" hash="9da1afc128962e84044f4463c44ed558"/><file name="Element.php" hash="118b879171c589409b9fe40dd4629dab"/><file name="Update.php" hash="bd1af87aa563228ffd86fe622991ea72"/></dir><file name="Layout.php" hash="9d2c128a29924244431610cd1cf69f0a"/><dir name="Locale"><file name="Config.php" hash="83ad0ba769761ebcced7e5b5aeada4c9"/></dir><file name="Locale.php" hash="fc771d4a95e27648181e69bab7e7155d"/><dir name="Log"><file name="Adapter.php" hash="7a8401e4d25e0da113d0de139ef9a9e8"/></dir><file name="Logger.php" hash="d9ae8759b479ff92d354bc99d7ef4979"/><dir name="Magento"><dir name="Api"><file name="V2.php" hash="407d967185263a58ed75caf3a2d4f701"/></dir><file name="Api.php" hash="25df5649d1cd7953941dcf13df2e3a7f"/></dir><dir name="Message"><file name="Abstract.php" hash="8c3a895255d819b98a37499bad00bf76"/><file name="Collection.php" hash="e0b87967a18fb8c9bf9835f95bf0d2a1"/><file name="Error.php" hash="5f899d95612fdda8df4bbc2ea457dfd5"/><file name="Notice.php" hash="79ab2b274b750be42ba95dc67c0d12a7"/><file name="Success.php" hash="bd6a19eb5801bda3b13238022bdd3718"/><file name="Warning.php" hash="1e6b045c0cfb6108278a65fc3c56a3d4"/></dir><file name="Message.php" hash="22fefaca51c85298d2b9840d0dcf8c2b"/><dir name="Mysql4"><file name="Abstract.php" hash="a5b0dffc0523feb7ac71b98d4ecc8689"/><file name="Cache.php" hash="d153d94172471184bd189ff347569ecd"/><dir name="Collection"><file name="Abstract.php" hash="acbea581a60f43d5a4b84785a114ca6a"/></dir><dir name="Config"><dir name="Data"><file name="Collection.php" hash="e85b8dcb782634137f8b6a5616c16adb"/></dir><file name="Data.php" hash="970870fb626f85630c78ed1136284e51"/></dir><file name="Config.php" hash="bc3c014b73d5ae8e24961b289ab0ebb2"/><dir name="Design"><file name="Collection.php" hash="48943d6c564b7db32e4c09d69f271dbb"/><dir name="Package"><file name="Collection.php" hash="293f71c1a6f67e1e3b4bf6c85782c360"/></dir><dir name="Theme"><file name="Collection.php" hash="636491bc7c6f569f96c5005022d242fb"/></dir></dir><file name="Design.php" hash="692036df13b9d9c1058b550f52483f69"/><dir name="Email"><dir name="Template"><file name="Collection.php" hash="f23e024d78302a7f9f0c0be8b0694c22"/></dir><file name="Template.php" hash="846c3b75b324d575200359a7b8be2220"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="49eb25d34e39054e01b0b7d4d741323a"/><file name="Database.php" hash="1fd0f24f483a7c10a977fdd27fe715e2"/><dir name="Directory"><file name="Database.php" hash="bd191938529bab16adb6def749799b9b"/></dir><file name="File.php" hash="d32e4e94fa8a68db9fbf8c617da0b066"/></dir></dir><file name="Flag.php" hash="14ac206457b121fcc7df5ea9832d38b5"/><dir name="Language"><file name="Collection.php" hash="8c51e96c56e66e3911208a2317628c45"/></dir><file name="Language.php" hash="79ba6c8a50b5f52ab05668ca361d58d4"/><file name="Layout.php" hash="2a0208447b0ce6ef1505ba9868f4b590"/><file name="Resource.php" hash="3f3896a0e511a1e4591dfb9aefada380"/><file name="Session.php" hash="c912515bf0c0dff233e7d64b38735d9a"/><dir name="Store"><file name="Collection.php" hash="2b66b1cec8018315ba307bb3c5b60159"/><dir name="Group"><file name="Collection.php" hash="351d169b4d8eb2ef01d5db074252ab59"/></dir><file name="Group.php" hash="9d9f26a9133487df0615352335df733c"/></dir><file name="Store.php" hash="8dfb196abb20d16f825095dfdae70c44"/><dir name="Translate"><file name="String.php" hash="2808fdec826d5c451b11e3d798eaf20e"/></dir><file name="Translate.php" hash="6f8cb9fd5e0edafd2ea9bc56633e14f8"/><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="faf8681e97b36e6c3f47af3183064f46"/></dir><file name="Rewrite.php" hash="130d9e44375487c19b51eb4c64b117d5"/></dir><dir name="Variable"><file name="Collection.php" hash="b2f02972a0dfd4f1ea42f306927eaf54"/></dir><file name="Variable.php" hash="00f32aad2d2e2cf3eddc6206ede0cc6a"/><dir name="Website"><file name="Collection.php" hash="5b62abbb214c52c22bdb72d403e9e75e"/></dir><file name="Website.php" hash="cdb13ace26831a84c72d61b06f9cb8b2"/></dir><file name="Observer.php" hash="effe59867a72d6e8d69652d85069fb2f"/><dir name="Resource"><file name="Abstract.php" hash="6249b6cd53449f175086e864fc701dd7"/><file name="Cache.php" hash="f6cdcf5c628073e9de24a12699dea566"/><dir name="Config"><dir name="Data"><file name="Collection.php" hash="6e12f1d9bed4f1199509a106ec4c1ab0"/></dir><file name="Data.php" hash="334c7f498c9f362160456d5afa2e4f61"/></dir><file name="Config.php" hash="628fc6ad70658c502e01d43fb01cc428"/><dir name="Db"><file name="Abstract.php" hash="70742e4f98224203c04a01836d23c1c5"/><dir name="Collection"><file name="Abstract.php" hash="45689c0f4f1a0e1a016fe72610a9c2b4"/></dir></dir><dir name="Design"><file name="Collection.php" hash="2786593e20815b30b8b372717b78fcd4"/><dir name="Package"><file name="Collection.php" hash="3d7a17b1b7abe93afeb6ad623f8235c1"/></dir></dir><file name="Design.php" hash="5cddce7c05e36d1ce1aef2c4ef950d9e"/><dir name="Email"><dir name="Queue"><file name="Collection.php" hash="a0f9a4bec6ed16c4fcc554dbe958c862"/></dir><file name="Queue.php" hash="281cd39e5d3edf692a5604e722c20b0c"/><dir name="Template"><file name="Collection.php" hash="7fcbb63a73cfab972415daf18e35aecb"/></dir><file name="Template.php" hash="708e3b8fd6327cdc960659b90d82275c"/></dir><dir name="Entity"><file name="Abstract.php" hash="99e23e03c62b44e02b581d78c8b79cbd"/><file name="Table.php" hash="6335ecad183a1955ac12bcb0fa581773"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="76e4cc5f176c054926e2006b90f63635"/><file name="Database.php" hash="52245f989927dc671eb9182a8e35b007"/><dir name="Directory"><file name="Database.php" hash="11b6a6f504540e2e0e0ac53a32c0f20b"/></dir><file name="File.php" hash="bc0da83b2bff3932edccd77e5e79fcc4"/></dir></dir><file name="Flag.php" hash="e61fd49103e42a38d912f9a11ca4fd8c"/><dir name="Helper"><file name="Abstract.php" hash="fea98c00b89d7976ef18d0961346b212"/><file name="Mysql4.php" hash="c6e9f97258577a6a4c587f90d99341dd"/></dir><file name="Iterator.php" hash="a210d63d17e893b907e96190bfa38fae"/><dir name="Language"><file name="Collection.php" hash="0d4a2657ee3c590f932c66b0bae934c9"/></dir><file name="Language.php" hash="c24c716d7dcd561bc5b729f1423322cc"/><file name="Layout.php" hash="51de17855da5063e25941ee9b891acf5"/><file name="Resource.php" hash="54558489eaeaebcc7160ecbcfdb3e67e"/><file name="Session.php" hash="10d4d694c026ba0422c8743406b110bf"/><dir name="Setup"><dir name="Query"><file name="Modifier.php" hash="73d0f717ecf8901097a15ea8f3d43504"/></dir></dir><file name="Setup.php" hash="5a4a58fe4bd1a2a3f642ef46cc81c4e9"/><dir name="Store"><file name="Collection.php" hash="9a7cc552adb5eb04f5576bfdbadae03d"/><dir name="Group"><file name="Collection.php" hash="cf663e2dda1c1130e0e47d59b686ee92"/></dir><file name="Group.php" hash="ab767197a0686013520ed7ad64c1bcb5"/></dir><file name="Store.php" hash="724e5fbbcdeae9491ed48a969477714d"/><file name="Transaction.php" hash="f2fbd76d08845ca1b3ec53e12230c668"/><dir name="Translate"><file name="String.php" hash="a346efbf76625f7b3399f40d62ab228f"/></dir><file name="Translate.php" hash="6f6549e2a389e08c68aadeb22e9f2b15"/><dir name="Type"><file name="Abstract.php" hash="a8e391ec218b55760800284ae511f37a"/><dir name="Db"><dir name="Mysqli"><file name="Setup.php" hash="63c50624b4fb9ac00a780dc0fac2a96e"/></dir><file name="Mysqli.php" hash="0b741fdb7e318bce2b61d25a2da498a8"/><dir name="Pdo"><file name="Mysql.php" hash="00a917b3cb7eb4f8c72ccc4805eec0f3"/></dir></dir><file name="Db.php" hash="1c91391d4ddee72a30df5a684a2927b2"/></dir><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="2cb8f9d4f734a0937d1f0b356d3a1da8"/></dir><file name="Rewrite.php" hash="ccc4dcdc077ca7ce028295faa7f1ac1b"/></dir><dir name="Variable"><file name="Collection.php" hash="b7c09727d07c9b7fe0fc1ba7e89cfdb0"/></dir><file name="Variable.php" hash="ec4b046ce49519d63a091a4f48e2df81"/><dir name="Website"><file name="Collection.php" hash="e074d4b0943374022b3ce225bb4d26e2"/></dir><file name="Website.php" hash="0cf266c0cd26f8d0e4f3d1f376fe6b0a"/></dir><file name="Resource.php" hash="0d494aef71eb1df19e34cdd6581a2092"/><dir name="Session"><dir name="Abstract"><file name="Varien.php" hash="c1c73292138566eec395feba1697886c"/><file name="Zend.php" hash="5ca67559ac0904e1474b7ce6686056d9"/></dir><file name="Abstract.php" hash="e3bbbe8c2fe16e0a8830a7ca57f18b39"/><file name="Exception.php" hash="2ce0d2e3923104ec5f9e041285876f41"/></dir><file name="Session.php" hash="2f427ed8f6303d1dc9573dc76920c11a"/><dir name="Source"><dir name="Email"><file name="Variables.php" hash="ccd018681dfa5eead7152f379714ffa5"/></dir></dir><dir name="Store"><dir name="Api"><file name="V2.php" hash="18ee7c33dd0a8ff7eca9b5b82fdcd30b"/></dir><file name="Api.php" hash="973ae7808f90acc5f50eeef25b5a0d4a"/><file name="Exception.php" hash="f6043d3c13b888eb4c57fa55b26fb49a"/><file name="Group.php" hash="53414869d792ce401cd539ae795cc549"/><file name="Observer.php" hash="eb7511c32941f027fc485b860b1805c0"/></dir><file name="Store.php" hash="234b1bad13494763cbb47f3addcadde9"/><file name="Template.php" hash="aa933216eb7f4c0f228e6f74866b9974"/><dir name="Translate"><file name="Expr.php" hash="5e9c06ad00e633bcc4a9592a5120ecec"/><file name="Inline.php" hash="bedb481b05c8d3a721cb5c52a0f4a16b"/><file name="String.php" hash="4934297c507c27507ace7d898cfc3ae7"/></dir><file name="Translate.php" hash="bbeaa42c48a253f0366bc8f43c162796"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="f3d5ccdada27a76c2a7c15cf926973d5"/><file name="Request.php" hash="f40827c0146b53cd6e93ee3f5955035f"/></dir><file name="Rewrite.php" hash="a00559f1795bb44f61fc43c9923c2a0c"/><file name="Validator.php" hash="04b9e2c0fb7bf6e4337335fdea3ff759"/></dir><file name="Url.php" hash="1078f2a6231e5c9bc2f05db23b41d239"/><dir name="Variable"><file name="Config.php" hash="affa171299550c5558dfcc94c5e9d8ee"/><file name="Observer.php" hash="501bd5408054c499673c515e679545f5"/></dir><file name="Variable.php" hash="7b91ae3d55518b0c2f8de6c8363c0e59"/><file name="Website.php" hash="20477ae06b1c27fd6a60fb8da6fb7b04"/></dir><dir name="controllers"><file name="AjaxController.php" hash="5cf58eec53bbcbd449e23ac865daf7c9"/><file name="IndexController.php" hash="edbad5b5eb4a268c83859cf51d64610b"/></dir><dir name="etc"><file name="api.xml" hash="90a4f686b4b8900874eab726e149c880"/><file name="config.xml" hash="0cb790f5adfada1d06fe668b571bee87"/><file name="jstranslator.xml" hash="22bc1abd3a680fe5e22b61a81fb902f9"/><file name="system.xml" hash="7a58d8527b930fa01f3278ca2403d532"/><file name="wsdl.xml" hash="79501d6ccf39846b5dd551e85880dcb8"/><file name="wsi.xml" hash="31fa195d527181c946019bcd44d819d6"/></dir><file name="functions.php" hash="033663bd0a00fd88f0bc91f4e8606073"/><dir name="sql"><dir name="core_setup"><file name="install-1.6.0.0.php" hash="207fc73211835ecd5b49093f69bab4d1"/><file name="mysql4-data-upgrade-1.6.0.2-1.6.0.3.php" hash="1d4fcc69c6f9fa8067678977b0dc5c95"/><file name="mysql4-install-0.7.0.php" hash="d83334de1789e098603fefa69f39f282"/><file name="mysql4-install-0.8.0.php" hash="7061c4a797513e811c7efe7c6f735c63"/><file name="mysql4-upgrade-0.6.26-0.7.0.php" hash="1dd91b18dfe36b82216fe1c6ed9e4a0f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="19e29347f075f6189ad00f3c4c012e56"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="1143d68867fd0ccbf562d4aec21660fd"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="169fab24feb57a49a42daded0d383958"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="a6600be894f2532c5cef50cec2007c0b"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="e793862db62739a013029bc4c3abef6b"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="f60564dbab8975c5a72aba870e31bd22"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="ea7ea8fa28524f360df30308e6557c97"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="d87fff0113dca61276ec2f7decb3e8fa"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="b4c44da961498683ee9f7f0ec6aa125e"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="825e321edf450059ea62412a78fa4b11"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="e0efe65cf9d2d987c7b83e95bdd4b34f"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="7d6c21a027ba7fb754ec92577dad3ef7"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="bcdaa98ee4d7c83c7568c063bda07699"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="eb967ee83a8c7bd5b0cdefb693ba4062"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="e1f09afd0caef193b05453634390b8c5"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="396c159dac306c08379918f06e824b2f"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="0a8d8ae910028fd5aa59c229f919d07f"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="64ef5bd40aab9d958211614b4f68a568"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="88d0c45baab863a737b2d15973294322"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="ba233f3cda242eed69e6793382dfda47"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="bbbb2b3554505abb07a1988a87b8d9d1"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="75bf4b1ffde80714098dc3bb4fe4e2de"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="77fdd776cd12f1114eaa6d7f85f2d20f"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="2704ddfaaec17ac0a99883cd91072ea6"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="0e70926bb4262b24cbdfa1e947c7eddd"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="2321dd3ebdb9898d6616dd324a7ef54a"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="e0ebe20e9ab0dff68647ab00fb9f0c66"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="85d3080545d141ca6ff8bcbdff1b514b"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="48f40823eefa729259add6b2f81f366d"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="1a5ec8dccd994ad3761e68e1cd588372"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="240256a88580d96a50ca0fd833a8c7f8"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="f7275b1915e80d7296113a3dfe725cf8"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="13df9d23e39c7570e1cdb18abf1e996e"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="8b20971ed0197db54611f227413ff239"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="fb213c2773f2f2cdd2cfd83bd4077ea8"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="120fe10e615eb5943b42a2ca06a3336f"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="667bf08e56b52f9eb049d177abe5b1a0"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="078c49764308e40b133039ae907044fb"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="3e1d4dae0a1de35ac70551d438e50a58"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="c276a2413a5af5bf2ef31270d20f6afe"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="86d0277801776f2fde3fd53a4b85914e"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="1fcc06dca2bc742c1c8cb4730d19f951"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="6449ac67e5dfdeb275fa4b4ff485dd63"/></dir></dir></dir><dir name="Cron"><file name="Exception.php" hash="698e1ae4ab5e8ea37299653add15f225"/><dir name="Helper"><file name="Data.php" hash="9eef300858d951cebc7297535a2768e8"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Schedule"><file name="Collection.php" hash="af9a782cc7af9b9770bd820e092dd9b6"/></dir><file name="Schedule.php" hash="5214e7c13aa7365707a7040e97533ba1"/></dir><file name="Observer.php" hash="b27044c1c30795906f10c5c8bab1dee7"/><dir name="Resource"><dir name="Schedule"><file name="Collection.php" hash="031a856a7e5f60d8d7ddb9195707a19c"/></dir><file name="Schedule.php" hash="5466ff7798ca4a0ee0382a58c41ae6b3"/></dir><file name="Schedule.php" hash="04144e52081a8cf3cab6d3f78c812d77"/></dir><dir name="etc"><file name="config.xml" hash="46d440f1e6ee5ed818a6efd37c0d7d2e"/><file name="system.xml" hash="bad12ffe57452fef65dec8c8b2b638c2"/></dir><dir name="sql"><dir name="cron_setup"><file name="install-1.6.0.0.php" hash="272c23770f78ad5b1eb97345a5b9ce02"/><file name="mysql4-install-0.7.0.php" hash="1f39f29137ac0af690ea2b818bf32bdb"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="acad1a38a1dd136af831fcefc5c72710"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="46911e5c2891db7f51148ca7750b16ee"/></dir></dir></dir><dir name="CurrencySymbol"><dir name="Block"><dir name="Adminhtml"><dir name="System"><file name="Currencysymbol.php" hash="e76a96fbb861ca950eb63de00bdf4a9f"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="9a8845e99868d20d9c8306511ecf98ba"/></dir><dir name="Model"><file name="Observer.php" hash="b95780e39abdb087465e8e003b08969d"/><dir name="System"><file name="Currencysymbol.php" hash="e5ee2b0c099200097bca1cb992ea2a1e"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="System"><file name="CurrencysymbolController.php" hash="63fde0a3389998317587a527401f6070"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="10a63d13f96c5fe11c378a589e538635"/><file name="config.xml" hash="80547d477b4c01ed8a9d1e12a9eaa20f"/></dir></dir><dir name="Customer"><dir name="Block"><dir name="Account"><file name="Changeforgotten.php" hash="2165e8674836d3f6077b483dde55a524"/><dir name="Dashboard"><file name="Address.php" hash="bb468d82e2fc11e7e04f257bc726e146"/><file name="Block.php" hash="07ed7e21b9e1eeb23da49076b69a594b"/><file name="Hello.php" hash="94b9169f9ae6cdd0a55e4eb0681404de"/><file name="Info.php" hash="b1680c05fed7931f2db96b524f70f1cf"/><file name="Newsletter.php" hash="1307cd50a5fd5adbdc16e76492915152"/><file name="Sidebar.php" hash="3f294c394525e981a3b054626ea8e368"/></dir><file name="Dashboard.php" hash="188cda8616e1d4d9023ac4b8bed5d66b"/><file name="Forgotpassword.php" hash="90e79520d13aed885e774160a42fe01b"/><file name="Navigation.php" hash="026681e321fbbad6ad29d815b0faac9f"/><file name="Resetpassword.php" hash="ed7f01bb5386900ee50245ab36016ec1"/></dir><file name="Account.php" hash="396fc3f7fb48be6a3538b04135d875e4"/><dir name="Address"><file name="Book.php" hash="0b171d4bd5ad21144aeec5b81bba61f0"/><file name="Edit.php" hash="c4b0c1d640b1b0b935ab96529e7b21f8"/><dir name="Renderer"><file name="Default.php" hash="125728a42ac70607881ed13d88b00983"/><file name="Interface.php" hash="24e732400bee61ac8323c7ef40ea2207"/></dir></dir><dir name="Form"><file name="Edit.php" hash="feb426e2d7fb6e4bcec1bc5988266523"/><file name="Login.php" hash="2d66cd34739d5a311d05fa91e512f00c"/><file name="Register.php" hash="d851618f8c530b3b02e81f41b6a1d13a"/></dir><file name="Newsletter.php" hash="1d134f5c6cdbc5dfd7c0df6ee075cc43"/><dir name="Widget"><file name="Abstract.php" hash="37a2d217bd8542ec907776eb292e12dd"/><file name="Dob.php" hash="3960da7db95ac69ac800ac021137cd2e"/><file name="Gender.php" hash="5780729cb26d78623fa19fff5ab5cfc0"/><file name="Name.php" hash="c678280a641859850a38743bf5f0702a"/><file name="Taxvat.php" hash="4d45092a70e3fb94ec24c346b8aeda22"/></dir></dir><file name="Exception.php" hash="dca1ff1b1dfbf189979aa500f9d48158"/><dir name="Helper"><file name="Address.php" hash="d8ab02f0954687c02146356ad289289e"/><file name="Data.php" hash="e6d0f585162c55285ce4407a56df52cc"/></dir><dir name="Model"><dir name="Address"><file name="Abstract.php" hash="c8b4c4c792d297cec5f245c0efdda8b4"/><dir name="Api"><file name="V2.php" hash="0df7a6b269c9c66de3f507b12539cc4e"/></dir><file name="Api.php" hash="7cf53451b28c4aef47b4a3bf1797a900"/><file name="Config.php" hash="d3b2fda5b82d2fdbcdc7266771cba0c1"/></dir><file name="Address.php" hash="04170cb7363debfca14d81510fdbe38b"/><dir name="Api"><file name="Resource.php" hash="cec904fdca1932b6f939931ec75512dc"/></dir><dir name="Api2"><dir name="Customer"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="47f7475beed2029f8249dc85dbacc003"/></dir><dir name="Customer"><file name="V1.php" hash="c750635dfeb399f3191648769749b401"/></dir></dir><file name="Rest.php" hash="d7b1d8b2a87435993f9ad1720902533f"/><file name="Validator.php" hash="723dcf84a7c3041e4a65b61028af8238"/></dir><file name="Address.php" hash="982ca3e8815193ab93bcc74a2cd4a4ff"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="14dcb7f30dc8307cb4ef66ee010ab461"/></dir><dir name="Customer"><file name="V1.php" hash="2fc46be21aa72477180284a4270607f2"/></dir></dir><file name="Rest.php" hash="76b670c80fcb2e755279f08cd97db60c"/></dir><file name="Customer.php" hash="bb2083444d7dcf5ae9851c533979ae54"/></dir><dir name="Attribute"><dir name="Backend"><dir name="Data"><file name="Boolean.php" hash="a83b90a0cadbbaf0a6a2a0ca97f42ef7"/></dir></dir><dir name="Data"><file name="Abstract.php" hash="d6fa9133e31c8836c7cc86e678bf6e17"/><file name="Boolean.php" hash="3c81d8a93839757c93e2dbf672de7fcc"/><file name="Date.php" hash="bee8757ec8cd9e7d6cf6227e2412b4ff"/><file name="File.php" hash="d3c09e55bb7f81c617654e96f9fd36f1"/><file name="Hidden.php" hash="9167d59b97ba65de906c9bcea4cbbb12"/><file name="Image.php" hash="1ad8011e210c69f928179646e930aade"/><file name="Multiline.php" hash="0b9a4dd5ebd3dac1e6d9cfbd26dcd314"/><file name="Multiselect.php" hash="f3dd8e4a58e04ba6fed979909fe29eae"/><file name="Postcode.php" hash="0ebcfeb413f684090ad77986637b46a9"/><file name="Select.php" hash="78ea1fea99b14dadf1d16c10bd7a2bbc"/><file name="Text.php" hash="774686a2285b7b1d8d3349d479851ed4"/><file name="Textarea.php" hash="e6bfed03f06a397ac0e9a9398f61e03e"/></dir><file name="Data.php" hash="27aaf4bd021dc85a3481ce1795c3fe90"/></dir><file name="Attribute.php" hash="294c4b2feae71fe4ccefb29272bf07db"/><dir name="Config"><file name="Share.php" hash="7c686c3441868fcc6b13428e74b630c0"/></dir><dir name="Convert"><dir name="Adapter"><file name="Customer.php" hash="a48b5b89d865057a61899c4db960c9ca"/></dir><dir name="Parser"><file name="Customer.php" hash="f454ce0b343c8b6db2344c1ecdc07c56"/></dir></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="1b0032263dfe9dc3b454df91f5d5b59c"/></dir><file name="Api.php" hash="1879b627678e095d9201ace5f6c87d20"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="c790e51101d66c9f15f83063674d2ab0"/><file name="Password.php" hash="ca5cf2dd24a73edc132006c033d605a2"/><file name="Shipping.php" hash="e3115593c9775f827fcec44763c129b1"/><file name="Store.php" hash="d0a6243dacb6ab1dee73fa06a9d34ed4"/><file name="Website.php" hash="efadf3585544e5a303131aed29902150"/></dir><dir name="Source"><file name="Group.php" hash="0c33bb6eaeaa3cbd4d708c5a327dc6a8"/><file name="Store.php" hash="245b6db46348a41721c61caff65ca042"/><file name="Website.php" hash="4f71e88c526adde06c0a70dcd21d2f52"/></dir></dir></dir><file name="Customer.php" hash="9c05aa3e6820feae8280fbfa0a940c9b"/><dir name="Entity"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="e7bb13fac9313d6244a0773cebee9b90"/><file name="Street.php" hash="3adb0e7e180f12d16e08871b46d9c54d"/></dir><file name="Collection.php" hash="df7147b4c1eabf10f0ae9098e7eca5dc"/><dir name="Source"><file name="Country.php" hash="6d08cda63ae6b8cf55e59a2624012f5d"/><file name="Region.php" hash="a2b67e84fa17a62b5d908d2b3a2c1778"/></dir></dir><file name="Collection.php" hash="949fc8a7a58aae1c8b9c59a7f2a8a182"/></dir><file name="Address.php" hash="0492fcbb856189d00d66a2dd6ac7fd72"/><dir name="Attribute"><file name="Collection.php" hash="2b7624138b5c4c0d743673be04edf040"/></dir><file name="Attribute.php" hash="2cb29633e3866836fca7d65f4fb362ee"/><dir name="Customer"><file name="Collection.php" hash="7ca7ee4b50bd1f60b166ff2d1888f255"/></dir><file name="Customer.php" hash="20127bf34252803f5f48b366a22e9f4e"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="6c7584593f3f6df841e62d0753f16c79"/></dir><file name="Attribute.php" hash="3dcc90e92a126e425625268a4af3708d"/></dir><dir name="Group"><file name="Collection.php" hash="c75ecbc772ba3e31982682709c5e9b75"/></dir><file name="Group.php" hash="65b79330116831293f4a76a2d2d63875"/><file name="Setup.php" hash="ce1184ded6a42aa443a5c8c43c219390"/><dir name="Wishlist"><file name="Collection.php" hash="e3db89598d9088101f81c276f491655c"/></dir></dir><file name="Flowpassword.php" hash="6dab53fb9b686fbe5ff7b6c412eb5442"/><file name="Form.php" hash="578b7921ecb8a6e47d9fecfe8496dc72"/><dir name="Group"><dir name="Api"><file name="V2.php" hash="777166c9c186dcb5895e85b5dfd5db0c"/></dir><file name="Api.php" hash="94648fc954036011fb28b18732d196dd"/></dir><file name="Group.php" hash="e2014a157641a22edb354a3aa99ad7b6"/><file name="Observer.php" hash="3f0671a7e623f6b5bb32235175ab0dd1"/><dir name="Resource"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="017256abf7f99dae72fd05961d812e19"/><file name="Street.php" hash="27145361c9523b9c3e0f1ed68c19b6c5"/></dir><file name="Collection.php" hash="f7ec8cff4bb7c41ae82e5ee7918bed20"/><dir name="Source"><file name="Country.php" hash="229c22d6d4c7f94072f8b101cc070561"/><file name="Region.php" hash="91645ec1e733b718e6a54b5c61015057"/></dir></dir><file name="Collection.php" hash="dfcd8f8884a9847982800bf0948ec20b"/></dir><file name="Address.php" hash="763b668489edfb8432a70b38cb828fda"/><dir name="Attribute"><file name="Collection.php" hash="d66a1141fbc70acf24d179600b9c61c0"/></dir><file name="Attribute.php" hash="0e188694a33b3acc70ec71ec5871a75b"/><dir name="Customer"><file name="Collection.php" hash="a29158a6b9b5b35d8e6267d73cb02ce4"/></dir><file name="Customer.php" hash="478d8f4f866c20b86bcc1363744a9813"/><dir name="Flowpassword"><file name="Collection.php" hash="78d4510d187abac4a3891054b6ae7034"/></dir><file name="Flowpassword.php" hash="bd2057a2d3ac57f00d4d582674a7ad1f"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="5572cab9a0e1e3f5417cc08ce5a50e29"/></dir><file name="Attribute.php" hash="cb0b5cf6af662e3b4e71af72d1885244"/></dir><dir name="Group"><file name="Collection.php" hash="3b47d4c152cabece1b1328bee3b70143"/></dir><file name="Group.php" hash="2a109f070024d1eac7de055ce89e1129"/><file name="Setup.php" hash="e92903e8249c89f34fe325bb3afcf981"/><dir name="Wishlist"><file name="Collection.php" hash="568caa7c996736d83fa1b3fd16780a47"/></dir></dir><file name="Session.php" hash="f6c22413f7f9f6cbcf83314e0e7157ff"/></dir><dir name="controllers"><file name="AccountController.php" hash="11ba2ddc87439e592be2459e64bee992"/><file name="AddressController.php" hash="0f0692985f38e2fbc4b895910e80c71f"/><file name="ReviewController.php" hash="09c4a76238c9aa2f6a53679ca1b1ca70"/></dir><dir name="data"><dir name="customer_setup"><file name="data-upgrade-1.6.2.0.2-1.6.2.0.3.php" hash="5e2bc7393945d4c1f916c3beb51c9a0d"/><file name="data-upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="238f41bdbe43950cfec729c37bbb48d0"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="6fcdaaa7fde1907e2385bb0343c1bed8"/><file name="api.xml" hash="12578cdd5eb4f083910ecf88408b4439"/><file name="api2.xml" hash="ead1ed09da00aa66b9aa877be5d1e084"/><file name="config.xml" hash="ea2233e4eb4bb61ef86173320d64e251"/><file name="system.xml" hash="51c792ceb49448faece9b1a325b70204"/><file name="wsdl.xml" hash="b31ebf1de4a58469781b383f455991f5"/><file name="wsi.xml" hash="4c81aee30c525677be5c38e078b98408"/></dir><dir name="sql"><dir name="customer_setup"><file name="install-1.6.0.0.php" hash="d2954a98182da41fde0adbfcbaffe195"/><file name="mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="c33fd77867bcf4f13c8c06ff3d7b7024"/><file name="mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="343415802d404a260070b7e098105e38"/><file name="mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="cbaf3411b9c93fb4c11368359d55199c"/><file name="mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="1916487374f08a6438c203688a682f11"/><file name="mysql4-install-0.7.0.php" hash="fd9b5478bfda45834810ca7d12a4743d"/><file name="mysql4-install-0.8.0.php" hash="804d79a4d498b6ff315d9234d30bcd20"/><file name="mysql4-install-1.4.0.0.0.php" hash="f69dca07689d5184dc47a55170559b62"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="94edeef8a4d892b308d1435a627dc26b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="b078ab70e40aeb9d8e8e5b2500ce9394"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="708aebee9d6b0a0c8ba683f48f2e25cb"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="ccd49f55274344a42aa0c28352095230"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="2643dcdc4d3af31f3fc64ccbe229005c"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="722c8c7019240145f83503ef3c25672d"/><file name="mysql4-upgrade-0.8.12-1.4.0.0.0.php" hash="e9a5d864230004ee0588cf8c03aeb58f"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="0a08f7e04adb43ce644b12e2324b7e7c"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="5bace0b9dcf142bc7f81e74255b2b411"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="9ef24d3661aee9fbd69ce708641ef4f2"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="58d79dcc8e9772b9996c5cf98c6983ef"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="08c336853502414b87303d506f103772"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="0149e3e53723b5121571cebbadc8c18c"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="5bbffccca8a6178ecbabf3bf289056b1"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="b635e478f1c9f61e5099ac0c2bb0dc1c"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="255fa61555ef1ae9ee49642aade7d9c5"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="dcdb4497854588ca6e12e4907404f27c"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="0a93f1e367aaf0a62cae6c07734ea129"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="e0ecad3fc1c05d112dab117c67059c78"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="87b10e436f90b5fa56ad6cc0cf6904e5"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="21ba959239cbd436d78834464f258b22"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="f99f0568dbbfbb8284fa40107c6d367e"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="176f6b5b7f52fa3d619e90626da1ce22"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="214d180f85958672b4588404e66aa13d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="b6ebde8d13e2b4fc83d5d7a76909f6ee"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="5ec13b9bbd4aff56e7f912ee163f204c"/><file name="upgrade-1.6.1.0-1.6.2.0.php" hash="79483a191e9a06f439e1c301bccb750a"/><file name="upgrade-1.6.2.0-1.6.2.0.1.php" hash="df76a788c48d9e06a521271fcf333b4a"/><file name="upgrade-1.6.2.0.1-1.6.2.0.2.php" hash="05ef590163c85515a2dc5ba6f59e2763"/><file name="upgrade-1.6.2.0.3-1.6.2.0.4.php" hash="7793e15f6b89ae1ef39a111346bfa04f"/><file name="upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="44d497f99af3a16c7ba7590f7a5dce82"/><file name="upgrade-1.6.2.0.5-1.6.2.0.6.php" hash="1f52f23f1e014e40deb9cb0300850e33"/><file name="upgrade-1.6.2.0.6-1.6.2.0.7.php" hash="8864bd4550bbcf0eb8bdafedc12bbc3b"/></dir></dir></dir><dir name="Dataflow"><dir name="Helper"><file name="Data.php" hash="ba0c7d7b0ebbe85cdc161daf58ed818d"/></dir><dir name="Model"><dir name="Batch"><file name="Abstract.php" hash="3543ba2800ba5ee38bac37ec00d275c3"/><file name="Export.php" hash="d701e10f4c6f3f5cbc31744be7811dee"/><file name="Import.php" hash="9173bb07584a68e50e5c88102089576b"/><file name="Io.php" hash="a2b3504d88757ab81f133752006b7559"/></dir><file name="Batch.php" hash="b070f1a35519016888ed33eb43a388b0"/><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="16cb4e158c1e976cc8a23f1b1969e625"/><file name="Interface.php" hash="9685043ccbdec28bc203f6f89ff58538"/></dir><file name="Action.php" hash="a0eac5d684aad0a52ebd9999d93e40eb"/><dir name="Adapter"><file name="Abstract.php" hash="4b599e7300ae3025c45734f3eae53103"/><dir name="Db"><file name="Table.php" hash="bc8f691b432a592c58af98ab6fe497fe"/></dir><dir name="Http"><file name="Curl.php" hash="e7d49e8826112b54d7379d7a8ae1cbe1"/></dir><file name="Http.php" hash="0210afa8d3272999b9fc98e05f8daf94"/><file name="Interface.php" hash="73f2c70039dde1a6228db866735f4f19"/><file name="Io.php" hash="41615998377cfa8c8be8566587395094"/><file name="Soap.php" hash="ba8a2bc6d1db1fadfbf62ea44dbca02b"/><file name="Std.php" hash="2ed56f9f09c3cd2b2a43572e8f6cb067"/><dir name="Zend"><file name="Cache.php" hash="5098b27d145d6e3e600354668382191c"/><file name="Db.php" hash="f79aaa83f74d4e7127ef7828da023325"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="a5eeee61ff65d3e562041feeee60f130"/><file name="Collection.php" hash="524623eb4ee22f41733a719f610256e0"/><file name="Generic.php" hash="0aa8ef9254ac3992f3a2c44760d94161"/><file name="Interface.php" hash="0cdcdb866b5e763a00d17983fd7da4f5"/></dir><file name="Exception.php" hash="67c3a53179e7611fd85b6b9cddb6e74e"/><dir name="Iterator"><dir name="File"><file name="Csv.php" hash="abe3394015e92bd440377fdd26112e54"/></dir><file name="Http.php" hash="cd9fe0bd3f40a0d6a138f5b7bfaffe09"/><file name="Interface.php" hash="6c862c3886f10444133f674de27ed12d"/></dir><file name="Iterator.php" hash="3e0435baffe704561b94bd3fa094cfb2"/><dir name="Mapper"><file name="Abstract.php" hash="f1c55848d32916f3aa0d7fbe29745b34"/><file name="Column.php" hash="314699dda7a12c97db22b44d7c76797c"/><file name="Interface.php" hash="14bf4780e2b0714b915817bca16baef6"/></dir><dir name="Parser"><file name="Abstract.php" hash="184653a172556aaf30ae011bdf8a709b"/><file name="Csv.php" hash="956ff398a9e77aa5721529a65cb7d3ac"/><file name="Interface.php" hash="8c034c04958dec654b4ff6e89e995548"/><file name="Serialize.php" hash="5bc986b7f5d75fb631fb4e9886791abc"/><dir name="Xml"><file name="Excel.php" hash="80afe217220f9e1bd3155d3b45b8eeff"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="8625b39536ed7f8ac6c6f1ff362b3be2"/><file name="Collection.php" hash="ac7f050bf0893a95dd5d1763c0a73286"/><file name="Interface.php" hash="0d3b1dfd027ff14c33d2e0a1aaf29441"/></dir><file name="Profile.php" hash="364dc7b99afed83feb7582e8fc823d8a"/><dir name="Validator"><file name="Abstract.php" hash="cbfe5a09ccdb86444a5d4cdcdcb8051c"/><file name="Column.php" hash="1abea0910f88e265bc829b4c331c9a46"/><file name="Dryrun.php" hash="b5c492bba60680cc846e9d24955b4c49"/><file name="Interface.php" hash="03f27c47cf2e481da96423e1d36e5087"/></dir></dir><file name="Convert.php" hash="b64fc1b5d816f58afec56ee51dcc8351"/><file name="Import.php" hash="4573a6ef4d0b95b803b2c01f9663462e"/><dir name="Mysql4"><dir name="Batch"><file name="Abstract.php" hash="e70e77cc8668a29189dec4ad9e56fa8f"/><file name="Collection.php" hash="ed46e43597beb2ec95002a840c47a641"/><file name="Export.php" hash="6ef9e98156da48ad51cbfd0f3776d681"/><file name="Import.php" hash="74a0db2a88fc41dc80355cf7ea25af56"/></dir><file name="Batch.php" hash="89929eba1effb5486ff4ec2b319f50c4"/><file name="Catalogold.php" hash="b66882011d992c6b8b2517e109d77dea"/><dir name="Import"><file name="Collection.php" hash="70bb331246ec17243bd6c300636750cd"/></dir><file name="Import.php" hash="a71013c6cb85f1ef29892ce889f18550"/><dir name="Profile"><file name="Collection.php" hash="56876c9976738f0e21a9b8ff6aa3c27d"/><dir name="History"><file name="Collection.php" hash="163b2a826d2b8fd96398960aa92f3e81"/></dir><file name="History.php" hash="09b2b4f263b324b523d832d75071dee6"/></dir><file name="Profile.php" hash="9aa4936500033a62679b84f1da27c041"/><file name="Session.php" hash="6c30e12d60f78221dae3835dad0037e9"/></dir><dir name="Profile"><file name="History.php" hash="728b39b8a1520b7fd91952a695c379ad"/></dir><file name="Profile.php" hash="54b918565d7afc27e5da9f35a4c099dd"/><dir name="Resource"><dir name="Batch"><file name="Abstract.php" hash="612fafd01d83759b1e10a39ed50e0652"/><file name="Collection.php" hash="02ff02d640c78e9a06490215daebebcc"/><file name="Export.php" hash="0d22450c096f16387ba00e0ba8f0a24f"/><file name="Import.php" hash="7a1e167147c4a5641c5a3e52b4b1aaa9"/></dir><file name="Batch.php" hash="9403c9b07303b56e3f442e37af936651"/><dir name="Import"><file name="Collection.php" hash="bde0dfbd42b4ff401e481bd268b5f859"/></dir><file name="Import.php" hash="58574de8620131253f1ed739e549056a"/><dir name="Profile"><file name="Collection.php" hash="98cc3701db9032fd8826d1fc75d94193"/><dir name="History"><file name="Collection.php" hash="67a836cfe4cafe0b2b3d7ef0a5ff3051"/></dir><file name="History.php" hash="ce6905b9dbae69351f57c0ed524bbc53"/></dir><file name="Profile.php" hash="f3cff7f8e8155732fae8d4f421ab0103"/><file name="Session.php" hash="453263f698ac876ce8557ac2be7c1496"/></dir><dir name="Session"><dir name="Adapter"><file name="Http.php" hash="edc6b564cf9d56e0f12de5ea447dbdfd"/></dir><dir name="Parser"><file name="Csv.php" hash="61840f83e0d43b67d53930fec1385d1e"/></dir></dir><file name="Session.php" hash="b94c5b87b2d4f3ea7cf6c84b46cb4cff"/></dir><dir name="data"><dir name="dataflow_setup"><file name="data-install-1.6.0.0.php" hash="42c052e1062f756b947dd923e50c3776"/></dir></dir><dir name="etc"><file name="config.xml" hash="035ee01a0e0220f14801318b58f8be49"/></dir><dir name="sql"><dir name="dataflow_setup"><file name="install-1.6.0.0.php" hash="094c2853f4d7308dea858833be058181"/><file name="mysql4-install-0.7.0.php" hash="b6f614644e7b7ccca8c5b321fd25fc7d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="30d4761c1860cd8d42ce0a43727e5943"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9ba941a259ee395cfd90ad3dbdd71c2e"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="7eda27a8f788e7ee1fb6e380e02cf5fa"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="5535484fec01d7822ac93e7096290ca3"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="303ca60636f0518f09239cd259a5a338"/></dir></dir></dir><dir name="Directory"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Currency"><file name="Base.php" hash="e0e170e03ca4d96a7dce5d56336a80a2"/></dir><dir name="Region"><file name="Updater.php" hash="f47e815e8c798610b80dc4b6fcf186d5"/></dir></dir></dir><file name="Currency.php" hash="bd713bb957c6a23c548a7697de84efb4"/><file name="Data.php" hash="c257ee7d3517ca2ee9d8bb2e6252afc7"/></dir><file name="Exception.php" hash="f9639b73bf22148a74976f4daf6f6af4"/><dir name="Helper"><file name="Data.php" hash="4bf35e82fae3db2aba4958bd836d5d09"/><file name="Url.php" hash="f17914084283bc6d7aa4dd5d237ba68b"/></dir><dir name="Model"><dir name="Country"><dir name="Api"><file name="V2.php" hash="312e1300362594a3ba7a522305c5d227"/></dir><file name="Api.php" hash="5133388d9e059b505cae9c4b04f2e354"/><file name="Format.php" hash="ad52c9c51abe5f00f6226c5e43bb0fac"/></dir><file name="Country.php" hash="8c2fafcf43814d42244965f9c09ac52a"/><dir name="Currency"><file name="Filter.php" hash="0b8340daa8a90406059f1acb59933825"/><dir name="Import"><file name="Abstract.php" hash="8d6378f932e87726aadefcd28215eb42"/><file name="Webservicex.php" hash="d53038bf530401b6f1c8201210a5ac72"/></dir></dir><file name="Currency.php" hash="75aeb64410600e854a30f6cfc7645c42"/><dir name="Mysql4"><dir name="Country"><file name="Collection.php" hash="c1fc63c262198bbf18c3edb570c0d52f"/><dir name="Format"><file name="Collection.php" hash="16a17d89b911114555cb775cedf550dd"/></dir><file name="Format.php" hash="e8fcf24b451e4a2454c11df0e7dc1810"/></dir><file name="Country.php" hash="b2bea61b669d97241aa89fc42e17e524"/><dir name="Currency"><file name="Collection.php" hash="41261c0556f08a31e14a233764003e37"/></dir><file name="Currency.php" hash="f415ccb29551abf0dba5d7e43c12863d"/><dir name="Region"><file name="Collection.php" hash="3be48e3b6caf317f289af5f386c5284f"/></dir><file name="Region.php" hash="c2db0ac95c10e1d366b7837318c936f1"/></dir><file name="Observer.php" hash="3e5b58a1b7a1b6bd7ddf93656fc8162e"/><dir name="Region"><dir name="Api"><file name="V2.php" hash="84695e6d5d487bd0aea05eaac060dae2"/></dir><file name="Api.php" hash="2fbbd4774edec8785db449c066b43b71"/></dir><file name="Region.php" hash="63f29958a6533648182ea867d18cc07c"/><dir name="Resource"><dir name="Country"><file name="Collection.php" hash="514bbcc131797481e5ae5021be0e6ff4"/><dir name="Format"><file name="Collection.php" hash="211b05e29af2f95189b64b5ab5bebb5d"/></dir><file name="Format.php" hash="624d5e614fad28b2d23d470a49a780ed"/></dir><file name="Country.php" hash="90802624de442f1813e202179761f294"/><dir name="Currency"><file name="Collection.php" hash="6143827bee6390e2106da6b6020b2bd2"/></dir><file name="Currency.php" hash="2b05897729d8c123b0906a00ad3c5d37"/><dir name="Region"><file name="Collection.php" hash="b84e4245bf5f29be351840d6bf8debfa"/></dir><file name="Region.php" hash="de5686e13ec0ae244ea2981da6f2eed9"/></dir></dir><dir name="controllers"><file name="CurrencyController.php" hash="0a8ad93782d6a0ed66fa1e42912feaca"/></dir><dir name="data"><dir name="directory_setup"><file name="data-install-1.6.0.0.php" hash="c33868f8e7e39dc584672a9d0514d293"/><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="98b30b282695ba73fd344cdbfeacbb5c"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="902c18199d5c5cc78222277ff5cf7626"/></dir></dir><dir name="etc"><file name="api.xml" hash="2f6edb16617f5aba97008638ebbfec36"/><file name="config.xml" hash="56c352b6bdebc026b4ab3ef846cec026"/><file name="system.xml" hash="e73b60ed25b6c6b787a135793388ff28"/><file name="wsdl.xml" hash="cc488b81c0eae648a0ee360d6e2d9960"/><file name="wsi.xml" hash="66de37cc17e24c0c66f74c52e2df616e"/></dir><dir name="sql"><dir name="directory_setup"><file name="install-1.6.0.0.php" hash="47aa97efec924128eab805e5636fe099"/><file name="mysql4-install-0.7.0.php" hash="b5c454d8d309525d71a8634781b931ce"/><file name="mysql4-install-0.8.0.php" hash="bb3cf4e3d432dfb8f94bebfcab61cbc8"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="cfd6af022870643f32aeff8b6cb27c99"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="5542d4352bd04edc8803c729c371db22"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="e1c4fbe48c99a7e87fc27b693683e1f7"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="f81458a4b6f6734b4acc1ec01db4220e"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="e640398483b9695c739c88507ac65690"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="eeeb163cefe0c778c2077c63cc1fcb73"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="6ff564fa86ffdec80ab88379f5da5134"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="bf3b8d577a19cc941eb14c7f261c8ceb"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="a29e42eaad895ed4a8c0f3ecda42c19e"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="b1b88c828f88211e1260dcee4108b173"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="62f5447cdc62ac6799375bf5db44a7ae"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="29ae507ef1d1aee81047dbbfed152895"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="5d8904e905b2ac9d962cc7bcbc937fd7"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="cc3a1d63c33612a38b1824b37c40f606"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="c9f1054bd8fe3afb6837f5a8546d313c"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="8245890ddee5b8f396ffa6274794d205"/></dir></dir></dir><dir name="Downloadable"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Downloadable.php" hash="77e55e5dc308822d8bc555fcbefdbe58"/></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Downloadable"><file name="Links.php" hash="3a08edc2a67d0f56b08a44c3cce6253a"/><file name="Samples.php" hash="eed530baa2d844aedad97aeed7239c78"/></dir><file name="Downloadable.php" hash="5ef9d5819dd23845c4f22f607010b699"/></dir></dir></dir></dir><dir name="Sales"><dir name="Items"><dir name="Column"><dir name="Downloadable"><file name="Name.php" hash="51f6e2c18ac7f9c318fcb17ee035d277"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><file name="Links.php" hash="8f19b5ed669a01eacd225b6a9907779c"/><file name="Samples.php" hash="75c9baa52ae8bc43f9ec8103f2e25c1c"/><dir name="View"><file name="Type.php" hash="485e6be75ad728e4aa26ea594026e69d"/></dir></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="b2e42724a1d0f44b52058741c43afc23"/></dir></dir><file name="Success.php" hash="d56ec2dd50af50f75a135e83b466c3c3"/></dir><dir name="Customer"><dir name="Products"><file name="List.php" hash="9127274b3057d49572318b694e1e0292"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Email"><dir name="Items"><file name="Downloadable.php" hash="df331c7b0aa306c6f7ea15045b719953"/><dir name="Order"><file name="Downloadable.php" hash="6d2ebaaaef11110583be03527941a5a4"/></dir></dir></dir><dir name="Item"><dir name="Renderer"><file name="Downloadable.php" hash="8f303cbe0ace26b706fcb00be8cc498e"/></dir></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="af46f2f32acab466b264892a3ee3e29b"/></dir></dir><file name="Data.php" hash="7aa704d7f269529a1ed08854b763f322"/><file name="Download.php" hash="34b7eb406082d674cf335c93cddd64f1"/><file name="File.php" hash="5a3d283e711d328246742b39a378c14d"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Downloadable.php" hash="97bc07e2d0627436ea42bed84819a22e"/></dir></dir><dir name="Link"><dir name="Api"><file name="Uploader.php" hash="ebf17810830ae7f0f7ffdfa2943eb8b1"/><file name="V2.php" hash="630b806eb820e97db4e24579b582478a"/><file name="Validator.php" hash="a33511ef63ce2b72f4cbe0f52b385a34"/></dir><file name="Api.php" hash="40977ea134fe7d7a7e7f1df52812a05d"/><dir name="Purchased"><file name="Item.php" hash="967313e0d6d239338ae63da5e09c1614"/></dir><file name="Purchased.php" hash="3c28742e85b74a5b32fe4063133e5097"/></dir><file name="Link.php" hash="c8421acc93494d6bc7ae215724b5ae6b"/><dir name="Mysql4"><dir name="Indexer"><file name="Price.php" hash="029700e06b7b63b8572c4fbcc150eda1"/></dir><dir name="Link"><file name="Collection.php" hash="87d378e29012ffc6fc6e0a4a6688f609"/><dir name="Purchased"><file name="Collection.php" hash="bf291246aafb628ac154df41cfb26f2c"/><dir name="Item"><file name="Collection.php" hash="926cdd08de3a6f7ffcde1a82a1acd6bb"/></dir><file name="Item.php" hash="788b0541f99fe64ac3522326375d14c6"/></dir><file name="Purchased.php" hash="172425d690bbf19f12c3a5226f570ba8"/></dir><file name="Link.php" hash="27c16f53f3a9035b32ebcdb0b027705f"/><dir name="Sample"><file name="Collection.php" hash="3e191b153dfeac19f3ee50a203f07c0d"/></dir><file name="Sample.php" hash="4c8f836ce98f98f1461b020949e9609c"/></dir><file name="Observer.php" hash="ed975e0eab2425f9f0c102c30ca804f7"/><dir name="Product"><file name="Price.php" hash="6c2d6ecb0d3fc48e0f479c980dcdd2c0"/><file name="Type.php" hash="67d40e317b34be3a3caabfffd1752028"/></dir><dir name="Resource"><dir name="Indexer"><file name="Price.php" hash="526544bd79468c6641b785d6cb07da31"/></dir><dir name="Link"><file name="Collection.php" hash="729b6d9003d8b3f942db75b6c4befce2"/><dir name="Purchased"><file name="Collection.php" hash="d7adc05ec8432f95c6c7e3a3be40b697"/><dir name="Item"><file name="Collection.php" hash="8f42e22586347f5f895572cf88b95070"/></dir><file name="Item.php" hash="abcf293327e3bb0bfa709d18fadb7c8f"/></dir><file name="Purchased.php" hash="2b59397a1aff196004542a14230fca00"/></dir><file name="Link.php" hash="9be179d68f5448d38aca23fa27e16289"/><dir name="Sample"><file name="Collection.php" hash="3b40c3da6ed3aed34822d6eff4e4a2a0"/></dir><file name="Sample.php" hash="0f32fb1d00539f03e5221e200ed85522"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="432e2c16960010365705e365ca35fc6f"/><file name="Creditmemo.php" hash="7cf76116841c5c8b409cc51503637bc5"/><file name="Invoice.php" hash="2ab75c691e6f8efa21c1c34f23147fb3"/></dir></dir></dir></dir><file name="Sample.php" hash="5eadf7eae3a5ec395bc2c25816d59b9a"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Contentdisposition.php" hash="7d63d4e0768044cd86480eca8edd5ebb"/><file name="Orderitemstatus.php" hash="dc8ed67d3a3bf8d905389c71a46a5a72"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Downloadable"><file name="FileController.php" hash="7f6088cc8e8cd74444e50e71d73829d9"/><dir name="Product"><file name="EditController.php" hash="2880fec7d953a2fd52ea2a126b5a4246"/></dir></dir></dir><file name="CustomerController.php" hash="a34bf5346a11e528f854363492b9441a"/><file name="DownloadController.php" hash="62d043ad37366ab6b772b727eb7f81bb"/><file name="FileController.php" hash="e8b1eb0949070406deea301a08bb87d9"/><dir name="Product"><file name="EditController.php" hash="17f8841c6c0d40b268326e489d46d594"/></dir></dir><dir name="data"><dir name="downloadable_setup"><file name="data-install-1.6.0.0.php" hash="310d216938c8e74cd319d063c90e7350"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="58497f09521db8a24ea83b86a7e31ad0"/><file name="api.xml" hash="c85905a7aeb88d75ab4e7bd18d121527"/><file name="config.xml" hash="44161669aa492757ff48e918d895d74b"/><file name="system.xml" hash="4defd2adf9adb88a3ed18c9e44f63d08"/><file name="wsdl.xml" hash="b3935ff3bf7e2ca40ddd304b4c78577f"/><file name="wsi.xml" hash="7eef36b29c2abf88596e63b6a042626d"/></dir><dir name="sql"><dir name="downloadable_setup"><file name="install-1.6.0.0.php" hash="4793286c9962b042b95f24b5bbd37c07"/><file name="mysql4-install-0.1.0.php" hash="1ab98631cd79b8e009b931b39a192a50"/><file name="mysql4-install-1.4.0.0.php" hash="a363ea42b837c06fbc7510caa62d8fd6"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="2f199f03c7223cf0c1b09f2075004fb5"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="6decba51bdbf5ed44f9a3ff1b3df385c"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="3c9fe53c07b3cf47ce1dcfae8316da12"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="a6ed75d590b8a0ca9102f8d51f2df969"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="19241f621502e8587b28b98f98c2cc6a"/><file name="mysql4-upgrade-0.1.13-0.1.14.php" hash="7947fb9ba92e7d49b5e6b2c624047a94"/><file name="mysql4-upgrade-0.1.14-0.1.15.php" hash="da6a046bf037037722fce7ab52120ce6"/><file name="mysql4-upgrade-0.1.15-0.1.16.php" hash="176c8f58e6d47958108f4f56d4b8fd64"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="01bb73724dff697f98fe0545ea9011d3"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="a6288325fa8db2cffa1f730413806caa"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="531ce0cd65051a1c1cc552a93cc14ae2"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="ef10502c5995e745e50054a6ad89dd58"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="3503c89a97630439c4bb07dd3021ff72"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="2c7d8cc7e2f9c5c0198c2373e861a852"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="21b6bd6346bc3bb610945592968e571a"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="0700661f8dbe9ce7233697d62b78317f"/><file name="mysql4-upgrade-1.3.9-1.4.0.0.php" hash="7b3c1cdf1d9c388e6d720cca660447ef"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="7825b58ac73156af8951af3995dfef02"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="9a8736e8e0e09d2cbe2495ac4d0146ff"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="a2414a36022f0f45523c5609e97dacac"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="34f2b29b89a18d245905516250292318"/><file name="mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="0704160c20e0de302e7847a9edff75ad"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="79c0faefeea54f1aaeb562c05489c584"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="540f11c1af76a687b147dd5b6e91f986"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="3887541a51fb2560ffce3c3132f5ce76"/></dir></dir></dir><dir name="Eav"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><dir name="Edit"><file name="Js.php" hash="76a9d04618fece6a5c7a56b0ff823b07"/><dir name="Main"><file name="Abstract.php" hash="d65003f51d01d39fe1509a30073e922a"/></dir><dir name="Options"><file name="Abstract.php" hash="460fd5dfc5de88544c7975ec2e34e27f"/></dir></dir><dir name="Grid"><file name="Abstract.php" hash="e6c5b5368108405afff2f0b9217b0ddf"/></dir></dir></dir></dir><file name="Exception.php" hash="0641af2a86f332e1386f6693f008086a"/><dir name="Helper"><file name="Data.php" hash="c5432d5aab78f9905451c8aa8440d75b"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><dir name="Inputtype"><file name="Validator.php" hash="a79c5cb074642fb8625491737e814266"/></dir><file name="Inputtype.php" hash="e43dd8ec548fe9f6b0229185e0b6cb0a"/></dir></dir></dir></dir><dir name="Attribute"><dir name="Data"><file name="Abstract.php" hash="4ce6313b746673f0d5b763cc2dccc384"/><file name="Boolean.php" hash="c26954c81573f845ae60285ab9b1b2f9"/><file name="Date.php" hash="1e012219855b5fa9f9ae5b58a1516a3f"/><file name="Datetime.php" hash="bf368d67a5d1f914dd279bbe6f73fa0a"/><file name="File.php" hash="5a70c867df2671b8d1c5f70f32383b5a"/><file name="Hidden.php" hash="1f5cdac56967998115ca00161c84eeb2"/><file name="Image.php" hash="97c7de0fa47b44f24d3142d90179dcfd"/><file name="Multiline.php" hash="0e5e8d7a805bab2ff6e17884ee51b377"/><file name="Multiselect.php" hash="9623ffb47b3e1c7ce71fb4bbaf4e27f3"/><file name="Select.php" hash="3431a4994c8b3374dc3c187ae26de33b"/><file name="Text.php" hash="732cd418b9c743b1bf71f1d781f0a2bf"/><file name="Textarea.php" hash="9538125fb3ba6bf6f4ae054300348f6e"/></dir><file name="Data.php" hash="00c615fcd2d67e2744b43d745ea3849d"/></dir><file name="Attribute.php" hash="adfc8ad9a0686925eb0861c360331537"/><file name="Config.php" hash="2486546f2a2e4191e6c3e3cfbfa3d1c2"/><dir name="Convert"><dir name="Adapter"><file name="Entity.php" hash="8af9af9cc6e7c6f6e4e555911c97f3e1"/><file name="Grid.php" hash="11516ac20dc12f8e677f195108e364fa"/></dir><dir name="Parser"><file name="Abstract.php" hash="0604c7ed305525ae9d81848f2b9a1b98"/></dir></dir><dir name="Entity"><file name="Abstract.php" hash="984170b2a8518fb1c5e8261dd41b4007"/><dir name="Attribute"><file name="Abstract.php" hash="297ed4642ce31d785cbd31ff8d6c3a11"/><dir name="Backend"><file name="Abstract.php" hash="70be013552d8c7c33e3051561f45b321"/><file name="Array.php" hash="25a71b55a3184e652f64d2756e46b24c"/><file name="Datetime.php" hash="44c3fa95099cb5317790305ca58310d5"/><file name="Default.php" hash="410e85e64c32085f147eda397bbdc692"/><file name="Increment.php" hash="69578bd86ad7cc788ab47c31f2c4d2fb"/><file name="Interface.php" hash="41097f25651a3faefe054b3a7e183c11"/><file name="Serialized.php" hash="f6dbd98ea2643317ce32eb8b89a04d0a"/><file name="Store.php" hash="01edda1a78495d0854978b05d23198dc"/><dir name="Time"><file name="Created.php" hash="8a340cc06767f6e337dae1d979ccb689"/><file name="Updated.php" hash="b1b554a1c03ba16781a79e587629c40c"/></dir></dir><file name="Exception.php" hash="abc42003ac62cf10f1c47a8aaa589ea5"/><dir name="Frontend"><file name="Abstract.php" hash="fdfdffe846bcacfd22d448174d2cc645"/><file name="Datetime.php" hash="5cd584d2fdf76e195c76bca5e994327e"/><file name="Default.php" hash="31bb8bc9f506d826364db720ef0b3cb4"/><file name="Interface.php" hash="f0fb5394dc3398c7cff693648c62c1b9"/></dir><file name="Group.php" hash="44982468cc5be1181c5b64ab7faa856c"/><file name="Interface.php" hash="9c6d1484d583d9970cb77b3d3e6fb6ee"/><file name="Option.php" hash="c4f375b24d469faa8233dd905daf1455"/><file name="Set.php" hash="060fee5055d424b6e3efff99389f845b"/><dir name="Source"><file name="Abstract.php" hash="db30a8e44b3cb508baba0f36872754ba"/><file name="Boolean.php" hash="e4582a62d9159a4b7648cb4eb3e2caa7"/><file name="Config.php" hash="3b0ee8512dc7b6dd5ac8dad9781db55b"/><file name="Interface.php" hash="629ae9ef9d6d0232d647a536b0792331"/><file name="Store.php" hash="220f8f06642156cd24cbd424ec5110b9"/><file name="Table.php" hash="eace4965b17821cc095761d1e37a6fee"/></dir></dir><file name="Attribute.php" hash="d43198173e548682b76fa1278b0c2d41"/><dir name="Collection"><file name="Abstract.php" hash="7f60905ac1b3094dba0d800095a3b682"/></dir><file name="Collection.php" hash="85f80d08170392a2868e5eb5b3186218"/><dir name="Increment"><file name="Abstract.php" hash="2888867d0a8ed162656cf340c0618dd7"/><file name="Alphanum.php" hash="860dcaee5fb974ae5b3fde7ded0495b9"/><file name="Interface.php" hash="579718f1c5f00d86de5f2cd6c86f9900"/><file name="Numeric.php" hash="ac9694098c66d6915599f7ac2156017b"/></dir><file name="Interface.php" hash="d16dc535ac2260f768d9c6f2969efdf0"/><file name="Setup.php" hash="bc9575a290ac0bbce793b7743cb3fe17"/><file name="Store.php" hash="0b577726b3c683de678502177834f122"/><file name="Type.php" hash="754b8eca697af02342e9af40ee5657dc"/></dir><file name="Entity.php" hash="136a4a48687f5f555cc85635b4006e45"/><dir name="Form"><file name="Element.php" hash="337a2fcf7c3b197dd70598dae6d8c340"/><file name="Fieldset.php" hash="b815b9e4cba0661813b9402f2893adac"/><file name="Type.php" hash="ebd19351b9b4e8db07aec320187fe0f7"/></dir><file name="Form.php" hash="215128f79657713d4df1f7ab56f771cb"/><dir name="Mysql4"><file name="Config.php" hash="2c70bf309223ff222b794e0268ce6d94"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="ea0d24b4433898f853be14f37f3b0ce3"/><dir name="Group"><file name="Collection.php" hash="b1f663cd69ca7195299b0d4226ff9f15"/></dir><file name="Group.php" hash="918798aea17c6f1797d6bbe5c7ece33c"/><dir name="Option"><file name="Collection.php" hash="53051a0f2e0c0a97c20c949f1a6d8145"/></dir><file name="Option.php" hash="229c97a12c8fbbc0a9b1c5486693fe9d"/><dir name="Set"><file name="Collection.php" hash="0fa368469dba3ad44790f892c3c894ea"/></dir><file name="Set.php" hash="d64928af617ebf66e443c310361fc09b"/></dir><file name="Attribute.php" hash="6922c29a0ccf56634f2a1ea71022bb6f"/><file name="Store.php" hash="91dac98040dd3993dd92eae8b4e403ce"/><dir name="Type"><file name="Collection.php" hash="a0194188e88174876b6178c3d1ace5a7"/></dir><file name="Type.php" hash="f0d84ba44ef5bdd32c024fed77604944"/></dir><dir name="Form"><dir name="Element"><file name="Collection.php" hash="73bf00347f1430684129d0796c2e79c2"/></dir><file name="Element.php" hash="45408edaab72d3012b0e3e7b9fc5e777"/><dir name="Fieldset"><file name="Collection.php" hash="aa3bc9586d55fcf814867b94e98c0fcc"/></dir><file name="Fieldset.php" hash="2ec1a2743fa322af7a4632f1ca61e3fd"/><dir name="Type"><file name="Collection.php" hash="85a3ccaf53b1fbff9fdca14d242ad072"/></dir><file name="Type.php" hash="0bd8c782878c8223226bd9d8bfbac4d7"/></dir></dir><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="f80f5f6af8fedad29bd1a8bd09dc976b"/></dir><file name="Attribute.php" hash="971e713c98d7c5ea3a11776ac80d38ef"/><file name="Config.php" hash="266c18abd1cbfcb3f3c1edeb6cefb7aa"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="9bbbefb45886601bce6ed592a8d8f73a"/><dir name="Group"><file name="Collection.php" hash="78ba0874bd6d3bd571e84e01908e26ea"/></dir><file name="Group.php" hash="ea6b9ac59278d659ef9b0d050219178c"/><dir name="Option"><file name="Collection.php" hash="68c28362189535c99c931f619fadad01"/></dir><file name="Option.php" hash="9d2b310b493a6e2dfc32ce9b06162977"/><dir name="Set"><file name="Collection.php" hash="dd07d151084deddf0b56d9bdb7006a21"/></dir><file name="Set.php" hash="eeb9c645eaf56f73741d0a60386c6b2f"/></dir><file name="Attribute.php" hash="15654e6c59dd1d58ed9dd767200e3a43"/><file name="Store.php" hash="beba844583f5400064864e040233da48"/><dir name="Type"><file name="Collection.php" hash="44235e7ca4dd3f77ea89d4ab8be0c82f"/></dir><file name="Type.php" hash="83a1a2b191f33f9a9e0dff4c5e93961d"/></dir><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="cb1f62b0b621db7d0eb27c3820849c39"/></dir><file name="Attribute.php" hash="b89d6dcb7d57698b0b2e393df3abdca8"/><dir name="Element"><file name="Collection.php" hash="736be5236a8285b6fa302c99da11c8c4"/></dir><file name="Element.php" hash="4688cecadc8df666e912d14a3258aedd"/><dir name="Fieldset"><file name="Collection.php" hash="25357b8097755c3973474340097b2ce3"/></dir><file name="Fieldset.php" hash="08d7abb063b6077f1d588645b79b289a"/><dir name="Type"><file name="Collection.php" hash="ae392ea4c078f226cf1da81e240f2279"/></dir><file name="Type.php" hash="eeb3c28b0cef7362c6c693c0f1ffcc52"/></dir><dir name="Helper"><file name="Mysql4.php" hash="247ebd95acc61ee421b3cb6362af18eb"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="098b2f79a17d6ed050fd839cc6fd874b"/></dir><dir name="sql"><dir name="eav_setup"><file name="install-1.6.0.0.php" hash="e9f0004ee2482d0f1c51814aced44076"/><file name="mysql4-install-0.7.0.php" hash="2a19f8adf9e922105a282606a65a3cea"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="9af1cc7c6346405c07794a5d120e5a94"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="681c496e8b957651551104ac7dcf5edf"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="4880b73f4ab3b2ffdef24e051b8ea659"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="9b51e19f1558aa72e479e9d0bf46377c"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="d4baa1ae2581f30ac4c2609ef72b570d"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="4687ead62851c02ef3e3165bd69ed7ba"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="8c620c539d07f9cf7035a9c338650bfc"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="650033cdf0d1a3b822827c281e7f2a1b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="154e0892c90540a1fe4d3a0a36aefac6"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="f58877d02c4887a4d35a6933dc181af8"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="abadd9f1c7c93f105c3b00f847dc93e9"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="e62460b26496c2faea8894e0cb1a739d"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="323cf145a26acd0c55c5757cfd3f4315"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d9a688efeac2bec4db158e1507e7f38f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="245da9e0c322b928bf58037735f257e9"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="47a6d832bdc3e6313b0af9f23039b468"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="99c24f3347ca435b6401548c2c0dc14d"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="05bb8b40f5ed919459bf25accd6249a6"/></dir></dir></dir><dir name="GiftMessage"><dir name="Block"><dir name="Adminhtml"><dir name="Product"><dir name="Helper"><dir name="Form"><file name="Config.php" hash="e71f2e04e4435423481ea322c3577517"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Create"><file name="Form.php" hash="0f4ff9f0f21d09351422ab01b835b22d"/><file name="Giftoptions.php" hash="3232e441e4d680a8ecee0decb81345c9"/><file name="Items.php" hash="d78fbf3af42cfd6967becbe11128a699"/></dir><dir name="View"><file name="Form.php" hash="9b50cb2c6e9d4f9b965f4d80b6ea873c"/><file name="Giftoptions.php" hash="3d08ae4a4ab9f780298f359c6c96607b"/><file name="Items.php" hash="b5f8879e95e1ec40478c779d93110e45"/></dir></dir></dir></dir><dir name="Message"><file name="Form.php" hash="6522fa4219475cf2c82015127e67fee7"/><file name="Helper.php" hash="633539513329d9ad7533b0296328f2a9"/><file name="Inline.php" hash="7c337341633b17fa8d8dc01ad4584526"/></dir></dir><dir name="Helper"><file name="Data.php" hash="1c4851cf5ca35fcb72683eeb417a97ee"/><file name="Message.php" hash="01c630fee1c4a874bb27f19a20e98af8"/><file name="Url.php" hash="34a66962d449bc84a752425779ef4bcc"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="425812d0c57c35dfb0dd43119e020240"/></dir><file name="Api.php" hash="0dc93eb3747f94245124ad822c2eaef0"/><dir name="Entity"><dir name="Attribute"><dir name="Backend"><dir name="Boolean"><file name="Config.php" hash="36b274f046bfb9b319176607356b6143"/></dir></dir><dir name="Source"><dir name="Boolean"><file name="Config.php" hash="ec2e57b5e26893ed338a99fefbe45e5d"/></dir></dir></dir></dir><file name="Message.php" hash="c9a2fba0ec16be13039fda703613c02a"/><dir name="Mysql4"><dir name="Message"><file name="Collection.php" hash="fe8df3daf9574cc194c03bf124e55660"/></dir><file name="Message.php" hash="410f8523e4dcad503a0ee3af64b8ff94"/><file name="Setup.php" hash="527fc0ae71838098211a6520cd832aae"/></dir><file name="Observer.php" hash="aa755924aa16458d401690baeb938855"/><dir name="Resource"><dir name="Message"><file name="Collection.php" hash="80b5e1f03de5dc20c607c4dbdc761c69"/></dir><file name="Message.php" hash="79c5c51500ab7effbaf9a99686d415b6"/><file name="Setup.php" hash="a6005fad51da9c18a83eb84e99db8d01"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="88d7e7c90ac99f80030c1f5be3c720f1"/></dir><dir name="etc"><file name="api.xml" hash="888db708fb445ab49d51ab4fda3fe516"/><file name="config.xml" hash="27fa6377d2e16d638d82d01b484a48c1"/><file name="system.xml" hash="46692861e2deab8d6bfb535cdb196dd5"/><file name="wsdl.xml" hash="b99aaaac0126c6e09a7ba59fa4dbcf30"/><file name="wsi.xml" hash="ab77c7cfecb0f5d6cb7b07c0b5abc1d1"/></dir><dir name="sql"><dir name="giftmessage_setup"><file name="install-1.6.0.0.php" hash="36402fec00264f941ef4642b0ae17f13"/><file name="mysql4-install-0.7.0.php" hash="2ac19d879e241289b72b8e432db7e6ac"/><file name="mysql4-upgrade-0.1.3-0.7.0.php" hash="650f9811d600721a9f1787c7fc3964c8"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5c3fb419447e54794cecab192cd54b4c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="778cdc4f68a01902bd9342de1371f1e1"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="e939d659a0424363d764e142e917df6e"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="7f78f03378a984b9263a1a345b3c7d56"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="2631230eca6a451392038dfb838c9a01"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="649670744ac9d43328ccb66a003b2264"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="1779217817376cb22d561d4dfe636f86"/></dir></dir></dir><dir name="GoogleAnalytics"><dir name="Block"><file name="Ga.php" hash="3148322407646e182554ccdaf8ccc45d"/></dir><dir name="Helper"><file name="Data.php" hash="04fdb8a7157cf81df10883c9a0ce7b28"/></dir><dir name="Model"><file name="Observer.php" hash="dc24aa1b34905724a135cff31a509c71"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Type.php" hash="b1a9154aec1ad478622cb67c8e019236"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="c155b0d0a90476653938711908cf57f6"/><file name="config.xml" hash="81df5ac1b5d262aee2989083a203419b"/><file name="system.xml" hash="62c1fd94ac8c60034212ff68faec8e06"/></dir><dir name="sql"><dir name="googleanalytics_setup"><file name="install-1.6.0.0.php" hash="7bba830fc3217cd1f73a2f80d2b83f8b"/></dir></dir></dir><dir name="GoogleBase"><dir name="Block"><dir name="Adminhtml"><file name="Captcha.php" hash="90ff64fec37f0b7893ee21ee719d1e69"/><dir name="Items"><file name="Item.php" hash="6d99c34d1dd6ec6c6019eb6297c0081b"/><file name="Product.php" hash="947028d77ec8f996c14aaaa9c9407275"/><dir name="Renderer"><file name="Id.php" hash="f0727df9056dace8587859a8a33b1af2"/></dir></dir><file name="Items.php" hash="d525d39493b7fffdd2fb4670e9bfbe74"/><dir name="Store"><file name="Switcher.php" hash="76478739b7d10298fa193d9a12d14420"/></dir><dir name="Types"><dir name="Edit"><file name="Attributes.php" hash="a7d12c39a051102057d4fe824d4349fa"/><file name="Form.php" hash="72ea980f9aae32dc7ad1ad60cb9e4809"/></dir><file name="Edit.php" hash="18293aa040bb66feb4498b7a64dce501"/><file name="Grid.php" hash="e30a7efef2fe7568caa966afe81bb828"/><dir name="Renderer"><file name="Country.php" hash="ea232b928ace2757bdf2b0c37e850771"/></dir></dir><file name="Types.php" hash="13966d79b28bd855808419902509f31a"/></dir></dir><dir name="Helper"><file name="Data.php" hash="e257389dbf828cce28e64b87fc695fb9"/></dir><dir name="Model"><file name="Attribute.php" hash="d2a7215c38c74ac923ce9735d89ef28f"/><file name="Config.php" hash="836458d8264fef80fc0cf315cdf2ee63"/><file name="Item.php" hash="591a9671462cbd4aeeb96ddcdb7638b1"/><dir name="Mysql4"><dir name="Attribute"><file name="Collection.php" hash="06759e3cfec97b909585d906f7d3eb9f"/></dir><file name="Attribute.php" hash="4c728a47b333e31c25bb8d4d12232ec8"/><dir name="Item"><file name="Collection.php" hash="a813f8532f8f7829cd2c32a24c0aaa1c"/></dir><file name="Item.php" hash="28d9123d1da5a9cf7ac0563339e20d89"/><dir name="Type"><file name="Collection.php" hash="e5aadc72c6d629ae56c715fda9edbc30"/></dir><file name="Type.php" hash="56449cad35d34524c04cfa68c693bb41"/></dir><file name="Observer.php" hash="6c7a7527c4dfa444af5ba8f7db00ecda"/><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="62b3e3c64888ab3869b09694504cf2f2"/></dir><file name="Attribute.php" hash="516c058fc8aa2072c6ea8fcfaf556c83"/><dir name="Item"><file name="Collection.php" hash="40d9819d8d6a5f7bcb825e8f232eef5e"/></dir><file name="Item.php" hash="a13e5622f56537b8ba0254da3fcc0a87"/><dir name="Type"><file name="Collection.php" hash="4c7917040926f5a05b39144f3d403b36"/></dir><file name="Type.php" hash="193c5d60ca3b742a85df5a1505861d74"/></dir><dir name="Service"><file name="Feed.php" hash="5d89c71e6c0de63ccbd1a254d9a48589"/><file name="Item.php" hash="b95af2ff6782b4827ae4a65a6c0fbc17"/></dir><file name="Service.php" hash="f62afc225bb3b3da18b1140f0016a270"/><dir name="Source"><file name="Accounttype.php" hash="89d4467103c6fc59b2c6b2be4f4c40b5"/><file name="Authtype.php" hash="605022851691e4b33931d101ba4f3f65"/><file name="Country.php" hash="d3078ff19116e32944f267686e147f15"/><file name="Statuses.php" hash="828a3352d9a3a818a40924f8a7274dab"/></dir><file name="Type.php" hash="cb9750a2d515fde890a7cfc6436ea0f0"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Googlebase"><file name="ItemsController.php" hash="c696d03d62662dc9ada15c1d06300923"/><file name="SelectionController.php" hash="3b6f44c81d8c9eb195f576a4363fb920"/><file name="TypesController.php" hash="525cbe0fa8c34f894af502c1f52279f7"/></dir></dir><file name="ItemsController.php" hash="68b04d48b14fd5427138af535c908398"/><file name="SelectionController.php" hash="33ed88d739b01c81177031ba08ab4103"/><file name="TypesController.php" hash="e96c32e59a0c3fc973a4e4fb1b8dcc5d"/></dir><dir name="etc"><file name="adminhtml.xml" hash="4e11c32c225957c0c8f8798d82a7e528"/><file name="config.xml" hash="cfe395c9828af3b7849193b55b34697e"/><file name="system.xml" hash="6319e314f403f9e23097e1ac47c62c38"/></dir><dir name="sql"><dir name="googlebase_setup"><file name="install-1.6.0.0.php" hash="169ffe03e43161146b9b41655824829c"/><file name="mysql4-install-0.1.0.php" hash="e24ec4fc9fece30ccf9afe11413ec51a"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="06d9ca8e476fb0bbe09e767ceff499d8"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="3ce5464a7bf542af3d8302d5dea3c50b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f29793e6f271898ef8aba120e3ac7953"/></dir></dir></dir><dir name="GoogleCheckout"><dir name="Model"><file name="Payment.php" hash="6c1ae663fd5ee1d044bb36fe05fa5042"/></dir><dir name="etc"><file name="config.xml" hash="5512b847eb250040ba373fd75d4ef468"/></dir></dir><dir name="ImportExport"><dir name="Block"><dir name="Adminhtml"><dir name="Export"><dir name="Edit"><file name="Form.php" hash="8c0a90aef430dff392c4f6c7535a298e"/></dir><file name="Edit.php" hash="42ad5e1f5eb593b34ebdaf1ac0fa58fe"/><file name="Filter.php" hash="a680e942e4aef9a3b973ca2246f6bf4d"/></dir><dir name="Import"><dir name="Edit"><file name="Form.php" hash="6005dde9dc29a61b9d922f5979c53de8"/></dir><file name="Edit.php" hash="1d6b68a203c0decb63d50d8bef85b091"/><dir name="Frame"><file name="Result.php" hash="6be7e32acf5f6eb8735339bfba41f425"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="23ccef7c01439576ad355a83bfd7fc33"/></dir><dir name="Model"><file name="Abstract.php" hash="da532014ec8c1da0ab7812048255d988"/><file name="Config.php" hash="acff4a07ddcb7287cef69349895c4dc6"/><dir name="Export"><dir name="Adapter"><file name="Abstract.php" hash="3f02a932eb9a60e09077435d1dc39253"/><file name="Csv.php" hash="3c8efb64063cb74f86c43f6279a68814"/></dir><dir name="Entity"><file name="Abstract.php" hash="ce8cfdade201dca6a72e07b5520cc534"/><file name="Customer.php" hash="22c4356e5836de3dd807429f829e41a9"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="0279244c65f5a569ab570786397f899a"/><file name="Configurable.php" hash="d6265cc14bf5dd82713c95e159a31aea"/><file name="Grouped.php" hash="4fc08bfd8997f4c67c980ff52b274285"/><file name="Simple.php" hash="ff9841cf5cf96961045a24887a4b3d61"/></dir></dir><file name="Product.php" hash="91ad9bfe5a122a2fa02e70cee409b2a8"/></dir></dir><file name="Export.php" hash="ecb1980aea6d70e9b5cb2194f9b5f4b9"/><dir name="Import"><dir name="Adapter"><file name="Abstract.php" hash="a0281e645a59766bcaa33f48019c868d"/><file name="Csv.php" hash="1485b97f96a3c37380b9f3ffc188e387"/></dir><file name="Adapter.php" hash="a6b4e8b8a815f874c0c50355ef10f67e"/><dir name="Entity"><file name="Abstract.php" hash="66d5255e757c039ae9c475f4cd203a25"/><dir name="Customer"><file name="Address.php" hash="2305d18df63e2d1f1aaf1d30b2cca0b9"/></dir><file name="Customer.php" hash="52825f97363b31c967e5fb4d76a49bb1"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="c2af099c3d104994c64b821638b347d7"/><file name="Configurable.php" hash="ae58a371b226560ea8396eb790686d78"/><file name="Grouped.php" hash="66f7fc872086bff458180ed71faf463d"/><file name="Simple.php" hash="7aab97fad42f1911c7594d52d12331f1"/></dir></dir><file name="Product.php" hash="362f4e0134026c123871d670208dfb99"/></dir><dir name="Proxy"><dir name="Product"><file name="Resource.php" hash="4f48a6772f3d37695949011744edce4d"/></dir><file name="Product.php" hash="546f152c0e20030a6d849bfd4faa3124"/></dir><file name="Uploader.php" hash="4f5ad1a1704839935b3bfe976bad6ebe"/></dir><file name="Import.php" hash="6b7d74d101280209f402ec3db6b75f6e"/><dir name="Mysql4"><dir name="Import"><file name="Data.php" hash="a49fb8aafb9050ae578115c21e829888"/></dir><file name="Setup.php" hash="febd1871bbe88278134887274d9e1394"/></dir><dir name="Product"><dir name="Attribute"><dir name="Backend"><file name="Urlkey.php" hash="dcdf48b3f12bfb824df47d49a1bf87fa"/></dir></dir></dir><dir name="Resource"><dir name="Helper"><file name="Mysql4.php" hash="1da742e4cc124c54413dcea86cca91a4"/></dir><dir name="Import"><file name="Data.php" hash="6684f138f53d2f21bbec021834d32178"/></dir><file name="Setup.php" hash="5486ea84fba5e15d8a95bfb1e4e37464"/></dir><dir name="Source"><dir name="Export"><file name="Entity.php" hash="b3e8f29c401d0b51149c7a335d723333"/><file name="Format.php" hash="755c5944f6cf76a73410670b5ca82e71"/></dir><dir name="Import"><file name="Behavior.php" hash="dae5c8358bdcfdba82126628fc0749a5"/><file name="Entity.php" hash="55b550eb1bc4f6d62991e3c984d3b213"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ExportController.php" hash="ac53bc75b82d0758f5d41c6f32c93c50"/><file name="ImportController.php" hash="c262b652812db581fab1c19eab947e80"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="cffe27dd5f4445f2a075c6db18ec068d"/><file name="config.xml" hash="69acc517b147579559fa30ac2429e03b"/><file name="system.xml" hash="52728a6afa67432259b07510a4857aa8"/></dir><dir name="sql"><dir name="importexport_setup"><file name="install-1.6.0.0.php" hash="7b243fdb587af327b86df6561d6f4ff3"/><file name="mysql4-install-0.1.0.php" hash="a669634907c6393797a7fc9f57914a3d"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="2ef4e95819de7a6f825f217dd2c13c56"/></dir></dir></dir><dir name="Index"><dir name="Block"><dir name="Adminhtml"><file name="Notifications.php" hash="0502428a04f868b969977e8cbe9ca68c"/><dir name="Process"><dir name="Edit"><file name="Form.php" hash="7138d95f471b73cd1db8c50048dbfa59"/><dir name="Tab"><file name="Main.php" hash="70e7ed7e545def02e2fbbd3501b648a3"/></dir><file name="Tabs.php" hash="77bed81cf36df06a6e5c85c525afd393"/></dir><file name="Edit.php" hash="4e7e3d405a775d0412bd2c59bfa48348"/><dir name="Grid"><file name="Massaction.php" hash="94b8d97b7a62191439ed0533278ee246"/></dir><file name="Grid.php" hash="a6763a508c9608587c554b655ba6cd4b"/></dir><file name="Process.php" hash="6a34dee446d98c1a021b45403b807e43"/></dir></dir><file name="Exception.php" hash="2abd7e24d0e5f42ec2e94fbaf7f83713"/><dir name="Helper"><file name="Data.php" hash="ddc60c6babe27a91d185aa9eb65bf1a9"/></dir><dir name="Model"><file name="Event.php" hash="9d541285ef6dec4776e8a99a962bd8e5"/><dir name="Indexer"><file name="Abstract.php" hash="17a2d6175c88b0b6314e5f4fd9f82c9d"/></dir><file name="Indexer.php" hash="036771069dfa406996ae0146c3fc2efb"/><dir name="Lock"><dir name="Storage"><file name="Db.php" hash="8b2746a15e7e92f0e44ee2462067e434"/><file name="Interface.php" hash="8e3de0b1cc4acbf532be5244a21105bc"/></dir></dir><file name="Lock.php" hash="571bb826223b080017bebc8a36abda92"/><dir name="Mysql4"><file name="Abstract.php" hash="c91d020895e5bba42395d8d81254fa40"/><dir name="Event"><file name="Collection.php" hash="ca52f306157be7b688a47d8a148cd12c"/></dir><file name="Event.php" hash="da1a734fdfc309952d3a9c98589b3359"/><dir name="Process"><file name="Collection.php" hash="62f31af83a5fda6963e6c4a4146f8f93"/></dir><file name="Process.php" hash="a6a69af2c162b57f704955853896c050"/><file name="Setup.php" hash="730e01929ea0e3af40d5fc31413f3811"/></dir><file name="Observer.php" hash="009367d6b0bfb2426cc2dd65b7fa99fc"/><file name="Process.php" hash="43ee21cf9b5b9692b8f80a5c367423aa"/><dir name="Resource"><file name="Abstract.php" hash="c2eca7b501fb4229c95e10e1083e0167"/><dir name="Event"><file name="Collection.php" hash="aa7f8135cd9543988d78363b5264e00b"/></dir><file name="Event.php" hash="38a7f4231adc01251fa8d4de3cef2258"/><dir name="Helper"><dir name="Lock"><file name="Interface.php" hash="0683f031e83e0d0d08623d37470fa9f2"/></dir><file name="Mysql4.php" hash="e3ebcf77c8f5bc9adcebf7f7d1add03c"/></dir><dir name="Lock"><file name="Resource.php" hash="5745201b6fcf0e8c9e1f72f15111d6ad"/></dir><dir name="Process"><file name="Collection.php" hash="a97368a80473465782fc276e0c4e6e4a"/></dir><file name="Process.php" hash="4f698ade97452f2c5f7df154f8d8fec6"/><file name="Setup.php" hash="ae8759b256c26d361606070814b62bae"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ProcessController.php" hash="ecbb2ba955cff030e762d9bd17ad36e6"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="73774f3cb6b8a9ecabe2a34825863cc2"/><file name="config.xml" hash="ef73494843fdd261b72c8dfcb2265e4f"/></dir><dir name="sql"><dir name="index_setup"><file name="install-1.6.0.0.php" hash="c9abd384d75bd9ae6c1eef9a72474506"/><file name="mysql4-install-1.4.0.0.php" hash="064e9f0e1403436d6802523e9dbc825f"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="9c5b0567a6070eb64728519ba631eccf"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="d50af25db7c40f134c0454db38409866"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="370153229feabc0ae76027266c9245a8"/></dir></dir></dir><dir name="Install"><dir name="Block"><file name="Abstract.php" hash="ca03b54314c4fad54b1d80a88cd966c1"/><file name="Admin.php" hash="94bbdac89b39c44885fec8abacaebced"/><file name="Begin.php" hash="4cda74306ad4bdeaa41bf0934b0b6bba"/><file name="Config.php" hash="0f50fa4ee04f7042fed47947cd2cdc5f"/><dir name="Db"><file name="Main.php" hash="13343e3f0097e095e19d2f36458e5a25"/><dir name="Type"><file name="Mysql4.php" hash="733faabc64a68d2e8bb23ea2345e7a3e"/></dir><file name="Type.php" hash="f489d8450f382ae541288464f3ef1e5f"/></dir><file name="Download.php" hash="4710dd31557c53b09fdf15abee245906"/><file name="End.php" hash="7764ff5608344fc6f705b0eed702355c"/><file name="Locale.php" hash="1096108913896157368789eb7be68b38"/><file name="State.php" hash="53f3de195337567ad91bf0f8a814991a"/></dir><dir name="Controller"><file name="Action.php" hash="84731263011f3251f47bcb9256e57277"/><dir name="Router"><file name="Install.php" hash="bbcd341a81cfda360877355aae659f22"/></dir></dir><dir name="Helper"><file name="Data.php" hash="1cef380829a4f6322a102f8ca55acb02"/></dir><dir name="Model"><file name="Config.php" hash="4d8084f912d33f4af9f23340bf8fbadb"/><dir name="Installer"><file name="Abstract.php" hash="369ea7aca230b883a76e9f595c73b608"/><file name="Config.php" hash="3dc50e732fabf3c49f50255be5476cf8"/><file name="Console.php" hash="b2b1744e38de05f532de3854611c6fba"/><file name="Data.php" hash="92e0782d07009cde613c52a6664d4edb"/><dir name="Db"><file name="Abstract.php" hash="55770957bbfe3065b56fddf03df8eb0f"/><file name="Mysql4.php" hash="0ab2d6c06304f53798ba6df2c0dbdafa"/></dir><file name="Db.php" hash="d553f0ae56ff856ab5589ace6d299028"/><file name="Env.php" hash="28341cd7cb8623e86a5430e7822dfc04"/><file name="Filesystem.php" hash="eda0f45009142a40fe81ce8b6430d8d1"/><file name="Pear.php" hash="5204107313d23dccc88a2c3334f091c8"/></dir><file name="Installer.php" hash="72d72d93692b073c644c55414b776b88"/><file name="Observer.php" hash="6afe735d213f59504a041eacb2bd26a5"/><file name="Session.php" hash="2ab7246cd2d3becbb96792f64f2193b6"/><file name="Wizard.php" hash="1a368631d270e8f2b0660de98b4624e1"/></dir><dir name="controllers"><file name="IndexController.php" hash="3ab953dafd6000928bae8bf53d3177fa"/><file name="WizardController.php" hash="7a5d5cb369c7b21372365ad4077e1fcb"/></dir><dir name="etc"><file name="config.xml" hash="17a0d6f4472fe496b4cdaaca7586b7ea"/><file name="install.xml" hash="5cacf1ea5ba56f6bd7d42d63060e3026"/></dir></dir><dir name="Log"><dir name="Helper"><file name="Data.php" hash="8a0325ed14a7bb3a523488c9217d8f56"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><file name="Loglevel.php" hash="d28f40ec66bb0d887d63b895767df47b"/></dir></dir></dir></dir><file name="Aggregation.php" hash="d0db269470bec4d97162fe39307d9d95"/><file name="Cron.php" hash="aa69d2f341ae137e478333b890304695"/><file name="Customer.php" hash="f10b6b88fccf821375d0dd8e15079b57"/><file name="Log.php" hash="1d7a29c78da548b24096aaaa674b01e1"/><dir name="Mysql4"><file name="Aggregation.php" hash="befc68bb34bb3781e3e203324edecca8"/><file name="Customer.php" hash="2bc896862a996728066c8093d023879e"/><file name="Log.php" hash="16760341353457edcdac0abb6acdea60"/><dir name="Visitor"><file name="Collection.php" hash="97e0d353e927b67961baeabb002f8ca8"/><dir name="Online"><file name="Collection.php" hash="31ef43622058d9408334d075c537abc0"/></dir><file name="Online.php" hash="990d2fd509874f9960767c23fc61f92f"/></dir><file name="Visitor.php" hash="33eece4b2d319675ae96a868e219b828"/></dir><dir name="Resource"><file name="Aggregation.php" hash="065f18fb7ad3ba1f9fc2e076c45835ee"/><file name="Customer.php" hash="7ca21af42caddc5b33b58ce8294be65f"/><file name="Log.php" hash="fadc7f5e01b580ac241d164b2f849335"/><dir name="Visitor"><file name="Collection.php" hash="aac8c82a4ab29539278d5db8f90afec2"/><dir name="Online"><file name="Collection.php" hash="c3b633da19a3cd3b23758779042a16c3"/></dir><file name="Online.php" hash="e6b52cc97bd8728d118d7444c7fb9622"/></dir><file name="Visitor.php" hash="c4d6976141b8d93935f12c76b07ea100"/></dir><dir name="Visitor"><file name="Online.php" hash="770284f9f8fe6ce975faf50b82b65598"/></dir><file name="Visitor.php" hash="632017210c729948a32355bc02873e6f"/></dir><dir name="data"><dir name="log_setup"><file name="data-install-1.6.0.0.php" hash="20b4e578d26ddbcd1c85dc29cba07a56"/></dir></dir><dir name="etc"><file name="config.xml" hash="d2597554e1238297fd72f85d34de55ee"/><file name="system.xml" hash="32348c1e64534363d08d63bc6128a26c"/></dir><dir name="sql"><dir name="log_setup"><file name="install-1.6.0.0.php" hash="642fa050d97e47739a594074459321bd"/><file name="mysql4-install-0.7.0.php" hash="e7c5af70b26609ce168c5c8a34a8c4f8"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="0fa3790c5b1f31fec3cdca25576bba13"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c1d51bbae35b2722dd39c79062e4eabb"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="cf4cf002bbeb5ec86d6087d980244b3d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="038f6b84cee27c3df17407c0fe179541"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="b251796e95da3a9bfbbce375ddff8731"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="da65b0a560db302bd8bebe40d136914a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="2df887c02ecbcf996b7e1f44ab610f38"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="afe7b3adab3a1bc4d094db7913b455f4"/><file name="mysql4-upgrade-1.6.1.0-1.6.1.1.php" hash="7fa22a9b4db88b9a6f0f8f4d04ca8d3f"/></dir></dir></dir><dir name="Media"><dir name="Helper"><file name="Data.php" hash="59877530e180bccec76efb3e20409751"/></dir><dir name="Model"><dir name="File"><file name="Image.php" hash="170170d6bc9c26cf246696592ffbb59d"/></dir><dir name="Image"><dir name="Config"><file name="Interface.php" hash="364f837bf1fbf25107ba7c8d1face188"/></dir></dir><file name="Image.php" hash="4ea65115b0a4ae3cfe3fed0aff0e3d00"/></dir><dir name="etc"><file name="config.xml" hash="c60ba7f82d63de51e0a0d4a1d1adcd29"/></dir></dir><dir name="Newsletter"><dir name="Block"><file name="Subscribe.php" hash="001313ea7cad90c6d0c583bbe271f577"/></dir><dir name="Helper"><file name="Data.php" hash="3bf5afa684ab87ccbbd8ffea14667c82"/></dir><dir name="Model"><file name="Message.php" hash="04c45f03d227d377136f7bfb8a9c2060"/><dir name="Mysql4"><dir name="Problem"><file name="Collection.php" hash="a621e853213fef78b97d092f22f4b6cf"/></dir><file name="Problem.php" hash="1af0aaf83dd64970dbec2315846767f3"/><dir name="Queue"><file name="Collection.php" hash="63bf3582e463cfead41f06170f12ccb6"/></dir><file name="Queue.php" hash="20f7e8925518a5c2be1da31a653c537e"/><dir name="Subscriber"><file name="Collection.php" hash="2435451ef565788c5db52ed04b73173a"/></dir><file name="Subscriber.php" hash="b1af8c88da9b34d6b347eb1e90b7c9b2"/><dir name="Template"><file name="Collection.php" hash="7d7b251f328c367f4b5ab980f5835df9"/></dir><file name="Template.php" hash="e31a772f50c21b6c6779a168a363ef29"/></dir><file name="Observer.php" hash="7144a9695e8337210a846fd479ef3104"/><file name="Problem.php" hash="90a8edbda50aba746bb0b8cc84c81c10"/><file name="Queue.php" hash="f0a21e1f019200e3a0d5f260fbba8898"/><dir name="Resource"><dir name="Problem"><file name="Collection.php" hash="c0c91fa3da32f63211d446d50ca616ae"/></dir><file name="Problem.php" hash="6846ee74581878cc1573b546c720ccc9"/><dir name="Queue"><file name="Collection.php" hash="143911e1b419cf4de343ba133e42cbc8"/></dir><file name="Queue.php" hash="24428d90f8bad535d69e2d6969dfc007"/><dir name="Subscriber"><file name="Collection.php" hash="d0aba05515f102eb1a3a233241aeb973"/></dir><file name="Subscriber.php" hash="eb4415875435b356b0e936b44b1994fd"/><dir name="Template"><file name="Collection.php" hash="b4f3f8b0d2fa733f07da322ee83b9465"/></dir><file name="Template.php" hash="b8a9e7f12cbcaae5d74a8281fb8701e6"/></dir><file name="Session.php" hash="0f6118a9d3bdda33759a08d538a42b1e"/><file name="Subscriber.php" hash="f39a6a7deb2530e53a7b2adb7dfd916d"/><dir name="Template"><file name="Filter.php" hash="694a7adefb521667830b6c8622fb922f"/></dir><file name="Template.php" hash="b23eeb2b2576b5ce84367d842454f465"/></dir><dir name="controllers"><file name="ManageController.php" hash="e023f87aa2fbc1681bdc71e1fafff6a5"/><file name="SubscriberController.php" hash="44f5ae94ee1bd2433716a404d4c0c588"/></dir><dir name="data"><dir name="newsletter_setup"><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="a6839702c558b5e316e9bb2e8d34e9e9"/><file name="data-upgrade-1.6.0.1-1.6.0.2.php" hash="bc41dfa900ae72dbd1f4bc9cffb8061c"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="a138f30d7540d1ae5aea45f497409e56"/><file name="config.xml" hash="4f5b07bedd42a9c0c04a46cd61c48f94"/><file name="system.xml" hash="061b10846b83f8d61b9da7f4e49a42a9"/></dir><dir name="sql"><dir name="newsletter_setup"><file name="install-1.6.0.0.php" hash="0041ea9db1cfaf73d997d0db7c0f15f1"/><file name="mysql4-install-0.7.0.php" hash="864456494c3a7bf98bee7c063a99f968"/><file name="mysql4-install-0.8.0.php" hash="9ed900416bc1d897bb14b8dc7aa8d6c6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="685e2c4b18639bc53a648d557b4d41b4"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="bd7699cb9b1d5bac800c402e15b70cb9"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="ce3fc3ca7c687838fa3c978c8b33a898"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="ff85d1f43997c605d063bd9a9c90d79d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="a2927ab2911de988787206f2e9ba610c"/></dir></dir></dir><dir name="Oauth"><dir name="Block"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><dir name="Token"><file name="Grid.php" hash="d7ad6175b76249112fdeb036d335461d"/></dir><file name="Token.php" hash="8341bedc79dacc47d95c8862f7166fcb"/></dir><dir name="Authorize"><file name="Button.php" hash="4ff67d854c73f8cd745de2b104eee189"/></dir><file name="Authorize.php" hash="3292dc0ad49f627ce3ee3c756a44336d"/><dir name="AuthorizedTokens"><file name="Grid.php" hash="b487b3940c469bce7cd44f6bf5abc0df"/></dir><file name="AuthorizedTokens.php" hash="2436e4acbf44cbe2225185d21a59bb27"/><dir name="Consumer"><dir name="Edit"><file name="Form.php" hash="553b7b38651e1923a7d3ca4dc3051ee2"/></dir><file name="Edit.php" hash="3cf9750c84f9a0925f9ea76737ae46c8"/><file name="Grid.php" hash="b9b5225f9c184fce14efd2bf94c90d9a"/></dir><file name="Consumer.php" hash="a6796218280d28a9b4aa764e0fbe66cf"/></dir></dir><dir name="Authorize"><file name="Abstract.php" hash="67872cb70be20664180b8f2715c02247"/><file name="Button.php" hash="ee5ba47ae932fbd57a61e735714d9ee1"/><file name="ButtonBaseAbstract.php" hash="ce3cd8de0ca383fde819ab0222de6fcd"/></dir><file name="Authorize.php" hash="107980275153c2b9142bf9577f86647f"/><file name="AuthorizeBaseAbstract.php" hash="ca037d0d2df1d671741d7a7f7becb93d"/><dir name="Customer"><dir name="Token"><file name="List.php" hash="e1154a5aa51e493ccc59c6017a30cfc0"/></dir></dir></dir><file name="Exception.php" hash="bf992e72284e6d524c3c5cfb0fbdaf5a"/><dir name="Helper"><file name="Data.php" hash="4aa4712963e132d4398a551781c4cd6f"/></dir><dir name="Model"><dir name="Consumer"><dir name="Validator"><file name="KeyLength.php" hash="9ad199cfcb84fda61c1712b7e6f62e04"/></dir></dir><file name="Consumer.php" hash="d5cdcf8a24636f5128fe9714de8811a0"/><file name="Nonce.php" hash="af39ce6d03adf99e78fb605e40a8cd8c"/><file name="Observer.php" hash="2de5f25babecf6a3c8ddc0b450579200"/><dir name="Resource"><dir name="Consumer"><file name="Collection.php" hash="f2598ca728e610b5401482f4ae261dab"/></dir><file name="Consumer.php" hash="031f8162d9ddb8feccc6480822e74e17"/><dir name="Nonce"><file name="Collection.php" hash="84ec6dd23847cf83641c4693e59d140d"/></dir><file name="Nonce.php" hash="0e0c57b0fe53c2bc701b8c14c5be733e"/><file name="Setup.php" hash="f73d99109f2c624776ff6d437361007d"/><dir name="Token"><file name="Collection.php" hash="db4f41a6704364c432151f831689ad03"/></dir><file name="Token.php" hash="d39fd4df2cffce3eef1295aa1fb1043e"/></dir><file name="Server.php" hash="affda00d99f8e97a5f66eaa9d6d5abc8"/><file name="Token.php" hash="6888cc747cb8fd9ac26c97559775b46e"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><file name="TokenController.php" hash="3808752665df116a118330ee48a993ac"/></dir><file name="AuthorizeController.php" hash="9b94b9f0d5e97b2033633415f8fae483"/><file name="AuthorizedTokensController.php" hash="0bd734a21bc403a5bdf79200a57c8d19"/><file name="ConsumerController.php" hash="a7313fd6baf55eee9eb35a9207de02cf"/></dir></dir><file name="AuthorizeController.php" hash="69e315001d701bedcb9cefdf11d1b8d4"/><dir name="Customer"><file name="TokenController.php" hash="20b723ac1c7b628d9aaf0cc18d6a5539"/></dir><file name="InitiateController.php" hash="cb05ebe5c1907a17b7c3dfd260d8b31d"/><file name="TokenController.php" hash="f46650e9544b7e39898a71007eb0deb7"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ccf2f251a3c6a7da0e267971268072ef"/><file name="config.xml" hash="2a569a46049a4fe51fd320a2120011f4"/><file name="system.xml" hash="cdb0c93c59b685d393941b692ef2c711"/></dir><dir name="sql"><dir name="oauth_setup"><file name="install-1.0.0.0.php" hash="706315e7e5959f345ebc31ec00d8139b"/></dir></dir></dir><dir name="Page"><dir name="Block"><dir name="Html"><file name="Breadcrumbs.php" hash="93e28b409d3a5b0f63b2689fba7e3ebe"/><file name="CookieNotice.php" hash="c06fc21ddfb2f44eeccd3bc9f341f08b"/><file name="Footer.php" hash="5f74dc2996e75f739ee64a2a9f251cbf"/><file name="Head.php" hash="cf1c00c6a6dcaf8708e93e079ddff208"/><file name="Header.php" hash="1348228a8d831522b6a92939bf4f881c"/><file name="Notices.php" hash="91d69e32e5509a58657508b0d18c3a72"/><file name="Pager.php" hash="1b44a7c48c5dd03e47abecaf0a133748"/><file name="Toplinks.php" hash="4a58e40613ac577a7487c5941c12352a"/><dir name="Topmenu"><file name="Renderer.php" hash="d9e62509655fb2d255e144a92c2e70a1"/></dir><file name="Topmenu.php" hash="e4c9a9a257738d14584ebc587b5d602d"/><file name="Welcome.php" hash="38d4c135aa6bc74a3f6c18d548bc8fb4"/><file name="Wrapper.php" hash="261d0533aeabbff798d731f0b9c050c9"/></dir><file name="Html.php" hash="54b3ed2528283d911fef2303bc6ccd55"/><dir name="Js"><file name="Cookie.php" hash="daa2c60da73eeaba950105c3c6888f90"/><file name="Translate.php" hash="f5b463fa97737a974fe828f701c4a434"/></dir><file name="Redirect.php" hash="83af10528b7bda2fe3c82391a5220382"/><file name="Switch.php" hash="51d834776dc6e0be52ded27c8552566a"/><dir name="Template"><file name="Container.php" hash="a80162d0a24bbd3109f11dfe830acbce"/><dir name="Links"><file name="Block.php" hash="1e3e7f7434f91922333cd826b5db69b7"/></dir><file name="Links.php" hash="a8c62ede972f85a933cccd1e9b581703"/></dir></dir><dir name="Helper"><file name="Data.php" hash="15f25e825046ba13e1d6b58f37d118c5"/><file name="Html.php" hash="de6bee855b74d76a22fc043566bfe867"/><file name="Layout.php" hash="d00d4f1b1af50f507c1cd1434b3e8626"/></dir><dir name="Model"><file name="Config.php" hash="dda5bf4a680db95ad29899fda27ed4fa"/><dir name="Source"><file name="Layout.php" hash="c7b53a3434ce4ef8ce6de81289195d25"/></dir></dir><dir name="etc"><file name="config.xml" hash="80e0a9431cd91a7b8b7e8ce0d15c45bd"/><file name="system.xml" hash="cf33658d2dad24b629e9a143bc06c092"/></dir></dir><dir name="PageCache"><dir name="Block"><dir name="Adminhtml"><dir name="Cache"><file name="Additional.php" hash="ffdc593bf1074652a6e54726fde56938"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="dbd9122cf85f1aec65ad0fed6f7f59a2"/></dir><dir name="Model"><dir name="Control"><file name="Interface.php" hash="e8f4d14631df668f14d1683d26be97d8"/><file name="Zend.php" hash="2b34fc0230e45e7973dabc442e533c8a"/></dir><file name="Observer.php" hash="84b6a38809a505c003c7a93f4d839f09"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Controls.php" hash="3047b1a853d32f1580f50206ad80fe10"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="PageCacheController.php" hash="78ae7c705ebbe98cd0934687adf645fd"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="567ab3520a74f946ccd70bdb62299275"/><file name="config.xml" hash="1480ca7d245a4aa9e6c02a08b91763a0"/><file name="system.xml" hash="d1af2a63d486ef54f9aa0e6e950fb35f"/></dir></dir><dir name="Paygate"><dir name="Block"><dir name="Authorizenet"><dir name="Form"><file name="Cc.php" hash="7da4933e03c5a66f5f923d2844154687"/></dir><dir name="Info"><file name="Cc.php" hash="bb3eda4d33ea69c96d58c3a8f99e1080"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="5b691fc135d1992204a1c11193c3735f"/></dir><dir name="Model"><dir name="Authorizenet"><file name="Cards.php" hash="22d2b8c2507d05a231721df9f93bc479"/><file name="Debug.php" hash="312171d4c03484ed2cfee33b6529a6e7"/><file name="Request.php" hash="62acd350f308b107fc73df8f816af07e"/><file name="Result.php" hash="1bbc3f8c1594a48d7dce1d37e7feb2e0"/><dir name="Source"><file name="Cctype.php" hash="878e7bb13c2f22aa287bef7aa636f118"/><file name="PaymentAction.php" hash="8597a947dd50a19b2a2d8630903bf422"/></dir></dir><file name="Authorizenet.php" hash="f77d1046c5ccfa1f286d249a7395c536"/><dir name="Mysql4"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="28786186721465a7d214616ff567a118"/></dir><file name="Debug.php" hash="0333884d2080bf6530ae9931e7a27d57"/></dir></dir><dir name="Resource"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="b878381b266f6231b16189772ba6947c"/></dir><file name="Debug.php" hash="3df93081e0c043058204412176253ed3"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Paygate"><dir name="Authorizenet"><file name="PaymentController.php" hash="d54d0d987ef05a77d91ff2b84415908b"/></dir></dir></dir><dir name="Authorizenet"><file name="PaymentController.php" hash="65644062e9003c97617f5df3ae959ad8"/></dir></dir><dir name="etc"><file name="config.xml" hash="3de2efa6cbc25168fcc78dff3c75d956"/><file name="system.xml" hash="43937ed87f594f3d5d44e22380d2b815"/></dir><dir name="sql"><dir name="paygate_setup"><file name="install-1.6.0.0.php" hash="3c82de7f761f2568603b3ea44f045937"/><file name="mysql4-data-upgrade-0.7.0-0.7.1.php" hash="008fda217c9664889741849a96919ea5"/><file name="mysql4-install-0.7.0.php" hash="e808b390c548a92017dfa85109f37afc"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="27de0cae75014bce4e7812430185397e"/></dir></dir></dir><dir name="Payment"><dir name="Block"><dir name="Catalog"><dir name="Product"><dir name="View"><file name="Profile.php" hash="400fb0c50e0ea4ed3c31a67901438c30"/></dir></dir></dir><dir name="Form"><file name="Banktransfer.php" hash="eb7a99ea502731e80ce00081556cea8d"/><file name="Cashondelivery.php" hash="7a3090b201a31646137cd9ac16107e6a"/><file name="Cc.php" hash="32e21ce2492807c174c21c33d85bbc55"/><file name="Ccsave.php" hash="9a73badc8aefca6f8e3764c29be36a6b"/><file name="Checkmo.php" hash="079eb1ec995b1f53311162df7f09c0e3"/><file name="Container.php" hash="78c3b538d465e5c0800018cd633f8cc4"/><file name="Purchaseorder.php" hash="0a38e5024f5445ccd7bd6727c7e856fe"/></dir><file name="Form.php" hash="797157be5f6c8afc42777bb1f0dbafb9"/><dir name="Info"><file name="Banktransfer.php" hash="e702c12a17fb8eae7ca0fa79558b875f"/><file name="Cc.php" hash="439edfb22a4b99b77e3f0d3d5ea39397"/><file name="Ccsave.php" hash="096cc6fda5538bc305f77a7c32e5447f"/><file name="Checkmo.php" hash="c379c97543229f1126d9f5d2d98d39b5"/><file name="Container.php" hash="07140ee36b9c5b88424530de2ea42c98"/><file name="Purchaseorder.php" hash="6cfa9189f9c5412d6567932d63caeb9a"/></dir><file name="Info.php" hash="3ea3a123e9845c709de46abd06851004"/></dir><file name="Exception.php" hash="32910bf105bee28695f0cc5c3efc682b"/><dir name="Helper"><file name="Data.php" hash="fac30d9d7659d7bfb27aa94d6b76ec08"/></dir><dir name="Model"><dir name="Billing"><dir name="Agreement"><file name="MethodInterface.php" hash="ebdb0ea122d412d09c92227a5b911a9a"/></dir><file name="AgreementAbstract.php" hash="7e726c5fa0066cf1ad5c734c47b2be32"/></dir><file name="Config.php" hash="d27b768958f62c3887ce3311f4f82d82"/><dir name="Info"><file name="Exception.php" hash="7d1565ac6743daf7a528c633f1cb9351"/></dir><file name="Info.php" hash="0524fc5de69c8c2f4d4c239708c2f1d5"/><dir name="Method"><file name="Abstract.php" hash="c407dd2eaccefeb158a0c6a4607abe9b"/><file name="Banktransfer.php" hash="88924c3aa18f916733b9a8d8bd391f70"/><file name="Cashondelivery.php" hash="f5cf8d57b76f676790a2e2bc8dab5688"/><file name="Cc.php" hash="32d47c4e0ca2a4351931c9dbe8aa9097"/><file name="Ccsave.php" hash="2dba3d79d5bb3d52a651b307a71c7916"/><file name="Checkmo.php" hash="b4bb1c0aec560df4430ac6ac4519d889"/><file name="Free.php" hash="5124e7dd6dfc5922e744330aee0b06da"/><file name="Purchaseorder.php" hash="f912adbe0be4ee6e253faf5235aeada6"/></dir><file name="Observer.php" hash="7eb7f453a05ec64df921edca6a943b99"/><dir name="Paygate"><file name="Request.php" hash="0b0ab286f578e34158e888a632be5eab"/><file name="Result.php" hash="ac430ec777d776e957bf5e0675e14067"/></dir><dir name="Recurring"><dir name="Profile"><file name="MethodInterface.php" hash="7a5c2be97a5a381c3985a8d8e4e5a001"/></dir><file name="Profile.php" hash="5eb791e3acb4b95f51fed05743fd3ee8"/></dir><dir name="Source"><file name="Cctype.php" hash="ba11e8b19f705ab4928683722ec3d1c6"/><file name="Invoice.php" hash="9dcd17eda0df7b4432eb878bd096a92a"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="333585cb2d2317233c01aa3fd498fe9d"/><file name="config.xml" hash="d537f055d6791dedb25aa002498469b6"/><file name="system.xml" hash="73e980e72c76624ce84007acee61b628"/></dir><dir name="sql"><dir name="payment_setup"><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="59bf49af8807915cc8a7f8938b339111"/></dir></dir></dir><dir name="Paypal"><dir name="Block"><dir name="Adminhtml"><dir name="Settlement"><dir name="Details"><file name="Form.php" hash="943fd1a6109bc15b18f19f6673ee368b"/></dir><file name="Details.php" hash="31f3c41cea1eae8ce5d3017f3ec08660"/><dir name="Report"><file name="Grid.php" hash="1bc2951104d9eb349d5c48f99eab10bf"/></dir><file name="Report.php" hash="52b24a25ae41bf008036d935b32fa9fa"/></dir><dir name="System"><dir name="Config"><file name="ApiWizard.php" hash="8864cda15d76c91bc199553bc93254bf"/><file name="BmlApiWizard.php" hash="43141332d0e47f6c899dc2a4ec84c459"/><dir name="Field"><file name="Country.php" hash="2ffab6c627e84d1d1cc7d32e7872bad8"/><file name="Hidden.php" hash="c40f5e71f2ab8eab783a47ac9fcd8235"/><file name="SolutionType.php" hash="40d3c97492923a4fadda2d04891c79bc"/></dir><dir name="Fieldset"><file name="Deprecated.php" hash="2b5fa55674bb53c7ff2ddd9510b38a28"/><file name="Expanded.php" hash="a6a591981f4849100acf12392dd115a1"/><file name="Global.php" hash="717a39f6f8403902306edf4277951864"/><file name="Group.php" hash="44b47e18e1db70b5a978df90b4a57dba"/><file name="Hint.php" hash="c5f825fab528b4a397bf307d9e3a78e6"/><file name="Location.php" hash="07de7b09618d77526c79efff936f1cf3"/><file name="PathDependent.php" hash="3ff75723b61567049b44b010d2ef7685"/><file name="Payment.php" hash="fce97c4954900e60b30733462dd6607d"/><file name="Store.php" hash="e399e625dc5588fef17ed2f241db3b3d"/></dir><dir name="Payflowlink"><file name="Advanced.php" hash="529de1707a1fdb01ad10dbe4d0683369"/><file name="Info.php" hash="657f8befdf7798c3615403c14cd06bc4"/></dir></dir></dir></dir><dir name="Bml"><file name="Banners.php" hash="f9760a8b10a2b8c1c200e32ee50ca0da"/><file name="Form.php" hash="399187c36c5355e76e57bc69f57139e7"/></dir><dir name="Express"><file name="Form.php" hash="4a7d8f578a58dca6a53b7c2087fa1d82"/><dir name="Review"><file name="Billing.php" hash="8317d350dfe6ef3fef169f359c80f623"/><file name="Details.php" hash="575c3382e55db9c3a31e6ed8554ac2ea"/><file name="Shipping.php" hash="defc7869be7f634d8228bd51e625278d"/></dir><file name="Review.php" hash="be9ecaddb367e9bfa889e93e9374a70b"/><file name="Shortcut.php" hash="0da5a135a12055bdb899d15e911093dc"/></dir><dir name="Hosted"><dir name="Pro"><file name="Form.php" hash="6b54945810ac593cf1e3f106109b8374"/><file name="Iframe.php" hash="e8742903bcb9e4825b28bd91d0a41f8c"/><file name="Info.php" hash="14e3192fb955c3f6d4b6303590d1d7b8"/></dir></dir><file name="Iframe.php" hash="7e68e970303d8018208ab794439af280"/><file name="Logo.php" hash="96c385824a71b8d7dab7a88acfdd2d56"/><dir name="Payflow"><dir name="Advanced"><file name="Form.php" hash="4b824bca36d5a89e291217282dc716e1"/><file name="Iframe.php" hash="c65848b435a4a734aaca4062fba9af3b"/><file name="Info.php" hash="27d34399d6e3b3d0a22f1d686018d951"/><file name="Review.php" hash="52fd78714986a6367133f38368519e62"/></dir><dir name="Link"><file name="Form.php" hash="f284cd98f12f4916ca7f7a1cf176a6dc"/><file name="Iframe.php" hash="ccd27737b93296e02fd2ef8b92547c27"/><file name="Info.php" hash="e1fb0c2e5e690007f4dde584c07e62b4"/><file name="Review.php" hash="76dfb1d8d1e97c602303cb065147a24b"/></dir></dir><dir name="Payment"><file name="Info.php" hash="f653755ab5d497405d60030cd38550b2"/></dir><dir name="Standard"><file name="Form.php" hash="9d7433a3ab3abd085827110fff1d323a"/><file name="Redirect.php" hash="9edb0937d0459a9d1cf30bfef9618051"/></dir></dir><dir name="Controller"><dir name="Express"><file name="Abstract.php" hash="d9f7906e11ab212b3b81fa5dc3f38dc3"/></dir></dir><file name="Exception.php" hash="42e83ea0a524e322ae29ffce6afff0a6"/><dir name="Helper"><file name="Checkout.php" hash="26db733a6331cb9b7da81bea1798c9df"/><file name="Data.php" hash="854aaa4dc2a886f395b220b4f8c98851"/><file name="Hss.php" hash="4c0e7a330baec9548dc6b051d2174db3"/></dir><dir name="Model"><dir name="Api"><file name="Abstract.php" hash="853cf7ffe16c382efad46fb290cf59c4"/><file name="Nvp.php" hash="9a1ee7b7e52006aa40b11c34645705c3"/><file name="ProcessableException.php" hash="1064f915485c3e5d7d449c0155979583"/><file name="Standard.php" hash="2a83ec089b13c9f6001151c3eadc17b9"/></dir><file name="Bml.php" hash="d62d2a41e8efbf9cb5e62fecc077e4e1"/><file name="Cart.php" hash="f3db65cf7e0e8144eea161e5d373970d"/><file name="Cert.php" hash="1b0788670cb85bfab85d7c9b734cf2f3"/><file name="Config.php" hash="15c04141ed3d32818c38a260ec19bfbd"/><file name="Direct.php" hash="a5257cfa4d5f3a8a37f1a0f41839a6c3"/><dir name="Express"><file name="Checkout.php" hash="3d670375fec8751c7fd0d5c51774b5b8"/></dir><file name="Express.php" hash="3ab66ca2f5c3eaa3d0ede96370ac8e73"/><dir name="Hostedpro"><file name="Request.php" hash="7803af9165f870a26fe55ed0e5304eca"/></dir><file name="Hostedpro.php" hash="32987cfd97eac02ec8427c33030bd7f5"/><file name="Info.php" hash="673aa7caf2e8ed45789f7a73f702512d"/><file name="Ipn.php" hash="6e41d2ec1abdcdae52de0f541f8ceb58"/><dir name="Method"><file name="Agreement.php" hash="37133725de519922babdc325eeca5c6f"/></dir><dir name="Mysql4"><file name="Cert.php" hash="3e50ad315820151832a91a7cc81e0283"/><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="220a8ae1369406bd42c0f539494338cd"/></dir><file name="Row.php" hash="69a7309359db488b67d07b1d4fe4b3c4"/></dir><file name="Settlement.php" hash="01355aa6b6fe1ccbb351801dea7c3259"/></dir><file name="Setup.php" hash="7f12d0cd81f3871df62837cd55e1412b"/></dir><file name="Observer.php" hash="a45ae1a8f93adec22fc360186222b5ab"/><dir name="Payflow"><file name="Request.php" hash="44a4b60d484872a42b57bbd80d18dcab"/></dir><file name="Payflowadvanced.php" hash="d35b51c8a16527be09a2d01c9d934fd0"/><file name="Payflowlink.php" hash="d666697ba0cbe6f9416e845959f8542e"/><file name="Payflowpro.php" hash="156c9a6f7aa845df2066ace07ef89c0f"/><dir name="Payment"><file name="Transaction.php" hash="f2f56d3a0cb7c6e9651876122f4fa4de"/></dir><file name="Pro.php" hash="c8e1d2b03360c7f72de2ea6f9d808594"/><dir name="Report"><dir name="Settlement"><file name="Row.php" hash="c42f00ca8183f901742b3a7777c4f1a3"/></dir><file name="Settlement.php" hash="a3c27c3ef2e4d6b5960a79da0beca709"/></dir><dir name="Resource"><file name="Cert.php" hash="b6dea9e13029a42bd3d49f2502a42269"/><dir name="Payment"><dir name="Transaction"><file name="Collection.php" hash="25c817d238602fab9d9327de023ddcfb"/></dir><file name="Transaction.php" hash="7525357211b299e0a8455adac883b886"/></dir><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="d5e957f951b99ac2dd4fd7b70be46008"/></dir><file name="Row.php" hash="6e3a32b786fbd22b2156643e96e66231"/></dir><file name="Settlement.php" hash="fb84007539707028d79eb6d7d5108c11"/></dir><file name="Setup.php" hash="c6cb9fd182492d7df0c0d067a39473db"/></dir><file name="Session.php" hash="25ca7d53d013f0b0f2bc69a6087a413d"/><file name="Standard.php" hash="eadbe724e3d47448b40bd48044bf886b"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Cert.php" hash="9d128f09fe873cf0b1ea41f3f30f4bfc"/><file name="Cron.php" hash="d5f128f029d1c0ba2f334f5c549dbc75"/><file name="MerchantCountry.php" hash="7c9acac0ae45a6c57ec89726d8a7f394"/></dir><dir name="Source"><file name="AuthorizationAmounts.php" hash="afaa58d50abf29bd79274d7823b84543"/><file name="BmlPosition.php" hash="71b9471ae79adbcf6165119f56b1a314"/><file name="BmlSize.php" hash="c6794e9bd317969a391f18fba0a8a9d6"/><file name="BuyerCountry.php" hash="6f82dd2cb4e1a881459cf2f851f1512d"/><file name="FetchingSchedule.php" hash="6b80b1b53e5a7c2db35bdfa6c754df6d"/><file name="Logo.php" hash="3a58193ab5ed076ce6286179fc4ec80b"/><file name="MerchantCountry.php" hash="48bb537fa3023995b841e58686ebecb2"/><dir name="PaymentActions"><file name="Express.php" hash="e8d3100896ab6279bde84b9cc50fade5"/></dir><file name="PaymentActions.php" hash="94cc301d1ee998781bd21573c56d8b92"/><file name="RequireBillingAddress.php" hash="c9b32d3278f246c75e252c85b87c8975"/><file name="UrlMethod.php" hash="b7dec1e93e7d2c08fbf019391690b25a"/><file name="YesnoShortcut.php" hash="50835466524574e594a9f572a0637e5a"/></dir></dir></dir></dir><file name="UnavailableException.php" hash="3ec714e8f5d5027c32975ec6d16f110f"/><dir name="controllers"><dir name="Adminhtml"><dir name="Paypal"><file name="ReportsController.php" hash="10dc0d85d2087037e39e9bf380d763b0"/></dir></dir><file name="BmlController.php" hash="31ecd5f6b28d6a96a8c1b64a11bc84c6"/><file name="ExpressController.php" hash="95f3525ed328039f38291df86dae3c29"/><file name="HostedproController.php" hash="d7cd59e1fbd59a9702228a792bb02341"/><file name="IpnController.php" hash="1585633541488a4ff26be867e10b8102"/><file name="PayflowController.php" hash="eef2ada71c05c92234b044e1705091a8"/><file name="PayflowadvancedController.php" hash="f4dad4ab0e1b288cf8ac0481398b5f17"/><file name="StandardController.php" hash="40d81bd725bb66e2e4dd7944aed5d355"/></dir><dir name="data"><dir name="paypal_setup"><file name="data-install-1.6.0.5.php" hash="16d27f5072c11de73cf19438769d46e1"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="1ddb866b5fda22aef57d9e6f27293e41"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="6f06b0f0389f11480fd31e9fb85afd96"/><file name="data-upgrade-1.6.0.5-1.6.0.6.php" hash="9daed402dc30188c642561d5da250afa"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="27a136b11e33a71fc995b5e39283a223"/><file name="config.xml" hash="8a431563a9ff24fd00fe56597778e292"/><file name="system.xml" hash="e9573182c66efd1c0db47d44594b903c"/></dir><dir name="sql"><dir name="paypal_setup"><file name="install-1.6.0.0.php" hash="cf384731360aa321869c23ea8c6262bf"/><file name="mysql4-install-0.7.0.php" hash="fb088a2d9879d6717fe7d733b24a4535"/><file name="mysql4-install-1.4.0.0.php" hash="fb71462488ba2df5a684898d4ca755e1"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="a1ede75a2e0ec1580bb74edfcb864a6d"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="f9ac7626e645092c7d978880dd94b8d8"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="ace3769cd4317e84e9d67829835e3235"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="3b3def86d87adbda44acb5918924b1b2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="8e7b965c1b036cebe91e03edf4cccfd3"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="f16c4e0ae70d3115275a0a9e37d5a87f"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="15a2caa712db43590b6146184b65d5e2"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="aa71a5a0229015f44cac2fc6eadb7f70"/></dir></dir></dir><dir name="PaypalUk"><dir name="Block"><dir name="Bml"><file name="Form.php" hash="1f9333136682dc8a31339858005ec546"/></dir><dir name="Express"><file name="Form.php" hash="88a4955df3a5475d0606d8031097e093"/><file name="Shortcut.php" hash="7233a1c4e03ac8410d52d99b06ccebb8"/></dir></dir><dir name="Helper"><file name="Data.php" hash="d5fbb6590a6bc2c779d083574373aa55"/></dir><dir name="Model"><dir name="Api"><dir name="Express"><file name="Nvp.php" hash="d8b04d57dc25cf8b6665f03d2a1be06c"/></dir><file name="Nvp.php" hash="38db2b5abaee5b221bab3db7ef771299"/></dir><file name="Bml.php" hash="679a28c0dbb409617820ffdd18f7cd64"/><file name="Direct.php" hash="9957d2d79c133cd123b3be3e78989138"/><dir name="Express"><file name="Checkout.php" hash="83102d7294cbc2c07b2689125793b1ba"/><file name="Pro.php" hash="8ae7abbeed2c6ec78ad6f3389c2e999b"/></dir><file name="Express.php" hash="5b2718de3bf92a445c01c9f8046e88db"/><file name="Pro.php" hash="9af4a3524ab19d522cc4a16c7aebd889"/><file name="Session.php" hash="e9588933e26fc8c80e51476e889ab6b0"/></dir><dir name="controllers"><file name="BmlController.php" hash="deb635b1c700214db52fe4fda7e319c2"/><file name="ExpressController.php" hash="e3d9b7ac163b37cdaee7521bc6a53085"/></dir><dir name="etc"><file name="config.xml" hash="a03e54b4588f8c5fea00138d1e42f354"/></dir><dir name="sql"><dir name="paypaluk_setup"><file name="install-1.6.0.0.php" hash="b93205d0a10e1908eb6dc2ec5e6f2742"/><file name="mysql4-install-0.7.0.php" hash="504f997c41748c227273773bec0c3e67"/></dir></dir></dir><dir name="Persistent"><dir name="Block"><dir name="Form"><file name="Remember.php" hash="94f49b0d45c5e369d5d30b77c33ed683"/></dir><dir name="Header"><file name="Additional.php" hash="546b107bb5c0b5b1a3fa673e11caee9b"/></dir></dir><dir name="Helper"><file name="Data.php" hash="8bd90637e4e896351fa58084135016d7"/><file name="Session.php" hash="88fca3bb462e6d785c66d3ae2dde9a84"/></dir><dir name="Model"><dir name="Observer"><file name="Session.php" hash="ccb74d67b42504aa95ef599053ca91dc"/></dir><file name="Observer.php" hash="839c67becc6407533e0da7a95ad3f965"/><dir name="Persistent"><file name="Config.php" hash="7126ed3ceef9579a2dc1e28299e4a247"/></dir><dir name="Resource"><file name="Session.php" hash="a2a2d5e75095da58c9c81e07b2c949a2"/></dir><file name="Session.php" hash="0b2d41e85d7549aa28d551d691e32ce4"/></dir><dir name="controllers"><file name="IndexController.php" hash="372173d8b96a211f01f8ed64c61349bc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="6f8b408461a312be90b93e7961042c2d"/><file name="config.xml" hash="bd0b27ed57da2ae34280ef3037076d4d"/><file name="persistent.xml" hash="a0e87bf517504b97eb701e32c17471cf"/><file name="system.xml" hash="076afa82bd518ad235c0dab39ea17310"/></dir><dir name="sql"><dir name="persistent_setup"><file name="install-1.0.0.0.php" hash="e5656fdbdacf94b68b51e39e9636fc70"/></dir></dir></dir><dir name="Poll"><dir name="Block"><file name="ActivePoll.php" hash="254e4c67b627e429206f588e89cd7993"/><file name="Poll.php" hash="14ef393cbb51b21c0da136c249a2f06d"/></dir><dir name="Helper"><file name="Data.php" hash="28ad5ee2e890add5454670357cfb1f4d"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="896656db7f0ceebf41866847db845dff"/></dir><file name="Answer.php" hash="cb3a15c456156ceae68b7a6bf4d34e5f"/><file name="Collection.php" hash="a8c7446cefbbdfcc724780f91976da85"/><file name="Vote.php" hash="b0b9d43bb5b721cd34732920e93c14b2"/></dir><file name="Poll.php" hash="ba6549fb378c210139cbae5511e05171"/></dir><dir name="Poll"><file name="Answer.php" hash="8b2deff169e661a9acf8e82698400515"/><file name="Vote.php" hash="ba7582e4b60d332d54a9888c68b79c35"/></dir><file name="Poll.php" hash="0f646670b02e0a28e9d33fd4ee0c547c"/><dir name="Resource"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="ec17b425f80443f0a1de9ff678d487d0"/></dir><file name="Answer.php" hash="ad9fe830786ea59a04bb21144f05c3ab"/><file name="Collection.php" hash="a375e13a62d37f90b418b0781180e4cd"/><file name="Vote.php" hash="b07328698520b5fa6b04086948365f60"/></dir><file name="Poll.php" hash="a6e7382a68703fd3818de79a25035a79"/></dir></dir><dir name="controllers"><file name="VoteController.php" hash="808b67d06bffe3532ae85d8351fee8c4"/></dir><dir name="data"><dir name="poll_setup"><file name="data-install-1.6.0.0.php" hash="a49d377281c50ee4e343c08050b09a17"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="506e81b1176a12e8954cbccf238b69a9"/><file name="config.xml" hash="d5169d78910aa37b8549ce35eef7963a"/><file name="system.xml" hash="6165fc5ad861d8348ae7a2d22bb67823"/></dir><dir name="sql"><dir name="poll_setup"><file name="install-1.6.0.0.php" hash="0290aac27bab616ccee4e881d245743d"/><file name="mysql4-install-0.7.0.php" hash="dd6baa3e698e92912a842dd48dd52a59"/><file name="mysql4-upgrade-0.6.0-0.6.1.php" hash="2c2ac1b2ed8159e887df907e40578908"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="39a968ab7cf9c54ce43b5fd076b1f17f"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f68feeafc6b066c87f3b3f82e0f5f2dc"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="58f6256165abb574299497e6bef09626"/></dir></dir></dir><dir name="ProductAlert"><dir name="Block"><dir name="Email"><file name="Abstract.php" hash="180466a4e42fa7b00ec4c167ab84cb71"/><file name="Price.php" hash="199022e844eec73d620c776d411f141f"/><file name="Stock.php" hash="a2a8f094f28e0546d5eea0ce746b29bc"/></dir><file name="Price.php" hash="d2ea30eee3cf0a3e5c4084ecf836102a"/><dir name="Product"><file name="View.php" hash="30d336f7b5fbe5a6e071f452d03c7629"/></dir><file name="Stock.php" hash="f88befba6f33ddf8b9479b927e030236"/></dir><dir name="Helper"><file name="Data.php" hash="afc9d024257d6e19e97adef35d1bfd6f"/></dir><dir name="Model"><file name="Email.php" hash="77d9e1f754c75e0f78468f996ce57d2b"/><dir name="Mysql4"><dir name="Price"><file name="Collection.php" hash="6964afdff4afd3066bc4a6732b52df90"/><dir name="Customer"><file name="Collection.php" hash="29c4afe926176cbd533ca9ee2bd02c13"/></dir></dir><file name="Price.php" hash="1bda8f4a3da6e4329ace884601c9741c"/><dir name="Stock"><file name="Collection.php" hash="593885fb2c4ea2d387394235036d1e4a"/><dir name="Customer"><file name="Collection.php" hash="64ffcce0a6aabc0a63746d06c9e17779"/></dir></dir><file name="Stock.php" hash="67e8dec9681a786c174aa18a0491a613"/></dir><file name="Observer.php" hash="b5366037ff21258e7e3946a1c6ddeb5b"/><file name="Price.php" hash="816eed25a1634ff354596aace36e3bc4"/><dir name="Resource"><file name="Abstract.php" hash="40974792395eb8b961d3b43bd1e0ddd0"/><dir name="Price"><file name="Collection.php" hash="f5bd6c2e575b884086c1d919b9f630e2"/><dir name="Customer"><file name="Collection.php" hash="993462038beef968c4e6a139c9a15083"/></dir></dir><file name="Price.php" hash="c34070d8f2e470cd8a36b3c237f0fa3b"/><dir name="Stock"><file name="Collection.php" hash="109d708f7f86755bcded9afa0cf63f25"/><dir name="Customer"><file name="Collection.php" hash="22db201e6257823f0a7e0d593e3bb086"/></dir></dir><file name="Stock.php" hash="b02fee2a39793c4f5f7b5b7db06b6967"/></dir><file name="Stock.php" hash="033eb55739192ccd341f8be23ce6490f"/></dir><dir name="controllers"><file name="AddController.php" hash="2eb24a257ad8497186b4d15bd1e4010f"/><file name="UnsubscribeController.php" hash="1afd4a2b49a7fc13ab2f8db53b4f2bb7"/></dir><dir name="etc"><file name="config.xml" hash="4cbd97dee3ea55e81c26af8dba7c062f"/><file name="system.xml" hash="8d41f470b63e3bbc9a69edebe21c245f"/></dir><dir name="sql"><dir name="productalert_setup"><file name="install-1.6.0.0.php" hash="f05a601521ddd5347019c0efae234404"/><file name="mysql4-install-0.7.0.php" hash="472fb607fe6444d41fb471d6f82198c7"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="97c9dc1b38d237b6bfaa354401b2db7f"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="9862ccaea6d1d41918d658cd689315ba"/></dir></dir></dir><dir name="Rating"><dir name="Block"><dir name="Entity"><file name="Detailed.php" hash="9808da6eb9e27b1ab3132a553df6be5f"/></dir></dir><dir name="Helper"><file name="Data.php" hash="4a42d0d980c4f23e0e9f293f5e370e52"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Rating"><file name="Collection.php" hash="fe89e510b4a91085104b57ba5e28868e"/><file name="Entity.php" hash="9e29aa9791199f8f73be37231a99de5c"/><dir name="Option"><file name="Collection.php" hash="39f52caa8737126f96cd3407972fe53a"/><dir name="Vote"><file name="Collection.php" hash="663731196577b76086678dbcbd6cee54"/></dir><file name="Vote.php" hash="5744e29099fe9f8323be25ab15f55904"/></dir><file name="Option.php" hash="08c0fd436f320fabdb961a60ebf425f8"/></dir><file name="Rating.php" hash="5e40ad3d9114673e8824e212a7b5982c"/></dir><file name="Observer.php" hash="abd07f006140cc5ec6c59cbd274a8460"/><dir name="Rating"><file name="Entity.php" hash="4412fc6a356e54e433ac0786abea94a5"/><dir name="Option"><file name="Vote.php" hash="2a6eb28fd1017fe0aa15a6a96ebc7787"/></dir><file name="Option.php" hash="d4bf99a32d4732da56a781659586d0fa"/></dir><file name="Rating.php" hash="0564cdbcd61e92649cebdd1c49d80893"/><dir name="Resource"><dir name="Rating"><file name="Collection.php" hash="011f863b98c153de1f941f51ab6a447b"/><file name="Entity.php" hash="685f1ff9b51d0ab69ec43d6d87fdadce"/><dir name="Option"><file name="Collection.php" hash="87e167b305f17900c865da5a9e387492"/><dir name="Vote"><file name="Collection.php" hash="8b51efd07ce00578ee6086d7dcac0de4"/></dir><file name="Vote.php" hash="c48b18e451922310aee15a2c7ba35ccc"/></dir><file name="Option.php" hash="807c82864579de3ec167cee2ce262114"/></dir><file name="Rating.php" hash="3e26013cc1074178421b936a6189c582"/></dir></dir><dir name="data"><dir name="rating_setup"><file name="data-install-1.6.0.0.php" hash="8a98ae770970c8d7dd21c231a154c39b"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="3f7fce2cf5ad8f0fe05a391983f3dd36"/><file name="config.xml" hash="71a51d65f89a44fcb50996df3fbfd78c"/></dir><dir name="sql"><dir name="rating_setup"><file name="install-1.6.0.0.php" hash="b18a5da3ca872ed6b85c27666d28ed15"/><file name="mysql4-install-0.7.0.php" hash="a13b20061c25638ca42d7e0853de62f7"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3b33707e3f24362cf58962779fc72c93"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="8e1ffbea5a4c7d90120295935b1ce914"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="3cf83182ef097d07619d7751e5f37add"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="77f60eacd24bc10f17116eafab1a155f"/></dir></dir></dir><dir name="Reports"><dir name="Block"><dir name="Product"><file name="Abstract.php" hash="fbbb106c64faebf13fb51659041a6d34"/><file name="Compared.php" hash="0a39af19b20bc600864888aa77fbe09b"/><file name="Viewed.php" hash="436427d1849c3cf97761c805f33ca66c"/><dir name="Widget"><file name="Compared.php" hash="d8f42dd14dd3d002c33f630195fa9ece"/><file name="Viewed.php" hash="24beb247253ee60d03647e1d324051bd"/></dir></dir></dir><file name="Exception.php" hash="da8b99dfb486b75b46a9743a2732fb27"/><dir name="Helper"><file name="Data.php" hash="3eb61f32253af1804fda358dc1f227d3"/></dir><dir name="Model"><file name="Config.php" hash="cc663fe325525f348d7574a5b5c0c7d2"/><dir name="Event"><file name="Observer.php" hash="61bd0e764cd02c42faed676992821589"/><file name="Type.php" hash="5f73ac0e09697a704c3e6e9f5be95e25"/></dir><file name="Event.php" hash="092ed40e2e6f018544afd1d733d83d12"/><file name="Flag.php" hash="d4643e512bfba12c98a4f9603caa81fc"/><dir name="Grouped"><file name="Collection.php" hash="97d1d5b0f8d7da4a9edcfea6113604bc"/></dir><dir name="Mysql4"><dir name="Accounts"><file name="Collection.php" hash="1c1875d2c084f77c78fe97ca52b79fdd"/></dir><dir name="Coupons"><file name="Collection.php" hash="9c3b6b829a75ad8813b4132255f61456"/></dir><dir name="Customer"><file name="Collection.php" hash="b5c9669ce74a8877ab4a593d2b82919a"/><dir name="Orders"><file name="Collection.php" hash="7f47371908db9f5b77eadf7e988cc824"/></dir><dir name="Totals"><file name="Collection.php" hash="fade9685c8351201c224e4c6fe701bc6"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="83b5ed1349035ef06e10d4b5e92965f4"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="71a5338b1dd71ab110e180693457c8b4"/><dir name="Type"><file name="Collection.php" hash="b7f8318c3d8d5b504e55c2b98710eb6c"/></dir><file name="Type.php" hash="1f79da768c9c15a678f4049e011a646f"/></dir><file name="Event.php" hash="371242c785456ee36d6b5f49c08cd58a"/><dir name="Invoiced"><file name="Collection.php" hash="8664915953e0e451e5681acd1d6acc7c"/></dir><dir name="Order"><file name="Collection.php" hash="90dca9d9d48aaa82609643d712f4cda5"/></dir><dir name="Product"><file name="Collection.php" hash="fe950d67d51a6ad03681a89f1234a96c"/><dir name="Downloads"><file name="Collection.php" hash="3cba0533eb82c653654c5221d669447e"/></dir><dir name="Index"><file name="Abstract.php" hash="20710b44e6b9037a8bb1921f2b1b0c18"/><dir name="Collection"><file name="Abstract.php" hash="7437c80fbaaeb146ac119e9c414bdb69"/></dir><dir name="Compared"><file name="Collection.php" hash="38e9a0bdc91f9ee787009c28391ac670"/></dir><file name="Compared.php" hash="cb8512a55702be7c5b8c57222d8368ca"/><dir name="Viewed"><file name="Collection.php" hash="a33c636144939f7a0d6f2f4c99c9902b"/></dir><file name="Viewed.php" hash="1e7df154169d1c5275f7c270e22eb968"/></dir><dir name="Lowstock"><file name="Collection.php" hash="87bbd2c5813d078ccba23ee95e0b3bf0"/></dir><dir name="Ordered"><file name="Collection.php" hash="a32ab0e3766f913c96bb31e23c886849"/></dir><dir name="Sold"><file name="Collection.php" hash="007ede980f1829d022fb7b82124bf1ca"/></dir><dir name="Viewed"><file name="Collection.php" hash="d8eafef620e8eaef0a92b09c1056263e"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="34ed9230ae3905a50f828367e8556e6d"/></dir><dir name="Refunded"><file name="Collection.php" hash="5b03550cb6210c7194e329e5ed6afd79"/></dir><dir name="Report"><file name="Abstract.php" hash="fe9ea104135ee784228e9e1d7041a4f8"/><file name="Collection.php" hash="e5f5c13c0665830c9f412d49191051a3"/></dir><dir name="Review"><file name="Collection.php" hash="2a552c29e05091838ab8b10c866ee950"/><dir name="Customer"><file name="Collection.php" hash="5db13577519aa4fc48efff97693dd14b"/></dir><dir name="Product"><file name="Collection.php" hash="91776a3d21d06a39eaad123c14f2a249"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="33a1cd3f1acb06fe961e76ea73a5de35"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="a406d4470313dc54bcbef3ac4bc57b06"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="6133ccd408135a10c3dea03daaf3dd87"/><dir name="Customer"><file name="Collection.php" hash="152b9938b82326f039cedb958e2ee381"/></dir><dir name="Product"><file name="Collection.php" hash="cba584af6f7be500dac1e2ae9342d7f8"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="0acbb61867ed4cd612efc2cf9c503ead"/></dir><dir name="Wishlist"><file name="Collection.php" hash="4956fe36f4ef4c15b221b28f581091df"/><dir name="Product"><file name="Collection.php" hash="6a984971a61d099a863e5da9a7a8d565"/></dir></dir></dir><dir name="Product"><dir name="Index"><file name="Abstract.php" hash="27e75129a3b08c2b5fca26666b6ab7f8"/><file name="Compared.php" hash="04b1522deb834562fc24a6016072bb58"/><file name="Viewed.php" hash="eb9059d85ba6a2d3ea80d2eba29f6755"/></dir></dir><file name="Report.php" hash="60dfd019b4ea4d0acdddb64f0694c059"/><dir name="Resource"><dir name="Accounts"><file name="Collection.php" hash="4982e3152643b7c968d623b713313041"/></dir><dir name="Coupons"><file name="Collection.php" hash="6f3bae38a02e87ea23e061dcee5a2c43"/></dir><dir name="Customer"><file name="Collection.php" hash="dab25524552120e7ab10aa75c0f93b78"/><dir name="Orders"><file name="Collection.php" hash="98831d00cb9641e2a27eba2f2e9079fa"/></dir><dir name="Totals"><file name="Collection.php" hash="d01b30ec7be167f0cc9a9a48df09e279"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="466eff8822604dea2fa565d96c344ae8"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="6da3c7f128649b505ff190ce398246b8"/><dir name="Type"><file name="Collection.php" hash="a35b69401fb0af2d7b2257b4233bd3ae"/></dir><file name="Type.php" hash="054341a8a2e76ba1458ba6e8ee1be69e"/></dir><file name="Event.php" hash="018c31f9f8943753a0d1ce63172d15f2"/><dir name="Helper"><file name="Interface.php" hash="3bd31b382726e0392b885a5f322447e3"/><file name="Mysql4.php" hash="253638c6aafcd69c441cf0c2f84773aa"/></dir><dir name="Invoiced"><file name="Collection.php" hash="5ee6a60eda1b71c8a5c78b44cef74637"/></dir><dir name="Order"><file name="Collection.php" hash="6ba25321a9f092a59bac1c5e3561a29f"/></dir><dir name="Product"><file name="Collection.php" hash="443cc87b3f1908bcc0a944240cc0c725"/><dir name="Downloads"><file name="Collection.php" hash="a758bc6f4fa03f158d479aad4dc7b8c2"/></dir><dir name="Index"><file name="Abstract.php" hash="0d323595b3c30649935dd0dd17b59e68"/><dir name="Collection"><file name="Abstract.php" hash="2ebf8565c843986fe327e6d404d27377"/></dir><dir name="Compared"><file name="Collection.php" hash="48160635cb831066a1dc4574fc7ab492"/></dir><file name="Compared.php" hash="55b2a8f1176cb40917bfc6638c175433"/><dir name="Viewed"><file name="Collection.php" hash="6ffb976b877d1a1a0be24b20fd0c61e4"/></dir><file name="Viewed.php" hash="630aa8cf7c3ca68768d580e8df4204cf"/></dir><dir name="Lowstock"><file name="Collection.php" hash="902074235d9a9a3d6561bb22f0c4a4ac"/></dir><dir name="Ordered"><file name="Collection.php" hash="6fa111930e34d63d7ceecc66fe82339f"/></dir><dir name="Sold"><file name="Collection.php" hash="54b0599ac7620ea644086362f3651504"/></dir><dir name="Viewed"><file name="Collection.php" hash="e9a68efb6044904da6e559be2066fc8e"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="b17fdfa1934eec92cd8f6aabd116fffa"/></dir><dir name="Refunded"><file name="Collection.php" hash="ecf346d633194f286366e42fc77dbce0"/></dir><dir name="Report"><file name="Abstract.php" hash="4cde830115d9a4118205ef7a18678615"/><dir name="Collection"><file name="Abstract.php" hash="4295a90f9668e10c8323c4e9faf21b01"/></dir><file name="Collection.php" hash="e4611e41c7bc8482ade61c297665934b"/><dir name="Product"><dir name="Viewed"><file name="Collection.php" hash="ec638f6e6e535da277be4a3dfe00e5fa"/></dir><file name="Viewed.php" hash="b28454c797ed92051c70c2ae1a285049"/></dir></dir><dir name="Review"><file name="Collection.php" hash="0ca229c34293ed9c055d89af7ee5769a"/><dir name="Customer"><file name="Collection.php" hash="e228155ddc14b37135978c74110d4bf6"/></dir><dir name="Product"><file name="Collection.php" hash="d28988f84e60eb66f80a9116505f18f7"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="101977b37120e847295271c403fb54a1"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="c862f140f24a96f9e985bbf489acbeea"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="6970cb166f35a637027099c8c12e5ca4"/><dir name="Customer"><file name="Collection.php" hash="1579b71d00b8f73a7ffc536d58cdcb0f"/></dir><dir name="Product"><file name="Collection.php" hash="50b41f26ed827217c356a073fb6202f8"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="2e6ff63106cd7a4c785bcd554bfaa885"/></dir><dir name="Wishlist"><file name="Collection.php" hash="f777eae8af507917bcf75527b4c49b3a"/><dir name="Product"><file name="Collection.php" hash="a33471d2b24111d033b6af5872709f6f"/></dir></dir></dir><file name="Session.php" hash="fb5495f724e51d25697d8a0ba415a609"/><file name="Test.php" hash="87799b1b2bb7b6e35c6a40bdd12184b2"/><file name="Totals.php" hash="ceb6c34be077bc4b4c05054260649a28"/></dir><dir name="data"><dir name="reports_setup"><file name="data-install-1.6.0.0.php" hash="e81bcea0ffb79eb52fc86390c70e3979"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="ebd93caf512ee24432a0b0128c51b359"/><file name="config.xml" hash="3b4dfb231a0c6f6247718dc9a51de887"/><file name="system.xml" hash="debcc50171828ac2ad584cd3eb7e2580"/><file name="widget.xml" hash="daa76297cac646560c81c96edfdecaac"/></dir><dir name="sql"><dir name="reports_setup"><file name="install-1.6.0.0.php" hash="acb1917838f06ffe0cde8a4fcbc4c7f2"/><file name="mysql4-install-0.7.1.php" hash="f54c4c6a2cc2533c99f289b292110f10"/><file name="mysql4-install-1.5.0.0.php" hash="a878056ebb99e1d43bacc6e603579d00"/><file name="mysql4-install-1.6.0.0.php" hash="cdfbd790576b26ee8eaba4d9532e737f"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="7429a8261bf298645c9a5c0b47a607ee"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="dc72f48bd7ea4ef83542b53f35c42183"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="f6275eb1825bf13bae28ad8503f35a51"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="9c0b5b8aeda472848a66affdbd8a7eef"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="819ab599a4fe00b60962ee72e3fa30bc"/><file name="mysql4-upgrade-0.7.5-0.7.7.php" hash="c0b72c3aa67011f1a473c269f5210ac9"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="deeb78c94d0c4b97e51422331e2b46e7"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="f205868e82f73bca1ece7da016a05f12"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="45e56a55e8e221eb55a2d01260df08d2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="4e59fb21fce5202b290c7f240edb674c"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="e52873b0b0819e87f795046d2f6bdb19"/></dir></dir></dir><dir name="Review"><dir name="Block"><dir name="Customer"><file name="List.php" hash="fbdb9d239a7106325585c41a74b6b162"/><file name="Recent.php" hash="46793e36c3284f03036eb5c5cf5cd893"/><file name="View.php" hash="5bfa491bc2f17965b52b5fcd0082ec26"/></dir><file name="Form.php" hash="2e1a0e92226543cff0e99f886c6ab246"/><file name="Helper.php" hash="936c3ef7c2f6f9370ae75839be4c6f13"/><dir name="Product"><dir name="View"><file name="List.php" hash="af0e35e47b2c2f7fe4f4fa6049515f31"/></dir><file name="View.php" hash="ab25fd0e915cba28e5741aca2e4156fe"/></dir><file name="View.php" hash="7a07751a6aab8883f2fc629f4b3f0788"/></dir><dir name="Helper"><file name="Data.php" hash="c48d607399b2fbe23300301537b036f6"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Review"><file name="Collection.php" hash="83fe47bc9aa743e7374c1f051761004d"/><dir name="Product"><file name="Collection.php" hash="362ed01cd5a138ce481b00d0d0bae334"/></dir><dir name="Status"><file name="Collection.php" hash="f3d2dd3f3ae991c24670a6dee1968d8d"/></dir><dir name="Summary"><file name="Collection.php" hash="68d20fe99fb3f1158fc8dbef9e2ae21d"/></dir><file name="Summary.php" hash="fcddf4ec146f87d2f26a4ed66a58ae08"/></dir><file name="Review.php" hash="d6f58d2b1655e562b862578b045a3875"/></dir><file name="Observer.php" hash="540ca94b28cc4bd83f937ddbbde2b877"/><dir name="Resource"><dir name="Review"><file name="Collection.php" hash="e4a0bfb512fe55880670601532038b23"/><dir name="Product"><file name="Collection.php" hash="73d9da7ea7b6bb576dae492be4393419"/></dir><dir name="Status"><file name="Collection.php" hash="4fafa6b5c658d5beb8d6fb83e6edd38b"/></dir><file name="Status.php" hash="6c53ef509976ae173668d45fd7298f2e"/><dir name="Summary"><file name="Collection.php" hash="302a40923a6a3b65c27cf423760745dc"/></dir><file name="Summary.php" hash="6ec41019b27f5792b49fbecd7b7b16bd"/></dir><file name="Review.php" hash="1f363f6caa57bc0278dc95b0ce221e3c"/></dir><dir name="Review"><file name="Status.php" hash="377f94d597fea31818fb6dd80e735df2"/><file name="Summary.php" hash="09cc58b2f12f0b5baab54d06ce733749"/></dir><file name="Review.php" hash="5ec371c195aea1144276d247dca962f8"/><file name="Session.php" hash="cc0c43877594696daf90b8b5e97f4a24"/></dir><dir name="controllers"><file name="CustomerController.php" hash="397d011785901f734bad8514355b0edc"/><file name="ProductController.php" hash="dd45d26a559def55cace32cf14d34797"/></dir><dir name="data"><dir name="review_setup"><file name="data-install-1.6.0.0.php" hash="3e9cfb48530b5fd59a198fce28b7e838"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="c362ef135c844d96627451e2b2e239e1"/><file name="config.xml" hash="03265cae6f1cdb0459a182811e8774f2"/><file name="system.xml" hash="3ca3f96c86a2a3fcccbeb7eb60248efe"/></dir><dir name="sql"><dir name="review_setup"><file name="install-1.6.0.0.php" hash="fa1f25ad347fcd68907bb48a92ce24b7"/><file name="mysql4-install-0.7.0.php" hash="4b4614355d2343e0622cf6b55ccbbcae"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="fc12775106751910bd71ff087dddf6c7"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="ac880ce89f9ba0fd3816681b3278f62e"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="8360492e50256404cbc5da964faeba53"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="bfdddd2ff4f353170095057eee6cfa8d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="15faaea195ac780122bd8ea85d033180"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="ce99463545afcfd88550b33b3b874e87"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="c3130ca1398a1ac8d861a7cd7e40a14e"/></dir></dir></dir><dir name="Rss"><dir name="Block"><file name="Abstract.php" hash="cc31ad5349b3d152a7e0cddebaec4e37"/><dir name="Catalog"><file name="Abstract.php" hash="726d7cd2819cd8857fd7e9dc78627580"/><file name="Category.php" hash="e65c816201051ab640729c896688d07d"/><file name="New.php" hash="9fc9d2b5b7045eebe1c94b5d4faad766"/><file name="NotifyStock.php" hash="e9e164c65bfa33bfe0a8ee95e01cfc9b"/><file name="Review.php" hash="ddef1dd1a1a39a2dd9efdfc6e24c95e3"/><file name="Salesrule.php" hash="3ebb9ab8e2d2023645a9c54e54b06ab2"/><file name="Special.php" hash="f5eff97f4abc268a148c86dbabf7bd50"/><file name="Tag.php" hash="3d94c336311e9c7970e8d9be474cbd03"/></dir><file name="List.php" hash="0af069c7b12c06842a4400ab4b14e801"/><dir name="Order"><file name="Details.php" hash="a6ae5526db72457dee64381f8c272a8f"/><file name="New.php" hash="0e319778fa757dee8617f46c2e023436"/><file name="Status.php" hash="ec489d0a6434e94b0f379ac5184b8286"/></dir><file name="Wishlist.php" hash="bd61443c31a553e1e38dd866801efe26"/></dir><dir name="Controller"><file name="Abstract.php" hash="c5eb27eba9246b2fed64bbe3691e83a6"/></dir><dir name="Helper"><file name="Catalog.php" hash="de6650cbfd706fee0cecf4ef2120c25b"/><file name="Data.php" hash="4872f95820294bb1d86ae9db79cc6287"/><file name="Order.php" hash="a22c1fdc9e43240630f9fda94b2b9c60"/></dir><dir name="Model"><dir name="Mysql4"><file name="Order.php" hash="56207b0bb0eff8d6bb37f6ad7d081e4d"/></dir><file name="Observer.php" hash="a983a9071c01591f5953a2d78bbfa9e1"/><dir name="Resource"><file name="Order.php" hash="d88b41a90424438643f951a9a802aa88"/></dir><file name="Rss.php" hash="0ee42d3600e0b51d1bed80d03fbe1c76"/><file name="Session.php" hash="7ee609d4fe89a08c16955c6eeb39f180"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="0caf83f58b2b1fa4a2ea4813aae73fb6"/></dir></dir></dir></dir><dir name="controllers"><file name="CatalogController.php" hash="2b371c8110a407d423049a1d2836df67"/><file name="IndexController.php" hash="2b57ddcac1f5722ccad8b859e4be9f62"/><file name="OrderController.php" hash="2b452f0cddf06507899514543c6e03ae"/></dir><dir name="data"><dir name="rss_setup"><file name="data-install-1.6.0.0.php" hash="95316a42add6367a0afcc74b46116ade"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="ab2e6ccbbd51a80b25947d5db5af091e"/><file name="config.xml" hash="213cf7bc0350528c5fc63dbc2dc4e894"/><file name="system.xml" hash="a587557c11d778d767c04319ba09ed3f"/></dir></dir><dir name="Rule"><dir name="Block"><file name="Actions.php" hash="8527d1ca709d6c86d7cd35ecafcd2332"/><file name="Conditions.php" hash="dda8cd77e3b3528b8fc1bda8995e384f"/><file name="Editable.php" hash="57f08071e011d08ff49e64bd647a3cbc"/><file name="Newchild.php" hash="4fe32fbf0472a5cb15c2d3fc6e729731"/><file name="Rule.php" hash="1d58782b570adaa5c6e172c91f0f3dd1"/></dir><dir name="Helper"><file name="Data.php" hash="820eb25fd5b03ee2ac47a4d32da4ebd3"/></dir><dir name="Model"><file name="Abstract.php" hash="0e334f91ae2703ad7a3d5ecce656996a"/><dir name="Action"><file name="Abstract.php" hash="ed699ad6a37a404ce305cdcb35094c6b"/><file name="Collection.php" hash="ca0e77dc84ed99a2c00df39838d42ec5"/><file name="Interface.php" hash="fbf8148f637edeca14605e23d34cd933"/></dir><dir name="Condition"><file name="Abstract.php" hash="22b85203b9152db796aa82d5d623e123"/><file name="Combine.php" hash="00ba9531541416718fc898b374358e64"/><file name="Interface.php" hash="6bf7378dda343c6496e1a8d821dc912c"/><dir name="Product"><file name="Abstract.php" hash="11dea89ca226e9e27dcdbd3e2e5d0f6d"/></dir></dir><file name="Environment.php" hash="5ae41a6cd48afcf87f5849c9619ab378"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="67e0c3a73038663bc1ba468ab2773d58"/></dir><file name="Rule.php" hash="8d4f1dccc0b6920f3429d0c4db52705b"/></dir><dir name="Renderer"><file name="Actions.php" hash="687bff27756de727b12b416f7e835153"/><file name="Conditions.php" hash="c6a6865bf0d23a2bcbed83d67053bc22"/></dir><dir name="Resource"><file name="Abstract.php" hash="4a4ed5f7a3a74ce28115708eb46f8874"/><dir name="Rule"><dir name="Collection"><file name="Abstract.php" hash="4cb762737ddbe32872ed38bdf07dd6e8"/></dir><file name="Collection.php" hash="6079f3e5d38a6f9d476e5ad49aa14a78"/><dir name="Condition"><file name="SqlBuilder.php" hash="99e1da4401a45597c71e82b4420020a0"/></dir></dir><file name="Rule.php" hash="8d9116c0f91a9792e5d32c4c4cddeeb8"/></dir><file name="Rule.php" hash="a6793176072c406bd1bf82aa4168a305"/></dir><dir name="etc"><file name="config.xml" hash="71515fec86935cbdfc60e4bbeab032d4"/></dir></dir><dir name="Sales"><dir name="Block"><dir name="Adminhtml"><dir name="Billing"><dir name="Agreement"><file name="Grid.php" hash="731a6d4431089d673568fee25a1821c8"/><dir name="View"><file name="Form.php" hash="d55ed07a15a3a40c4e66c316070e56b7"/><dir name="Tab"><file name="Info.php" hash="751162977acc829a4c8239017fc9b445"/><file name="Orders.php" hash="bc2e902543efb90c0e8147513b683301"/></dir><file name="Tabs.php" hash="5dbf53911c137ffd1923856597f32080"/></dir><file name="View.php" hash="b1e643862e56043d27157df71a911427"/></dir><file name="Agreement.php" hash="678c4ca3fc6dcf8d2a910b44ed40ef9a"/></dir><dir name="Customer"><dir name="Edit"><dir name="Tab"><file name="Agreement.php" hash="18308f1ee681be8752ad64dfe687773f"/><dir name="Recurring"><file name="Profile.php" hash="f33d920bfe0ff8d41b87b524ffa90d6c"/></dir></dir></dir></dir><dir name="Recurring"><dir name="Profile"><dir name="Edit"><file name="Form.php" hash="54e253057108760b6c348e1ed5d2f9d1"/></dir><file name="Grid.php" hash="a0af24699ca5afd2ce23bd8fe683c9a7"/><dir name="View"><file name="Getawayinfo.php" hash="6d6904f661356956e5420e7a3a61f57e"/><file name="Info.php" hash="68a4ced850651d0619211358c71fd7ed"/><file name="Items.php" hash="45c9eea4d4d877e8c1621633dc88ca24"/><dir name="Tab"><file name="Info.php" hash="dd2030aadd0df31a58ffed0063ca8baf"/><file name="Orders.php" hash="66722b9e60959c911aa02ed582be90a6"/></dir></dir><file name="View.php" hash="65ce71535a6b4db9665d7c7cc1570cc0"/></dir><file name="Profile.php" hash="0884eb84dbd6b6aca480ea1a9af1e63f"/></dir><dir name="Report"><dir name="Filter"><dir name="Form"><file name="Coupon.php" hash="c868085bbec0d1c84b291b9c18390585"/><file name="Order.php" hash="dbbbab64d3f9266193b374c28a425412"/></dir><file name="Form.php" hash="b7d07bb6e94e68ac123678a2b85977bc"/></dir></dir></dir><dir name="Billing"><dir name="Agreement"><file name="View.php" hash="6b36d0ad7a47beabddc82f949a92e09d"/></dir><file name="Agreements.php" hash="7e78ea7b37c985cfe9bf2844ec3f5daf"/></dir><dir name="Guest"><file name="Links.php" hash="0899e8bb3c88457537d748acdf528896"/></dir><dir name="Items"><file name="Abstract.php" hash="dfabe87497fe5bf6dd80861e225adeef"/></dir><dir name="Order"><file name="Comments.php" hash="4aaa70b4d507cf69e9107230f39ed5c7"/><dir name="Creditmemo"><file name="Items.php" hash="7e786ba61574790c2d662a49ad33088e"/><file name="Totals.php" hash="6b2f159419d11a0e7a01a459ef9b8c91"/></dir><file name="Creditmemo.php" hash="6f1e6573c29b5742f4b1b0b83faa8e7b"/><file name="Details.php" hash="ae9b48d38abc9417ddc38bdd066bb38e"/><dir name="Email"><dir name="Creditmemo"><file name="Items.php" hash="e98c91a726a8cfc31a48058556b2c32f"/></dir><dir name="Invoice"><file name="Items.php" hash="4a459f1ac0d3f977416673b093e28d71"/></dir><dir name="Items"><file name="Default.php" hash="9d1ab96c68eae1aca379fd1d84049adc"/><dir name="Order"><file name="Default.php" hash="5b85990caed894dcf3db88284b230661"/><file name="Grouped.php" hash="7040147c2727c706b09b2aa288dbcd25"/></dir></dir><file name="Items.php" hash="d783506738f74da23e6adf93ab98b828"/><dir name="Shipment"><file name="Items.php" hash="0accfbbac76233b93d35c25ea69216a7"/></dir></dir><file name="History.php" hash="0e95c61fe0d84b3af13e20529942be72"/><dir name="Info"><file name="Buttons.php" hash="56f6c1a100d31d6c7859a7492aecfb83"/></dir><file name="Info.php" hash="262907ea31ba7fbc8985aee0f3005302"/><dir name="Invoice"><file name="Items.php" hash="ecf5652547ffdf624c3432ff1c78ce68"/><file name="Totals.php" hash="f49053546c5ec744d3cc2dbd5ad19883"/></dir><file name="Invoice.php" hash="6631f3550edde0d68b546cce8a9b203e"/><dir name="Item"><dir name="Renderer"><file name="Default.php" hash="0b70309d42e7278fa111f055dc01893d"/><file name="Grouped.php" hash="7adb3eca2aeb5171234ecb8418707aec"/></dir></dir><file name="Items.php" hash="7c5acad96992ab00488e157b557f4d3c"/><dir name="Print"><file name="Creditmemo.php" hash="7d1cb5fb5891168292dd28a5aa69d0ac"/><file name="Invoice.php" hash="e402b1b36280fd107c33a81a9a7b5cb5"/><file name="Shipment.php" hash="026470ae29503dcd21b09d427440f59e"/></dir><file name="Print.php" hash="bc4ea4880868c3ecddef053397f801ed"/><file name="Recent.php" hash="66e8882567122a953f642640d1a38a58"/><dir name="Shipment"><file name="Items.php" hash="ae4e4b77d96ef11241c071da7bb486f6"/></dir><file name="Shipment.php" hash="9cade979e6b84b18e2ff0727ddf2e8b9"/><file name="Tax.php" hash="50eff71972e3a8c0c83aa7fd801f6914"/><file name="Totals.php" hash="c8e155f695ba5ad9b4bf8498b61a2454"/><file name="View.php" hash="938f533f5a2baa8247a1e4dd896c57e5"/></dir><dir name="Payment"><dir name="Form"><dir name="Billing"><file name="Agreement.php" hash="8376c3e4025b7a2183bbcff925ff590d"/></dir></dir><dir name="Info"><dir name="Billing"><file name="Agreement.php" hash="2a6ae5346ecec19d6467d8fc3f049e6f"/></dir></dir></dir><dir name="Recurring"><dir name="Profile"><file name="View.php" hash="62fc9c5817b617f4c885de160fa77bd0"/></dir><file name="Profiles.php" hash="bc2e409f5c868e6308485540e2646371"/></dir><dir name="Reorder"><file name="Sidebar.php" hash="32f59b0b7e9d30ac235dfbc8ae6dd3eb"/></dir><dir name="Widget"><dir name="Guest"><file name="Form.php" hash="6955069b55666a18d7e8b8e33b4dd517"/></dir></dir></dir><dir name="Controller"><file name="Abstract.php" hash="fbef84194f2ccc32e3bbd73f44df8967"/></dir><file name="Exception.php" hash="7e81838388d96cc6968ee4b51bdcbd7d"/><dir name="Helper"><file name="Data.php" hash="3dc4037e0ee40d0341b5c7e79b37d91a"/><file name="Guest.php" hash="7430c8340b742c89f1b9df79ccfd6423"/><file name="Reorder.php" hash="64363e857d1d4f27c52b4a7c37633c9b"/></dir><dir name="Model"><file name="Abstract.php" hash="15c35a95af26282bc3415440d104c4c6"/><dir name="Api"><file name="Resource.php" hash="b6a6e3198dca54321c362e416c29bba2"/></dir><dir name="Api2"><dir name="Order"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="a9cd51c52b1fa29f93fd561c41ffb439"/></dir><dir name="Customer"><file name="V1.php" hash="ca81d1c423589c0ddb3f9f8c7a6a24a2"/></dir></dir><file name="Rest.php" hash="6497ac20229b978f7f23e89f53373c72"/></dir><file name="Address.php" hash="7a72bae899c9cd07e6add684ac29c342"/><dir name="Comment"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="a13ae1ad2c5747dcfbac1c8ece1b2c67"/></dir><dir name="Customer"><file name="V1.php" hash="92d399faa510a32aa3ddd63b15cb868a"/></dir></dir><file name="Rest.php" hash="b00787ff671d5cc7d9a05a35dc252c38"/></dir><file name="Comment.php" hash="0d883d8e594866d11f911e0f274aca7a"/><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8dd05e7819e578199076803c095ec4c0"/></dir><dir name="Customer"><file name="V1.php" hash="e142556d3204f557be2a06aec371ef50"/></dir></dir><file name="Rest.php" hash="7f6fa94e2ef5b8e4900c5f01c944c587"/></dir><file name="Item.php" hash="386e1c7c5366391e2583d359a3ed629e"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="56f48c0055845c6f30e52d196217972e"/></dir><dir name="Customer"><file name="V1.php" hash="5c610aaaf6a391086403970e0cdcbb6e"/></dir></dir><file name="Rest.php" hash="9559e10500e5ad5f961e1101617620a6"/></dir><file name="Order.php" hash="538a9c85f6469ab63c855a35528fde1b"/></dir><dir name="Billing"><file name="Agreement.php" hash="4e8ea0af2a7495649d8a95009f6e8a23"/></dir><dir name="Config"><file name="Ordered.php" hash="3a4be5b5224d6090674b2627d40b1e54"/></dir><file name="Config.php" hash="959cca427edc9c153e37659cb3997c60"/><dir name="Convert"><file name="Order.php" hash="1d901f03cf4b4334c6f7b72563f38ca8"/><file name="Quote.php" hash="58bb5963b286315939302ef204dadcfa"/></dir><dir name="Email"><file name="Template.php" hash="33194f93d26c4fa733d68d0757747191"/></dir><dir name="Entity"><dir name="Order"><dir name="Address"><file name="Collection.php" hash="a1d3de3d384ddb587c9d5a9deb499832"/></dir><file name="Address.php" hash="0c3d7bd2ac73e2782a5475ea661800e2"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="3e96c95aa215a7f8c79206f914b40f3f"/><file name="Child.php" hash="2282d7a3861e84186b093889514898f2"/><file name="Parent.php" hash="74c3a37546150dee9e60e74228de60a2"/><file name="Shipping.php" hash="70b7e2e3b01a6de90da6c1430510dfc5"/></dir></dir><file name="Collection.php" hash="1936546dbd1330260f70a6569f0dabfb"/><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="dde8b4f5973301eedcbf228dc900be9f"/><file name="Parent.php" hash="3d95b65278357577153c901a37068c57"/></dir></dir><file name="Collection.php" hash="f4b3e0be5100002c61eae38662e4ac3e"/><dir name="Comment"><file name="Collection.php" hash="83fec6b0ce33f8b056625d12b23b2594"/></dir><file name="Comment.php" hash="6fc6f75d606a8ffd015156a42243c193"/><dir name="Item"><file name="Collection.php" hash="abbbfad59483de496dedb3d52c7c7735"/></dir><file name="Item.php" hash="d19aaeee0f812bb6de3d2c7fe701d5e8"/></dir><file name="Creditmemo.php" hash="47ab866823475eaff8086191c9a5241b"/><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="95787d5da966da7a7cd5041fcb9df4f3"/><file name="Item.php" hash="9dcf7d662960b24ab43285ad3d32a2f5"/><file name="Order.php" hash="0e46c7858e143f022b1f4748598ae5d1"/><file name="Parent.php" hash="9a90a6bb7825245279a525898d553e0e"/></dir></dir><file name="Collection.php" hash="5a9fe5f7b03afeac3e274c74501b7817"/><dir name="Comment"><file name="Collection.php" hash="276b1a9138d6b99254c387c4208fa64f"/></dir><file name="Comment.php" hash="ddf9374110059a4a7a998b2efeaca355"/><dir name="Item"><file name="Collection.php" hash="a855f2ec27dbd06377b90894c4f57213"/></dir><file name="Item.php" hash="ca9f19d5344bcec195a9dd7ee4b86c09"/></dir><file name="Invoice.php" hash="a910c4b305b4c703385579bb2111f827"/><dir name="Item"><file name="Collection.php" hash="4c5a4c63df1370502e8181e303daf2d9"/></dir><file name="Item.php" hash="3ab0874949eb9211dd6b12d8e52ef7b3"/><dir name="Payment"><file name="Collection.php" hash="4b303fa1527c0ffb64b1f1b8f1661a90"/></dir><file name="Payment.php" hash="d904e88dd89fc16b14c32731e04ea5bd"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="f80aa21caab93911aafb8294bd6583b5"/><file name="Parent.php" hash="5b37ec538416fc102dab6135f6a69d63"/></dir></dir><file name="Collection.php" hash="5340c11df274aa920e2c00fba837905b"/><dir name="Comment"><file name="Collection.php" hash="795f343f4c93a7d1ab0b882afe0dc724"/></dir><file name="Comment.php" hash="0c0d15944721c2b917abec843911f60d"/><dir name="Item"><file name="Collection.php" hash="56978a6a80aaab02413ad45ac2c40c30"/></dir><file name="Item.php" hash="9e0cf544f51a2e9d06a567486f4aee9e"/><dir name="Track"><file name="Collection.php" hash="fc720726b0ec6cb32fa07f70273542d2"/></dir><file name="Track.php" hash="7f5171959b3c1f678eb5117d2ab8aaba"/></dir><file name="Shipment.php" hash="2e49e12ddbd605ba931aa388a6766287"/><dir name="Status"><dir name="History"><file name="Collection.php" hash="853b175b354164b46f87bf6717fa671d"/></dir><file name="History.php" hash="ee6ca00631be940e3c098df66237b4f5"/></dir></dir><file name="Order.php" hash="eb05b004590484129104413d04a3c601"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="9a2c760c600e33050ea97a2eedcf4cc8"/><file name="Parent.php" hash="d94644bd6198bf8f6436fe8291804e21"/><file name="Region.php" hash="8f13224e2a6251347aacb9903238ea8f"/></dir><file name="Backend.php" hash="8d4a77534dc423c6772697010523eaf8"/><dir name="Frontend"><file name="Custbalance.php" hash="9f1ebf6e9277a5fe2df3eac9c08126d1"/><file name="Discount.php" hash="473b55f052b6286a2bdbd5d96b0c56db"/><file name="Grand.php" hash="e44defdee69f52d289d91d0b82c844b4"/><file name="Shipping.php" hash="209f5ec87e9a49293b0d1ae6608720ed"/><file name="Subtotal.php" hash="07047c705f7a52fd7917852a58e4e92e"/><file name="Tax.php" hash="ee70db9daec07ee6ae8638b0e3f30507"/></dir><file name="Frontend.php" hash="45939010f0c761f6d4ae06e3ef58471d"/></dir><file name="Collection.php" hash="35deb968fc321e145a5c5eb83ce639c2"/><dir name="Item"><file name="Collection.php" hash="900b8a0389e7f419e03bdb713a533a4b"/></dir><file name="Item.php" hash="58776decc94a4edef4956e27b3ca6077"/><dir name="Rate"><file name="Collection.php" hash="6a17628c290dbc81c3027ddd715f644b"/></dir><file name="Rate.php" hash="8fc30443edbd5cfc340c95e71cbc9ceb"/></dir><file name="Address.php" hash="8639e86fe505ba92ef0185f4248e9621"/><file name="Collection.php" hash="3ff4299cdf7e767058119014c55b7a1a"/><dir name="Item"><file name="Collection.php" hash="4fb1440ad26709bdd75933d1eed92cb5"/></dir><file name="Item.php" hash="41ff5164f42c7b0be7c7ab04b28b4188"/><dir name="Payment"><file name="Collection.php" hash="bc6f8459aaede8d00b3ac69dba599d4a"/></dir><file name="Payment.php" hash="3f5564e9c0876ead6b73f51d2aa6f899"/></dir><file name="Quote.php" hash="010443001240db9f9a1afa57f99aa847"/><dir name="Sale"><file name="Collection.php" hash="7c6c98916e8304314ad26d6c12e5f102"/></dir><file name="Setup.php" hash="7c18b9ba2558d9f974b2a7bb3d061646"/></dir><dir name="Mysql4"><file name="Abstract.php" hash="a718e6a40264a07ead20c11432c325c6"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="d3b693b853558d3cf4039881358f9fb0"/></dir><file name="Agreement.php" hash="da7487a0059b3859c2bb7da9a9e81215"/></dir><dir name="Collection"><file name="Abstract.php" hash="490013f187634f6f4b71c1eb4a5a4db9"/></dir><dir name="Order"><file name="Abstract.php" hash="9db4faf82f4c663fcdad7694a26fdc37"/><dir name="Address"><file name="Collection.php" hash="fb7641f9428d0a48766a7f1a8dfc56f9"/></dir><file name="Address.php" hash="7b8718fe6db3696c2cb605c1f512f7e0"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="4a8a16eb96bbf7aaad8d8188fba60636"/><file name="Child.php" hash="14a2ce8c5af928d659a8e5cf34c83a1f"/><file name="Parent.php" hash="640243255577f17bb262a1bfb6eade84"/><file name="Shipping.php" hash="a4e69f8319ba726ae9791fdaac7a6958"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="9160a40971710f1adda20239693697aa"/></dir><file name="Collection.php" hash="9996c78cbe27e353bbcb1275e517d402"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="1d8520f9dc78e945b7f962f5fac9a24e"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="ef8475ab1d19ee8d8fa315d0aa295386"/><file name="Parent.php" hash="683bd8ae826a8f5383e5146eee4720cf"/></dir></dir><file name="Collection.php" hash="41214d1ae0247e6e3c5f33cfc6b6023f"/><dir name="Comment"><file name="Collection.php" hash="b29dc3ac5eef35d26b869843fff269c7"/></dir><file name="Comment.php" hash="7b7d0c8644dd21343adf7d7bf2cc127f"/><dir name="Grid"><file name="Collection.php" hash="a3d13012f105f22fe2aa00a6f151f030"/></dir><dir name="Item"><file name="Collection.php" hash="4148ad8bd82a520850a2d8712abab0c3"/></dir><file name="Item.php" hash="7984f74e36b28c8c11aaa6943f4473fc"/></dir><file name="Creditmemo.php" hash="988378bfee2b037626163ee5902078dd"/><dir name="Grid"><file name="Collection.php" hash="df27b27ef5085309a2c1fb1e8b168bd3"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="317af04acf0b7e69b1cbdd9e3d2faf32"/><file name="Item.php" hash="d0311aff201be97cb557d24fd3754750"/><file name="Order.php" hash="72d3835281c696b3b26928cd7dd278b5"/><file name="Parent.php" hash="a3ac62eeed1dd2f9fc631d07526d6c8d"/></dir></dir><file name="Collection.php" hash="db6d9a454f8f7538ecf7890ea7c2a047"/><dir name="Comment"><file name="Collection.php" hash="a53f5d21071a1b1e74d07d1a49cda0c0"/></dir><file name="Comment.php" hash="3b1e3baef7109740d614b7856dfe841c"/><dir name="Grid"><file name="Collection.php" hash="c351999b5b6c93d8bd1558ebe68e1928"/></dir><dir name="Item"><file name="Collection.php" hash="93d2e9d840b54dba20a78dd3ed9b77a9"/></dir><file name="Item.php" hash="a711548629d54d07e7ff3b9562337cc1"/></dir><file name="Invoice.php" hash="d6337f07169332724c590e12dc000241"/><dir name="Item"><file name="Collection.php" hash="57766f358cae02614da06a56ebf68048"/></dir><file name="Item.php" hash="60c8f04859713c5cfb7330578bf336f3"/><dir name="Payment"><file name="Collection.php" hash="9eab37574da534db4ef22f6345294a23"/><dir name="Transaction"><file name="Collection.php" hash="ccc0e97c4316f95129bd90ebea9ac26f"/></dir><file name="Transaction.php" hash="83fa21cd606358176616b33110b0e13c"/></dir><file name="Payment.php" hash="a64998298c43c70957e56b69e91b4612"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="1df7fbf2a3e04ae36b78b142b50477e0"/><file name="Parent.php" hash="d6e321521a5c1996422d9dee59a1a4a1"/></dir></dir><file name="Collection.php" hash="6fd5cd93f34127991c097b70138f4057"/><dir name="Comment"><file name="Collection.php" hash="ec5ea997e5321b3c38d53fb5f051c8e0"/></dir><file name="Comment.php" hash="e5a5ae0ce325a6d8e4dab0dda6a372c4"/><dir name="Grid"><file name="Collection.php" hash="a3a041b5fed571c96c3d5dbc6460bcf2"/></dir><dir name="Item"><file name="Collection.php" hash="810e3353b31c8f6771a709dc66142ac2"/></dir><file name="Item.php" hash="8eaf8b193c2150db1f8311da4a9b6ee3"/><dir name="Track"><file name="Collection.php" hash="aa21f2acdeb0ef781a69301b10833ba3"/></dir><file name="Track.php" hash="ee0457dbf45560ac5911dce55c2fe3b7"/></dir><file name="Shipment.php" hash="4691e9adcb7a03ee4a464d8668bd56f2"/><dir name="Status"><file name="Collection.php" hash="a485ee0868fa12033f24c47639f51d14"/><dir name="History"><file name="Collection.php" hash="dec595caafb8eea44138c6864159b016"/></dir><file name="History.php" hash="134f002dfb8d6b14a26f6b70447de8d2"/></dir><file name="Status.php" hash="6b89b67664dea7f569d37a86d5139ee0"/><dir name="Tax"><file name="Collection.php" hash="6f6bf9dc4458315260ded0ceffa66c74"/></dir><file name="Tax.php" hash="8ac6240b20b5c08e5368d781f319eb3f"/></dir><file name="Order.php" hash="47d2e1636d6a54df38885b7844615353"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="be26c808511a087089aa7e08962791e4"/><file name="Parent.php" hash="fa97e68427448811aaa32d82881109e8"/><file name="Region.php" hash="7482ea51890c4587a1cc93e7ba56b10d"/></dir><file name="Backend.php" hash="805b81cf251ad652e2d208f0e0f7fbd5"/><dir name="Frontend"><file name="Custbalance.php" hash="dfb08b9d0680bddf40a784b1c3652707"/><file name="Discount.php" hash="7fb276ce85e37b894b9ed71e11537d17"/><file name="Grand.php" hash="e79b6a2c4ae1da1fb6f9a0a6a73fc230"/><file name="Shipping.php" hash="58035703127f091113e635f2747fdcb3"/><file name="Subtotal.php" hash="031a748026b4062777afab89a61382ec"/><file name="Tax.php" hash="267aff76937222e3ca525f978325802c"/></dir><file name="Frontend.php" hash="c4de050c924aa561b203f49c9aa77f52"/></dir><file name="Collection.php" hash="cf9a075a8d879ccb813fde325b8ea878"/><dir name="Item"><file name="Collection.php" hash="1764986d570000e1ed051efd4563ae65"/></dir><file name="Item.php" hash="17690376ee9c7581761bb0e83e403420"/><dir name="Rate"><file name="Collection.php" hash="2fccbac4a69ea4a863b06f167b30a5ba"/></dir><file name="Rate.php" hash="355a5a7fa205cd5162938ccd02fe3660"/></dir><file name="Address.php" hash="02074bc356903b060b5ca500a5ed0615"/><file name="Collection.php" hash="8406cd2fe85cf92d99e7b86f77c01649"/><dir name="Item"><file name="Collection.php" hash="1b7cd1e44d6b7e792cc46971f6720cf4"/><dir name="Option"><file name="Collection.php" hash="e772bd35040257d9dedbfcd11a1feaeb"/></dir><file name="Option.php" hash="c23b184da316d5b7f20ef415f260a119"/></dir><file name="Item.php" hash="664390b7e549e0d6f8e19e6e81efef93"/><dir name="Payment"><file name="Collection.php" hash="3f1b159c957342544faf1b8ae0467883"/></dir><file name="Payment.php" hash="a41b3fa7a10728fd2f806dc2abccb3d4"/></dir><file name="Quote.php" hash="543e27fcc1e4d03903360027278032fa"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="d1395a052ccb3c15218299cc30c1a922"/></dir><file name="Profile.php" hash="34d2a525e68e791028f0c886ad66653a"/></dir><dir name="Report"><file name="Abstract.php" hash="264e7a22582d19fe012b339d82fb28af"/><dir name="Bestsellers"><file name="Collection.php" hash="b9f067c6b59bacda74a3a9edba6f6564"/></dir><file name="Bestsellers.php" hash="fe867b3b2efa3697ccfe9594f28770c4"/><dir name="Collection"><file name="Abstract.php" hash="b3fb0dc1c6a8bd85b9ffb5ccb4c0f13e"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="cb31bd6a8718c3d9b9e30f7f6ffbdcd0"/><file name="Order.php" hash="c4ea26ba47b4abad683809bdd8fe6e20"/></dir></dir><file name="Invoiced.php" hash="3838e450140aabdaa9a84d18a5680321"/><dir name="Order"><file name="Collection.php" hash="76c2d00b49ecc6479d5272ed520d6ef6"/><dir name="Updatedat"><file name="Collection.php" hash="5ea2acf2e43881c261c371e7d03492d3"/></dir></dir><file name="Order.php" hash="cee72fd4fac73ab28c735b182d3830a0"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="45cdb9a7f4b2aea0a5e92d95906f3f7b"/><file name="Refunded.php" hash="58a714e1193b56714058ebd306415ad9"/></dir></dir><file name="Refunded.php" hash="4cd043f5734d21bf6e650887a23ee1eb"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="c243edc0a166c78c2005e5e0ecebeacb"/><file name="Shipment.php" hash="945e5b66fcde6ebabf1d5d379486980f"/></dir></dir><file name="Shipping.php" hash="8e1b13cacd6ea502187bc5e6660632ab"/></dir><file name="Report.php" hash="ee15aad82166a514b2af7905bb00a4e8"/><dir name="Sale"><file name="Collection.php" hash="f219ebe08f9a11d9dc1304b0ee8b483e"/></dir><file name="Setup.php" hash="2c52c0bb23917998f6e96b0851420280"/></dir><file name="Observer.php" hash="6b3ae0486bb0d6ff4cd6a6d27ce4951d"/><dir name="Order"><file name="Address.php" hash="a3615a36e6213aa81e9faa6bde9780c3"/><dir name="Api"><file name="V2.php" hash="7067acd424538ad5c7bcf2ddaf57a4ff"/></dir><file name="Api.php" hash="3674caa8e6636a7b7e5a8d6607304e37"/><file name="Config.php" hash="16189fa4292a0135999f2e271662e2e6"/><dir name="Creditmemo"><dir name="Api"><file name="V2.php" hash="14079d353e770eb86bca26f4bb3a9fbd"/></dir><file name="Api.php" hash="30c77953cf52796be8085711545505fa"/><file name="Comment.php" hash="51864ddc190da192e6740764b3d8f822"/><file name="Config.php" hash="6c3f23705e98e04c13f8b7e7716f5e1b"/><file name="Item.php" hash="87edae9659a545c3b11a5e04a2722ff5"/><dir name="Total"><file name="Abstract.php" hash="1b6bb665ef2a88693e37dc6dfa63348a"/><file name="Cost.php" hash="f4147f87113140b1e8110dc86f430238"/><file name="Discount.php" hash="05013434cb347a8f1191d6ba4f220ff7"/><file name="Grand.php" hash="7e4e3d77d2f4d9e3c4c85d77aeaa1f5a"/><file name="Shipping.php" hash="8ea84819c3f7f28a563081f7c30a5bbe"/><file name="Subtotal.php" hash="096dca410a51133e58b75f74a7306921"/><file name="Tax.php" hash="10f4834b7f38602b19dcee614abe352c"/></dir></dir><file name="Creditmemo.php" hash="518a9596065ddb64fa63ceb9a4fada41"/><dir name="Invoice"><dir name="Api"><file name="V2.php" hash="1c5cb7dbfad894ecdd710a6501ab00fe"/></dir><file name="Api.php" hash="4d76d08b8d4312bc478d20c916b21b2d"/><file name="Comment.php" hash="d0bf13150f6a0c5c7a61c9ad733c9be0"/><file name="Config.php" hash="db8b79964525f16c624bb1d5dc81df8e"/><file name="Item.php" hash="c2d7a19f2ddbcbf008ff05d331bc4374"/><dir name="Total"><file name="Abstract.php" hash="847070d3c4113d54c8cc999a970ecc55"/><file name="Cost.php" hash="a6b23caa4c456d8ce1ac713a0cce01d2"/><file name="Discount.php" hash="75da9a43578e469699733717dd6dcf94"/><file name="Grand.php" hash="297500b958462e1e22d42c24030425cb"/><file name="Shipping.php" hash="5212cea8bca9d2a48fbe66b8d1730586"/><file name="Subtotal.php" hash="22646f1812eeec3618a243a6747ab2a1"/><file name="Tax.php" hash="22456b1b16cced9d3eafa22f2d36af07"/></dir></dir><file name="Invoice.php" hash="787438946107a4c47ad0b722ac1d65a8"/><file name="Item.php" hash="abe38e10e46622284a2cf35a253fcf14"/><dir name="Payment"><file name="Transaction.php" hash="d7dac2a25750236c45b9beeedcd5fd5c"/></dir><file name="Payment.php" hash="fee69051078badb383ed6b4d4595fcfb"/><dir name="Pdf"><file name="Abstract.php" hash="17bcf72dc9d0998a8d429ddfd95b7c47"/><file name="Creditmemo.php" hash="b5e722b76b6e332feea56e8c1a0ef544"/><file name="Invoice.php" hash="46ded5d0e47f6b11e8256afba29780d4"/><dir name="Items"><file name="Abstract.php" hash="45e20ce44c7806ae65d6959c4d3fdbe2"/><dir name="Creditmemo"><file name="Default.php" hash="dd08cb764624df49c7f939250e539226"/><file name="Grouped.php" hash="d37384547040e88d0132c153400fa61d"/></dir><dir name="Invoice"><file name="Default.php" hash="8ada82c1dbc31d52701480f1902bc047"/><file name="Grouped.php" hash="5bf317fef6242a6e40c7e49c07eddb8b"/></dir><dir name="Shipment"><file name="Default.php" hash="ff3d1db3a86a1bb42544f7b7ef08e3ad"/></dir></dir><dir name="Shipment"><file name="Packaging.php" hash="d94bb45890c005d3e90f10913956f106"/></dir><file name="Shipment.php" hash="6ddbd07c34c77d647875d27c66a9ad4c"/><dir name="Total"><file name="Default.php" hash="388395eaacb6714fbd399787e2115c7b"/></dir></dir><dir name="Shipment"><dir name="Api"><file name="V2.php" hash="6c7aa70683a5b5016a33cb45f07c5f83"/></dir><file name="Api.php" hash="8bfc4007476bf40b7f151ec05b3f2277"/><file name="Comment.php" hash="a4082edca5b999c0c78665790de02cdd"/><file name="Item.php" hash="e6aa9931492b3f5cdf178124ab82b59c"/><file name="Track.php" hash="56f2f0f84f1a3ed8dbd51d86ff103a32"/></dir><file name="Shipment.php" hash="5115b7c8b6f3971d5bf7a9dea5b75190"/><dir name="Status"><file name="History.php" hash="f83b695ff16adaee53b44a4c72cae947"/></dir><file name="Status.php" hash="52f4b3481ea4a178eeb3217f2b0217e5"/><file name="Tax.php" hash="5ec3e6df4cc355e634c88b1fa43ba4bf"/><dir name="Total"><file name="Abstract.php" hash="ab08d63eea14f655d3c0b19c5ec903f5"/><dir name="Config"><file name="Base.php" hash="8c43c43eb05255b24fdc8e31b31efecd"/></dir></dir><file name="Total.php" hash="b205b779b9242f6b19a21afbb733c162"/></dir><file name="Order.php" hash="346d2b0fd980510f97f0498bee35f308"/><dir name="Payment"><dir name="Method"><dir name="Billing"><file name="AgreementAbstract.php" hash="9725b084bbd355e8c221dcc613df41a5"/></dir></dir></dir><dir name="Quote"><dir name="Address"><file name="Item.php" hash="3ae1834f6fe626cbf63410aec2940627"/><file name="Rate.php" hash="14fc3c2112712db9717b4a0a13d15ec3"/><dir name="Total"><file name="Abstract.php" hash="a7f2fe7c03af2c89584b5ae257ec28aa"/><file name="Collector.php" hash="543475b79a9578f126f56ccd52cd6cb0"/><file name="Custbalance.php" hash="9aff8cf0f8e6d563fe89a5e16318aaf0"/><file name="Discount.php" hash="3919a311503fe2bc6f40f27e5fc460cc"/><file name="Grand.php" hash="be1eeabe2ea7af11b4792df4097959a2"/><file name="Msrp.php" hash="47068f636822c3abbc0829fcf421e448"/><dir name="Nominal"><file name="Collector.php" hash="279e887182cf75fc0d02d326e5107dbf"/><dir name="Recurring"><file name="Initial.php" hash="1cac1579ed7eace68b6f3ccd6dd0f6db"/><file name="Trial.php" hash="9bd24e561b17ac910035f1c94e0a66d3"/></dir><file name="RecurringAbstract.php" hash="df3faa2c787706c968e5e040997149f2"/><file name="Shipping.php" hash="024dcf97a900fd8b617ee378c35e0161"/><file name="Subtotal.php" hash="9fd604d4f422ca811a5a4f0eb82a85f7"/></dir><file name="Nominal.php" hash="9d7397526d4aed1fa40791a2dae842d3"/><file name="Shipping.php" hash="90240c3a38456d95cfe14477ff9a0aca"/><file name="Subtotal.php" hash="e45ab96ba686d0f7797c15738bdaf3a8"/><file name="Tax.php" hash="eaad017972debd4ee4b0e84f35528829"/></dir><file name="Total.php" hash="c1c66f97471c41ecc5200162001b30a0"/></dir><file name="Address.php" hash="b302cdb6dd5a26d0653c77426b458eaf"/><file name="Config.php" hash="1a405048ffab0aa9286ef1a9152e4cf4"/><dir name="Item"><file name="Abstract.php" hash="404b546babd7fbca3f4102938c5b10b6"/><file name="Option.php" hash="2354c151737bfa46a68d12fe173690db"/></dir><file name="Item.php" hash="f93885569fb2cd0a3236f43519f4ad97"/><file name="Payment.php" hash="4f48c4140768f66179ecd6384bf3a296"/></dir><file name="Quote.php" hash="976835f2ad40d36b95f16f05397c28ab"/><dir name="Recurring"><file name="Profile.php" hash="2efabc2b8df13eb5fa66c1de41d66afd"/></dir><dir name="Resource"><file name="Abstract.php" hash="ea490ac031b524bea4ba05969fc96e6d"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="bdb4107917da11c3c6c1af73ba11886c"/></dir><file name="Agreement.php" hash="cd36bc5506d7c761a1b9e7391524d86c"/></dir><dir name="Collection"><file name="Abstract.php" hash="51b42b98ea4c98c529aa08f8315ffc74"/></dir><dir name="Helper"><file name="Interface.php" hash="f76607969a2cfd69a53dfbf05bb925de"/><file name="Mysql4.php" hash="1875b015b52c3560592b6d02db6666a7"/></dir><dir name="Order"><file name="Abstract.php" hash="20dbcdeae97c722938469bbea6438fea"/><dir name="Address"><file name="Collection.php" hash="4a1787b25f7c6e726ba31a2e4f589570"/></dir><file name="Address.php" hash="e46b64d38f40223036f1de1a9c108102"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="c131e65596d6eebe16994c6448dedfff"/><file name="Child.php" hash="62a4cc6f57097793e50ce0ac88d8ff11"/><file name="Parent.php" hash="0d434c37560203b7ab50bb1302bc8f0e"/><file name="Shipping.php" hash="1e5a30a9c5598387a3e1d737bd4df4f5"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="dd4c06db4cbd8ed33a0c26207e393c92"/></dir><file name="Collection.php" hash="43dc36f6936b91fc113bff644dbf520a"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="bb99fec3c7900d0e1eacf7bb13fc437e"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="85ee4c6d66f60cfe7e35898f90109ca3"/><file name="Parent.php" hash="ce51a4256150044320202e1f6790f6c4"/></dir></dir><file name="Collection.php" hash="8936337edd51b5ff9a117ceffd9486c8"/><dir name="Comment"><file name="Collection.php" hash="2a074d811df831ed3e63db2de9802204"/></dir><file name="Comment.php" hash="24902dcb883850b0addef5b87380c7ae"/><dir name="Grid"><file name="Collection.php" hash="831f3834ab51086b38dce2dc846c61ed"/></dir><dir name="Item"><file name="Collection.php" hash="23cfedfa19cd81c21a08a937696f3ab8"/></dir><file name="Item.php" hash="ce67ef24a2ad12d75764b8c61ff10dd1"/></dir><file name="Creditmemo.php" hash="daa34995c168670ffd3ea174c46613b4"/><dir name="Grid"><file name="Collection.php" hash="6dd70bd3305b924da5c44675c5894f93"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="cbb0693ffaf5fa22757eb232b7fbc70c"/><file name="Item.php" hash="413b22e9354b3a07fc7b257670782cef"/><file name="Order.php" hash="1e2fdac3e2c21b76b4f42c9c53dcfda0"/><file name="Parent.php" hash="7fa160f57f4714cb4a18fe33a7388f5b"/></dir></dir><file name="Collection.php" hash="12aac698234ab6fc10ff17034ce8df45"/><dir name="Comment"><file name="Collection.php" hash="0d06272d5576f2b18e7b798c39c7f7e3"/></dir><file name="Comment.php" hash="6915c732d89bde5dc4e4e24cc44472ba"/><dir name="Grid"><file name="Collection.php" hash="c5624a52729803e5c8620337aca171a9"/></dir><dir name="Item"><file name="Collection.php" hash="525b58c10c6c1037ee34c4a79dbe7ad0"/></dir><file name="Item.php" hash="c6585be8f7b1db0e62e2cf8ab6b7874f"/></dir><file name="Invoice.php" hash="8a1a7b0ef68669c7b34fc48c4f0dcddb"/><dir name="Item"><file name="Collection.php" hash="176f717ac739052b6916463790441b8f"/></dir><file name="Item.php" hash="dce1a127f66a9e6428e9f808fdc769c3"/><dir name="Payment"><file name="Collection.php" hash="a8d7e7f56e811a9c36ac0c789dcbed12"/><dir name="Transaction"><file name="Collection.php" hash="0ac39e0c1c389727de0c11879639ba87"/></dir><file name="Transaction.php" hash="298b33cceb85b5a757ff9e2c5e4f5afc"/></dir><file name="Payment.php" hash="118414190d11cc9baaf63cb49828b5b0"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="3fa9311faa46ac5f9797131e05db7395"/><file name="Parent.php" hash="42928c2eeb53a7b52a2a07df26985119"/></dir></dir><file name="Collection.php" hash="e12bb87e81e655b5767cc7f93ecaaa93"/><dir name="Comment"><file name="Collection.php" hash="970946b0c0af5604a1206113378e0ebc"/></dir><file name="Comment.php" hash="26b0f55b0d8c8857f8cbee190f2b1d3d"/><dir name="Grid"><file name="Collection.php" hash="e3ac9bc8545d2797a7a05bc299fb3e80"/></dir><dir name="Item"><file name="Collection.php" hash="90ce90a50a2bc64c9c5eda09b87a7f4b"/></dir><file name="Item.php" hash="60b087d1d6af44919efd905e49c3c62e"/><dir name="Track"><file name="Collection.php" hash="b99b08006f31786e0ecbbda2e4caca83"/></dir><file name="Track.php" hash="432355e34939bd400d1b1cbb3b74a32f"/></dir><file name="Shipment.php" hash="68a9a03dd12e76fb449de0967d195efb"/><dir name="Status"><file name="Collection.php" hash="3278d85b3e345f9cb952d62d1de47692"/><dir name="History"><file name="Collection.php" hash="bdef52f9fabb1f71e3edd6b89219ffe8"/></dir><file name="History.php" hash="1b458a7d3e5d271bddd96ef479f132db"/></dir><file name="Status.php" hash="4288eb12408bf67290826cff7df4aa7a"/><dir name="Tax"><file name="Collection.php" hash="fa155762b727314be328312941189d00"/></dir><file name="Tax.php" hash="6129f98bc5b2984e5283b1b650624d8d"/></dir><file name="Order.php" hash="904377587c7a8bd27354b41b23a53d23"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="369543a2fa39d232fd4f6646b63e8ec1"/><file name="Parent.php" hash="eda07b62dd8c0a1635029d13a585abbd"/><file name="Region.php" hash="530d94dace10e60b341d1fe7cd6422e5"/></dir><file name="Backend.php" hash="5be4ed862760bc33b3e54a30e996a1d1"/><dir name="Frontend"><file name="Custbalance.php" hash="9be96592493a3ae7b3fda82f209156a5"/><file name="Discount.php" hash="97b4061b4fe3cb688dceb3257666004f"/><file name="Grand.php" hash="2106653f49bda21734a52abe74be249d"/><file name="Shipping.php" hash="4fb2173a120e98fa933552caaf2a6bf3"/><file name="Subtotal.php" hash="e8df507e5e9792d758d839ea9b3bae8f"/><file name="Tax.php" hash="6dcf8738025d2f06effdd58e6dfef27a"/></dir><file name="Frontend.php" hash="2a5b816c2bce98c2b576fa3259354403"/></dir><file name="Collection.php" hash="451ce58ddc5b65f7889fc191b9c4a536"/><dir name="Item"><file name="Collection.php" hash="9e0c3063b4e137a251a66c5c14431343"/></dir><file name="Item.php" hash="20e10524e121cd1bac70064c4c72fd8a"/><dir name="Rate"><file name="Collection.php" hash="b34a0efa65709981133d8399dddcdf28"/></dir><file name="Rate.php" hash="3e61ffad4f72a78e0888a985d8fef8f6"/></dir><file name="Address.php" hash="2cb48cc23d5e5206958745da72d13686"/><file name="Collection.php" hash="01999f2337a532357698782f263fac5c"/><dir name="Item"><file name="Collection.php" hash="2afb7b5b8428e3b51ee78adca7476045"/><dir name="Option"><file name="Collection.php" hash="48e63e2fbba4c374c074e14c06d56338"/></dir><file name="Option.php" hash="4fefd261aebbe023fc107fcac6f0c305"/></dir><file name="Item.php" hash="292c094548d77a4455cf83faf93f0710"/><dir name="Payment"><file name="Collection.php" hash="2e43057411cbc115b82f2c0d303cf97a"/></dir><file name="Payment.php" hash="0130e600e213853660d996f1f1b32ae2"/></dir><file name="Quote.php" hash="486b3ac1533e640724b9afc471b05c1e"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="e62415bf7f7b0dd9a450713e6c4ac4d4"/></dir><file name="Profile.php" hash="3f70af49f45077f9dd1582119f0eb91d"/></dir><dir name="Report"><file name="Abstract.php" hash="38c9b8c1083e50c351426d3e3031949f"/><dir name="Bestsellers"><file name="Collection.php" hash="c9cde9d55954ba6b9ee7f6f108425446"/></dir><file name="Bestsellers.php" hash="4967fc6ee92b497de0388a1460aacdef"/><dir name="Collection"><file name="Abstract.php" hash="f595f30f74245c975150764709f08d73"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="4b36243994f78b1b24e3e978d069f9e8"/><file name="Order.php" hash="ffa266b09fa0d97557988e7a03bc07e9"/></dir></dir><file name="Invoiced.php" hash="11e111fce08ce735e56a54c3f8aa6d41"/><dir name="Order"><file name="Collection.php" hash="b2cec0c1f9c36f7a408030e60a01307e"/><file name="Createdat.php" hash="6e1c7e18f82ebd8908e73b2c004cb476"/><dir name="Updatedat"><file name="Collection.php" hash="3fa1df8ad8b1848a097d543b003a85f8"/></dir><file name="Updatedat.php" hash="e58e612a18b802c0b557d7e434e633e8"/></dir><file name="Order.php" hash="7c33ab34a6d11ddc78e61bc683816259"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="13a060a38654076459217de14071fc1c"/><file name="Refunded.php" hash="c54996f3bfa443eef148d392030683ab"/></dir></dir><file name="Refunded.php" hash="ff9b24303743367136d0c2e86d9cfa33"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="4ee344e59e240ffc3e48e2df4e78a9a0"/><file name="Shipment.php" hash="b9dde12fc18d59c1575a4322ef3e7544"/></dir></dir><file name="Shipping.php" hash="e1c416b2401864dd2c0463e2b9fed0f9"/></dir><file name="Report.php" hash="8783521c829f4045b6969502894d544c"/><dir name="Sale"><file name="Collection.php" hash="04f2c47481d7d51db1b1da3b1ac4b4a4"/></dir><file name="Setup.php" hash="3a4b62fef594c0d114153e2855ba1669"/></dir><dir name="Service"><file name="Order.php" hash="f8a7159d6427c7a3680e774aaa009741"/><file name="Quote.php" hash="0be73db6503e7bbd239d719e1b3cab1d"/></dir><dir name="Status"><file name="List.php" hash="aa25608d8612ba8971bd501d0fa94d4d"/></dir></dir><dir name="controllers"><dir name="Billing"><file name="AgreementController.php" hash="97322684834e02e16d64f0c11bfd1fe6"/></dir><file name="DownloadController.php" hash="cee6dfef90a6b58bcca8a764bdc627ae"/><file name="GuestController.php" hash="3bedc09dada50e06d5629f01bb790092"/><file name="OrderController.php" hash="c79c2f10bc284936c4f192d11c762f4a"/><dir name="Recurring"><file name="ProfileController.php" hash="9054131ddbe14d510745b9204c43c0e2"/></dir></dir><dir name="data"><dir name="sales_setup"><file name="data-install-1.6.0.0.php" hash="02cefc47dd017845278948de5b307e6e"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="46ce4a49f4522436e675252ede79b2bf"/></dir></dir><dir name="doc"><file name="invoice.txt" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="order.txt" hash="5dce876530c94ebbedbba7a234c23846"/><file name="order_actions.HTM" hash="b955e61bff753ea0534f907ef6ba9bb6"/><file name="quote.txt" hash="55ecfbdd576958ff1b1fbf16957ba9df"/><file name="test.php" hash="66d29b9e2fd667710fa7f1b03e588cd2"/></dir><dir name="etc"><file name="adminhtml.xml" hash="b10c4287ee15479510f28a499304ad1f"/><file name="api.xml" hash="dafc425001905db65660a077d77a8082"/><file name="api2.xml" hash="909f2d2b94d1a746ddeee52cca26fb8d"/><file name="config.xml" hash="3ecd88607ae60c576d52da1292869156"/><file name="system.xml" hash="51b69bdf518a615fe6971d7e32e05438"/><file name="widget.xml" hash="a00f4406f3f567e77f360d82a93c1932"/><file name="wsdl.xml" hash="ed13de1dde6408ab508892374ef57b81"/><file name="wsi.xml" hash="6aba2f44765955ec8bcd1afcebfb0800"/></dir><dir name="sql"><dir name="sales_setup"><file name="install-1.6.0.0.php" hash="0bb0f98e83cc59f0a96a245b688876bd"/><file name="mysql4-install-0.7.0.php" hash="462ef3674fe632dded10934e350e132c"/><file name="mysql4-install-0.8.11.php" hash="33eb92bab72ace62f913a1f6a49b10e2"/><file name="mysql4-install-0.9.0.php" hash="aeea2ae2bf3921fb861663ac43890821"/><file name="mysql4-install-1.4.0.0.php" hash="b8e163bec9787ec195214817ccd25aeb"/><file name="mysql4-upgrade-0.6.2-0.7.0.php" hash="b01396fa2d364bf24f31111fbc7480fb"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="7184eaf5301bf86734e27d35af77ec2a"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="3f7c0e697c9156d795a9171ebd2cc6b2"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="60fec48ecd973b0880a7ba0c1601f745"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="e3fb495eeae476ed6ed936d2da080d6a"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="a382796307c879e9978b6e919e06a0ee"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="cb97a875a9de942193d08787e4b5d0ad"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="77aa2ddafb2e56c2810037573704355d"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="9148158224e988cc0cda3c0f9447a676"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="b744d677ef8a3c4d8e7aac727faca09d"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="30f29aab40ee4b16f96137f021959739"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="e9511a88e249699f67b4f299190ffa29"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="923e0d6ffbb167057c5dce8ea0cf9cf6"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="00c5ac7a53fd59f7b1d22984e2961670"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="2a9d7aa03f976fdc19635631a19fb20f"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="4f97ee809943e787c96b4d8face8782e"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="478988a292e5263b88d39701fa246579"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="e57d49e1848d77d691b3eabb8d1cac4e"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="2e95a587381666c511af8e33cc29add9"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="09820b143bd2c14e0f755186ff6dd099"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="e3d5bf92a6338fb36b651729dbf6b5e2"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="3bc697c07cb99afcbcd547421d32a029"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="a2dec68bf46c62e4135a15adc4054a01"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="b659a882629e65e957b070eea0b64e92"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="cee327efb851c3d4c6755a6eb5ebb486"/><file name="mysql4-upgrade-0.8.28-0.8.29.php" hash="3f7df5f348dfd2cd8b5dcca8c7c327eb"/><file name="mysql4-upgrade-0.8.29-0.9.0.php" hash="f908b74ec1d3ca439b68f3e53da73d32"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="5f3bd96bad7a59e1fc5bed3c6a981e18"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="478988a292e5263b88d39701fa246579"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="359d1844bcced0a4990109d5a3e42f0c"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="999bd5a25ecddb2d761b305bb4d72a3c"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="37da657ede40afb7a5182183d5e34c78"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="e38c9cab4a09c709fd753f8dd10172c6"/><file name="mysql4-upgrade-0.9.10-0.9.11.php" hash="f19b6d1077b4a43fdd8242190b9014a1"/><file name="mysql4-upgrade-0.9.11-0.9.12.php" hash="c2f730a54671a4a8d0aff9b20b001bc5"/><file name="mysql4-upgrade-0.9.12-0.9.13.php" hash="7941dce96df5b27e0091a30f7e641384"/><file name="mysql4-upgrade-0.9.13-0.9.14.php" hash="c692b5c3a033952e280c5a3f3ac250d0"/><file name="mysql4-upgrade-0.9.14-0.9.15.php" hash="75c7659a026b12105c775dca9b3a35d8"/><file name="mysql4-upgrade-0.9.15-0.9.16.php" hash="66fbe7eba8efa04618e47798d700cf22"/><file name="mysql4-upgrade-0.9.16-0.9.17.php" hash="b4ad0ba23383895098baf2595e7ed2e8"/><file name="mysql4-upgrade-0.9.17-0.9.18.php" hash="46d2aac6cdcdade35a6cd56470b675d8"/><file name="mysql4-upgrade-0.9.18-0.9.19.php" hash="95fc75c590ef109016d64a7e046c6a0a"/><file name="mysql4-upgrade-0.9.19-0.9.20.php" hash="a3e4c82a24ea923c4172fbf7953c191d"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="6626c9dcd59254a9f7d95f6849974dbc"/><file name="mysql4-upgrade-0.9.20-0.9.21.php" hash="9153e34efed12b4c6c3b7fbd0c835c8e"/><file name="mysql4-upgrade-0.9.21-0.9.22.php" hash="2faf29b7392840fa59e0fc03d96d61ce"/><file name="mysql4-upgrade-0.9.22-0.9.23.php" hash="1eb3ec821367d5f48fd0abbe60fc519d"/><file name="mysql4-upgrade-0.9.23-0.9.24.php" hash="027e9756bc75cf23b6bac1b7332bf4cc"/><file name="mysql4-upgrade-0.9.24-0.9.25.php" hash="fb956ea2ecc81ac02957d988b377cf0a"/><file name="mysql4-upgrade-0.9.25-0.9.26.php" hash="f210bac7762c0e7fdc66f62fb6cbe6b4"/><file name="mysql4-upgrade-0.9.26-0.9.27.php" hash="5253aa7faf062641bf7e556871df8e25"/><file name="mysql4-upgrade-0.9.27-0.9.28.php" hash="c708bfd6a507ecad7fc6c355fd1e4930"/><file name="mysql4-upgrade-0.9.28-0.9.29.php" hash="0a0dc5d23a7e036d936752a62404d4f9"/><file name="mysql4-upgrade-0.9.29-0.9.30.php" hash="38c3ff2b635d8ec6517e9c7dcc5de6f4"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="aafe70d96984e181507705441823d7c0"/><file name="mysql4-upgrade-0.9.30-0.9.31.php" hash="c777f32ef312bdf861b79622e9612bf7"/><file name="mysql4-upgrade-0.9.31-0.9.32.php" hash="76847f4d1f0e1357a895fdd4d0c30e1e"/><file name="mysql4-upgrade-0.9.32-0.9.33.php" hash="dc2296114158ee945deb60843962cde9"/><file name="mysql4-upgrade-0.9.33-0.9.34.php" hash="4114bf6b67bc92d34bfd18ec0810b0d5"/><file name="mysql4-upgrade-0.9.34-0.9.35.php" hash="ab41ec52694af14a35e17dbe43c55c9f"/><file name="mysql4-upgrade-0.9.35-0.9.36.php" hash="8364015ecfe1d5e347c17a5a097d78d8"/><file name="mysql4-upgrade-0.9.36-0.9.37.php" hash="b27b346cef4e4d0b58df197b0a238c2b"/><file name="mysql4-upgrade-0.9.37-0.9.38.php" hash="dbd05460732dc1e06cdc3d1d37907f88"/><file name="mysql4-upgrade-0.9.38-0.9.39.php" hash="0edb44ca7a54e5bcd369d8f314b59ea1"/><file name="mysql4-upgrade-0.9.39-0.9.40.php" hash="f72dcfb2c0753d75a80244c654142391"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="e983567d4a31a6a7774161040ced0632"/><file name="mysql4-upgrade-0.9.40-0.9.41.php" hash="4794a4e83d55fb940f587b4a297dae64"/><file name="mysql4-upgrade-0.9.41-0.9.42.php" hash="5c988af33e6155f36b1a9894f53f98e6"/><file name="mysql4-upgrade-0.9.42-0.9.43.php" hash="df12068b0a9af6431ab71c4c4d7baa9a"/><file name="mysql4-upgrade-0.9.43-0.9.44.php" hash="e2fc0e2fb187f525c3c278e1364294de"/><file name="mysql4-upgrade-0.9.44-0.9.45.php" hash="99a088be09d24560c7680d04eebecb40"/><file name="mysql4-upgrade-0.9.45-0.9.46.php" hash="2e1808631633138ef84167c35087871b"/><file name="mysql4-upgrade-0.9.46-0.9.47.php" hash="a1fbab58b6281d7c73e249b1172fe346"/><file name="mysql4-upgrade-0.9.47-0.9.48.php" hash="160448e66de783cbfa64c13483ea793f"/><file name="mysql4-upgrade-0.9.48-0.9.49.php" hash="5657862f11b8a2ccf05decf6bf651495"/><file name="mysql4-upgrade-0.9.49-0.9.50.php" hash="33e922d769595a4a22257df3288d0b23"/><file name="mysql4-upgrade-0.9.5-0.9.6.php" hash="7534168cbeafd219b913fad70ef0b604"/><file name="mysql4-upgrade-0.9.50-0.9.51.php" hash="727555136eb0ca74c78c0ae605bbcca5"/><file name="mysql4-upgrade-0.9.51-0.9.52.php" hash="fbf3075eb1122eb16a78ab1da6c87280"/><file name="mysql4-upgrade-0.9.52-0.9.53.php" hash="b95803e85855ad53a32036b4e2e422ce"/><file name="mysql4-upgrade-0.9.53-0.9.54.php" hash="ff3d7c4ff6666e38c8694403987358ce"/><file name="mysql4-upgrade-0.9.54-0.9.55.php" hash="221e4d19ff8a3b168ad2a77adb403947"/><file name="mysql4-upgrade-0.9.55-0.9.56.php" hash="0e5d2a62541e8d6f0150515bc95b6e21"/><file name="mysql4-upgrade-0.9.6-0.9.7.php" hash="bb9fe9fc17135267b8dceda66ba573df"/><file name="mysql4-upgrade-0.9.7-0.9.8.php" hash="51f542d4e4dc2eb4d151fa1d199e76c7"/><file name="mysql4-upgrade-0.9.8-0.9.9.php" hash="1ef9eb2e04ff17094c9fbe4dd04dbb43"/><file name="mysql4-upgrade-0.9.9-0.9.10.php" hash="e4c2fd4e25264a59dc4d2c2fed009b55"/><file name="mysql4-upgrade-1.3.99-1.4.0.0.php" hash="064bd9a3a66afbcec73dc6eba2d91aab"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="58cd3b1e53113ccf8da37272261f5420"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="abb82596cd80405e68ead6c3f9b118d6"/><file name="mysql4-upgrade-1.4.0.15-1.4.0.16.php" hash="8703f8f8f23ae434e029dc49d28f6724"/><file name="mysql4-upgrade-1.4.0.16-1.4.0.17.php" hash="02a61839f64351389226749ee95f2ac2"/><file name="mysql4-upgrade-1.4.0.17-1.4.0.18.php" hash="bd0e06542f412eb829d14f3a5fe389ba"/><file name="mysql4-upgrade-1.4.0.18-1.4.0.19.php" hash="8a67dcba5b4af5ce97eb6a5960dc37d6"/><file name="mysql4-upgrade-1.4.0.19-1.4.0.20.php" hash="f94a7026618758fcc4410f9cbf395513"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="7c8baf053e8f385017e5e6d7c9e4fadd"/><file name="mysql4-upgrade-1.4.0.20-1.4.0.21.php" hash="fd6098e114e8c077781ae9a109900e75"/><file name="mysql4-upgrade-1.4.0.21-1.4.0.22.php" hash="eec8bca856f155321127aa16554b6ff5"/><file name="mysql4-upgrade-1.4.0.22-1.4.0.23.php" hash="7dae40e457321e05723eddd332b3f777"/><file name="mysql4-upgrade-1.4.0.23-1.4.0.24.php" hash="ec6aca579e3d8bcdab92be6f0101edd7"/><file name="mysql4-upgrade-1.4.0.24-1.4.0.25.php" hash="90c7bdaa5340eadab0af599d27c26ad7"/><file name="mysql4-upgrade-1.4.0.3-1.4.0.4.php" hash="30ba90e80302ad78fe6ca46966b4ebe0"/><file name="mysql4-upgrade-1.4.0.4-1.4.0.5.php" hash="4d5b5a1832ff24134b7bee78a6347cbb"/><file name="mysql4-upgrade-1.4.0.5-1.4.0.6.php" hash="2eb2af257f342358fe654bc2ed203be0"/><file name="mysql4-upgrade-1.4.0.6-1.4.0.7.php" hash="1092e380e4d97fec73b574f5ca1210d1"/><file name="mysql4-upgrade-1.4.0.7-1.4.0.8.php" hash="321d6f3cac598aebb3a6d5690783bb8d"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.15.php" hash="2605e1f309aaaa83e66e19952de196f1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="fbb6d6a9211af940a9d09ea7ce124acf"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="1702e52d9327642cf39c787272e00088"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="51a01243c80475b335461fab5b124919"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="0c3fc39d972a310d1802bd45d1086478"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="d8f56295b53d69f61389f839001c7ead"/><file name="upgrade-1.6.0.4-1.6.0.5.php" hash="3d7df8adc7319e6568f7367e95f7f32e"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="b99799afe881cb0c2c31534a4e4ddb51"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="d874572b66f8d5893b1d58004cf2093f"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="312c728e68f607a869e50e27edc81df8"/><file name="upgrade-1.6.0.8-1.6.0.9.php" hash="5e1ea6e5d77dc8c7ff9776d54007d8e7"/><file name="upgrade-1.6.0.9-1.6.0.10.php" hash="9f3b171078b5bf448639865bb8e759ba"/></dir></dir></dir><dir name="SalesRule"><file name="Exception.php" hash="c684bcb6cf5c1b0a6b652d34be1ef4d8"/><dir name="Helper"><file name="Coupon.php" hash="bec5fdde7197a727a2e2ad2a01d10e95"/><file name="Data.php" hash="56c45ee011ec0f06c7df0e3a88e33764"/></dir><dir name="Model"><dir name="Coupon"><file name="Codegenerator.php" hash="a9137a826ac5b0d94739a4f494616755"/><file name="CodegeneratorInterface.php" hash="50d019dcd547e2d36656037f6e4867e8"/><file name="Massgenerator.php" hash="91159302a81f191f9ecb9aefc6935cfe"/></dir><file name="Coupon.php" hash="d1acd813c8dd00fad47929b2a66964cf"/><dir name="Mysql4"><dir name="Coupon"><file name="Collection.php" hash="3631489bee3c9db6bed33f50dd87188e"/><file name="Usage.php" hash="abef6dd5e2675044255c4847b5ebfa75"/></dir><file name="Coupon.php" hash="481513e97ecba9c1dcbf58c988618dfa"/><dir name="Report"><file name="Collection.php" hash="0e5028d770ba6502e017a548ae3eb9f2"/><file name="Rule.php" hash="10834499b347164af794cbe10e8e5c8a"/><dir name="Updatedat"><file name="Collection.php" hash="ff414b6c919389d524727f245274259d"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="a97146dfb96259d4a80983c9ce8248cb"/><dir name="Customer"><file name="Collection.php" hash="9cc9dfff6b46c35ead43b3fb3f3cec14"/></dir><file name="Customer.php" hash="dceb0116dbcaaac015b52649f87374eb"/><dir name="Product"><file name="Collection.php" hash="fa0176fee491bf06424fd7c97c859f53"/></dir><file name="Product.php" hash="d5fe431e624eb4b1befba2a65e371026"/></dir><file name="Rule.php" hash="94993e080ff63622f8ecd433fde71796"/></dir><file name="Observer.php" hash="de6d39e558f4b7e39ac387733349ec6f"/><dir name="Quote"><file name="Discount.php" hash="905eccf34b5449fbf29d140c99953b23"/><file name="Freeshipping.php" hash="5ddbf5e58d137e2fe770b706a0956a55"/><dir name="Nominal"><file name="Discount.php" hash="341b490273fd5ab1498f7cfc3d15ff0e"/></dir></dir><dir name="Resource"><dir name="Coupon"><file name="Collection.php" hash="5030636a7a7dcc83f9f1c6f94b5cac62"/><file name="Usage.php" hash="7cee04feb2a624612e2cafc0dc192cf1"/></dir><file name="Coupon.php" hash="5f5f7751ea0c29d52981b02e55b07894"/><dir name="Report"><file name="Collection.php" hash="50122478a87fdec2b8a65f2d9aef282e"/><dir name="Rule"><file name="Createdat.php" hash="02466900b021fb1018ea89937fd34943"/><file name="Updatedat.php" hash="fe7b776559cb3dd2c3ca59b4e7043b08"/></dir><file name="Rule.php" hash="45f3ebecfe6f000328bce7c6ec3adebf"/><dir name="Updatedat"><file name="Collection.php" hash="85b1b702a0c934bda4efcb5c8380a830"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="9a70dcc2c97f85fdf47aae7894e0e5c2"/><dir name="Customer"><file name="Collection.php" hash="c119ca2272ba918b13b47d4e96e06f86"/></dir><file name="Customer.php" hash="712cd6ec527d506c00baecd09da49b81"/><dir name="Product"><file name="Collection.php" hash="819f0f9ecc77b8e7f20c4dd9b319f84d"/></dir><file name="Product.php" hash="14853418a21d59e0f8129c80bb88c032"/></dir><file name="Rule.php" hash="91b0b65b1443be890b430e282634d8d0"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="6836dfb390954debd9dbd1afe7df7721"/><file name="Product.php" hash="939d551e4e2ee92a5e5a9fbf0dd4c1a0"/></dir><dir name="Condition"><file name="Address.php" hash="32a9e7fd2ebd47d262832981f1317f1e"/><file name="Combine.php" hash="204f588c6cb09327b87267cb5c268577"/><dir name="Product"><dir name="Attribute"><file name="Assigned.php" hash="cea0241d92d0cad9c8d0f173e2f27a8a"/></dir><file name="Combine.php" hash="349d3f8a0f993e734112faf9f4593cca"/><file name="Found.php" hash="869319a13c49152426cd3ffabcf41865"/><file name="Subselect.php" hash="b53651f2371343ecaad1d22c5360b62b"/></dir><file name="Product.php" hash="da818046bf8cb6d85384970da1c4da16"/></dir><file name="Customer.php" hash="c91b48167015da5c26d161bd01d418a1"/><file name="Product.php" hash="be5aa814892976919f2841ad4f593720"/></dir><file name="Rule.php" hash="9ec22daa35075a786027eb387586ea64"/><dir name="System"><dir name="Config"><dir name="Source"><dir name="Coupon"><file name="Format.php" hash="453554268efa272468d5feef8f886a7b"/></dir></dir></dir></dir><file name="Validator.php" hash="5d85e113e95fc4326cbddc640ce17a52"/></dir><dir name="etc"><file name="adminhtml.xml" hash="caca53de6786b3be6da03586579fc893"/><file name="config.xml" hash="628ed6fd7df6d252288d15ce9785f6cf"/><file name="system.xml" hash="cc5d6bd5257f149325ea0feb73521cc1"/></dir><dir name="sql"><dir name="salesrule_setup"><file name="install-1.6.0.0.php" hash="9ab8955322ab4339661c69e0cb9802c6"/><file name="mysql4-install-0.7.0.php" hash="275f88f7f61f6664e0ae6e5d80b0c240"/><file name="mysql4-install-1.4.0.0.0.php" hash="323c4b2e46b3132092bd9b318367fb86"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="739a8b7fa21395aac36a605a553fb93b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="6b4cb8acdbbc2b2a4d187190c4ea0a91"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="6ad55cf361a23b17b9f36ae3abd0a984"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="d36a365e98e923ba45dcc74ffba18dcf"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="041f91b8c7c1be504f47125fa5ca0bf2"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="14a660771d58b2d182edabef3d38db02"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="c0c8bc7581f4a4eee50d6dde49977897"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="5f666558669daa62735513080fcfffb7"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="cc7329eb9f61f5f6c0d5d2fc098b39aa"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="6cf794be9adc22351a7f6493f6665b1f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="c4abbb799e56777dbb013727160a89af"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="4ae0398464264e326ce321c2eb7e0ca8"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="6536ffb5f313b156479a470894e7d473"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="dba49c9eab9fdb487d5ea4b2a9b19a61"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="2b430a6577e1e771b493d18b49b05817"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="54953e3953f5d0e8b4cdb02a70064e57"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="382240c00c8ef6e6da763a9e8cbf9ab6"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="9d7c0dfceb59c78a1b6809c69b119ad0"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="622e976224bd8234da9c026118f55849"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="e9c25f97809f2312d577e99eefdd1a43"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="70824ec16e4e39d26578e29917625f0d"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="81b3f1ab912631abc90bf4d5ed5596b0"/></dir></dir></dir><dir name="Sendfriend"><dir name="Block"><file name="Send.php" hash="b5f206f06b37f9f01ee3d23d34c4247f"/></dir><dir name="Helper"><file name="Data.php" hash="0d275b6d1e3607b79ec9a367c64c3128"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Sendfriend"><file name="Collection.php" hash="7c248d260e46c38da0961c6a1ab619a0"/></dir><file name="Sendfriend.php" hash="04962b095cc694d104d063772025ab33"/><file name="Setup.php" hash="2bf3e91ecbc58c463c17d58f2c03cacf"/></dir><file name="Observer.php" hash="6c5e9d18af2beaef0197aa284fe16ef6"/><dir name="Resource"><dir name="Sendfriend"><file name="Collection.php" hash="394927238d33f913906cc2ace443cbcd"/></dir><file name="Sendfriend.php" hash="e125543a8af18a8d4b244f3d2b824aa2"/><file name="Setup.php" hash="151a112174b9d83dcc6afc91683f54f2"/></dir><file name="Sendfriend.php" hash="aad537b2bd08139afca049186b0d0af6"/></dir><dir name="controllers"><file name="ProductController.php" hash="90cf4742e2b768696b28a05c9a3c32ae"/></dir><dir name="etc"><file name="config.xml" hash="546188e9ad02740203f9ddc35b58797f"/><file name="system.xml" hash="952f5059081dd3f114048a659b111f59"/></dir><dir name="sql"><dir name="sendfriend_setup"><file name="install-1.6.0.0.php" hash="5b1ae683858942384de97a4cabecb1eb"/><file name="mysql4-install-0.7.0.php" hash="bc16be0aaca8a2b6c50a7e87e9cbff12"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="da7a15eeb941d568818815dfbcaf9162"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="af38b95ee3b76f5acd3269170d93ce1d"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="a7013b2917b9e69fd6ca03c1bb8082db"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="db6d0a1eb02d805f42dcd3756381800c"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="8b493ea7ab72b583e910a22190295371"/></dir></dir></dir><dir name="Shipping"><dir name="Block"><dir name="Tracking"><file name="Ajax.php" hash="09df05bd55e577bb5260daa3e6caf5c2"/><file name="Popup.php" hash="f1a041dc4a7b17409b1cb343a49e038b"/></dir></dir><file name="Exception.php" hash="7817d908c16effb37641b413e3f07687"/><dir name="Helper"><file name="Data.php" hash="b454fdb55ec1039f9f7b692a0214b491"/></dir><dir name="Model"><dir name="Carrier"><file name="Abstract.php" hash="7191502b6ba0254127afd12521f56080"/><file name="Flatrate.php" hash="397b264a8d1dd04be1166be762c9dc30"/><file name="Freeshipping.php" hash="b41e034f705bd5806f356002421b8e16"/><file name="Interface.php" hash="8ee86ddab84fee146bba67f2f9ad4958"/><file name="Pickup.php" hash="574b87b25e9fcc7b11eb6a302edbc531"/><file name="Tablerate.php" hash="57a55677ba65ee9b31942a7d9ab789e1"/></dir><file name="Config.php" hash="d31ab0d1a4b74c009b08f54112d6b024"/><file name="Info.php" hash="9b396c342b5726b53a74a285bd50dfd8"/><dir name="Mysql4"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="6078fa27a483e4a499897fd930d8d6a0"/></dir><file name="Tablerate.php" hash="0e1157a910db560e02c468c292edf81d"/></dir></dir><dir name="Rate"><file name="Abstract.php" hash="61509b986aea96d297a7ad3d86c25f35"/><file name="Request.php" hash="4192d1bb68ec2e6b4ed2335d8ca4fd4f"/><dir name="Result"><file name="Abstract.php" hash="89ce290aa89085499fd46d9548ae1226"/><file name="Error.php" hash="e1576e0070daad2b4ae989afc9f60491"/><file name="Method.php" hash="5130215a38bde7a264574e6bb20d2f7f"/></dir><file name="Result.php" hash="b42c6afee8ed678f56823a4acbfd7c8c"/></dir><dir name="Resource"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="3f948b246a012a0014f5105eb4f673db"/></dir><file name="Tablerate.php" hash="dfcbfab619a7d316d2e76ec48621e1ea"/></dir></dir><dir name="Shipment"><file name="Request.php" hash="cd106fae6188411ac722b49ed9514308"/><file name="Return.php" hash="2d0ed8f59eaf9efe0cef5bf1092b8e54"/></dir><file name="Shipping.php" hash="3def0a3b57d1a80b7601bf172b730587"/><dir name="Source"><file name="HandlingAction.php" hash="996710c24691253907f5551fbe640ec2"/><file name="HandlingType.php" hash="b0e707f62445bfdfcd20114b182571a4"/></dir><dir name="Tracking"><dir name="Result"><file name="Abstract.php" hash="caefbcf638339cb3a8a3b029e1283e55"/><file name="Error.php" hash="2e8326379ef3d1065ce37b7e76ec32ee"/><file name="Status.php" hash="2aecb82f4a61a323341a9a52439892dc"/></dir><file name="Result.php" hash="54852fbada70b39109d974281decaaf1"/></dir></dir><dir name="controllers"><file name="ShippingController.php" hash="a5b8bef3ebea80cf2436f69ac91376cb"/><file name="TrackingController.php" hash="914ed8c271764e76146cdf6dba2ae138"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ee7864ea693423dbebbf2117258f4fab"/><file name="config.xml" hash="9c151220072be650f02113efe448bd03"/><file name="system.xml" hash="1b06754dd005ef11249090a54f806217"/></dir><dir name="sql"><dir name="shipping_setup"><file name="install-1.6.0.0.php" hash="fcfb648931efb9d39587d3fc1cc16aa8"/><file name="mysql4-install-0.7.0.php" hash="3ba11142c239180345b133929dd7fe13"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="cd7f1e9d351ef3afeae5d984c906a86b"/></dir></dir></dir><dir name="Sitemap"><dir name="Helper"><file name="Data.php" hash="c270138e049bbb86acc9e1c2035d9ed4"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Catalog"><file name="Category.php" hash="0d61e1bd297c0f0828c8c48c54bc6694"/><file name="Product.php" hash="53b4f1d7a3f61d354d94e13239e0014b"/></dir><dir name="Cms"><file name="Page.php" hash="801f82576eb1b96075c0bd6b3e478ff1"/></dir><dir name="Sitemap"><file name="Collection.php" hash="595975e9005b823585ae7005b8f7dfcf"/></dir><file name="Sitemap.php" hash="4af5f75017fe5bb77b533531604a539b"/></dir><file name="Observer.php" hash="036f0b83fdaedf9286941d553598cba5"/><dir name="Resource"><dir name="Catalog"><file name="Abstract.php" hash="1cd8a377251d312570c5eb3657afd0d5"/><file name="Category.php" hash="05fb05a039d929cf962d7cf5f500e1d1"/><file name="Product.php" hash="134cd9d49b0512786085d262450a6a56"/></dir><dir name="Cms"><file name="Page.php" hash="4c639ea1f9d626b9cdd9e4ac6d0ef9f4"/></dir><dir name="Sitemap"><file name="Collection.php" hash="96b6d4e3e41b9e5fa00fdda474b3d8c2"/></dir><file name="Sitemap.php" hash="cf58c50c4d3f7b2f3c2e3f96e0466066"/></dir><file name="Sitemap.php" hash="500f0f29c85e257c0f38018a5a24e553"/></dir><dir name="etc"><file name="adminhtml.xml" hash="75878bb50b464dc4369ec0eb591bc2da"/><file name="config.xml" hash="0e5e5ea7c4939d57463ebad190b1e983"/><file name="system.xml" hash="dfe986e50cd5a136827d3769400a0d2a"/></dir><dir name="sql"><dir name="sitemap_setup"><file name="install-1.6.0.0.php" hash="37b9bd783871c32a2685a22f2685229a"/><file name="mysql4-install-0.7.0.php" hash="1ff0248cb18bdc7dfc43b148d4aeeeb4"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="387f9d64e5c70357758cfd41f7d2d984"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="add73e139487436a15eaf78041a62eea"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="339be126cf5fecb42ba94c091b6bfaf8"/></dir></dir></dir><dir name="Tag"><dir name="Block"><file name="All.php" hash="2b10c43d0259b15611d361d5aa5f2220"/><dir name="Customer"><file name="Edit.php" hash="38335c42cf669e79300863f2a0ff9a11"/><file name="Recent.php" hash="dc47c04c147be4edf19b470eb9c88002"/><file name="Tags.php" hash="c18cfe297d463576d3e89b3a70317a58"/><file name="View.php" hash="58b6780632baaae5ae284e4993943356"/></dir><file name="Popular.php" hash="c7b7bd0d09459ae8d9e407ee55af6e3c"/><dir name="Product"><file name="List.php" hash="2f468bd086810c64c3fc000e6fa60190"/><file name="Result.php" hash="176d0d0503b3f2b51410666a5e4ec23e"/></dir></dir><dir name="Helper"><file name="Data.php" hash="fd848bd0f6c212495ceb27036e026771"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="08c1314720e17a9d69840bb97e08a3d7"/></dir><file name="Api.php" hash="6f2ae203c0613724468d6547fe53315d"/><dir name="Entity"><dir name="Customer"><file name="Collection.php" hash="13a8174f56f60852e5a244c7b0654e80"/></dir></dir><dir name="Indexer"><file name="Summary.php" hash="055e6136d402a80a304b556582ce4af8"/></dir><dir name="Mysql4"><dir name="Customer"><file name="Collection.php" hash="fcb051b22d3f11807a2d0a265b7fe219"/></dir><dir name="Indexer"><file name="Summary.php" hash="e5eae61043e224555d060352f291dd42"/></dir><dir name="Popular"><file name="Collection.php" hash="925799b24790135bcd9448e551b8e197"/></dir><dir name="Product"><file name="Collection.php" hash="d33a5409c13eb26f009e1374e7cf7efb"/></dir><dir name="Tag"><file name="Collection.php" hash="ae317625d040ce3b88feef9861fef446"/><file name="Relation.php" hash="1686029b634873343ea27813f44cad5a"/></dir><file name="Tag.php" hash="1ae7f46144e78b9e7a03babd7c8b1aec"/></dir><dir name="Resource"><dir name="Customer"><file name="Collection.php" hash="7ee5e5cf14204c1de84f09d17d12b7b9"/></dir><dir name="Indexer"><file name="Summary.php" hash="98d1e87f795799942bc9a38b148cc1a1"/></dir><dir name="Popular"><file name="Collection.php" hash="955c61e8c737b5a7fdf0cdff51f8ad7e"/></dir><dir name="Product"><file name="Collection.php" hash="42d899ed5fd34b4e9c360c8360ebd553"/></dir><dir name="Tag"><file name="Collection.php" hash="01ec18be96cc21e359c20132e8b8c207"/><file name="Relation.php" hash="7656c42494af35d1d5aab8897e5b68b9"/></dir><file name="Tag.php" hash="809e9c5a59411c7d7724945a7d29628f"/></dir><file name="Session.php" hash="8232aef267200f52ca854f23da795d77"/><dir name="Tag"><file name="Relation.php" hash="d9271123737d3597f53ab950f1456642"/></dir><file name="Tag.php" hash="0db7c73371824a990e1e98e3300a905d"/></dir><dir name="controllers"><file name="CustomerController.php" hash="19a82c81c2a407c54baa8c42c6f781af"/><file name="IndexController.php" hash="ed3e6346fc9d9a3d1a4896caf7a6903f"/><file name="ListController.php" hash="59a042865c7156a76625012ed805c15a"/><file name="ProductController.php" hash="d6cac64124e81c6039f8d87b147bf278"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3a5e2d7833e12167bff5538dccb62117"/><file name="api.xml" hash="5ba5cc7e306de8c6f373bb35da19dfa0"/><file name="config.xml" hash="8ba316a8a0494ee3fc5f0967dcbdc59d"/><file name="wsdl.xml" hash="e87343a710e0068dcc555ffc4b302a9b"/><file name="wsi.xml" hash="1d31787826a686590acf89ec2703b76e"/></dir><dir name="sql"><dir name="tag_setup"><file name="install-1.6.0.0.php" hash="b3505685d64341a0aa39e2d3540a113f"/><file name="mysql4-install-0.7.0.php" hash="c80119c3ca8931b21c6f83a4901493ee"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="d025d405e893633c7fa3d843970dbb61"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="62c19aaa204b99e514ac276b2e85a32e"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="9cd101ac643f0e4b411485cf1aed4511"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="e0fce96f5e2a1c7a68d6139a28430a2c"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d064708fbb9959e46c76cea8577a2902"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="b55c990d52b55f9892b81aa95f603bf6"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="c51a489802c94bb97791a8418f0ef038"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="de16b58fbe072fd9da5ea5d77602daef"/></dir></dir></dir><dir name="Tax"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Region"><file name="Updater.php" hash="9c539994222b2ccba529ef7523502f66"/></dir></dir><file name="Notifications.php" hash="13e0fea969efa49c9722b8ab03bd3974"/></dir><dir name="Checkout"><file name="Discount.php" hash="127f3423153e2d7f67cfcbaa91766602"/><file name="Grandtotal.php" hash="9acd428450dcd0adbc40a47acbad0b25"/><file name="Shipping.php" hash="fd777c58967613bf5d324250a299becc"/><file name="Subtotal.php" hash="b13f24a02859e66afa218b17eaec243a"/><file name="Tax.php" hash="7f28709d44b0746918988441f8bbf131"/></dir><dir name="Sales"><dir name="Order"><file name="Tax.php" hash="109d897cef41288ec2fe93dec035aeb4"/></dir></dir></dir><file name="Exception.php" hash="137061427d20d97d4c9a9a6818df13a9"/><dir name="Helper"><file name="Data.php" hash="f7dce31baee4fc06401afb241fbc4779"/></dir><dir name="Model"><dir name="Calculation"><dir name="Rate"><file name="Title.php" hash="02bb922f55528ebef509d5e0e9ebae65"/></dir><file name="Rate.php" hash="bbd1308fe0489fb4556a0c806fbf08eb"/><file name="Rule.php" hash="988b1cc47f7d6d228fc6540c3424a8d5"/></dir><file name="Calculation.php" hash="472b71425220842f84ff584883642c65"/><dir name="Class"><dir name="Source"><file name="Customer.php" hash="63b7119885e4ad056e0e2ad057b72d50"/><file name="Product.php" hash="d290546c2bb67c752b99188a8da2f498"/></dir></dir><file name="Class.php" hash="9f2803f07a9ea115414e8a6393d01f0b"/><dir name="Config"><file name="Notification.php" hash="212b1d132571039ec1d5e4704186df67"/><dir name="Price"><file name="Include.php" hash="005b4273aa8924a1a544813baf0614f0"/></dir></dir><file name="Config.php" hash="0b48517dcfcdf7eefb7634085eeeb3df"/><dir name="Mysql4"><dir name="Calculation"><file name="Collection.php" hash="acee2081ff6130c31e803cf7357370fd"/><dir name="Rate"><file name="Collection.php" hash="6639d010cfd018b433d83f8e7a22c59a"/><dir name="Title"><file name="Collection.php" hash="91c99b4433579b91c71269feb6dbbefd"/></dir><file name="Title.php" hash="0e89072d83e4777442040a7574aa83d1"/></dir><file name="Rate.php" hash="313f71cfb3a2bafb2c32a1525826e198"/><dir name="Rule"><file name="Collection.php" hash="7012224a3a48324cd2a150813109886f"/></dir><file name="Rule.php" hash="2b6c704f4c2638a3437ef3a854fc25e8"/></dir><file name="Calculation.php" hash="3456ca2272f2b3cae2da6b6871f30c41"/><dir name="Class"><file name="Collection.php" hash="d7eb62ee3ec9a1c6646b0635d717ea51"/></dir><file name="Class.php" hash="0ed3a7f6a226f1a3a7153ca6edaaa0f0"/><dir name="Report"><file name="Collection.php" hash="7c4f76e0bbab563d0e9500ba29c7c84e"/><file name="Tax.php" hash="9d4663271b07a6ea06f6d2fe050d77a0"/><dir name="Updatedat"><file name="Collection.php" hash="f4e3a896c5ed84b877089aef1c4d80ab"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="4f54d51918aa5eb195e6afc8a1eb45a7"/></dir><file name="Tax.php" hash="9acb3b525dac90052b49438a62297eb0"/></dir></dir><file name="Setup.php" hash="e2b2c63fb65d21a63545b6350bcc9ba9"/></dir><file name="Observer.php" hash="435baf91ff86b4bbf951b8fe5c043366"/><dir name="Resource"><dir name="Calculation"><file name="Collection.php" hash="a656ca320a7a842e9e7345e5bf90fe1d"/><dir name="Rate"><file name="Collection.php" hash="a9dad3a3547763d54a6f2e8397ab8939"/><dir name="Title"><file name="Collection.php" hash="71e03bcc404205a2e00508af30059c68"/></dir><file name="Title.php" hash="1799ff0b83154a012e253fd791937746"/></dir><file name="Rate.php" hash="bf5436c06b9739b445ec524d4025b5ea"/><dir name="Rule"><file name="Collection.php" hash="b4e8a702efc1c248a836ddcf2ccf04c6"/></dir><file name="Rule.php" hash="aff96159602561fed62afd38f9363d19"/></dir><file name="Calculation.php" hash="6dbf4e382a27389417ed16649446bce1"/><dir name="Class"><file name="Collection.php" hash="b57891d2fa76e7723cec725c0d9adc89"/></dir><file name="Class.php" hash="6b774638de6d33f5379f12c22481493f"/><dir name="Report"><file name="Collection.php" hash="840ab6e77345d6637c666e7b9aa91e84"/><dir name="Tax"><file name="Createdat.php" hash="453488bd85f0c73489271c209560b862"/><file name="Updatedat.php" hash="438e8ec8a41bb88e05c77b6f465b0bba"/></dir><file name="Tax.php" hash="75c988eb5f91331aff24ea0bcb4bf856"/><dir name="Updatedat"><file name="Collection.php" hash="9df584cdf5b13ecd84a78f33d288f38f"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="e3c20cf620eef255710accd7b9da2ff1"/><dir name="Item"><file name="Collection.php" hash="f6522bc0d72f91c690fee45362cf3900"/></dir><file name="Item.php" hash="129e05491979b151ded3b8c07b1e973d"/></dir><file name="Tax.php" hash="ddd7f31e7e0ca5b52d46250c6ee3876d"/></dir></dir><file name="Setup.php" hash="04a2c38ee0899c7a021a9ff6bae13962"/></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Item.php" hash="0eed1d9b7192bac284302d1a8e91b04d"/></dir><file name="Tax.php" hash="5e710edf3ec7da8ef92b2ce5e5c92c94"/></dir><dir name="Pdf"><file name="Grandtotal.php" hash="4ae9ecc456bf14ac11d1438157dbf141"/><file name="Shipping.php" hash="685e7f8e542622614f8c55107a275de8"/><file name="Subtotal.php" hash="9c4ad817f5ba7efeb4efb4bcbf7995c6"/><file name="Tax.php" hash="b30bf4ee2e5a561e02cbd8a09f60c58b"/></dir><dir name="Total"><dir name="Quote"><file name="Discount.php" hash="a9de231ca3a7f526a59c3d6d0fe2736f"/><dir name="Nominal"><file name="Subtotal.php" hash="b0700ee2ba5ddbaa32f1c52c70446cf4"/><file name="Tax.php" hash="ff57753e8f29c1e643116ee1f9a6be93"/></dir><file name="Shipping.php" hash="72d95e56b11c0894e2665f7c5ce51739"/><file name="Subtotal.php" hash="188127daf6d7caf4e0b19da5406b81b4"/><file name="Tax.php" hash="9ee64046fc7dbe93aa1ca28b78644654"/></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><file name="Algorithm.php" hash="3875a5df6548d2e26dd6094031eb21ba"/><file name="Apply.php" hash="24417cb46b72ae7d786a1287e65c355c"/><file name="PriceType.php" hash="3ad49e466e217f91b7a9cc0215087eae"/><dir name="Tax"><file name="Country.php" hash="4d339243a8b0ea86358c79794fe72f8a"/><dir name="Display"><file name="Type.php" hash="0d10ddfcde7846daf7a5b6289b38913a"/></dir><file name="Region.php" hash="612de787b3edcddda31cd92327f70c43"/></dir></dir></dir></dir></dir><dir name="data"><dir name="tax_setup"><file name="data-install-1.6.0.0.php" hash="72a45a706856b256b33b6a686d6770d5"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="25b715b70e89c7aad2f35837111f8f1c"/><file name="config.xml" hash="a37f7923d9572f694b345508f8f416e6"/><file name="system.xml" hash="9bfb94df858942a543d01e7bb3817b2c"/></dir><dir name="sql"><dir name="tax_setup"><file name="install-1.6.0.0.php" hash="47275f20fcb53b121a26bedd85acf189"/><file name="mysql4-install-0.7.0.php" hash="6af9a3a2032042f0a82061c648a38592"/><file name="mysql4-install-1.4.0.0.php" hash="99d14ce0508bea87cb7e7ff46d7b2ab2"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="65f0465b130ae72a2f5fdd17a9e19133"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="57ebc4d2cec035d195259bba5f2d7bd8"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="fc49129e268c5f491a72a61c06c8ca66"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="a15701c73f006ab7562fc604a7dcba31"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="942696dbd66e7ca015c2df2366f0383e"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="60cc70667b6dfdc8aa6f0a62317d447d"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="5ba42f67dbb39d056faa38e6f5293584"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="efc647f0b3a3e0edb39b5fb17b9726fd"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="73028dccf709d7589fc4fe14dd71b17c"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="5b21e927c01676fae722b6915029ab62"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="44d5d47c89504b2a6bb3bf0927983416"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="74207ee3337c8b8f2bb93c6ab56866b6"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="7a442df7deb26bcaa7398959db63a815"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="4569ddc62d6799b9888b7b5b9b11eef1"/><file name="mysql4-upgrade-1.3.9-1.4.0.php" hash="1c70836736ab8aa8f794e8738d105a25"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="568f0e58abf4abdd5a976fdf4cc1e33f"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="39d31a4422cb7a24d12d49c062e25afe"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="77a2a7d24823b1d9e785ebf88e6fefe1"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="e52eff98527c16c3450a4c686c34fae0"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="7c7ccbff4bfc4391c05576b237ba8b65"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="32016166d8e4fa6b88503fb58974e90f"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="32a7faab02716507b4354cce24265bc5"/></dir></dir></dir><dir name="Uploader"><dir name="Block"><file name="Abstract.php" hash="6e4944e5f0818e7c29fb03d61ef437f7"/><file name="Multiple.php" hash="1dc4aaa49b77b8887cf9262c4e7a823c"/><file name="Single.php" hash="611c3242ac6a31c23e6a83a96acba2fe"/></dir><dir name="Helper"><file name="Data.php" hash="119b14b7e390e1b73d38da8981f1d37f"/><file name="File.php" hash="48ec474f67f69b2deab0f4e3b025a312"/></dir><dir name="Model"><dir name="Config"><file name="Abstract.php" hash="598717f192c3feb8fc5e1c5fd396a853"/><file name="Browsebutton.php" hash="7a4de22abad5e523130109b0ef7e54d1"/><file name="Misc.php" hash="d6608560c74ab5350a3f76a27fa1aa60"/><file name="Uploader.php" hash="e9de9de6797368a7be14e07f6c3272fb"/></dir></dir><dir name="etc"><file name="config.xml" hash="c17cd380e882b6641808f4e52a0d9f10"/><file name="jstranslator.xml" hash="fa97045eb98e4bf7e7f4b76be18df90a"/></dir></dir><dir name="Usa"><dir name="Block"><dir name="Adminhtml"><dir name="Dhl"><file name="Unitofmeasure.php" hash="ba5dfe994d3152b055f9580ac3e58e4d"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="5dbe8f0326ef7a80f9318d0b2707ecd5"/></dir><dir name="Model"><dir name="Shipping"><dir name="Carrier"><dir name="Abstract"><dir name="Backend"><file name="Abstract.php" hash="9e91ce65ec1af0388b0c4456d32e1711"/></dir><dir name="Source"><file name="Mode.php" hash="d8568690e4b84fbf992362bd19ba0961"/><file name="Requesttype.php" hash="68589f59c69d5976fe153c8f4fe7eb82"/></dir></dir><file name="Abstract.php" hash="451f18c7e73d25c156487264b054bbce"/><dir name="Dhl"><file name="Abstract.php" hash="62e61c6a4dfd171a2b65e6fb1259c924"/><dir name="International"><dir name="Source"><file name="Contenttype.php" hash="0a4f3ebda2706ead647430b69e0892e4"/><dir name="Method"><file name="Abstract.php" hash="fb157d1f72ca464e8417ed73c167b5d8"/><file name="Doc.php" hash="4ea8f26b671ed220c32a492d1d1910e3"/><file name="Freedoc.php" hash="af14e65122e6e6e50a3e0dceae59a2c4"/><file name="Freenondoc.php" hash="fe699070755f3bfea90a62332707209e"/><file name="Nondoc.php" hash="f9491acea7b9fcf19a2f80b189580da5"/><file name="Size.php" hash="48e51a58a97be356f6331b3f80669c49"/><file name="Unitofmeasure.php" hash="35d02c4ecf0eac1e2f07bd4fe741ad0c"/></dir></dir></dir><file name="International.php" hash="35db2cb4d784f5a62b46cc478b4fa067"/><dir name="Label"><dir name="Pdf"><file name="Page.php" hash="d7ac2bfa030833fb9cefb76d0a823fba"/><file name="PageBuilder.php" hash="077f7f18f1f31aee2a7ce37a7b206beb"/></dir><file name="Pdf.php" hash="a44414148bf1abce2a07dbb4b3f81fd0"/></dir><dir name="Source"><file name="Dutypaymenttype.php" hash="e09767c041f9bae77700de9098e19a47"/><file name="Freemethod.php" hash="92afb8d13bc722df555df60508f8b835"/><file name="Method.php" hash="6bcf3f33fc6251155ecebb7a2a237539"/><dir name="Protection"><file name="Rounding.php" hash="4e4dc5c4f76b64972d18ecb788fca908"/><file name="Value.php" hash="b47fd2001a57fef4942be3e784382324"/></dir><file name="Shipmenttype.php" hash="5cbfeef6890b5970fc8ccc55f580acc0"/></dir></dir><file name="Dhl.php" hash="477ebaa5f0beda378372c85238c6e93b"/><dir name="Fedex"><dir name="Source"><file name="Dropoff.php" hash="758baf8dd0c2712bff118b2ddce3809d"/><file name="Freemethod.php" hash="fb49427126fd659914106808656031e2"/><file name="Method.php" hash="bd03b725b0d2cefa0f6677c9acf75336"/><file name="Packaging.php" hash="e299e8cee3e12f7c0f2662cb23484abd"/><file name="Unitofmeasure.php" hash="00b65bb159c2d0a786266878dde01def"/></dir></dir><file name="Fedex.php" hash="9c574bcdd34f07d02183b7ff61f34b52"/><dir name="Ups"><dir name="Backend"><file name="Freemethod.php" hash="3facd57849c49291ec969865e79b7395"/><file name="OriginShipment.php" hash="68122e78998b4bfbec768a01b686e161"/><file name="Type.php" hash="bece4019afd10e9ef670a5dbc6bbb41a"/></dir><dir name="Source"><file name="Container.php" hash="f6e18ffbaa876c899fd980672664d23d"/><file name="DestType.php" hash="439d7061f0bac5f42e721e8a044596ea"/><file name="Freemethod.php" hash="345f2366c87e5e7c7a57dd660dfac1ab"/><file name="Method.php" hash="52a37667bc4b0174df75c8e13c507065"/><file name="Mode.php" hash="6ccfd387582e7c1696e2d017ff8fe87f"/><file name="OriginShipment.php" hash="cdba14537c9bc5a25f5eb2b4244f73cc"/><file name="Pickup.php" hash="60cb63ede7fdff5b84e97f4bc07a9b2b"/><file name="Type.php" hash="1ad70d88c013eedcf77235e210fe47cb"/><file name="Unitofmeasure.php" hash="cc8d95a75abe465054260c29e7379c48"/></dir></dir><file name="Ups.php" hash="cfa133745fb5c641f9b40525eca7d161"/><dir name="Usps"><dir name="Source"><file name="Container.php" hash="cef574246f5dc390bb24fb41782b0e20"/><file name="Freemethod.php" hash="94eea66308a014b81c09f380399ff4a8"/><file name="Machinable.php" hash="f9a501780b104ced4e9a17ef3dd5b9a1"/><file name="Method.php" hash="e878c4010f2efedf0705afd7ebe668df"/><file name="Size.php" hash="7dda4a9535dcfbcbb0d93c5f6403b5c9"/></dir></dir><file name="Usps.php" hash="1de3814105ec5c916967a0379820bef1"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="226528ed59016bf1b79898d7a9b1a4a4"/><dir name="dhl"><dir name="international"><file name="countries.xml" hash="f7836aaf1918cb82a65d5abb0adc8699"/></dir></dir><file name="system.xml" hash="a4e17eb8e419c2f05d6da3ae05a2dada"/><dir name="wsdl"><dir name="FedEx"><file name="RateService_v10.wsdl" hash="352ed0cd739b31d42d206aba31bf4c31"/><file name="RateService_v9.wsdl" hash="5e698519a3b3ae3dcea2105545053763"/><file name="ShipService_v10.wsdl" hash="4e661e70491a1af695c27878610054e2"/><file name="ShipService_v9.wsdl" hash="9c3779aa87540dcae41b43b16b724df6"/><file name="TrackService_v5.wsdl" hash="89cc7077a8fc439446e70bac0ca0f0c1"/></dir></dir></dir><dir name="sql"><dir name="usa_setup"><file name="install-1.6.0.0.php" hash="26fbb7e34b87914697cc6871edda22a4"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="197e9bc2a98589def93089b694673615"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="13d60fce09900951eae682f8b13fc2a1"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="c06b0b3e1f934ad33101607adfe53247"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="6711b63165039cfe60cf00e735d5e5ff"/></dir></dir></dir><dir name="Weee"><dir name="Block"><dir name="Element"><dir name="Weee"><file name="Tax.php" hash="dd1d38a54afff3f31078819c31bd5f9f"/></dir></dir><dir name="Renderer"><dir name="Weee"><file name="Tax.php" hash="12f03363dce2e8a1a56ad1c991de6a14"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="65fb35999d1f4c94c230460297249720"/></dir><dir name="Model"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="e3f8dfb51300048782418fd06e08a06d"/></dir></dir></dir><dir name="Config"><dir name="Source"><file name="Display.php" hash="b43c72a43a59c1143912288e12d913b3"/><dir name="Fpt"><file name="Tax.php" hash="9f9d2495c23e82df238b6458f8388ace"/></dir></dir></dir><dir name="Mysql4"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="32c06b72032549792c9638fceed8c587"/></dir></dir></dir><file name="Setup.php" hash="54dca7d7912ba877f6596fbeae69af70"/><file name="Tax.php" hash="0fde280f65cb36288adb2e57cd3eb40c"/></dir><file name="Observer.php" hash="528f551ccda1e7ad35f2a98cc2719060"/><dir name="Resource"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="67d628ba369d04c642e69b150c073c7b"/></dir></dir></dir><file name="Setup.php" hash="d2aae8d090a8bef563e1c763488f063b"/><file name="Tax.php" hash="b23f72ae8ac264ab7fb2c0485d7d2277"/></dir><file name="Tax.php" hash="5863d32ec6ee177a4f77e9b31ed01d14"/><dir name="Total"><dir name="Creditmemo"><file name="Weee.php" hash="b99109bcf0327463824430c6d52b8744"/></dir><dir name="Invoice"><file name="Weee.php" hash="8dba424309d6fe761905d4c8e4021f85"/></dir><dir name="Quote"><dir name="Nominal"><file name="Weee.php" hash="ca2bed0f15d71df9805520cabf028766"/></dir><file name="Weee.php" hash="e7f633d68063d3b7e7fcb486d43a8c0d"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="564863c962652804d710b50caf40a30f"/><file name="system.xml" hash="6998725f0d5f5ed88d739b19cd62beb5"/></dir><dir name="sql"><dir name="weee_setup"><file name="install-1.6.0.0.php" hash="373aa75567720ce8918d6a8745e72168"/><file name="mysql4-install-0.1.php" hash="8c8bbf4877723d9f2b94f75913f4c597"/><file name="mysql4-upgrade-0.1-0.2.php" hash="79f8c5597c228f4320c23d7f948e75b1"/><file name="mysql4-upgrade-0.10-0.11.php" hash="393eed4a14dc3d1c37676fac2f236cf2"/><file name="mysql4-upgrade-0.11-0.12.php" hash="3431260605a9f5a9ada16b375300d5da"/><file name="mysql4-upgrade-0.12-0.13.php" hash="5bbd8872154955771c80c1977eced612"/><file name="mysql4-upgrade-0.2-0.3.php" hash="778548bda9fe41143db0cf45823a1471"/><file name="mysql4-upgrade-0.3-0.4.php" hash="190f38f67c5f726a93b961e34d7921b6"/><file name="mysql4-upgrade-0.4-0.5.php" hash="757b01b1356c285c04a2e5bc7402c209"/><file name="mysql4-upgrade-0.5-0.6.php" hash="702e2a896807a7b3bc635ba2a1a66a59"/><file name="mysql4-upgrade-0.6-0.7.php" hash="be2e155cde14eb7f8cc4bf638b1d81fd"/><file name="mysql4-upgrade-0.7-0.8.php" hash="0b1ae83118ac099a5560d09e158e996d"/><file name="mysql4-upgrade-0.8-0.9.php" hash="176dbc4942fe2400ea10a2525b017077"/><file name="mysql4-upgrade-0.9-0.10.php" hash="8ead68994714d0b25c5c39047f9fba02"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="19a59139ce909992c07b0425c58cd12d"/></dir></dir></dir><dir name="Widget"><dir name="Block"><dir name="Adminhtml"><dir name="Widget"><file name="Chooser.php" hash="169ce71cc8f5a01ba89ca4ec57c9a8a9"/><file name="Form.php" hash="2a80e1b1767c134726f818f995c78fd3"/><dir name="Instance"><dir name="Edit"><dir name="Chooser"><file name="Block.php" hash="b0c34d86835152a9c3d2afe02c890200"/><file name="Layout.php" hash="9bd8455d73ffba1ee4f8be01eeb9c18c"/><file name="Template.php" hash="447c7fe84f235f1923ebb2db50953cc0"/></dir><file name="Form.php" hash="a37c182ebb8950863dc9a0d776f09dd8"/><dir name="Tab"><dir name="Main"><file name="Layout.php" hash="fff4297f8ddba98eb089243531ebf763"/></dir><file name="Main.php" hash="b82b7774468a5973fa42f9755234f503"/><file name="Properties.php" hash="516dbe2d7b2d7f8756b99b1688e812d0"/><file name="Settings.php" hash="ecd469678157f228c30a9aac78102afb"/></dir><file name="Tabs.php" hash="e59f2b777dd7e94489559e671d803102"/></dir><file name="Edit.php" hash="cecc5b56b71ecffe69f651c050ef4e90"/><file name="Grid.php" hash="69a1c8ec85fd30003de6c5133c117437"/></dir><file name="Instance.php" hash="07b63add76ac1e6dfacb2afacdc05a90"/><file name="Options.php" hash="497fede60bac6b7a216df0a45b33b14a"/></dir><file name="Widget.php" hash="039dde0f995450ca2f9148c71209a996"/></dir><file name="Interface.php" hash="2cb55b8c0d6af5bd2a0758830c004842"/></dir><dir name="Helper"><file name="Data.php" hash="7f013e78ed95a1ad41ffc5f23f0ef5be"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="6b3febe92ecfd914c98c754a5eb158dd"/></dir><file name="Instance.php" hash="ee0d4cc5636ce4b2651e65b5099587e8"/></dir><file name="Widget.php" hash="e5d40bda5ff5890238d3c3d6e4527acc"/></dir><file name="Observer.php" hash="c3445374fb6906f0efde283488ba9378"/><dir name="Resource"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="e3902166a81e8722b641aedd9f95cfce"/></dir><file name="Instance.php" hash="28079677f50b80fac1f6bc488c0b0807"/></dir><file name="Widget.php" hash="3099262fdcfe8a8f16323aa6b1d7ca3f"/></dir><dir name="Template"><file name="Filter.php" hash="c843c67434cd66fbfa6a86f38549536e"/></dir><dir name="Widget"><file name="Config.php" hash="7da77d63701c312fb130a7b0feaa9106"/><file name="Instance.php" hash="9d125f015d1485e51904defdb816974b"/></dir><file name="Widget.php" hash="37c2a2a84f8fb8fcfc515b293ff53f02"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Widget"><file name="InstanceController.php" hash="218860b74b7e0f0c8353bb60ef68beac"/></dir><file name="WidgetController.php" hash="945ca2af03294aec29c45872e6644197"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="b18272a0985c3ac10406d8013faaa000"/><file name="config.xml" hash="1296d4a61cc78b03af7d12e778b0c637"/><file name="jstranslator.xml" hash="15fa15335d56f745e1451a58a6d64304"/></dir><dir name="sql"><dir name="widget_setup"><file name="install-1.6.0.0.php" hash="f5fb5499b6a63d4165afa465cb43d465"/><file name="mysql4-install-1.4.0.0.0.php" hash="d4cbcbd5b184f6f8d88d1de0c0e8d9d3"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="4caf94862163caa778280da0a38918b2"/></dir></dir></dir><dir name="Wishlist"><dir name="Block"><file name="Abstract.php" hash="2a4368fb1240108eb3ca0bf3b969ec7b"/><dir name="Customer"><file name="Sharing.php" hash="456d004729709c8d7c93d1cce98062cb"/><file name="Sidebar.php" hash="773c7e0a34e82902e643d5f6e6ba4d18"/><dir name="Wishlist"><file name="Button.php" hash="08f371025f96b0b5f1a61bf478108a4f"/><dir name="Item"><dir name="Column"><file name="Cart.php" hash="7d83a707cb3ded3870f84b071ced9926"/><file name="Comment.php" hash="f1bb301ffeb315bbc70be80fdbb54682"/><file name="Image.php" hash="ed984449a33f12e4a14bf3ee4ae83283"/><file name="Remove.php" hash="05160b4067a96a0929287540508aa2f2"/></dir><file name="Column.php" hash="c6b2b4381ad3e3379c7fc0c536a12d96"/><file name="Options.php" hash="d73c2dfb807e650368066856fecef77b"/></dir><file name="Items.php" hash="089145c3af734b031ffff57008f6f562"/></dir><file name="Wishlist.php" hash="e4b1ee5fb9f8588ff4f7822ffb98dab0"/></dir><dir name="Item"><file name="Configure.php" hash="d088576750ccf8037a03695d1438087f"/></dir><file name="Links.php" hash="2655dcb3efac4930924e6b58bc5f5075"/><dir name="Render"><dir name="Item"><file name="Price.php" hash="cb0b316c82175eac440a4d6846da4b78"/></dir></dir><dir name="Share"><dir name="Email"><file name="Items.php" hash="9d80a790d02b536963c7e88eae6b95ce"/><file name="Rss.php" hash="0838f3cfec5688655a8642874552b823"/></dir><file name="Wishlist.php" hash="8ff7ff53e213f270377969b3558c0f0e"/></dir></dir><dir name="Controller"><file name="Abstract.php" hash="99a465e8de4587316cdfa8b8ee74620e"/></dir><dir name="Helper"><file name="Data.php" hash="4e16099480123dc7c31a7e58df83289b"/></dir><dir name="Model"><dir name="Config"><dir name="Source"><file name="Summary.php" hash="8db150e8cd58659adb15ba1216d5b864"/></dir></dir><file name="Config.php" hash="9b36ac4d278559067440f0db63584bdb"/><dir name="Item"><file name="Option.php" hash="002538fc6f15eaeff15576e02ff9d5d1"/></dir><file name="Item.php" hash="af65dabdad473bbae1de031daf9f1fb2"/><dir name="Mysql4"><dir name="Item"><file name="Collection.php" hash="a0878abb3d34f513d74d644e5d6a6b5b"/><dir name="Option"><file name="Collection.php" hash="c32c1b96b6cb1a5d220d2f4da4842068"/></dir><file name="Option.php" hash="2cb17ff416a0c3e10fbe5c0f87131a14"/></dir><file name="Item.php" hash="dc6643f16dc4c4b30ebc7b8f40b772fe"/><dir name="Product"><file name="Collection.php" hash="ce35de73b53e36b821d5f39681deed3d"/></dir><dir name="Wishlist"><file name="Collection.php" hash="e3055aa7f4420786d4ab7246a19ce4c9"/></dir><file name="Wishlist.php" hash="ce4a3be4f46f359f8b9e8d97a132dde5"/></dir><file name="Observer.php" hash="eec0fe965db7b03ad718ef5b5431899d"/><dir name="Resource"><dir name="Item"><file name="Collection.php" hash="5859138d39949c65768c8c205fcbae20"/><dir name="Option"><file name="Collection.php" hash="5b509abd69357bd6f4f5bfb4ce1f0a2e"/></dir><file name="Option.php" hash="a9520ad57cd860ef7a6b692f1e495604"/></dir><file name="Item.php" hash="92cb2dd3e24b0e6bd2ef2845d6c7d094"/><dir name="Product"><file name="Collection.php" hash="79761acc3422b92c21b0dae222e8b3b9"/></dir><dir name="Wishlist"><file name="Collection.php" hash="7b9722281bd55802b91ef20eab53255b"/></dir><file name="Wishlist.php" hash="78c5b1d349978896cea12317ed382fdf"/></dir><file name="Session.php" hash="9d74602cc1a45399e7b97f70df2c17b8"/><file name="Wishlist.php" hash="62fa9d7924b61421f382b0c01b6dda92"/></dir><dir name="controllers"><file name="IndexController.php" hash="083239ca58be27c828dbba8a5afb5215"/><file name="SharedController.php" hash="72a145bcb802ea7505c9bcb6f4e85a2f"/></dir><dir name="etc"><file name="adminhtml.xml" hash="027373e7b6da22b634a79733660c267c"/><file name="config.xml" hash="42860b28fefb8230e54b66efc6cca7e1"/><file name="system.xml" hash="b3451ddf7936228ac9c4319d0f896f0c"/></dir><dir name="sql"><dir name="wishlist_setup"><file name="install-1.6.0.0.php" hash="c086bab117e32d9b2a37be6f6841fa8b"/><file name="mysql4-install-0.7.0.php" hash="83b22b61bfe862192d54321cd89ee3e6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="1fec6213ffc583c317f1cc8b01421f5b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="fe9e1be0465528dcc9b9f9a4bc33f671"/><file name="mysql4-upgrade-0.7.2-0.7.4.php" hash="6aad117dd4ed68cd7fabfd28f52c5eb3"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="17b24b6b18e8b60c85c2bd24542b18a4"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="1492241a61245378b59422098d922dc5"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="560fde491b85eb08575a212137e4dc77"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="ad907977c112455072ec3877caa6467f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="6458a21c207db69ec3b0ff16ece201e9"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e7de27080f47c179fa64044b7c7f01ef"/></dir></dir></dir></dir><dir name="Zend"><dir name="Controller"><dir name="Request"><file name="Http.php" hash="92d5e6e2538a8c23af43faae8200c60b"/></dir></dir><file name="Date.php" hash="95bf218944785f606f22c2ea0c077f5d"/><dir name="Db"><file name="Select.php" hash="28f3efa5f9797af22f899fb525dbb44f"/><file name="Statement.php" hash="4b5b39a1e1c651ab9d6db332c882fdf7"/></dir><dir name="Filter"><file name="PregReplace.php" hash="1b5bbd52c2b2d17f19db273606e5ddfc"/></dir><dir name="Form"><dir name="Decorator"><file name="Form.php" hash="fbd6a6687ef13a8b7ba416c1ca50dd38"/></dir></dir><dir name="Locale"><dir name="Math"><file name="PhpMath.php" hash="a95d7d3d0d7220b47d0e518ffad508f7"/></dir></dir><file name="Mime.php" hash="f216d84221e3d7601822b4c95948aeaf"/><dir name="Serializer"><dir name="Adapter"><file name="PhpCode.php" hash="d19044ca7b67e672bb9627f572f1a069"/></dir></dir><dir name="Validate"><file name="EmailAddress.php" hash="e04917b783b4880bdc984e7774abf7a6"/><dir name="File"><file name="Upload.php" hash="a5de679b71a82a061dbddd3afde626b2"/></dir><file name="Hostname.php" hash="08c032ea8831e62e79c792e274220aa9"/></dir><dir name="Xml"><file name="Security.php" hash="7366a7b9e2dab5551b557f49d900d6a1"/></dir></dir></target><target name="mage"><dir name="app"><file name="Mage.php" hash="757d8a3309bfed2157db4797c9bbb257"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name="bootstrap.php" hash="f4a82f3d5b3e180f6c3edaf54400ce9d"/></dir><dir name="."><file name="cron.php" hash="acaf5a64a15dacb758ac99767e8da6a4"/><file name="LICENSE.txt" hash="59563e7be45096d0833dade102989042"/><file name="index.php.sample" hash="516477ded8fca96db7b7baf32cc12677"/><file name=".htaccess.sample" hash="971c336db60ac86ae96b5c5871be1e8c"/><file name="LICENSE_AFL.txt" hash="45a399f2095030865fb962263ccd7506"/><file name="LICENSE.html" hash="caf0a79ffb5e4719f9f4de286f253a61"/><file name="cron.sh" hash="0fbc521a7d6c9ba5460c3184967e0f12"/><file name="install.php" hash="765ccaa3255ba707420b760e1fc78ffa"/><file name="php.ini.sample" hash="d7412c2f78440a96fc2d9378ccf460cb"/><file name="get.php" hash="72c6c8b5ea9450a46d2852448d39ded3"/><file name="RELEASE_NOTES.txt" hash="7c28dc7c4b41ec8819352e0c97bbdb1c"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="api.php" hash="c254de5be8783255e05b7161392ec7ca"/></dir><dir name="errors"><file name="404.php" hash="52eb809b4ac842f5d8b8a0e8162fb87d"/><file name="503.php" hash="ad502fac41a76914095ee504186bb60a"/><dir name="default"><file name="404.phtml" hash="060eed9c360b7f2b7c835e396257697b"/><file name="503.phtml" hash="a4f4cdf8c571de3bee43f3334a5e3236"/><dir name="css"><file name="styles.css" hash="08e8a2dd4953f273a86c6b5105c14956"/></dir><dir name="images"><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/></dir><file name="page.phtml" hash="6cbf2242c9e7c370fd3eca50f3a74a19"/><file name="report.phtml" hash="06f47a20a74d6eb5cfd9f6ab0a3091fa"/></dir><file name="design.xml" hash="92f4586ad3d45a8a05fc342035669d78"/><file name="local.xml.sample" hash="83c646d259d7b0afbcf7878c352dbd1c"/><file name="processor.php" hash="885881c4fa60a3e97f3ae351b8d81110"/><file name="report.php" hash="3de9c5efc110fc6dd30941dedf33ae4d"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/></dir><dir name="var"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="shell"><file name="abstract.php" hash="40f2c3410dfc2a0b676a5e58c696a510"/><file name="compiler.php" hash="f2d926c4a51d2197def3c66c51205d08"/><file name="indexer.php" hash="2284eebdec56889a7de2ebd959757bf2"/><file name="log.php" hash="0544716ccbfa851341951cdd5eae6f7b"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="lib"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="media"><file name=".htaccess" hash="08de5b2f5ea1ce6f51f40a19bacbf42e"/><dir name="dhl"><file name="logo.jpg" hash="68500df59e568e01333ba078a262ca27"/></dir><dir name="downloadable"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="customer"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></target><target name="mageetc"><dir name="."><file name="config.xml" hash="26e7fcad34e33bf1c86d34aa5229569f"/><file name="local.xml.template" hash="d618514ef235cc0766c28d533a0ff0ae"/><file name="local.xml.additional" hash="dcf73b5a1b54822cdccd79610e4f47ff"/></dir><dir name="modules"><file name="Mage_All.xml" hash="54bb2aced1306adc8062f7faaf463699"/><file name="Mage_Bundle.xml" hash="0427fde4b98189033d22c475bf952aee"/><file name="Mage_Api.xml" hash="099ab4ebf639c4d7e08610a9abacdfef"/><file name="Mage_Downloadable.xml" hash="8e907dc0be6e843acca4cd9ad5183e33"/><file name="Mage_Weee.xml" hash="ed33da8b3c051a2f05cec8691b80a836"/><file name="Mage_Widget.xml" hash="62f954220f02a866f1c195544198b57f"/><file name="Mage_Connect.xml" hash="62fbc51b1e64cb580ebe81e8b89d72fd"/><file name="Mage_ImportExport.xml" hash="e1591ab0bf438c3d2868cfb794fd2716"/><file name="Mage_PageCache.xml" hash="a4ec3cac551d62995c97cedd99a2fdd1"/><file name="Mage_Persistent.xml" hash="3c16a3e0c22c7c2398253afd7f3231d5"/><file name="Mage_Authorizenet.xml" hash="54837c3b1432c6074de7add7da07fc43"/><file name="Mage_Captcha.xml" hash="a38d5a04b956f3f45f50540a1359bfb8"/><file name="Mage_CurrencySymbol.xml" hash="334f1b4b44a8a235da5aa3ff7d693e30"/><file name="Mage_Api2.xml" hash="cb422c0dc04c27e86a481ee1d861c36c"/><file name="Mage_Oauth.xml" hash="3ae635189b55f252c5e94d4a9ee11b6b"/><file name="Mage_ConfigurableSwatches.xml" hash="e2eaeb2cc79a53541fe54aa53c412307"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Varien</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Google_Checkout</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.17</min><max>1.51.1.17</max></package><package><name>Lib_Js_Mage</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Phpseclib</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Mage_Locale_en_US</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Mage</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Magento</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Pelago</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Unserialize</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_IDNA2</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package><package><name>Lib_Mcryptcompat</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Core_Modules-1.9.4.1.xml b/var/package/Mage_Core_Modules-1.9.4.1.xml
new file mode 100644
index 0000000..21ed885
--- /dev/null
+++ b/var/package/Mage_Core_Modules-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Core_Modules</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Collection of Magento Core Modules</summary>
+    <description>Collection of Magento Core Modules</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:53</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Admin"><dir name="Helper"><file name="Block.php" hash="458b8f115baadb9bb2a64772ecf6faaf"/><file name="Data.php" hash="ee37966b67fede75d28e2bd4b642a206"/><dir name="Rules"><file name="Fallback.php" hash="63a2a06fcc65d1365fe14389b0cc8590"/></dir><file name="Variable.php" hash="e6a48f57af455ab3f3610a7094680bf0"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="df761d8226d98aebd5047558c90dddc5"/><file name="Time.php" hash="8581922d946be6f1e6496228f250d63f"/></dir><file name="Resource.php" hash="c78602679aa503a4641100a70d87dd21"/><dir name="Role"><file name="Generic.php" hash="8e268c160dc69b1f052e1948b3772cf4"/><file name="Group.php" hash="85cbd9ce11fa91cd866387e7f2241cf3"/><file name="Registry.php" hash="10ae5d0ae8eb22282213406a3b1c6b57"/><file name="User.php" hash="45dfe3b059b4d76232dd0f4266d27de4"/></dir><file name="Role.php" hash="8319d780dd06ac1ee61b34b9bd9b1cf5"/></dir><file name="Acl.php" hash="f1a340153512be4e5809f5dac8369d90"/><file name="Block.php" hash="2c43da933450e800f6dfe9b44342153b"/><file name="Config.php" hash="5a9ff605e890d318845b08fce172cd87"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="1d6d5abcdf73801aa101061e1aa65f06"/></dir><file name="Role.php" hash="86f57a0a161f1c2f83f6d024f4c2912c"/></dir><file name="Acl.php" hash="4d305204a82da4aac2da4610b1e0124d"/><dir name="Permissions"><file name="Collection.php" hash="18351c0c29cfc2b5aeda23676981ee6b"/></dir><dir name="Role"><file name="Collection.php" hash="81c32bf683040142c56c4d7908eea7b2"/></dir><file name="Role.php" hash="c273803640f531fe3a70789c138bb2d5"/><dir name="Roles"><file name="Collection.php" hash="c49a4a37edecd189de05abd22317afb9"/><dir name="User"><file name="Collection.php" hash="d2a2541d7b716cb149e8bf85892de2e5"/></dir></dir><file name="Roles.php" hash="7ce5c01f31ab0a0a17733dd5d287d971"/><dir name="Rules"><file name="Collection.php" hash="d899f64d25b4b94c8af851758d7aae23"/></dir><file name="Rules.php" hash="bb1854a73b92b474a8b08e1cc3744a55"/><dir name="User"><file name="Collection.php" hash="4c660da859de8fc555ec5762ddcb36e0"/></dir><file name="User.php" hash="2476a65f5413ca88bc472e667d1e2fae"/></dir><file name="Observer.php" hash="fa5800ac1cf353a58ac6c54302b00092"/><file name="Redirectpolicy.php" hash="63c1657f8bc4057fbff402a787f5b4b3"/><dir name="Resource"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="f303429166be37291210a09bf5a5b7b0"/></dir><file name="Role.php" hash="024d8fd83ad0202cabd4681ad49d5353"/></dir><file name="Acl.php" hash="4fcc23cfdb5640f0d7a586106b11b1a4"/><dir name="Block"><file name="Collection.php" hash="47c9c77cf4fbcf4e23e92177883e61c4"/></dir><file name="Block.php" hash="6da7836e73f2b7bcd6ffe441dcb2d8b5"/><dir name="Permissions"><file name="Collection.php" hash="f189808b46860de0a1371b6e4c4893cc"/></dir><dir name="Role"><file name="Collection.php" hash="a08a34456c4d21b735949239d8c88158"/></dir><file name="Role.php" hash="9f10fd18cb941f3282ab0b6612fdc2eb"/><dir name="Roles"><file name="Collection.php" hash="9bee6ac75a949e5b403cfd19d259fd06"/><dir name="User"><file name="Collection.php" hash="e7e9996a1128f35cb87b9aa75fdbe2a5"/></dir></dir><file name="Roles.php" hash="6d9d4a4704bd62b7c2af7f7c1f0e244e"/><dir name="Rules"><file name="Collection.php" hash="9aa586accf6b402ca57b5930dbdbc21d"/></dir><file name="Rules.php" hash="9b48b047903611a52d91dda257048da9"/><dir name="User"><file name="Collection.php" hash="d68fbdc9b6e0b59ece07b8a9e6786735"/></dir><file name="User.php" hash="19f9662e179ae93b95a7414197e1e97b"/><dir name="Variable"><file name="Collection.php" hash="bf75d58b6748a9061cf9f0d894444d6f"/></dir><file name="Variable.php" hash="381276f5ab482fac9f276a7bf09edb1c"/></dir><file name="Role.php" hash="0c579d2eb5a9f993e5e3329286ba02e7"/><file name="Roles.php" hash="be8be3c2225ad59cec09aad3696cd154"/><file name="Rules.php" hash="9aec2dcc8843a9b2aa7c2f169b27967d"/><file name="Session.php" hash="6fb43a7459f0af522f74b9044f41ed66"/><file name="User.php" hash="ef71c71301203ba99064fc7473ad9f30"/><file name="Variable.php" hash="aec37b73e2b07b24642873047404f20c"/></dir><dir name="data"><dir name="admin_setup"><file name="data-install-1.6.0.0.php" hash="7113336c6b7992a5336c8ca3d38a2c52"/></dir></dir><dir name="etc"><file name="config.xml" hash="fa53dadd6e1989703d157a53dfc29920"/></dir><dir name="sql"><dir name="admin_setup"><file name="install-1.6.0.0.php" hash="1c84ae65e4147d21198b1f6ff96a8090"/><file name="mysql4-install-0.7.0.php" hash="dc2ec63c66efe0667052f5695093efe2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="893eba8a43a2437db98f8f089deba809"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c256c803009aaa3b08c09811fe01ce64"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="3c493153e71d4fa917b648c4b3ab0399"/><file name="upgrade-1.6.0.0-1.6.1.0.php" hash="1558790a6f8e8cf5c778a242fbe756ee"/><file name="upgrade-1.6.1.0-1.6.1.1.php" hash="4d46adc07a9f68c089c6ee25ebb54064"/><file name="upgrade-1.6.1.1-1.6.1.2.php" hash="9025a95c29a05a354458e97a9d7444b9"/></dir></dir></dir><dir name="AdminNotification"><dir name="Helper"><file name="Data.php" hash="bdf63a1450e6a0d77647163e535a1a7d"/></dir><dir name="Model"><file name="Feed.php" hash="1cbe43f8f0f79d4ba4d104d022485e40"/><file name="Inbox.php" hash="822e30a30c67ebc5651a059370edc50e"/><dir name="Mysql4"><dir name="Inbox"><file name="Collection.php" hash="0c711250151fb41968688e8a7baaa8f5"/></dir><file name="Inbox.php" hash="c8767a365e9f9b0302aebc42e72d8761"/></dir><file name="Observer.php" hash="a85254ea61683a6146e266c46e4cfa91"/><dir name="Resource"><dir name="Inbox"><file name="Collection.php" hash="8a1c2a44972cfbf2a0b5c24da5133318"/></dir><file name="Inbox.php" hash="95e2ddc1912bd2efa08a618bdc542721"/></dir><file name="Survey.php" hash="c71fe449197c0a95484361b06e1acc9c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9184c5e0cd123342fef181533713a39a"/><file name="config.xml" hash="4bf128768d14ef45927ca932d8423d58"/><file name="system.xml" hash="627114a3b4fd2cdebe5fb76a6cfb41ca"/></dir><dir name="sql"><dir name="adminnotification_setup"><file name="install-1.6.0.0.php" hash="fabadefeaa0cbadc7d765e49b00c03e2"/><file name="mysql4-install-1.0.0.php" hash="7be8540787e2171bca831efa9692cdc2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f1039f623c2ce22aaa01d97277e0523e"/></dir></dir></dir><dir name="Api"><dir name="Controller"><file name="Action.php" hash="bd77a9bdaf5850d9bfad340174c12d17"/></dir><file name="Exception.php" hash="d1e38258a214dc8db2751c8e67058737"/><dir name="Helper"><file name="Data.php" hash="0235c25d21316a6b1bf71e5f06602892"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="4c325d339c19b0bbb8a14b180556920a"/><file name="Time.php" hash="06cc212749e4d7e2a8f5afd03705414d"/></dir><file name="Resource.php" hash="aac365b2c3ee9b552e7fc375a609187b"/><dir name="Role"><file name="Generic.php" hash="1a92e79f592330147dfc5812c749b7fc"/><file name="Group.php" hash="7524be45a0860a7ade02a8d94037464f"/><file name="Registry.php" hash="c728275604c9e3710b3001973d10fd00"/><file name="User.php" hash="653adf396b08780f2175f7c96548aecc"/></dir><file name="Role.php" hash="bc68c60309dacff590e7ca5687b0618e"/></dir><file name="Acl.php" hash="6d3a947164d97c653d7408b28965ebee"/><file name="Config.php" hash="0d7cbdc5a29b2ea9e0018b9ec3084bcc"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="0021a4898d1b458957eb82bc056f468e"/></dir><file name="Role.php" hash="9dba1e6bb824820fce1b2e3cb878bebd"/></dir><file name="Acl.php" hash="f9a5a4868835e3fb9ef2befc2e2fca97"/><dir name="Permissions"><file name="Collection.php" hash="93e7ed97d480968828126f8cbac2b664"/></dir><dir name="Role"><file name="Collection.php" hash="e564b8136d2beebd7dfd3c8795a6e7fb"/></dir><file name="Role.php" hash="d2303886929c5a2d9484ab6dc9fc648e"/><dir name="Roles"><file name="Collection.php" hash="39f697e304e7a4a2978c35a4d89cf0fe"/><dir name="User"><file name="Collection.php" hash="d51c2908f06e072ed90c8fd252383549"/></dir></dir><file name="Roles.php" hash="6305b9320e2bd030fb2081df86e91004"/><dir name="Rules"><file name="Collection.php" hash="e3edf62d099fab993099fe7978f509e1"/></dir><file name="Rules.php" hash="e6b2ebb7b9f814d6707a299b239dd5e5"/><dir name="User"><file name="Collection.php" hash="b0f3a87ba9cc21ec9cad2c3f70c8006a"/></dir><file name="User.php" hash="2a6f6b9b53cdf0a51ad2c9e253c483a9"/></dir><dir name="Resource"><file name="Abstract.php" hash="b40505a25b52fec30b0301500a4c496e"/><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="c39386eacf0f62cb47f5f5e0d7014901"/></dir><file name="Role.php" hash="2928e279cac38426a7412c14807c2213"/></dir><file name="Acl.php" hash="b4d9d34d5da6ed935cc21116435dc471"/><dir name="Permissions"><file name="Collection.php" hash="1ed55c2383301800a07667bc81cc64b3"/></dir><dir name="Role"><file name="Collection.php" hash="389bc113941dbc97b9d66f1f466bc517"/></dir><file name="Role.php" hash="d7024cb60533f6f695d7b2640cdb3b29"/><dir name="Roles"><file name="Collection.php" hash="2ecc66e5450ce840ba0815baae50b628"/><dir name="User"><file name="Collection.php" hash="843c0817b32d47a643fe228d8da97658"/></dir></dir><file name="Roles.php" hash="7ec43dce63b207595cdf18d11f3678de"/><dir name="Rules"><file name="Collection.php" hash="bce86b29edc97fcc30288a6c17087cb9"/></dir><file name="Rules.php" hash="5c5e0f6b3f7ebfcf40b262897eb3136b"/><dir name="User"><file name="Collection.php" hash="74e42dad01f99a8d90ecc0ee9bc434f9"/></dir><file name="User.php" hash="940e1623c70b37ba21d9f379298d068b"/></dir><file name="Role.php" hash="1a34866ab10a5126f886b37ad9393026"/><file name="Roles.php" hash="b69872a87d5080c393bbee4946347e41"/><file name="Rules.php" hash="bfad6890c425f6ef2867454dc7a09257"/><dir name="Server"><dir name="Adapter"><file name="Interface.php" hash="49d97f0fdf244cba251f2e71df4532d6"/><file name="Soap.php" hash="aea4f7712b8e053cfb3ad0b2aa579a58"/><file name="Xmlrpc.php" hash="f4d77d694c5c55097cb816f94217f438"/></dir><dir name="Handler"><file name="Abstract.php" hash="cf7483db39b44c1234fb852592770d05"/></dir><file name="Handler.php" hash="402d95a6f76155ddfc676b6a71baa259"/><dir name="V2"><dir name="Adapter"><file name="Soap.php" hash="3a179c5fb3150c3d8aba66e8999866e2"/></dir><file name="Handler.php" hash="6a939cce44aa9cde7be5b5954c5d753a"/></dir><dir name="Wsi"><dir name="Adapter"><file name="Soap.php" hash="9b2e5affb656129f9e71a0c64853eb84"/></dir><file name="Handler.php" hash="edc38c50fd82505aec0352afc03e691a"/></dir></dir><file name="Server.php" hash="b18193c91fb496f53ad7b089a4dc354d"/><file name="Session.php" hash="11b03d4e7981b9cfb1084591a0aea701"/><file name="User.php" hash="96d22cd787a295bb80a5260d134b372b"/><dir name="Wsdl"><dir name="Config"><file name="Base.php" hash="29d45f55afd1d66cf64af7444e18c559"/><file name="Element.php" hash="93d907a44ab1bc5f7d0424b83c1c501f"/></dir><file name="Config.php" hash="c5a618233b98eb5b0e37d67b65a18597"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="568e76f1884f10d0f5bf8e645ea875bd"/><file name="SoapController.php" hash="a94f525c875292024c976a3274954024"/><dir name="V2"><file name="SoapController.php" hash="7a128ce7e5dc7ba6807e059e45c346fe"/></dir><file name="XmlrpcController.php" hash="7368bbf60c4f6ea50c07b8b555ddc0ed"/></dir><dir name="etc"><file name="adminhtml.xml" hash="b4264dc427c433e5e98207dd637e5e57"/><file name="api.xml" hash="01302962e36ba24259cb3c19a035e856"/><file name="config.xml" hash="26783afff003adf6af459ea1679581ae"/><file name="system.xml" hash="b6a534e8fa06ee34c7befd27b4e44339"/><file name="wsdl.xml" hash="f0db676b04733b38f310355bb44bc3cb"/><file name="wsdl2.xml" hash="7d527421ba4b63a8a812ab6b1095891d"/><file name="wsi.xml" hash="9fb1700cf935a26e7fada90a07fae7fe"/></dir><dir name="sql"><dir name="api_setup"><file name="install-1.6.0.0.php" hash="066ad21052c5b083ab2778e26bbe4db4"/><file name="mysql4-install-0.7.0.php" hash="5d039bc1aeb7f803ab216a1139919bb1"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="4cdf27ca6d95a560f40cbc7eb2665094"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="25e09696a22644ac6aa111ed73b5655b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="15efffec7b0ef3361156df41d15946de"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="1e64826e6d3ca3d0846017cf8acaa4b0"/></dir></dir></dir><dir name="Api2"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><file name="Buttons.php" hash="4376dded28b4aa5586685e2f732ad2ab"/><dir name="Edit"><file name="Form.php" hash="0af6dc58ce485e2f59bac5a46c0d7163"/></dir><file name="Edit.php" hash="1f99242190399def7e2ca9283fe5c410"/><file name="Grid.php" hash="30bd3ba3317f12cc7c52844cf150b994"/><dir name="Tab"><file name="Resource.php" hash="7856f0dbbcc9be2dbf353d58ce480b2f"/></dir><file name="Tabs.php" hash="f54db50cb4a392c688ae6d1be77c58e2"/></dir><file name="Attribute.php" hash="d2dcf496bc82ffdf9a705a3877bb8b2d"/><dir name="Permissions"><dir name="User"><dir name="Edit"><dir name="Tab"><file name="Roles.php" hash="72a6b7a56e4274b02a365ad0f30c8165"/></dir></dir></dir></dir><dir name="Roles"><file name="Buttons.php" hash="4c579d0bc782554233f06cac17412895"/><file name="Grid.php" hash="cdbb76a0a3d30ef0daf01283767fb85a"/><dir name="Tab"><file name="Info.php" hash="e43741793c49f3777e6b392c842c1fd9"/><file name="Resources.php" hash="7054ebad58581afc4407ad8da7c079b0"/><file name="Users.php" hash="f993e6653358f42ff71db5cf9286a429"/></dir><file name="Tabs.php" hash="9d35522fc2a4c3b02255f3d60e9331d1"/></dir><file name="Roles.php" hash="af1a304185f658eb382267e449f7ee47"/></dir></dir><file name="Exception.php" hash="c21f7e48d91909cdd8ff34c7b5f5996c"/><dir name="Helper"><file name="Data.php" hash="3b3b8c14d3e0062cc169f5170e865860"/></dir><dir name="Model"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Operation.php" hash="09038220fb9d14e00b7fb1161f443e40"/><file name="ResourcePermission.php" hash="0afbf662990f30b973a7000f90e130f4"/></dir><file name="Attribute.php" hash="0a5693b841c58a4cf2b11a586ab015b6"/></dir><file name="Filter.php" hash="3c35c99209e0e44972db68289427d0c5"/><dir name="Global"><file name="Role.php" hash="fbcf77d11b3ad6b3d76f62de2631cfd9"/><dir name="Rule"><file name="Permission.php" hash="b562dc5aface03f159f364dfb221046e"/><file name="Privilege.php" hash="0e758f46f64b58efed6ef6330417bb8a"/><file name="ResourcePermission.php" hash="7c7d8f9f33daeec606c5dc68d72aa6a0"/><file name="Tree.php" hash="7b5a5f72cc5f5bcb4c880e5c1b3e0533"/></dir><file name="Rule.php" hash="b4c30ae4bf8ad5111f56d5cc5c1f4c22"/></dir><file name="Global.php" hash="b8740f8a74f44181cfe72594c9962156"/><file name="PermissionInterface.php" hash="a2da51f36241c2f2cdadb52227ebc6cb"/></dir><file name="Acl.php" hash="1573afb52fc330438eac73bfc6d11763"/><dir name="Auth"><dir name="Adapter"><file name="Abstract.php" hash="3720722eff5b1948e4b8e8283cfc991b"/><file name="Oauth.php" hash="6cb6dc6f5e261710a5a217262e300725"/></dir><file name="Adapter.php" hash="b5759916b5235990ebaf3509b3d02790"/><dir name="User"><file name="Abstract.php" hash="ba1a6bba6d01055fda5fb3efc9e5342a"/><file name="Admin.php" hash="9fb3184fd96676702c15184ea14eae12"/><file name="Customer.php" hash="4c14d7df43453f52af73fa10e773e015"/><file name="Guest.php" hash="6402fa2d5ef1b6b688ca15057675ee59"/></dir><file name="User.php" hash="53283f1d82f3f704c4dbec8808ba22f9"/></dir><file name="Auth.php" hash="d2b4b8b817d6618ff2310e7d66f82be9"/><file name="Config.php" hash="65eee46fe1d1099fb3b0516e9279ee61"/><file name="Dispatcher.php" hash="bffc0249f6f9dbb2e8f52e8558b9baff"/><file name="Multicall.php" hash="f303ee72911f0628a181b206f5727c09"/><file name="Observer.php" hash="acf8944643c694c1e0b555d12c33cdae"/><dir name="Renderer"><file name="Interface.php" hash="d580bba55508a29b09eddb0e0f753eac"/><file name="Json.php" hash="038ae9d48ddd2d00fb3a73c0dcfc90bc"/><file name="Query.php" hash="5a3fc89d32a6e4540039fd7ae36feefc"/><dir name="Xml"><file name="Writer.php" hash="b5f2fb511668c0e713b7d569460dace8"/></dir><file name="Xml.php" hash="05844d8a79ef772e98eb1516fca69c75"/></dir><file name="Renderer.php" hash="a6dd26eadb27238cc5a39fc970ce60e9"/><dir name="Request"><file name="Internal.php" hash="85db2090307e0b32c11662dc274bd260"/><dir name="Interpreter"><file name="Interface.php" hash="7adc09d4d35ea0693d440e951b02d422"/><file name="Json.php" hash="c155284d01ba4967c03bcaf2ae6f2d04"/><file name="Query.php" hash="f1a500e1b52d781ffd85214111ec46fd"/><file name="Xml.php" hash="1474e9963e826ee65adf3d83d82d5b3a"/></dir><file name="Interpreter.php" hash="55520f65c5f50dc164784d328b7cc391"/></dir><file name="Request.php" hash="dbd1366ad80c96f28e9c6df621d1ee84"/><dir name="Resource"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Collection.php" hash="e5a758eb30a4ee0b406e14d90fed3f7d"/></dir><file name="Attribute.php" hash="bff17f4c6dae72f866075aed2143a7ea"/></dir><dir name="Global"><dir name="Role"><file name="Collection.php" hash="27100e15437eaf77ad1442c57512efd6"/></dir><file name="Role.php" hash="0573edd7fbdaec6c60677bf9524081b8"/><dir name="Rule"><file name="Collection.php" hash="f0e7595e6a38d6908f02a80f51d69a77"/></dir><file name="Rule.php" hash="bf31ec43122c7148631e8353ce072ee6"/></dir></dir><file name="Setup.php" hash="39bae99a03d25ec831edfe03dae94c6e"/><dir name="Validator"><file name="Eav.php" hash="7d5b412a1011ae3ebe26f5bedcd53b55"/><file name="Fields.php" hash="e49f90a6054e9668ece648c8af135400"/></dir><file name="Validator.php" hash="0f31952b0282cb8ce0c6de1a61e6faed"/></dir><file name="Resource.php" hash="f626093895fb369a857b3d93e895f595"/><file name="Response.php" hash="cf5bafdb46c7c5cd6954b2e64f3a581b"/><dir name="Route"><file name="Abstract.php" hash="b63d027e93acd4fac077146537be06c9"/><file name="ApiType.php" hash="4e239e1601c6604a185e267f8ae126d0"/><file name="Interface.php" hash="3191c533ce588c2df505c1504c66f5ad"/><file name="Rest.php" hash="e49d49128fb02808fe5c72d4a4b06f52"/></dir><file name="Router.php" hash="ac09ccb08d4a7da221e078d8c0faafb0"/><file name="Server.php" hash="97ce9fe49ceab3e8f87fab8cef1840d1"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Api2"><file name="AttributeController.php" hash="0780ce523414d956dc51b46867b51f15"/><file name="RoleController.php" hash="0f3e02c6804c03e4c76ca8458d9aa6da"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="9b99c5a3de756424196e58a98487e4e5"/><file name="config.xml" hash="c2c3d2f8ee69cce25c6cd662391b77f8"/></dir><dir name="sql"><dir name="api2_setup"><file name="install-1.0.0.0.php" hash="790f059183189cfa3fbb348c362403eb"/></dir></dir></dir><dir name="Authorizenet"><dir name="Block"><dir name="Directpost"><file name="Form.php" hash="951236a941f006e8d3067949dbb93eb0"/><file name="Iframe.php" hash="4ee9b7b6b588d7a36108af6b36d807f3"/></dir></dir><dir name="Helper"><file name="Admin.php" hash="242ce0696a5ea9123097869120543fb2"/><file name="Data.php" hash="745bce8bee42112c10d9e52705b96e67"/></dir><dir name="Model"><dir name="Directpost"><file name="Observer.php" hash="bc0cb094c3f4393861b2f5d3c45ac219"/><file name="Request.php" hash="3042662702dc0e2a8b5fe14e6bfe36c2"/><file name="Response.php" hash="3897d872b0f7a3edc3cbbcb02985c712"/><file name="Session.php" hash="94b77b8be59e39571d4e0d399a330e4b"/></dir><file name="Directpost.php" hash="c936c0798b8e329270273c43077c48e1"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Authorizenet"><dir name="Directpost"><file name="PaymentController.php" hash="2fe86219e1e9eec3b40eed97e5ca31ce"/></dir></dir></dir><dir name="Directpost"><file name="PaymentController.php" hash="5fad7bd1934637ff441eed6ed08358f0"/></dir></dir><dir name="etc"><file name="config.xml" hash="f91ed533702d8b51aee6ed41fe8d670d"/><file name="system.xml" hash="23b31628a9b437a899924c456cf23b71"/></dir></dir><dir name="Backup"><file name="Exception.php" hash="baa8812918560125167c4b3dff59fd4b"/><dir name="Helper"><file name="Data.php" hash="a74e2b999e106365de6d702acef15621"/></dir><dir name="Model"><file name="Backup.php" hash="2f0baa336548120691c2f86c5d7d6158"/><dir name="Config"><dir name="Backend"><file name="Cron.php" hash="e3afe2dac55f4c0c21035509a7ad03ff"/></dir><dir name="Source"><file name="Type.php" hash="80d255889f3ab648ecd2b96789cd5b8f"/></dir></dir><file name="Db.php" hash="20de8464af9b44585d86542770d84424"/><dir name="Fs"><file name="Collection.php" hash="bda11a66e9485d39bbd65ef106a5827a"/></dir><dir name="Mysql4"><file name="Db.php" hash="c709100f98d4c0e594ac781818ae91c4"/></dir><file name="Observer.php" hash="e15b50bd82367ba32a07ff7e920448f9"/><dir name="Resource"><file name="Db.php" hash="126e3ee2b9bd03fb2008f958852a9931"/><dir name="Helper"><file name="Mysql4.php" hash="433085a484930534865c7096108e5b18"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1bdf439e0dd516b2793aed5b29292595"/><file name="config.xml" hash="c116519a1ac0e6b14344a154addb3bd8"/><file name="system.xml" hash="c561811e44bbf97968fbde0d3f93cabc"/></dir></dir><dir name="Bundle"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Bundle.php" hash="7ba4af5e0cc19fd57543a1e8a435e463"/><dir name="Options"><dir name="Type"><file name="Checkbox.php" hash="b4802f23317cec64155a0a854fd05f38"/><file name="Multi.php" hash="666954cfc526ff66a93794c3a4a4329d"/><file name="Radio.php" hash="3e16ee3943c4dd6db44e6aaf43669534"/><file name="Select.php" hash="bf93776f105756314e810a20aaedfbcf"/></dir></dir></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Attributes"><file name="Extend.php" hash="6b15e48fbb1d64f91c9b33bf48117d0d"/><file name="Special.php" hash="ba9c7de799a80bad0f37c88a92bbc0ad"/></dir><file name="Attributes.php" hash="282fe2257c01625167d2499502b8f28d"/><dir name="Bundle"><dir name="Option"><dir name="Search"><file name="Grid.php" hash="0a157c18808c8e97a7090ca4014f88b3"/></dir><file name="Search.php" hash="ed0a329442cf1207bd9f7e2c91e9dcc0"/><file name="Selection.php" hash="2a3d2c794fbf9754978a8e751b935821"/></dir><file name="Option.php" hash="66bb0e76f1810c7f4908f2a8b531418e"/></dir><file name="Bundle.php" hash="4076b8967fe5d7507058338ba36c473a"/></dir><file name="Tabs.php" hash="e31c5a810990ab5c089df54761082bc7"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="c0afda9392dde9b38bc71eb09151a1fe"/></dir><dir name="View"><dir name="Items"><file name="Renderer.php" hash="9a5c04f6975466b25c3baf9436bbade7"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><dir name="List"><file name="Partof.php" hash="f14e5c86ee5482519933627ec0ac3da8"/></dir><file name="Price.php" hash="cf6e7d8dfdeb7c20102d78d955c3a08f"/><dir name="View"><dir name="Type"><dir name="Bundle"><dir name="Option"><file name="Checkbox.php" hash="234a0dde586568d352a2d63bdbc1a203"/><file name="Multi.php" hash="247fb02f6773737d566cd4f30dd42585"/><file name="Radio.php" hash="e69225f7462c36f62092b9264dc3ccad"/><file name="Select.php" hash="aa02b9e489a4b817875cf8352c5cca71"/></dir><file name="Option.php" hash="4a4049d3d4528214818366dd4238a73c"/></dir><file name="Bundle.php" hash="78e470548ba63160e4c3fb5eefe3c5e0"/></dir></dir><file name="View.php" hash="adf9d177b5f714144f732974a75f693c"/></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="b4846bf466d14816fdc960bad99253bf"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="8328adc7ab06c404b5f678f52c4b36ba"/></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="c3b92627d497d6af3420a70884a9900a"/></dir></dir><file name="Data.php" hash="1df35d7602d491b3a3a5896dbe1c4439"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Bundle.php" hash="07e8532dfdf36af78680fe629726df65"/></dir></dir><dir name="Mysql4"><file name="Bundle.php" hash="a42904a5602a94bd4bc682866b4db372"/><dir name="Indexer"><file name="Price.php" hash="2d31c9d360c0c3483157283f9675399f"/><file name="Stock.php" hash="178db785d8bd219a0cd789bf1c998259"/></dir><dir name="Option"><file name="Collection.php" hash="094532247ebc66e7531f8b4d37448a6b"/></dir><file name="Option.php" hash="757bbf29c2788e7ad3c46a1abe6e8c6f"/><dir name="Price"><file name="Index.php" hash="188f493c00e63966bf9bcc817e99c578"/></dir><dir name="Selection"><file name="Collection.php" hash="450f5c62e214a2739bbd65a8bf37cafb"/></dir><file name="Selection.php" hash="94b63b71c7d37885385223f7ff0d1f4a"/></dir><file name="Observer.php" hash="086ce0bea7d0b7e9c2c6862a0445cf6f"/><file name="Option.php" hash="c3286cf424d27fa9474691f44a8fe0aa"/><dir name="Price"><file name="Index.php" hash="b6ad3d5912b14b50e83105a5cb89171b"/></dir><dir name="Product"><dir name="Attribute"><dir name="Source"><dir name="Price"><file name="View.php" hash="999c58650a57146f6115b6152c931d12"/></dir></dir></dir><file name="Price.php" hash="5714d620d44a3b78e1824fb5ed3ae01c"/><file name="Type.php" hash="940953a610d3ddf54452750d4eb09ba6"/></dir><dir name="Resource"><file name="Bundle.php" hash="dff534e1e5b1bdd46d381e534163787d"/><dir name="Indexer"><file name="Price.php" hash="87e595b484a5e306e8a9111cdc41b770"/><file name="Stock.php" hash="467fd84b1330cc43410f9a11c9a7569f"/></dir><dir name="Option"><file name="Collection.php" hash="f933036863523dac13f6d4e0c5192de9"/></dir><file name="Option.php" hash="40c76760181b30092e745caf7e71a825"/><dir name="Price"><file name="Index.php" hash="156ea664373d1e7074f604e150b47416"/></dir><dir name="Selection"><file name="Collection.php" hash="5e637bea02628db76299f9141cd69280"/></dir><file name="Selection.php" hash="b92a36a662d7c15da0b6be34a72abd28"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="03572513aa7302634912cdb25682700d"/><file name="Creditmemo.php" hash="72830f7b86d48f04fabe7dc149d0c8a8"/><file name="Invoice.php" hash="4eb93c31fddd2743e9fad84f82468403"/><file name="Shipment.php" hash="ff978de79d7517c9665d43519f2ce386"/></dir></dir></dir></dir><file name="Selection.php" hash="69baeefb547cd3e266695ba07fe05428"/><dir name="Source"><dir name="Option"><dir name="Selection"><dir name="Price"><file name="Type.php" hash="0125cebe6acd7c5d8d5ba5471c560cc5"/></dir></dir><file name="Type.php" hash="b132757f9677ca55c605266de6357df8"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Bundle"><dir name="Product"><file name="EditController.php" hash="590760cfa7cba02f55192b805db49bb7"/></dir><file name="SelectionController.php" hash="c67d92020a00d1e92fb6d1ce2d143478"/></dir></dir><dir name="Product"><file name="EditController.php" hash="c707c3f48f3513035a2e0370fb5aade8"/></dir><file name="SelectionController.php" hash="c9865d2186f986d57d2024076914b381"/></dir><dir name="data"><dir name="bundle_setup"><file name="data-install-1.6.0.0.php" hash="834e88f6e39a4494fcd6e38c054c6928"/></dir></dir><dir name="etc"><file name="config.xml" hash="6b7ab06798a4fa4854b29ea2055d1d5a"/></dir><dir name="sql"><dir name="bundle_setup"><file name="install-1.6.0.0.php" hash="262c230428893cb4bdd1a4302009b98a"/><file name="mysql4-data-upgrade-0.1.13-0.1.14.php" hash="4998433373fab9c5c49160a29a0506b5"/><file name="mysql4-install-0.1.0.php" hash="6fa016bc3431841ce3207fec2d523b54"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="effab7ebe8c2e84c0f22657191758711"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="6e550a3d455cef957ecca7ead0d280e1"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="76ef43ee7da599cd9373ef468bf005c2"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="d1ba25ae101d380cb8d68335f2ab06b4"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="124054e21b0980238b0366f0a62bb42d"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="6f5ae289258acc4522d12ac5abf4ef3a"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="ebca03c63ca3d4cb2e99f0b35e994b3f"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="3773f524d98c2e47bf89d251f80fb2b3"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="f30a13c3101129c7235e51e5354dd6eb"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="68e4f5cafb451800272abc27d177ca99"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="6eecd8118f59a2207d79b30ba264f2b0"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="ad618762396db26f49047f72c70c1c8d"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="c118caf7158504dd027d7281e447d263"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="78643674b5e2a23ee8a7fde720863e25"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="caadeb7ff995da1e38205162eba466c4"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="58c22c0e8cd208b2d835653a3dde61aa"/></dir></dir></dir><dir name="Captcha"><dir name="Block"><dir name="Captcha"><file name="Zend.php" hash="3977d0d2bf3559ea2d1a8b61e34117f2"/></dir><file name="Captcha.php" hash="43bfc5969f3760b7722881264b40e0f7"/></dir><dir name="Helper"><file name="Data.php" hash="4c2c154247df498f877b454c1502d9be"/></dir><dir name="Model"><dir name="Config"><file name="Font.php" hash="16fe5a425b5904f4f0b00812cad7942b"/><dir name="Form"><file name="Abstract.php" hash="0597e90c9258fc7e9de472b9b25953bf"/><file name="Backend.php" hash="644d7f0c08686657a8ce89e644a86ca9"/><file name="Frontend.php" hash="6653882a570c41743beaa0067a8e2cf5"/></dir><file name="Mode.php" hash="0fcefa5ea27784bdd4b6e125ef68fff3"/></dir><file name="Interface.php" hash="fb4478e8efbcf6e5da049262cf66d888"/><file name="Observer.php" hash="b092094a1eddec47b3154d929d77bae6"/><dir name="Resource"><file name="Log.php" hash="5a0fcf217682a204b35e418f9651fcad"/></dir><file name="Zend.php" hash="0cad6772c236172521bd055e52f4b0ef"/></dir><dir name="controllers"><dir name="Adminhtml"><file name="RefreshController.php" hash="0a547debcf1ecf94f5cbf45af9df3ae1"/></dir><file name="RefreshController.php" hash="82f8029551cfd90cd49f2564b1d326ba"/></dir><dir name="etc"><file name="config.xml" hash="c61bc3cbc21b8f5962ad064b6360227c"/><file name="system.xml" hash="6b7e2abc886b31929e708032016d596c"/></dir><dir name="sql"><dir name="captcha_setup"><file name="install-1.7.0.0.0.php" hash="f55e8b44e85eb45a1c269ca812673ab9"/></dir></dir></dir><dir name="Catalog"><dir name="Block"><file name="Breadcrumbs.php" hash="fddd5639798e608beab3083ba2c8cbd7"/><dir name="Category"><file name="View.php" hash="20e9ffebff3b3b815744a1004c1ace17"/><dir name="Widget"><file name="Link.php" hash="958b7b4d4451c45c87eeec162fb036a0"/></dir></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="233349b4ed30754552beebf2017befaf"/><file name="Attribute.php" hash="89f25995def2df558d16cd5a789a62c0"/><file name="Category.php" hash="ea73ccf086dae6e75ab42f12a1e0fd4c"/><file name="Decimal.php" hash="a234d3e3d8ce706a6dc2d767dd3c1d2c"/><file name="Price.php" hash="8534996d8cef258d71058e8f7bd2a39a"/></dir><file name="State.php" hash="13dcb224587b9aa0713b328036823842"/><file name="View.php" hash="5704d8dc8c9eb75eefb2c0ab944ac23a"/></dir><file name="Navigation.php" hash="7b1ac252eb61561c2d5469f3334a4999"/><dir name="Product"><file name="Abstract.php" hash="7251ca5141601e62788d7ec8e45a90e1"/><dir name="Compare"><file name="Abstract.php" hash="4c5b544b7f377b24e37b00932c0a0cea"/><file name="List.php" hash="e955111eebdc60c2a544ad66ab97c676"/><file name="Sidebar.php" hash="e75063e747180ee5770d5ddf94acb21e"/></dir><file name="Gallery.php" hash="889da5cbd69b57dc962cab3b06005779"/><dir name="List"><file name="Crosssell.php" hash="16207ddc8747afd0e69498864dc3a709"/><file name="Promotion.php" hash="089d616d1256ba1c07ce77636ea7a8a7"/><file name="Random.php" hash="57fc65f888bf1dd0dfd9d42a21998e2e"/><file name="Related.php" hash="d247df0901913879c9c1087b72a21d9f"/><file name="Toolbar.php" hash="966dcf34a0eafd655d3a4ea7eaddb3a5"/><file name="Upsell.php" hash="c92ae83f08e6c4c45760728b3f40891d"/></dir><file name="List.php" hash="a9f4e8afa57585edb4a258c76f319898"/><file name="New.php" hash="999949bf0fcdb227134c8e961868586e"/><dir name="Price"><file name="Template.php" hash="8f0bc8a4e7c7461d36bc7a33a78ca1d2"/></dir><file name="Price.php" hash="9acaf5c95cb91048fabe750592f6db2b"/><file name="Send.php" hash="75f97faddb731f029cf699e65e2b8b3c"/><dir name="View"><file name="Abstract.php" hash="6e63017428696209c585e9bfd1385d28"/><file name="Additional.php" hash="802f73ac1e8a66549e5b5b40ffee88e5"/><file name="Attributes.php" hash="4d82fbb43a89e9dfcaae01d1a5b4436e"/><file name="Description.php" hash="f9fbc548fe417a1f1b633415d9f0a63d"/><file name="Media.php" hash="e2bb92043c1cbb187de2956dfa6876b9"/><dir name="Options"><file name="Abstract.php" hash="725b81be39c3848fcbc3fb70721db151"/><dir name="Type"><file name="Date.php" hash="f3678e2b3c39fa5d715cc05785312cb2"/><file name="Default.php" hash="72366888ca379300c605f731eccde59b"/><file name="File.php" hash="8686ba6fdd775c2ab0d4af2c60543eef"/><file name="Select.php" hash="1b8b22cfe146d294cd104ad63c2ef4ee"/><file name="Text.php" hash="7373b44ae870027f493e095720b84b0e"/></dir></dir><file name="Options.php" hash="946b45b2199ba1ec1e10896adbf43682"/><file name="Price.php" hash="6dbe44af12aa2cd9b2a7651f67edea8e"/><file name="Tabs.php" hash="e175ecbef45eea4c478d31c9d31fa31e"/><dir name="Type"><file name="Configurable.php" hash="99b1835743bd3aa1b53e80e5795ff037"/><file name="Grouped.php" hash="1352247682029865c76f704eb233c124"/><file name="Simple.php" hash="d7aaf15d55146d78d812d38b7fa6368f"/><file name="Virtual.php" hash="e64c5c2a8b71912d27657a44426727c5"/></dir></dir><file name="View.php" hash="621ca1ecc0cb4f21bb91ea26a0cfe29c"/><dir name="Widget"><dir name="Html"><file name="Pager.php" hash="d23f158ebb2383b7ff7a299915becc49"/></dir><file name="Link.php" hash="511a83b5c1328cd36f134d8f0814aab3"/><file name="New.php" hash="cb6dc0d7bd0c57d6a7c24e49fb279687"/></dir></dir><file name="Product.php" hash="5c2ad3dd5f5397c65efbf724f53f7d1b"/><dir name="Seo"><dir name="Sitemap"><file name="Abstract.php" hash="40505e53a280121520a9ab520c663a83"/><file name="Category.php" hash="620007da4f8211cdfb98fe9869f076ab"/><file name="Product.php" hash="4ef93e4a8947ff83f217e4af62c30037"/><dir name="Tree"><file name="Category.php" hash="931c98b2d937398ff7d4c1d8c3bb3965"/><file name="Pager.php" hash="0c7e6eb90729ea43712e6aef24e5b1ce"/></dir></dir></dir><dir name="Widget"><file name="Link.php" hash="e342be9976dbaffc9dcda7114f4ff07e"/></dir></dir><file name="Exception.php" hash="f12a83054d1a20c8e3aa4cd1d7aeed1d"/><dir name="Helper"><dir name="Category"><file name="Flat.php" hash="b25f4a4413c48058f1ad39cc58fc9d7c"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="14862f6ce3841239fb8e716978c1a311"/></dir><file name="Rewrite.php" hash="f6d564c29c38d9a0ef4aae9b80b91d64"/></dir></dir><file name="Category.php" hash="a3b276b2a88e1f97d986ed410fc89ea5"/><file name="Data.php" hash="f059c4211b1e40dc7c6bcb36b3b92d74"/><dir name="Flat"><file name="Abstract.php" hash="734af81e26cd91683decfd37c6fdb3bc"/></dir><file name="Image.php" hash="caccf877e69bcd2d1ddf44d4bdff0732"/><file name="Map.php" hash="8b29bb2b08a1db72f9e503a1e0e6b6c7"/><file name="Output.php" hash="3f66589fc28f12e2ae0ee9e64b42c17b"/><dir name="Product"><file name="Compare.php" hash="2f123719fa790283470f7014b3438d19"/><dir name="Configuration"><file name="Interface.php" hash="1f160deb5cc07c0b0cdc7f76939e4caa"/></dir><file name="Configuration.php" hash="834c453253c40cb83b407221589890e9"/><file name="Flat.php" hash="c3e13a893302fe1bc6a0cf7fb578d093"/><file name="Options.php" hash="69f21b6b8265daa0e9d05b9d92cb468d"/><dir name="Type"><file name="Composite.php" hash="d7a74a64416804402b0d285bbcabf41d"/></dir><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="031aa4fca8c3e0b1f55ddf8eadae6a8d"/></dir><file name="Rewrite.php" hash="edcb3ca25714d5898bedcc551022bc65"/></dir><file name="Url.php" hash="2f859186a0b33b2ffd81ce381515c003"/><file name="View.php" hash="2ebc969f69e0d229b68b6462a52cbfcb"/></dir><file name="Product.php" hash="2262cd6fdba539bf437c517ec9d83ca2"/></dir><dir name="Model"><file name="Abstract.php" hash="a8752cda0d7483ff1f2abe8c6d8667ac"/><dir name="Api"><file name="Resource.php" hash="c864b1f333f93a7e7f4e9dae32cf514b"/></dir><dir name="Api2"><dir name="Product"><dir name="Category"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7d7df63a06284862387fd3e183c10ff6"/></dir><dir name="Customer"><file name="V1.php" hash="8f4f1df79cd262f164d4830de2457792"/></dir><dir name="Guest"><file name="V1.php" hash="985d982fe174e9c574f79ecf71fdc79b"/></dir></dir><file name="Rest.php" hash="3e6a87ed62de65906241b2fd744d2d1e"/></dir><file name="Category.php" hash="8ee8aff92291ff265125a2a09c89cd60"/><dir name="Image"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="b99a15e80fcba83b69da3f0577732055"/></dir><dir name="Customer"><file name="V1.php" hash="b77c0d708c7341a755e7019cda0d638f"/></dir><dir name="Guest"><file name="V1.php" hash="1b25d97bb413a07e3cdedc4315d80552"/></dir></dir><file name="Rest.php" hash="3bedc3fdcb449e4fc552d51b4db3befe"/><dir name="Validator"><file name="Image.php" hash="8f563a0dd5eae33f59bb02d2350c8362"/></dir></dir><file name="Image.php" hash="4a435d724c9449619b9dfeada3c7f349"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="783b786dba0cfc0d7ac426f21985d332"/></dir><dir name="Customer"><file name="V1.php" hash="93bbb0c279c14210ccf40efda631ce66"/></dir><dir name="Guest"><file name="V1.php" hash="a6c70a60cb465ea65ae9d6dc5bd4a77d"/></dir></dir><file name="Rest.php" hash="168cc5bd719b85c205ec26742231701e"/><dir name="Validator"><file name="Product.php" hash="b1aeba72fd9478aa254e00befe7749d2"/></dir><dir name="Website"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8af3b32ea6a088a5eba8897a27b0fc0f"/></dir></dir><file name="Rest.php" hash="bce18e8c16db4be5067cf2e6ba364196"/><dir name="Validator"><dir name="Admin"><file name="Website.php" hash="8d22190d53b13b51a94eff9fd04f0aeb"/></dir></dir></dir><file name="Website.php" hash="6719ea0d36732907b897e377613d475c"/></dir><file name="Product.php" hash="11f9ccd6151a00d1cc19458ac5d05ee0"/></dir><dir name="Attribute"><dir name="Backend"><file name="Customlayoutupdate.php" hash="8a21fffdaf1cc4ffdf99f8ea7aa6d597"/><dir name="Urlkey"><file name="Abstract.php" hash="601a5cb04d820a1d28303e419708076b"/></dir></dir></dir><dir name="Category"><dir name="Api"><file name="V2.php" hash="5f0d39fc8300b9c4cdf080930ec27000"/></dir><file name="Api.php" hash="06db8ae01d1d3dcc9aca5a6ad4a8682f"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="c523122e1a5372678021801313f5fc49"/></dir><file name="Api.php" hash="b903a006267395b79ed6597c1f4743c6"/><dir name="Backend"><file name="Image.php" hash="8fd6fde98705cddced3ecf8253d5e9d4"/><file name="Sortby.php" hash="691af9d6173479fe7de0e82a3041ccfa"/><file name="Urlkey.php" hash="aeaa47c7a3aa478890f34d813456a40d"/></dir><dir name="Source"><file name="Layout.php" hash="ed247fde90f503a0ff797d9c019a3261"/><file name="Mode.php" hash="73e70a70a5aefbde6deb297882682fce"/><file name="Page.php" hash="9ab54c333bdb3458cc4ed5772cbda275"/><file name="Sortby.php" hash="8e19aea914848a0cbb31f3052677c255"/></dir></dir><dir name="Indexer"><file name="Flat.php" hash="604655e7cb987b716c2cf5b53f67d7f3"/><file name="Product.php" hash="9292cdefc56b9a80d68bb89a50b2b8db"/></dir><file name="Url.php" hash="937cbb08cf0df2a7f0c5ad78fcab17a7"/></dir><file name="Category.php" hash="fa9eab482b2dc9c89d9872963ddda499"/><file name="Config.php" hash="bfd4ebc72a0af7794c5866dea818db39"/><dir name="Convert"><dir name="Adapter"><file name="Catalog.php" hash="4a5dc0d4e4d513722ecb1e65507b9cac"/><file name="Product.php" hash="480c3893ac68ba8d5543e807cc8baa3c"/></dir><dir name="Parser"><file name="Product.php" hash="93fe85cc3b5d9c30adef55c6d17a9a99"/></dir></dir><file name="Convert.php" hash="d30056fc529cbc17b30ab1e9eade55d0"/><file name="Design.php" hash="015dc04db309159146bac792dc095356"/><dir name="Entity"><file name="Attribute.php" hash="17a40b3517dbe7ffe701f1da46970638"/><dir name="Product"><dir name="Attribute"><dir name="Design"><dir name="Options"><file name="Container.php" hash="7455da8147f8507b60bb0ba1418bbb4d"/></dir></dir><dir name="Frontend"><file name="Image.php" hash="f732289725a78b3c6632fa7990751899"/></dir></dir></dir></dir><file name="Factory.php" hash="12e1d2c3eda1542ea68d815255811d89"/><file name="Index.php" hash="d0b063d15d53b5cce0c43a04c98bbd68"/><dir name="Indexer"><file name="Url.php" hash="38765eba8afe37e6b2684e5ac29f8dc3"/></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="dd2cc2f440246631303bced9048750a4"/><file name="Attribute.php" hash="6a2c1c5cbe65138ef8bf33e274b61fe0"/><file name="Category.php" hash="98fa713a3a3bb451be05dd417be1c655"/><file name="Decimal.php" hash="e90016c6d18a189530fe888920dba47c"/><file name="Item.php" hash="201f811b88c46bf8a69db078eff5a3c5"/><dir name="Price"><file name="Algorithm.php" hash="544a88b82e4d3c494a479e8ea73e0b92"/></dir><file name="Price.php" hash="7cd7c428a372882153a61a032df62de9"/></dir><file name="State.php" hash="76bc7ddbb78683b65e71e905b575a5eb"/></dir><file name="Layer.php" hash="9a9b65ebd5a1c36011aaea477e198563"/><file name="Observer.php" hash="4bfd941d75131dd2232f888985849389"/><dir name="Product"><file name="Action.php" hash="decd0145a0f07fe7cbd7393fa118c9ec"/><dir name="Api"><file name="V2.php" hash="793a4b99d025fc6dfabd2da709cbdcd7"/></dir><file name="Api.php" hash="4501c79b530a237fce07c6a60d9ecbf3"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="3685f98a45122c256ede43ece696d5c5"/></dir><file name="Api.php" hash="bd1e32f897684f8dbd33bf8a05bbf072"/><dir name="Backend"><file name="Boolean.php" hash="2a5a0456c6620dea4221748911124d3e"/><dir name="Groupprice"><file name="Abstract.php" hash="b5900fc2c486a70e526baeda26cb0c3e"/></dir><file name="Groupprice.php" hash="3786eb7d502bd0b3a17f0f6f80e82dce"/><file name="Media.php" hash="65e6c1cbaa29a18f6aefa3fffdca8a75"/><file name="Msrp.php" hash="c7d44ca4f1ea3794cb19154bc2bc9e9a"/><file name="Price.php" hash="141048adfd0a2e00c4df780bec708c5b"/><file name="Recurring.php" hash="097c0474a762c4cf7cb87b5b0e4d048e"/><file name="Sku.php" hash="54a49ebfe99905992c11d6e193cbfcb8"/><dir name="Startdate"><file name="Specialprice.php" hash="0bb04fa551a461658cdfeea5c783be81"/></dir><file name="Startdate.php" hash="0ad91d8bccbe9dc867ccea9f99d0fd2e"/><file name="Tierprice.php" hash="3681dc3533c8604368a349c68ac68f1b"/><file name="Urlkey.php" hash="2e29bcde62d97ad85f8be84361b3e343"/></dir><dir name="Frontend"><file name="Image.php" hash="290245ae6814aebe9e6ef535973841f5"/></dir><file name="Group.php" hash="0d5a1d1d89c2d6a1055d77db9872ea6b"/><dir name="Media"><dir name="Api"><file name="V2.php" hash="133a39fb7e1107ef9fa81a0543a3e8dd"/></dir><file name="Api.php" hash="49913c934aa085481b744d7333fe343b"/></dir><dir name="Set"><dir name="Api"><file name="V2.php" hash="15517f2009ed3c7d72af842619926088"/></dir><file name="Api.php" hash="28959aef8dffec2ccc252a0f39660e38"/></dir><dir name="Source"><file name="Boolean.php" hash="72523d6f15bb4b7a5ddd8fb235f046bd"/><file name="Countryofmanufacture.php" hash="aadda3679470302577acd9f724d08ad0"/><file name="Inputtype.php" hash="15f7e59849a0ac4977e939caa3c4465a"/><file name="Layout.php" hash="c559a06df151d3d9c452a228f29876fc"/><dir name="Msrp"><dir name="Type"><file name="Enabled.php" hash="de117cb62373580b321199a446b804b6"/><file name="Price.php" hash="c8ee83148e929926333e11d838482b5e"/></dir><file name="Type.php" hash="5d6016b1c16da153676b7c0e4a081464"/></dir></dir><dir name="Tierprice"><dir name="Api"><file name="V2.php" hash="11ad5b869f9cb14fb0686f47b1680f08"/></dir><file name="Api.php" hash="94a5c06286100b29190c34655178bd33"/></dir></dir><dir name="Compare"><file name="Item.php" hash="1770a04bfd6b7663bb99e37904a91c13"/><file name="List.php" hash="72668aa9d697d58b18fb18191effd38f"/></dir><dir name="Condition"><file name="Interface.php" hash="f2cf66045ea9dd61986b758342556233"/></dir><file name="Condition.php" hash="19cd56bf3f2550ed01292cc341c7d6d0"/><dir name="Configuration"><dir name="Item"><file name="Interface.php" hash="0f23070446e06334285c197372c35b7d"/><dir name="Option"><file name="Interface.php" hash="c66bdfbe8f13e7a5edad0672275bee2c"/></dir><file name="Option.php" hash="ee7272d03f6afc6e9449d6e474f37b11"/></dir></dir><dir name="Flat"><file name="Flag.php" hash="363aded09ba741942b0aacb3d3a07c27"/><file name="Indexer.php" hash="0b3c9e5fed4229a33b5641075e637517"/><file name="Observer.php" hash="d5662401baa5cde6c28f01d141294bc7"/></dir><file name="Image.php" hash="baec4a63b96bbbf5e14e455dc2e2d015"/><dir name="Indexer"><file name="Eav.php" hash="e47e464e1023c564e911ab1961a0b11f"/><file name="Flat.php" hash="e88b212e14303f5869321e95dda2999e"/><file name="Price.php" hash="eebb7689c64c15b55a0cd5dc37a5d276"/></dir><dir name="Link"><dir name="Api"><file name="V2.php" hash="477152eaccdc7de5a464e56dabbb3612"/></dir><file name="Api.php" hash="0908690809e366ca32a85eccc39424ba"/></dir><file name="Link.php" hash="aeb02bfb03bb74c369e081e3ee0d8af2"/><dir name="Media"><file name="Config.php" hash="099a406b5674248b233f09f243a2920a"/></dir><dir name="Option"><dir name="Api"><file name="V2.php" hash="14bb5161d6a2a298d435f516798ede69"/></dir><file name="Api.php" hash="befcfd818c890847fd991db908f337bc"/><file name="Observer.php" hash="4356352cea7f0cf6aa42df08ae2f90ab"/><dir name="Type"><file name="Date.php" hash="f58c2ebf294cab03940eca55c4e84490"/><file name="Default.php" hash="d30754bfd2505dc7b7c2fa088dc4115c"/><file name="File.php" hash="6352b854844cdcfa25cf6f43dff7d54c"/><file name="Select.php" hash="9555af869c9cda85d96be06ce4ea8c88"/><file name="Text.php" hash="3343457af57c576140ab52c759de1d57"/></dir><dir name="Value"><dir name="Api"><file name="V2.php" hash="3939065d0e21ab3d7f91673be42280b7"/></dir><file name="Api.php" hash="0b85d0ce714b5acffa1e428c2d8aed58"/></dir><file name="Value.php" hash="4e14b90cc585e7a5b691625135dbd028"/></dir><file name="Option.php" hash="eb7598408500873cb7e55c9eca535b38"/><file name="Status.php" hash="e848573b6f8f57f01053330d20b2bcdb"/><dir name="Type"><file name="Abstract.php" hash="456ddf2b2a03e14e81e3e0a683119e4c"/><dir name="Api"><file name="V2.php" hash="b6707f76e85bc688dc5ba8f60dc10d3b"/></dir><file name="Api.php" hash="e42bfe85d504d4b9dd00b4b64b8fecb0"/><dir name="Configurable"><file name="Attribute.php" hash="b8ed3e9057b253b0f344846b188509d2"/><file name="Price.php" hash="1802e8c7a74d5795d125a27d1e3a53a4"/></dir><file name="Configurable.php" hash="0ba0e65168d5af4647b9fe6da254e39e"/><dir name="Grouped"><file name="Price.php" hash="d1afc84f82d025db921f5d4ce1b7e32b"/></dir><file name="Grouped.php" hash="9d5c08c0e094dcacedc542afa334d98b"/><file name="Price.php" hash="85eddbc0df0b45a54e5cfbb801b9a010"/><file name="Simple.php" hash="e4a0cefc389b7da8509a9b17b4c2ba09"/><file name="Virtual.php" hash="89d8e7e2b763427055e3da933a172e88"/></dir><file name="Type.php" hash="54d62b5d5c8d98f279443906360247ba"/><file name="Url.php" hash="9430be8c25239582d3aea22711db6720"/><file name="Visibility.php" hash="3d4d497257c9f3335dac07b41cb4c69d"/><file name="Website.php" hash="b65aaa5099f357f5aa688efb8a0823b4"/></dir><file name="Product.php" hash="8c1eca1931764491e74f1d15c735df1f"/><dir name="Resource"><file name="Abstract.php" hash="c14958ef6804679c24703aba82434753"/><file name="Attribute.php" hash="4b8177eb1f1e7241eba5e70806beddc7"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="3ffbcb599ae748665619ecb1bd4e32de"/><dir name="Frontend"><file name="Image.php" hash="265bcb0baebcc805a992d9e92a105c98"/></dir><dir name="Source"><file name="Layout.php" hash="8a605bb387b98c83eb8370714bc536de"/><file name="Mode.php" hash="2f54f5b1302a21f362e7f3776c1ab10b"/><file name="Page.php" hash="3f583421a6c6a90fcfded71ac86b1711"/></dir></dir><file name="Collection.php" hash="60ee6565b57ce712723d4e41a827dede"/><dir name="Flat"><file name="Collection.php" hash="c8dd70661951f7fd60a61fd08b1247fc"/></dir><file name="Flat.php" hash="5b2c10a35f424b8168dd1b2794f1dfff"/><dir name="Indexer"><file name="Product.php" hash="fb9f9cf67f670d287ff49a762b91fa3e"/></dir><file name="Tree.php" hash="76ddcd3417b6ec0b62e0b175933217e0"/></dir><file name="Category.php" hash="d5be53b29b16c8ae073b482daa66ef4d"/><dir name="Collection"><file name="Abstract.php" hash="f871c02ea4d88638f637eb24b790b3d5"/></dir><file name="Config.php" hash="3b6571774cadf96433902cd54297a9d6"/><dir name="Eav"><file name="Attribute.php" hash="e92cbf5f90282670c86bcedd005846ea"/><dir name="Mysql4"><file name="Abstract.php" hash="2a367c043fbc2858adb01c6c4ea2ff9e"/><file name="Attribute.php" hash="b2344f0813ac67e3d4550087a20ad2ae"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="bd7da78fe2526ae9ecf57eec773092f0"/><dir name="Frontend"><file name="Image.php" hash="592591274fd4dd36f1c101a40d4b2951"/></dir><dir name="Source"><file name="Layout.php" hash="645778015cea4f06dff49c5726502f4b"/><file name="Mode.php" hash="96bcbb702e35ecf20f03b12ebf8042d5"/><file name="Page.php" hash="5e5193c362e2fb605d7128c3f2894ac2"/></dir></dir><file name="Collection.php" hash="e3fe15e20c006b16c9aa38caa17caa95"/><dir name="Flat"><file name="Collection.php" hash="847dff2c53f375efc6107a5044afbd1e"/></dir><file name="Flat.php" hash="040ba88e64f19013f85b66834cf0f5f8"/><dir name="Indexer"><file name="Product.php" hash="33642d91c512107fb37252f6e97408df"/></dir><file name="Tree.php" hash="6115a020dc6913f3dfaf226601247c80"/></dir><file name="Category.php" hash="79029baf7c325430171bf30886a5caa5"/><dir name="Collection"><file name="Abstract.php" hash="124dfabd4981973f07975154bafea8d0"/></dir><file name="Config.php" hash="9fe560aa88aabe6f9fbe03b68b4085ea"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="ccbf9d48d22c7f077054e95b3d2042cf"/><file name="Decimal.php" hash="0d9a04b5a445d15d6b7b03a7febcb4be"/><file name="Price.php" hash="59d45ca47c02f4d1ee5860923d5c96d1"/></dir></dir><dir name="Product"><file name="Action.php" hash="0bb6f6cd561b111392302f58de49b7b0"/><dir name="Attribute"><dir name="Backend"><file name="Image.php" hash="b2ff2e77ca0a5c1b96e2b0ea7913195d"/><file name="Media.php" hash="08eab44f2071f37ed4a17771014d18a7"/><file name="Tierprice.php" hash="d8e1f29c9aded8a2f503e1e05f0f3508"/><file name="Urlkey.php" hash="f4a2a06d66828a9425032ff779971546"/></dir><file name="Collection.php" hash="42d92267179369ca1b53a04769202de5"/><dir name="Frontend"><file name="Image.php" hash="9ff5fc06d6bb7367283c7d4254d792f6"/><file name="Tierprice.php" hash="15c00b90689a29f9a011c9f485e49ddd"/></dir></dir><file name="Collection.php" hash="b79fc090c34b6fd44c9cf6ea9cbd4883"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="8ef3865a4184e44a79ae2e266135a6ab"/></dir><file name="Item.php" hash="3a11128e27a6e042c859fd9870b12138"/></dir><dir name="Flat"><file name="Indexer.php" hash="de2ed76c939ee2bdb9eb184176a8e604"/></dir><file name="Flat.php" hash="699390b439b8db9bde5104d2a59009da"/><dir name="Indexer"><file name="Abstract.php" hash="bc190cb0183bd1f7db0ac4c2e3cd182d"/><dir name="Eav"><file name="Abstract.php" hash="1f3bdac32c138ad8c5a71fad5f655eba"/><file name="Decimal.php" hash="8418e2274ff77522e8caa393339acf61"/><file name="Source.php" hash="956a03b9a4cb0602f28cb06373d41e82"/></dir><file name="Eav.php" hash="9dbfa6685d22718fd6dd81ac9112dd34"/><dir name="Price"><file name="Configurable.php" hash="460c5542704c3b11741821ff704d4fcc"/><file name="Default.php" hash="c5edd3e077b00463b3cbbaefad1ba6a8"/><file name="Grouped.php" hash="077cb723a265b1a5c43eeaa1b601e1a6"/><file name="Interface.php" hash="3f4c53d917ec9381894358b8822d806d"/></dir><file name="Price.php" hash="3fc351998bdaba729be4678a78a0da85"/></dir><dir name="Link"><file name="Collection.php" hash="34fe71afca447379ed7513536fecd642"/><dir name="Product"><file name="Collection.php" hash="853c7788c08dcf878e2607a555685122"/></dir></dir><file name="Link.php" hash="14758eb79f27b954abb80ed90a101a3e"/><dir name="Option"><file name="Collection.php" hash="0a201c7e6fb601f98e9f9cca226358e9"/><dir name="Value"><file name="Collection.php" hash="86aa68a240301b088861ed13dc8381f0"/></dir><file name="Value.php" hash="82d41979c3abf45111e1dd2c56a4b001"/></dir><file name="Option.php" hash="b3bc9c0b3ab001abf97628fb2d5dbf96"/><file name="Relation.php" hash="34958c4dacac719d88f9e2cdfdb8b136"/><file name="Status.php" hash="1ee8129ba6198845a4022cb0a23e1b60"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="9b7f72984109f13c28cf85a68b319bd9"/></dir><file name="Attribute.php" hash="e2caafaf5f244802e171ee2ed1ff7bbf"/><dir name="Product"><file name="Collection.php" hash="db3d68e3ebf537cd23158e9292d3d575"/></dir></dir><file name="Configurable.php" hash="6dde68202d2dfd1cd0cc00548b7a1985"/></dir><file name="Website.php" hash="cc737b50d6e2e43e14b81ed1746e9b3a"/></dir><file name="Product.php" hash="4151845a9d0686def340b920e098f741"/><dir name="Sendfriend"><file name="Collection.php" hash="db2654b8b3538dc570f4411d4735131e"/></dir><file name="Sendfriend.php" hash="0525ce13a3a3a10d7171fb8622dfd48d"/><file name="Setup.php" hash="3e1d02f8e0c571a19598f9d98ad84bba"/><file name="Url.php" hash="56970705a722b52eca45df8ae3a066d6"/></dir></dir><dir name="Helper"><file name="Mysql4.php" hash="346aed24f42fc8cb87edb7140638663f"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="9dad377ec4098111bc3db812204ff080"/><file name="Decimal.php" hash="749ff82a37683e09b24c65dcf701402b"/><file name="Price.php" hash="310aab644b6600746d0c27c6a01403ac"/></dir></dir><dir name="Product"><file name="Action.php" hash="298bd0d4c878a4c20ef1e38055302b53"/><dir name="Attribute"><dir name="Backend"><dir name="Groupprice"><file name="Abstract.php" hash="e14702c7892e3bafd6a7d8b1ba361b51"/></dir><file name="Groupprice.php" hash="646caeb2f18916e63c1432f1af1708e0"/><file name="Image.php" hash="ff506a149dd3f4e6bf3ea120d3473170"/><file name="Media.php" hash="01fafee272101d93242d0e574a32481a"/><file name="Tierprice.php" hash="b328e4cde490e74a3296882570c0ed6b"/><file name="Urlkey.php" hash="3fbc5b079cfc88a46e2e45a589182041"/></dir><file name="Collection.php" hash="63fdcf9337942f1dca816ea76dc35fe5"/><dir name="Frontend"><file name="Image.php" hash="22810c5cad61e224f0fc6881bc88fae3"/><file name="Tierprice.php" hash="04ea1ae5b17fc1a388859a0c4b9cbdaf"/></dir></dir><file name="Collection.php" hash="f1cd791dd63e491fce2dfdd13b64b82a"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="4fb51b54810df997353844058e8741b9"/></dir><file name="Item.php" hash="b744e1f4b3ad4b448e41162746c3dfe3"/></dir><dir name="Flat"><file name="Indexer.php" hash="d23c69dd71584b02c83cd997b390dfb3"/></dir><file name="Flat.php" hash="26e93d868615c55fb33db2213db4286a"/><dir name="Indexer"><file name="Abstract.php" hash="b51e95b7b0f89be7859b20e0c439d6c1"/><dir name="Eav"><file name="Abstract.php" hash="a7de365b3c24f7925d0aff2ded37f403"/><file name="Decimal.php" hash="8bca02dc0329c702b965f05f5a9949cb"/><file name="Source.php" hash="b207472624ad4d67f9f2a88e6e2ad2e6"/></dir><file name="Eav.php" hash="f5e66db5984ed89d7ff6531dd30633f3"/><dir name="Price"><file name="Configurable.php" hash="c0a92825df74de40aadab166763d6fc8"/><file name="Default.php" hash="3df089b3b5116fb4db829dc94ac66fd4"/><file name="Grouped.php" hash="ff69c8dc1428f1ed620843acfaaa5121"/><file name="Interface.php" hash="ec19f8d573eca3c7dcd43a5c33f98f4e"/></dir><file name="Price.php" hash="2c4385289d5a45a8a66ab41472b64754"/></dir><dir name="Link"><file name="Collection.php" hash="c0983cdfd3183129078b302021e57587"/><dir name="Product"><file name="Collection.php" hash="ea9ec18e1ba474635dde20f245f90430"/></dir></dir><file name="Link.php" hash="7dbac8c8fa2cc623f4d50aceb27e0e00"/><dir name="Option"><file name="Collection.php" hash="de9703a538cfe61ec3b5bfe0ddef228a"/><dir name="Value"><file name="Collection.php" hash="cf7203a390fe7bcdd2d80658ea638f8b"/></dir><file name="Value.php" hash="6e12f40c2708897a49aae723a2ff19d9"/></dir><file name="Option.php" hash="75fd5d228bbc80fd97e12c4d0d9622b3"/><file name="Relation.php" hash="46966dfd38f5d80d22ffe0ff9e43c967"/><file name="Status.php" hash="e77d71b99b3e29da963a7f76600f10ea"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="bd087f24c45cb093d8d536ea05c6e92c"/></dir><file name="Attribute.php" hash="2f2399997b9b922c2ea9f5ada87ff958"/><dir name="Product"><file name="Collection.php" hash="d24bba40636bf969f73e20b407dab32c"/></dir></dir><file name="Configurable.php" hash="a0ab436c28d58783caa04224c1f5d3bf"/></dir><file name="Website.php" hash="ae55f3449cfef9a583d3a0e2d43f2cb5"/></dir><file name="Product.php" hash="d8d540dbeca26d6dd3acdfc26302ac41"/><file name="Setup.php" hash="a9aceb3a22800559189a82f3d644d6e1"/><file name="Url.php" hash="fee84f8fd827c4b523c8bc72f1de704b"/></dir><file name="Session.php" hash="d215af2e51c77cd0eb48d01886d97c67"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Catalog"><dir name="Category"><file name="Flat.php" hash="5e7c93fe883ca86ae471ec9533b92488"/></dir><dir name="Product"><file name="Flat.php" hash="be6906d997d57412dc0f0678fed1fcda"/></dir><dir name="Url"><dir name="Rewrite"><file name="Suffix.php" hash="dc19187f7b9027e075e69ad5828bca08"/></dir></dir></dir></dir></dir></dir><dir name="Template"><file name="Filter.php" hash="be97244f623000eba021d31da010f457"/></dir><file name="Url.php" hash="b9cc8fa3476c3028ee3fd90852aa3050"/></dir><dir name="controllers"><file name="CategoryController.php" hash="0b623f4ee9d8e885aad13d0f23f13a30"/><file name="IndexController.php" hash="805f36221033bcbd93eb3121d0d0948e"/><dir name="Product"><file name="CompareController.php" hash="85c7287cb28dedb46402aa92fd594959"/></dir><file name="ProductController.php" hash="e14a5e084e5e2f024c5fd3b5477c906c"/><dir name="Seo"><file name="SitemapController.php" hash="34d2c078cdb514e676a60691d607e15d"/></dir></dir><dir name="data"><dir name="catalog_setup"><file name="data-install-1.6.0.0.php" hash="ef9ebc687f8cc23de608e3eec94232cc"/><file name="data-upgrade-1.6.0.0.12-1.6.0.0.13.php" hash="d472917c63d90778ca89350d7232ee13"/><file name="data-upgrade-1.6.0.0.13-1.6.0.0.14.php" hash="8212a73ea36cb390312bdb382ec6f408"/><file name="data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php" hash="5f60b06746ecaaa74f24ebc376fc0f38"/><file name="data-upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="d369491d2e0204a1708d8a8e0212be93"/><file name="data-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="8717445601b14a3f806bb161fb596a4f"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fd5a88df31874c873ddc47fd12128483"/><file name="api.xml" hash="61f1a48867bbfafb52e53a29b5c3d694"/><file name="api2.xml" hash="013a076022ddbf3fea4a0742d5b8bc8c"/><file name="config.xml" hash="0f41603c3f745b50d2a0fb4de8d0a546"/><file name="convert.xml" hash="8d8f7eba4c23dc6873132c771d46af97"/><file name="system.xml" hash="c68005c02276e6b02fcee376373c9248"/><file name="widget.xml" hash="772ee5617954b3a85519bd64bd25abdc"/><file name="wsdl.xml" hash="fa198392d766134085b3c2ec1be4a0e9"/><file name="wsi.xml" hash="0acfd65c613ccb83404317500078a85d"/></dir><dir name="sql"><dir name="catalog_setup"><file name="install-1.6.0.0.php" hash="c29963f106b44ac2bedf0ef43b16caab"/><file name="mysql4-data-upgrade-0.7.57-0.7.58.php" hash="9c5663631e26bc0dbae1ea7f31d2ee86"/><file name="mysql4-data-upgrade-0.7.63-0.7.64.php" hash="6073444dda366a4cb50d3b4704bbb1d5"/><file name="mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="fdf01e58ffaf834d4761675e99ba5b88"/><file name="mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php" hash="466304c2f961b3dbcd2606fc02cc8087"/><file name="mysql4-install-0.7.0.php" hash="a6b88eeac8ea791e1c6b50be6a2bdcff"/><file name="mysql4-install-1.4.0.0.0.php" hash="d4e60629ae2494d3d7d8db7424e4f463"/><file name="mysql4-upgrade-0.6.40-0.7.0.php" hash="507edb127b940c5b9c85dc5bfdd9ee30"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2f6b873ea84bac96da7be4905fe9c17f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f43a60fb17d36c541e08b0ad92d146da"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dfc471e252d3995a7ef491d1399d9ffc"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="bc84e63dd439f8a424ef9e6d8ca29adb"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="ea6b851a464cb7005f0798c17448a5e7"/><file name="mysql4-upgrade-0.7.16-0.7.17.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.17-0.7.18.php" hash="5677f19bba0d4e8cfa1f88363081e7af"/><file name="mysql4-upgrade-0.7.18-0.7.19.php" hash="7d624e6c993855ad8fba5f3898429401"/><file name="mysql4-upgrade-0.7.19-0.7.20.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="f9d888899433993fedac11a5ae62a2bb"/><file name="mysql4-upgrade-0.7.20-0.7.21.php" hash="5d8ff6a9614259de0da5aa89ab3f0c06"/><file name="mysql4-upgrade-0.7.21-0.7.22.php" hash="a8063991dd0567f63c169893210d04ec"/><file name="mysql4-upgrade-0.7.22-0.7.23.php" hash="d89516b96caced26119cf3a3f14442b7"/><file name="mysql4-upgrade-0.7.23-0.7.24.php" hash="8b96b8f483d5c21b42dbdf68ecf6c2f2"/><file name="mysql4-upgrade-0.7.24-0.7.25.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.25-0.7.26.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.26-0.7.27.php" hash="083503e821d19cfab3ca9d97bbbbaa72"/><file name="mysql4-upgrade-0.7.27-0.7.28.php" hash="64cb2325781d72a135aa2e5744e012e5"/><file name="mysql4-upgrade-0.7.28-0.7.29.php" hash="460f9b2de5477af5ec4c36ca2791d530"/><file name="mysql4-upgrade-0.7.29-0.7.30.php" hash="908ca45d436735f8d498de0d28c5a092"/><file name="mysql4-upgrade-0.7.30-0.7.31.php" hash="085e3ad264455870e6b57b135b10860c"/><file name="mysql4-upgrade-0.7.31-0.7.32.php" hash="25dbc8dc2e32d91e394ed76f2e68b94c"/><file name="mysql4-upgrade-0.7.32-0.7.33.php" hash="6c050648205a2971087c3822fa10f99a"/><file name="mysql4-upgrade-0.7.33-0.7.34.php" hash="53bfad70ff24d6227c2a3e4f831513e3"/><file name="mysql4-upgrade-0.7.34-0.7.35.php" hash="0bf51a7f95d6e11f5244bac7b4b7ce9c"/><file name="mysql4-upgrade-0.7.35-0.7.36.php" hash="8b01c971f3a27f7b49576aa8b7d4ddcb"/><file name="mysql4-upgrade-0.7.36-0.7.37.php" hash="09c848c52e1e27cd105e3cfb107a24b2"/><file name="mysql4-upgrade-0.7.37-0.7.38.php" hash="1c27b73c04e636200f7c8e388fec68c8"/><file name="mysql4-upgrade-0.7.38-0.7.39.php" hash="6c573296430a1e2ccdfe596ced83b201"/><file name="mysql4-upgrade-0.7.39-0.7.40.php" hash="c337c33147016060b3ff88c8dc415da4"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="e236771503e6d160a30a216bf7e77b43"/><file name="mysql4-upgrade-0.7.40-0.7.41.php" hash="8e594a691237dd91fc12635476d38fee"/><file name="mysql4-upgrade-0.7.41-0.7.42.php" hash="1b8378086638dba3520f1044d8352485"/><file name="mysql4-upgrade-0.7.43-0.7.44.php" hash="f824722e979b87d55941ad6d6d828452"/><file name="mysql4-upgrade-0.7.44-0.7.45.php" hash="a03e8d35ed5bb34226075266b395dbe5"/><file name="mysql4-upgrade-0.7.45-0.7.46.php" hash="fb4ebc451e162848f9897f94772862b4"/><file name="mysql4-upgrade-0.7.46-0.7.47.php" hash="b0ee6aa0fe5a6b836e91e2c4d03f4f2b"/><file name="mysql4-upgrade-0.7.47-0.7.48.php" hash="87aa57f14078c57fc1a8da34e314e347"/><file name="mysql4-upgrade-0.7.48-0.7.49.php" hash="6d76557d041bf75e5bfc306a2bb9f3ed"/><file name="mysql4-upgrade-0.7.49-0.7.50.php" hash="07d744ff031c377e2728ecaba6009629"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="9d946faeab0c58e3f085609032515478"/><file name="mysql4-upgrade-0.7.50-0.7.51.php" hash="7f9260d51a63a0a8f3c5192f1db14d0b"/><file name="mysql4-upgrade-0.7.51-0.7.52.php" hash="2c18d6c66df05f3b4207f7c00854cf66"/><file name="mysql4-upgrade-0.7.52-0.7.53.php" hash="5a1008b25157ec584c5c881c3c7e154d"/><file name="mysql4-upgrade-0.7.53-0.7.54.php" hash="15ff250c95b87120a83d90a062f73a5a"/><file name="mysql4-upgrade-0.7.54-0.7.55.php" hash="719516da1f701c670f856f60f98860cf"/><file name="mysql4-upgrade-0.7.55-0.7.56.php" hash="c771a19fff3b61373ce76646a701bc47"/><file name="mysql4-upgrade-0.7.56-0.7.57.php" hash="490d8c1cb40c3045dbe7484bafa2b1ba"/><file name="mysql4-upgrade-0.7.57-0.7.58.php" hash="9a0d6890063532aad3a0eb27e32fc622"/><file name="mysql4-upgrade-0.7.58-0.7.59.php" hash="76025781953b54f5316084857594254c"/><file name="mysql4-upgrade-0.7.59-0.7.60.php" hash="d74eeb502951b3f401813795be8c7a60"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.60-0.7.61.php" hash="88de24828d60913d63ce0c2f76315a3d"/><file name="mysql4-upgrade-0.7.61-0.7.62.php" hash="06aae2ea1d872fa83f0121324aa02400"/><file name="mysql4-upgrade-0.7.62-0.7.63.php" hash="f7ca5162b321dd64887c9d245eeed643"/><file name="mysql4-upgrade-0.7.63-0.7.64.php" hash="9e19c27309b19b275ca0bee0a4790476"/><file name="mysql4-upgrade-0.7.64-0.7.65.php" hash="979fb613a8ec5695ed2e6f615616d169"/><file name="mysql4-upgrade-0.7.65-0.7.66.php" hash="dc64aa0fa4c4198100948dceee48f96d"/><file name="mysql4-upgrade-0.7.66-0.7.67.php" hash="86a3c5fd7a06048cda04cdad7a6e801d"/><file name="mysql4-upgrade-0.7.67-0.7.68.php" hash="f2afb3c2630946476346958e29d9e70e"/><file name="mysql4-upgrade-0.7.68-0.7.69.php" hash="89b9d73c5b6c625ece67693ccd498ce7"/><file name="mysql4-upgrade-0.7.69-0.7.70.php" hash="a0548013b1718f68e9ce15fcf5d38408"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="79e710442cb653908c95b585829abfaf"/><file name="mysql4-upgrade-0.7.70-0.7.71.php" hash="e767f97578e42fc4a32162f58d9b2e4f"/><file name="mysql4-upgrade-0.7.71-0.7.72.php" hash="eeff783e2e2000befd14b9340ba28a32"/><file name="mysql4-upgrade-0.7.72-0.7.73.php" hash="419232e5dce501a80c5dc2a66a42577b"/><file name="mysql4-upgrade-0.7.73-1.4.0.0.0.php" hash="8b6172c12f58ce3ef1a16bf35ee31cdc"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="623853171877cf7085d6f3abcc49673f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="20555dcf3e6a01e408b1cb1c56957f23"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="5aa11d1c55bc3cd63db6c2cd157cd71d"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="87eb69de3122c4d90935518fe8868749"/><file name="mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="a3f9c9b41fb20c258248f98bb9e1ec2f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="f18e34961d0277f9ae9875075c2e4514"/><file name="mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="9a2dc72bb5b00912af39399d53021d21"/><file name="mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php" hash="de27b4f0ddc37e5cd856c66f041479e6"/><file name="mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php" hash="b1eb1bc037284300f4b7280c03eb241c"/><file name="mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php" hash="5651974d4eb2bae3c27be5cd312cfbbe"/><file name="mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php" hash="660ec00a2013d97bc10851ef4b27e940"/><file name="mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php" hash="dae45d8263ea6f26b98d6ac49a08e19e"/><file name="mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php" hash="79c4658fa552dfaeda70ba030a3642b2"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="593097cd07e2a4806d832c85fc735706"/><file name="mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php" hash="235e9a7c3ebe5ea369584b49e86276ef"/><file name="mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php" hash="677245c0b3379140dffede0d209deee5"/><file name="mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php" hash="841015edcc5f636391541fd252463c50"/><file name="mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php" hash="6504d290e95977304959211ac7bfc0c4"/><file name="mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php" hash="e83e00bed962a768af6ffc6906bf6c0e"/><file name="mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php" hash="e0e38aa2816abd6159b33717dc246e97"/><file name="mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php" hash="f7d17fca52fb06de66f430900fee2c13"/><file name="mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php" hash="6084b618f9a2d7d69e2e2e91f2e1f55d"/><file name="mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="a69471d54bede4e5afed8ccae51b8a9c"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="a7c535e680a7c9c623094e54f514b58f"/><file name="mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php" hash="2f221443dffe6cfd32ea64ecda52ce2f"/><file name="mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php" hash="d64fc6dd5225c10dd4e36bf298aa4d7a"/><file name="mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php" hash="d1fe2d8afb82cf468657ddda5389aa88"/><file name="mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php" hash="cf0e6b3578ad191f76157c0132d03230"/><file name="mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php" hash="9717a718577395f0e0646fcffeb7f6da"/><file name="mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php" hash="551b8c6cdd768e72050f686f267c9ebc"/><file name="mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php" hash="39a95ef491d0af85fa873fc53bc0a591"/><file name="mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php" hash="d8f9fa201cb8bee1872c01c5364710e7"/><file name="mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php" hash="3da4c8953eebd0faa442fe07ea3f94f6"/><file name="mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php" hash="8269869aaf91ae34cfdb2b6f2f6f4545"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="033cc6f1eb844eb2aca8bdb4ac2d7901"/><file name="mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php" hash="c123b4fd1db3e8638d748613d0af8138"/><file name="mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php" hash="fba18ca14ea477338ed50c1beec34bcd"/><file name="mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php" hash="e8fc42ea638f58c7221a19b49c9cf9ab"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="b80203909773a1f38c35383a983b3273"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="b41a118ff245764def690665767cca24"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="2ece267357c4d9440e3402c3f0c8b19b"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="e6580f466b4567f9db9c69ce4d19be6a"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="b65d059cd51c7d188ffa9bacff3d978a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="375eecb3c1d1378633edf5b674e14da6"/><file name="mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="7c81d529fdcbfeb15e293ce059c0cbca"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="077527314f082634ae92550d915e543f"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="9f2bacade9c4d2ad1a8542cac36097c4"/><file name="upgrade-1.6.0.0.10-1.6.0.0.11.php" hash="e7529d1f8a30b456f6577ff8b3b46245"/><file name="upgrade-1.6.0.0.11-1.6.0.0.12.php" hash="8814c53ea7fc2e5a15b96a4f2c15a391"/><file name="upgrade-1.6.0.0.14-1.6.0.0.15.php" hash="dc9ac4700806bdc55bd4ffcd5c22a49a"/><file name="upgrade-1.6.0.0.15-1.6.0.0.18.php" hash="d39d85f7ea7f2975dad11e467b8bba7a"/><file name="upgrade-1.6.0.0.18-1.6.0.0.19.php" hash="5e06c46ebebd369a3178b00603f0bc18"/><file name="upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php" hash="7d10833e5b4f9b540ddf4df06dbf63fb"/><file name="upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php" hash="ce8eb57226d3b66fda8ff9cace5fb8c9"/><file name="upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php" hash="ad98088ce7ecb304e78e7e4c2163fe33"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="a4f70ae360f99126e6b25e166431e337"/><file name="upgrade-1.6.0.0.3-1.6.0.0.4.php" hash="e0ad21122b4cee55e0f4c8b5c44d737b"/><file name="upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="1cbb44723229355c50f2202fab455931"/><file name="upgrade-1.6.0.0.5-1.6.0.0.6.php" hash="e78ecce5cfd76b13dbd7ef5d9f9735e3"/><file name="upgrade-1.6.0.0.6-1.6.0.0.7.php" hash="5f4e31a57366b12432190b0dbdc0a68c"/><file name="upgrade-1.6.0.0.7-1.6.0.0.8.php" hash="e79d5e53a7a4c25497eb3bfdda46eb97"/><file name="upgrade-1.6.0.0.9-1.6.0.0.10.php" hash="ce5b3dbc98219a2c0da94040da590f51"/></dir></dir></dir><dir name="CatalogIndex"><dir name="Model"><file name="Aggregation.php" hash="9c6f7998d76d1bca362e089175a93ae2"/><file name="Attribute.php" hash="78d663d4ea9f77754c2c3560d0b020e1"/><dir name="Catalog"><dir name="Index"><file name="Flag.php" hash="9524e2814fdeca550e656b6733338f65"/><dir name="Kill"><file name="Flag.php" hash="5a9339464929555f00c31e9ecaf098aa"/></dir></dir></dir><dir name="Data"><file name="Abstract.php" hash="b9ce96f710806d292935a8db74af86ff"/><file name="Configurable.php" hash="eee28753c670a9c2379b39f0234d427e"/><file name="Grouped.php" hash="bb07795d092a9ac2c63ff0c29e76b729"/><file name="Simple.php" hash="f007617c31143387958a8604e3f0870e"/><file name="Virtual.php" hash="4aca3ebe694553e66aa6e3ea0682cda9"/></dir><dir name="Indexer"><file name="Abstract.php" hash="61295f02872b473935c13c0aca969d47"/><file name="Eav.php" hash="9085f089b3882a86f4f847f2abb5caad"/><file name="Interface.php" hash="6c71d4648ba7201f7987022cdfce3685"/><file name="Minimalprice.php" hash="6decf39ab3208edce2543e75892ac265"/><file name="Price.php" hash="95c1e4e340c4caa61dd8d2468c082080"/><file name="Tierprice.php" hash="47dcfa2ab722cbe136b770f70d6edef6"/></dir><file name="Indexer.php" hash="56c31bb712bbe66591c98161de5e38e7"/><dir name="Mysql4"><file name="Abstract.php" hash="6e0f0fe11a1ce650c3e10a23a0d945e4"/><file name="Aggregation.php" hash="76f46435204ca54d4591ab2a0c616cbb"/><file name="Attribute.php" hash="a58cd34ef532d852bed7b9d4ad1b9771"/><dir name="Data"><file name="Abstract.php" hash="41bc6267ada02fa6fe8ec615ec3ebb3f"/><file name="Configurable.php" hash="4577c89b879e8f99bedc4465fb9661f3"/><file name="Grouped.php" hash="a6884d4b81b61a067b1e505dbfc93a19"/></dir><dir name="Indexer"><file name="Abstract.php" hash="d3a9da75a16656171c18bb86fa33fab5"/><file name="Eav.php" hash="1d0f16eebd4ce5b824e1ae1eda2cfc15"/><file name="Minimalprice.php" hash="064cc6452df17680b1512dbfc226c141"/><file name="Price.php" hash="3c6e97db8d77933ca4defea0b51d6e91"/></dir><file name="Indexer.php" hash="5898b1893183208da157dc36abf37cba"/><file name="Price.php" hash="74b8fa8fba67d2def8524a1dd460e1c1"/><file name="Retreiver.php" hash="df8626625cbcbd70a168d8d0176fa097"/><file name="Setup.php" hash="06f2b09a62a2ede2972d82217c12fa36"/></dir><file name="Observer.php" hash="323541f9c7627005c1097bae4745eaaa"/><file name="Price.php" hash="59d2c099a753e4bfc63a3dbc38182a4e"/><dir name="Resource"><file name="Abstract.php" hash="841e8054f863bb931a77ee7566252c2e"/><file name="Aggregation.php" hash="3ffea2e0c7fde3c001db5b39ebfa9f0b"/><file name="Attribute.php" hash="7dfb03a93545bbc0f3dfc764be9d7f8d"/><dir name="Data"><file name="Abstract.php" hash="835008239d9b91c16a2d972aa0f59568"/><file name="Configurable.php" hash="7ab1340e4d655b92110de56727b3baa1"/><file name="Grouped.php" hash="94e47080c8f6d107791271c21c88710b"/></dir><dir name="Indexer"><file name="Abstract.php" hash="ed70e8d2d098dab0aa3e69987a6eb43a"/><file name="Eav.php" hash="31a975aef9ba4b6342eaee5c807f3e65"/><file name="Minimalprice.php" hash="6eb6e4b3fb2fa545f2d038ccf0cadc0a"/><file name="Price.php" hash="064d4f9ae150af92c167e2f87bacac54"/></dir><file name="Indexer.php" hash="2cc939178ff4282eec7626cdba5f1c04"/><file name="Price.php" hash="92c794f7efea76b7743824653c1af1be"/><file name="Retreiver.php" hash="2c957b00ad7ce5a6b95edd019edb6d66"/><file name="Setup.php" hash="5554288996af6894c7775b145ffc5bf6"/></dir><file name="Retreiver.php" hash="1df136bf73b17d8359282db267f82c4f"/></dir><dir name="etc"><file name="config.xml" hash="c656807d07ca63f6559c2c16433a30e4"/></dir><dir name="sql"><dir name="catalogindex_setup"><file name="install-1.6.0.0.php" hash="97c3e10d65e4659926d6b421c1176ffc"/><file name="mysql4-install-0.7.0.php" hash="abc5d0a60e6aab9d45381283f81135fa"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2fe9002754d7040b3d81232775aeaaf3"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="3eea917118c05a18058a1cd8a4ba4bf1"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b6d8864d8dfd8c7ee3a02b8aa302e871"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="44255be8ed6d405d4fb46437834fd5bd"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="84481ab5908352b47ee67f8e567fdd51"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="31cb140799cbfdea28fd5664dbd20ebb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="4d6dacf7add59599453c62b2030f8a19"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="941ce43d345e02a8e2063372f668aee4"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="af882140c001d15fd714561a4edeba4a"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="ca365f245bb6431d707cb6b4191875ce"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="713fb9108b9cc1a693beb46c4bc0f70d"/></dir></dir></dir><dir name="CatalogInventory"><dir name="Block"><dir name="Adminhtml"><dir name="Form"><dir name="Field"><file name="Customergroup.php" hash="2e9c0b96002b64f4f7162bd226d8f272"/><file name="Minsaleqty.php" hash="f8e25f0b5e7963d56340bfedfe36568a"/></dir></dir></dir><file name="Qtyincrements.php" hash="2e8244667132250bac8df2261776922d"/><dir name="Stockqty"><file name="Abstract.php" hash="8e2e0ade0a0da53c6b35222dc09c071a"/><file name="Composite.php" hash="abf260fa1ed8bc927c5d8c3cc96ddc6c"/><file name="Default.php" hash="a9faf85cce3e6e55e3f6e4c6238cd500"/><dir name="Type"><file name="Configurable.php" hash="9e70eb26e469c140f8284f1e5ba40567"/><file name="Grouped.php" hash="e417d1c1e33593a0716fa13c08532b47"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="e0445a47c24084f278d63fd06637cd64"/><file name="Minsaleqty.php" hash="1d5f6decd8444784b18259933d81bb70"/></dir><dir name="Model"><dir name="Api2"><dir name="Stock"><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7a23ef28d5a0af8bfc560a0676b2a085"/></dir></dir><file name="Rest.php" hash="ba30f908399b6f74e8b0a7002d7a58ee"/><dir name="Validator"><file name="Item.php" hash="b4c1717c1e68a85e311b5824785578b2"/></dir></dir><file name="Item.php" hash="aa104a6ad7fcd8bbb5525d2b06da44b9"/></dir></dir><dir name="Indexer"><file name="Stock.php" hash="335ec51bc643daed577dfb2ba8bf6b46"/></dir><dir name="Mysql4"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="4473b479ce9ba081ed544e1b8f0b7309"/><file name="Default.php" hash="9ca91a40962bd6c477c078a630e13ab9"/><file name="Grouped.php" hash="8b101ec046557860d6f105ae41e1522e"/><file name="Interface.php" hash="326e696ddeacaf4276cbaab8a4182dec"/></dir><file name="Stock.php" hash="71d81a2696bacfc9c0dd6424ab85ab16"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="a38578f9783e2a4ac28c4e805abe2636"/></dir><file name="Item.php" hash="2cfd2de320892d92e7c8a292b56d78bb"/><file name="Status.php" hash="e08210b68acf2bffd5f42f13fc3e5664"/></dir><file name="Stock.php" hash="182adcece403f3ef3bd7dce42eac8d87"/></dir><file name="Observer.php" hash="020a068947260bb45ec1d78060aa5fef"/><dir name="Resource"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="ccea699212cff2126272bb083c5d263d"/><file name="Default.php" hash="8149b5c0bf67e786f7578dbb9deab3e6"/><file name="Grouped.php" hash="536e6f1a82a87fc585c12ef19dea0cf8"/><file name="Interface.php" hash="8618058d3e32ebd241f70cc2d2e2b724"/></dir><file name="Stock.php" hash="61375ad597c7aba54135ec211b1a82f0"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="869c034146c234b9903de6a77daad195"/></dir><file name="Item.php" hash="cd33d89bd9b106404390c13e45e59e1c"/><file name="Status.php" hash="3779311bafda42361e4914457843fe0d"/></dir><file name="Stock.php" hash="6b27005eed460abb8024062ab5689627"/></dir><dir name="Source"><file name="Backorders.php" hash="52bfd816b598f674af9246a386e853d0"/><file name="Stock.php" hash="8f989c3a9c2bfad7024c2972660b6230"/></dir><dir name="Stock"><dir name="Item"><dir name="Api"><file name="V2.php" hash="11906267f8825815d908e8dc4da2d5f7"/></dir><file name="Api.php" hash="ee5f50879277fbfb25fef1cd765fbec4"/></dir><file name="Item.php" hash="b1cd47179773a36d88e1cbbddcf35f08"/><file name="Status.php" hash="7bbd47e4e0f67216aa713490ba8f1325"/></dir><file name="Stock.php" hash="d855ca5b36d285f8a17ea50a6505b3ef"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Minqty.php" hash="4014d544cb255499a02e567d4996903d"/><file name="Minsaleqty.php" hash="fdece014d82645ec760f206ff7df57d7"/><file name="Qtyincrements.php" hash="285280b282792966c9a0f6ff1021a4a0"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1df150f6a6a441a5e7cbda8e585700f6"/><file name="api.xml" hash="e7091001f41aad0123d9b497de699ad9"/><file name="api2.xml" hash="cb0a1352c87cfc41d300433cdc751543"/><file name="config.xml" hash="bb99649315278ff3c9ab14c42e4da6b3"/><file name="system.xml" hash="e82c936b49b723bfaf7708955302f31e"/><file name="wsdl.xml" hash="cfad5924eb32b8fb7ccf79309e5966df"/><file name="wsi.xml" hash="ec7bdd8cb2bc5dd12c0a4d865fe3d313"/></dir><dir name="sql"><dir name="cataloginventory_setup"><file name="install-1.6.0.0.php" hash="c58fbf677912982192f8ba6f92da98a8"/><file name="mysql4-install-0.7.0.php" hash="c14adc7fd17314f606dd025e5a3596ab"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8bc1263072589be9aad31acec946d7d2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9ccd6c185ac8c4711b0dd2f23b41ee27"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a9b3620418d2989d776b7331c57f2662"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="b4ce29815129ac4a20e3c90c2e79c21a"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b6d74e91f068732e6d22ab91676c1f4a"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="643fe882b5ab42a56116119e424d0c63"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="e7b0e938da066210c9ebf4245ab58490"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="aa4b8366d8fa8eea648a025e99a8ad7a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="80990b2e6d3614b02bfbd1d937d34d5a"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="9658089831fd4d840ce4db56aed83b23"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="89d03a9fa5a570b3313142496c6aa615"/></dir></dir></dir><dir name="CatalogRule"><dir name="Helper"><file name="Data.php" hash="02fd668b6fac397272a825c3541da418"/></dir><dir name="Model"><dir name="Action"><dir name="Index"><dir name="Refresh"><file name="Row.php" hash="93b092e341b065a9bb317e12444c5bb2"/></dir><file name="Refresh.php" hash="0e568cce6cda87c03d340c870d0b1785"/></dir></dir><file name="Flag.php" hash="06cd7f3695868ca1179c714c21cf5940"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="386d62b6e7b73f4b6b9c3b02cf74d88c"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="129382f3131c13a18283adbfeb62c2a8"/></dir><file name="Price.php" hash="429bbac7f001786a730fcb4952cd08ed"/></dir></dir><file name="Rule.php" hash="f5d715c0ef2b3131f17f0b3b58b57c9b"/></dir><file name="Observer.php" hash="a4f5c653cf6ea08d438ed6cb7ab01815"/><dir name="Resource"><dir name="Rule"><file name="Collection.php" hash="e68a7c7f5f2c30135292dfec6a9ba1c7"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="24b6c52ec0ae8e4a77aa026afeba33eb"/></dir><file name="Price.php" hash="dbb69f5dc27ba7ac2906dfeef83058bc"/></dir></dir><file name="Rule.php" hash="333901cbed42699ed619591aefa54d3a"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="9f1535a506b3572ef624fb1fb6728420"/><file name="Product.php" hash="5ec3f6ce240e4a566df9c8f986952482"/></dir><dir name="Condition"><file name="Combine.php" hash="e5ee0060b291073742ccd8117e063dfa"/><file name="Product.php" hash="ad29e318311505376d6107505ce3ddf1"/></dir><dir name="Product"><file name="Price.php" hash="2c10f93fffed8412ee293593ee921f51"/></dir></dir><file name="Rule.php" hash="bb269632d99431ba30af6495afcf0a83"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c6b223bf5a5652ab22611116c8c657e2"/><file name="config.xml" hash="9d73f646bfdbb6cc8c5bd138193d7f5a"/></dir><dir name="sql"><dir name="catalogrule_setup"><file name="install-1.6.0.0.php" hash="f332d718d7bd99d71d0f082665693ecc"/><file name="mysql4-install-0.7.0.php" hash="76d2ed479091e930a6d38ee4352bd7f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="52b4d6b4f74ad67eb2bd2f55dd01d687"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="881908a6f1cb2168d75faec9c12386a4"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="7b46efbd5570db930a2c48c48d6e1d42"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="66928483f1f7b1998478515ccc51c5e8"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="de0d78cebca0488b813b3a2cd87446ff"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="e0a6bffa1b75781d635af98ab71d55ff"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b9dd39d53f3640cc1a3353db14b55184"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="c1a0379e645058c2ce17e82d085bd8dd"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2d8f52da58d3aa7c880c973253d79910"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="31c2d3d59471a95b3e76c7565badd1c8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="2a4f997d4154ba7eea0bd70341361870"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="b960a4dd01fa9fd52b6cc7a69182cf84"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="aa53e808b061f65ee9e96ab5dd4669d1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c12a6c50ab346177340f211130e35c5e"/></dir></dir></dir><dir name="CatalogSearch"><dir name="Block"><dir name="Advanced"><file name="Form.php" hash="e09857306805f17d7eab766db1a311b3"/><file name="Result.php" hash="3b276615955ba0b3f0e7aac91000be10"/></dir><file name="Autocomplete.php" hash="47bb6c0ee66fe844396761c32b7e0fd2"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="d61b49dfd69ac4911df3164b28c253c9"/></dir></dir><file name="Layer.php" hash="c184ba0c66101349863cf4ece22fecaa"/><file name="Result.php" hash="744bd500ea0a539689dfdc90a010928c"/><file name="Term.php" hash="dcaed98a36ce41a8aa772aaa2fe579a7"/></dir><dir name="Helper"><file name="Data.php" hash="21e8df110a7815488a32d826288a1779"/></dir><dir name="Model"><file name="Advanced.php" hash="68f1e6b7ae6d58b7c7dfffe451c12468"/><dir name="Fulltext"><file name="Observer.php" hash="55bb856408b532a5a2fcbe5d72ec7e5b"/></dir><file name="Fulltext.php" hash="7f979ca22146216bc5e79f54146c6307"/><dir name="Indexer"><file name="Fulltext.php" hash="37a36fa4fc2c5644590984c97b292c48"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="51fdc45bc9d7b73240e5912c96318e53"/></dir></dir><file name="Layer.php" hash="dc75dfbfb1d4500419fe2e920a9a197d"/><dir name="Mysql4"><dir name="Advanced"><file name="Collection.php" hash="93472c5b0519e8a32716607f44e2e931"/></dir><file name="Advanced.php" hash="91b392b7e91171e513edaaa7bf9daaa6"/><dir name="Fulltext"><file name="Collection.php" hash="64a3d6b2222856b359fc590e0f9123f7"/><file name="Engine.php" hash="02c44612ab356054281fdc57c8bf4f43"/></dir><file name="Fulltext.php" hash="5306ad7e0a51b62b4a196d12567a85fb"/><dir name="Indexer"><file name="Fulltext.php" hash="17ca5374bbfdc866c2042539413fd1a1"/></dir><dir name="Query"><file name="Collection.php" hash="2d199f6a7a59dd72431361882e2e3bdb"/></dir><file name="Query.php" hash="c50ba30123a9097da433d6477734aefa"/><dir name="Search"><file name="Collection.php" hash="3082b50e38e1316290f02d44cb7bea09"/></dir></dir><file name="Query.php" hash="3c554833d0d6d9ff28249413ec69c95a"/><dir name="Resource"><dir name="Advanced"><file name="Collection.php" hash="367e28f0b01e481639f9080af2103273"/></dir><file name="Advanced.php" hash="499d0194d4398b6112fe4728b4574d08"/><dir name="Fulltext"><file name="Collection.php" hash="c1aa738ba2762c740bafd30b91541811"/><file name="Engine.php" hash="f4ff7fb0fef054d0b9e07fc8d6a7a4f1"/></dir><file name="Fulltext.php" hash="49e4c0eaeec47644808638c06acfc79e"/><dir name="Helper"><file name="Mysql4.php" hash="d842b9fb5472821c9ab907e59d91aebf"/></dir><dir name="Indexer"><file name="Fulltext.php" hash="4904abfa5a1b521ac3cf6dba2e634de6"/></dir><dir name="Query"><file name="Collection.php" hash="423c3688bdd152ee2a3fd3b4edecfaa8"/></dir><file name="Query.php" hash="72c2d37cddee2a7324d11aefd52f14be"/><dir name="Search"><file name="Collection.php" hash="66208450247763e5966249f23686703d"/></dir></dir><file name="Session.php" hash="3745505f98b1a5048a6b7a9d8b6c4f6d"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Sitemap.php" hash="fa4e835f1e0cf01dbf1ac83f55b37b7f"/></dir></dir></dir></dir><dir name="controllers"><file name="AdvancedController.php" hash="23d18bbefe8d5adfdc9b9b55e733b273"/><file name="AjaxController.php" hash="2fdba8218e3c8a6459be9811df8ddc9a"/><file name="ResultController.php" hash="f426aec253d9637a23166d8b68ea7476"/><file name="TermController.php" hash="8e7c5c0c561a20e576a9bf92609f51b3"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c4ec08c32f76b59392eb05422a7aea0a"/><file name="config.xml" hash="a8ea307b4b0a8d243a562b722d5f6cc8"/><file name="system.xml" hash="11d073698075bd1d34bcad7b97ece881"/></dir><dir name="sql"><dir name="catalogsearch_setup"><file name="install-1.6.0.0.php" hash="5167ffecb4d0816729fa55ecfb031f6e"/><file name="mysql4-install-0.7.0.php" hash="60a67b21cf81c144a73b675c38b448dd"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f60f5ca4dfe09e5cb4542661ca100f58"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="933ff654bec558c06154bf4a94361e50"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ef06fdabc135f31e09f5d9d352afdb4b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b3d2a1b9f232e07ec18eef4eb73663ce"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="86d5358977b644d0cfcbffe3a2af2b5f"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="a69f6e028a210cacd6c25cb9da90f40a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="9558e9c0922c08180ca20bdc32bbb002"/><file name="upgrade-1.6.0.0-1.8.2.0.php" hash="8f960ea56b711026613027837ca2fe44"/></dir></dir></dir><dir name="Checkout"><dir name="Block"><file name="Agreements.php" hash="6c419b6e50cadacc1e3683175f78a52e"/><dir name="Cart"><file name="Abstract.php" hash="79ea3265df399c9d5aa26205b25029a8"/><file name="Coupon.php" hash="5ff10b062d60e48654a97a764cf9eebe"/><file name="Crosssell.php" hash="72f9367a7ca7afebcef1717958b3e2f8"/><dir name="Item"><file name="Configure.php" hash="122317fd9233a58f8431f5aa8fe6c6b3"/><dir name="Renderer"><file name="Configurable.php" hash="0499106074c07c07911e02bdabc28562"/><file name="Grouped.php" hash="7dc9b801b73e502eed94f688e56aa8f6"/></dir><file name="Renderer.php" hash="b115b174d92e3b9c89712be5fb1ddd25"/></dir><file name="Minicart.php" hash="baa802262a3d62eb9f5e9b9a6b575666"/><file name="Shipping.php" hash="98375067aecfbbd314a49b01703f35fc"/><file name="Sidebar.php" hash="eae9e0946e0ed91cb983d2cf3d8ff413"/><file name="Totals.php" hash="278079d9f15c7fb26a96d4eafbc2457d"/></dir><file name="Cart.php" hash="8927a89d17a7c5450a297f2fcd2f4d63"/><file name="Links.php" hash="5af955b92e6909a8037d3b2bfe3299d0"/><dir name="Multishipping"><file name="Abstract.php" hash="13eed75a648bc53d3f9cab30fa886d1a"/><dir name="Address"><file name="Select.php" hash="c1d42e9a074f1aae15e7cc8d2438958c"/></dir><file name="Addresses.php" hash="01bd295d52c0efd3d25c85eb70224b64"/><dir name="Billing"><file name="Items.php" hash="439e1c39eb8f0ff590855619ee0b487c"/></dir><file name="Billing.php" hash="cd0ce4f01da14b9db765b0e1a8b73939"/><file name="Link.php" hash="fd48a3860b89af8fa1fff0b6e8ee635d"/><file name="Overview.php" hash="c466ea1a4704fd3eb239d29bc18426c6"/><dir name="Payment"><file name="Info.php" hash="f3c621bf82891c1526e033658861985c"/></dir><file name="Shipping.php" hash="ed6224c3de5545061118a46eb26f323d"/><file name="State.php" hash="2d44a4589b51b51717d7388c1f089060"/><file name="Success.php" hash="fbfacb807fdcafd4303c876e95cf44c5"/></dir><dir name="Onepage"><file name="Abstract.php" hash="6636e2a60c4333b67476c1ab73470e42"/><file name="Billing.php" hash="6895de8b90b2ebfa0fd45c36b9d62a60"/><file name="Failure.php" hash="fd9d92089ff78b9c1bdd9c550b1b0beb"/><file name="Link.php" hash="244a96a744397a83e0adc48755462ec5"/><file name="Login.php" hash="acfdf55652b1b6216f948f9264107721"/><dir name="Payment"><file name="Info.php" hash="4c949f134995bfc85af1aaa1408d30af"/><file name="Methods.php" hash="e7e382062e415ee142eb874f3d7982de"/></dir><file name="Payment.php" hash="33174e1083b18f0ffd8b01193e346479"/><file name="Progress.php" hash="e3fd23946ed8dea075237cedad3504b9"/><dir name="Review"><file name="Info.php" hash="cbe8a8c5c7dda76be20018f22ddea285"/></dir><file name="Review.php" hash="01938f8f5d45925b4b6deafc95ef81ea"/><dir name="Shipping"><dir name="Method"><file name="Additional.php" hash="2e827ccaa46ad3f571dbe055da2d9d4a"/><file name="Available.php" hash="3b091336ac70c22a1f5c4254468e838f"/></dir><file name="Method.php" hash="fc1c37cd94b51f12a05ea5b34a505cd1"/></dir><file name="Shipping.php" hash="8bce6afd8592e02fa26e7838653fd2e5"/><file name="Success.php" hash="15215ffcbb27b211983f6729f16808e9"/></dir><file name="Onepage.php" hash="9c055da8dac9e6768e11410a5af1b111"/><file name="Success.php" hash="934b486b48e29808a83ce46548085f9f"/><dir name="Total"><file name="Default.php" hash="ac18f91a451a3b0e5f3534b8d331d801"/><file name="Nominal.php" hash="c680791504238741fbfda82bd3e529ae"/><file name="Tax.php" hash="c167aba9ce6886e0e039b299f02e266d"/></dir></dir><dir name="Controller"><file name="Action.php" hash="0b6b8223ff9fa50cce71a981b81a1e69"/></dir><file name="Exception.php" hash="8843b4d4cb6c2300c7eb41f25c36fbf4"/><dir name="Helper"><file name="Cart.php" hash="88c7a664f4b6235169238a1449a7cb37"/><file name="Data.php" hash="6dff22121e836f64f4495df89178514e"/><file name="Url.php" hash="aa56ee90a07fbe7011a7c0108ea8757f"/></dir><dir name="Model"><file name="Agreement.php" hash="3f041873a16711d3187093f99c0157de"/><dir name="Api"><dir name="Resource"><file name="Customer.php" hash="01695dd8fbf9dcb04e58452b7cb8dc4e"/><file name="Product.php" hash="60c82ea66b3307ada9629cfeb3085a70"/></dir><file name="Resource.php" hash="e9318ac0ccea53931bf3e1820440ad82"/></dir><dir name="Cart"><dir name="Api"><file name="V2.php" hash="8ed31090d4343e10f32096dfa8be5921"/></dir><file name="Api.php" hash="10c6022b2e4d543eeb176280d2fe9adf"/><dir name="Coupon"><dir name="Api"><file name="V2.php" hash="37e5b83cc1885403394b925d2f1811a8"/></dir><file name="Api.php" hash="248dab0865f6f11b33675ecf4d49aca0"/></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="437058c8e011f4451cd24092a687e1e3"/></dir><file name="Api.php" hash="4ab20a22e0e0cae84a8bbf7504230e3d"/></dir><file name="Interface.php" hash="90a82b74a7125491fbcf209f7253ee33"/><dir name="Payment"><dir name="Api"><file name="V2.php" hash="dfdd088a3c9cd8e0eadffe3478169bba"/></dir><file name="Api.php" hash="e061f0a8eafb776dfc9278c4e1bf194b"/></dir><dir name="Product"><dir name="Api"><file name="V2.php" hash="69b1b20f8507a6e1d49e60a6d6624552"/></dir><file name="Api.php" hash="4cd63af3cf6aebc8ab92a9870e256fa0"/></dir><dir name="Shipping"><dir name="Api"><file name="V2.php" hash="9745eccad000d73a39bdc942b078db6f"/></dir><file name="Api.php" hash="3beb01b7eb467504151f4930e3786f1a"/></dir></dir><file name="Cart.php" hash="39d64fd85416c389b8898fce0aa122fa"/><dir name="Config"><dir name="Source"><dir name="Cart"><file name="Summary.php" hash="a7de12a6e7bada6ee07ca7b420dfcc93"/></dir></dir></dir><dir name="Mysql4"><dir name="Agreement"><file name="Collection.php" hash="630bc38c5b7dd4282a8e5fc40b8dd82b"/></dir><file name="Agreement.php" hash="8b84786b700b9a3b1571ed60d200c1fc"/><file name="Cart.php" hash="a9c3c664819226cc6b991396dfe9da61"/><file name="Setup.php" hash="853da7adb3c0f2601cea42422b3c8615"/></dir><file name="Observer.php" hash="23f1b13f2ff512aa176127da47bc59ca"/><dir name="Resource"><dir name="Agreement"><file name="Collection.php" hash="d382c3cb681caf3595e8f1e74333afcc"/></dir><file name="Agreement.php" hash="76b6db40df8585da3f36316d560f52e9"/><file name="Cart.php" hash="b9bcb03fa78ac8e853c4e7a2f25bc8dc"/><file name="Setup.php" hash="d52f8c44ff0a18ce90186d998b5a1299"/></dir><file name="Session.php" hash="61d6212fcc8df3b07ebb3a7b561fe447"/><dir name="Type"><file name="Abstract.php" hash="876431c28c3e06020a1b0fc87e5280fa"/><dir name="Multishipping"><file name="State.php" hash="f22eb108e021c5654d6c956441c67836"/></dir><file name="Multishipping.php" hash="d7df9388663a58ed18d14eab796b5a77"/><file name="Onepage.php" hash="7623296ec5eca56b6b5ce5eedf96a9a2"/></dir></dir><dir name="controllers"><file name="CartController.php" hash="d8d9bba5baadb115ad53523d945b4306"/><file name="IndexController.php" hash="c27bcd873c8bd5608ab90ae78d200f96"/><dir name="Multishipping"><file name="AddressController.php" hash="c961a9cd3de294783ed7d41726430465"/></dir><file name="MultishippingController.php" hash="291fe953a99e782bd123ce1b3e88fa0e"/><file name="OnepageController.php" hash="256594edeec31e54e583883b075e8e1e"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3bd25edd429a1761399ce2f33926dbe0"/><file name="api.xml" hash="56f66248a45024499270e622af0b101d"/><file name="config.xml" hash="9d6e4eb2e746a7341535136d3891b01a"/><file name="jstranslator.xml" hash="c70d5f292b4e369d7c378346dbc05416"/><file name="system.xml" hash="f6f67fbccdc6a8223f22d0f2d94a1d91"/><file name="wsdl.xml" hash="9a10e25803e84713f5031a168dd0c624"/><file name="wsi.xml" hash="2567bee4ef18e1b426c700ce66c3bcb1"/></dir><dir name="sql"><dir name="checkout_setup"><file name="install-1.6.0.0.php" hash="bacfdd2c8ccb82057efca72250758a93"/><file name="mysql4-install-0.9.1.php" hash="7f40a79587cd339e871165bb4e8b38bc"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="0fae593af23654670a9a60e1ec93d7df"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="4f9a3d70f56c78478f5d1cc73b3ac918"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="96777089267f69ce0ece1f0b85b79a84"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="ad23b08fb3a6253b679846d7e2d9a877"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="4689dea6d535aca2681d91050aaf700c"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="feadb7e5160ff33b7d4b595c5594039f"/></dir></dir></dir><dir name="Cms"><dir name="Block"><file name="Block.php" hash="08baae8f852b0eb7ceb7f00703f90349"/><file name="Page.php" hash="d3893bc1dc3df63c65c3d8e3eee596d7"/><dir name="Widget"><file name="Block.php" hash="2d29800146e6e32e75a00ea9d8663bc8"/><dir name="Page"><file name="Link.php" hash="c8d6ab51cd313b3b2bbade08f8981727"/></dir></dir></dir><dir name="Controller"><file name="Router.php" hash="6a8e1f13e9da08ef8fd7364712a5dc8c"/></dir><dir name="Helper"><file name="Data.php" hash="63cb5d78811cde0406c55ac2706bef67"/><file name="Page.php" hash="e514993ac654fb8ac5bdd16f5476dab4"/><dir name="Wysiwyg"><file name="Images.php" hash="d38e6d1abbc0c30c7b9d556508aa68cc"/></dir></dir><dir name="Model"><dir name="Adminhtml"><dir name="Template"><file name="Filter.php" hash="23efebd6cd5e478ae573167f90f7e45d"/></dir></dir><file name="Block.php" hash="2510ee77473f2dfe1b70dffdb6c71ea5"/><dir name="Mysql4"><dir name="Block"><file name="Collection.php" hash="56f951c0fccd6f8f4217e48a0dc34e1e"/></dir><file name="Block.php" hash="c8e3e5c7817f2d9580092197b222e795"/><dir name="Page"><file name="Collection.php" hash="f8455b1b345414ae2233229e6e89ba21"/><file name="Service.php" hash="52cda9bdbc67bed0ad890ebc4253e044"/></dir><file name="Page.php" hash="57bbae6d1da3f3fbcae2e974dd24870e"/></dir><file name="Observer.php" hash="7c0841e97b147871d78ae5d4eacbf365"/><file name="Page.php" hash="cd5813f33a28df24d2a871176ef6a872"/><dir name="Resource"><dir name="Block"><file name="Collection.php" hash="6ceb057a593d25ff06064a6649039b32"/></dir><file name="Block.php" hash="40f9938bd66ad36f46899c78ef6a8b95"/><dir name="Page"><file name="Collection.php" hash="ef32535a56be83dfadbbd6d31b438353"/><file name="Service.php" hash="7cf9b5d216081a22cedfd6e203c5ec6e"/></dir><file name="Page.php" hash="3991ad97fd44ec669410b11d392eece0"/></dir><dir name="Template"><file name="Filter.php" hash="5d27b599aca8a35f85ec6d19f338bbe6"/></dir><dir name="Wysiwyg"><file name="Config.php" hash="464b3d700f42a84ef0c609f07f84e8e4"/><dir name="Images"><dir name="Storage"><file name="Collection.php" hash="b6e877870e17351df738be1dff5cd856"/></dir><file name="Storage.php" hash="0c179d8ef5099f7bbd66ae62175efccb"/></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="f872d2a6efeee3d405e5cc633481a6d3"/><file name="PageController.php" hash="0e0257f9133bbf7773508f0c5eba6e93"/></dir><dir name="data"><dir name="cms_setup"><file name="data-install-1.6.0.0.php" hash="a2524a24696ccc0c0051abc687b3b63d"/><file name="data-upgrade-1.6.0.0.0-1.6.0.0.1.php" hash="aa16ad74a468113741303f3a9b992efb"/><file name="data-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="364a7d774dc5f46ff84716a32374ae94"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5fdb8a794aa9c661491b77ba99c62eb5"/><file name="config.xml" hash="9fa2613be0401a9f07dba4f8021ba8e0"/><file name="system.xml" hash="568f4eb1982d6c4dd32b25dfd3083ed8"/><file name="widget.xml" hash="fb79ba2126ba0c725eb1813dff174fb7"/></dir><dir name="sql"><dir name="cms_setup"><file name="install-1.6.0.0.php" hash="11ceea6c6c0d695d822096571fab4b9f"/><file name="mysql4-install-0.7.0.php" hash="5ebbb4e38de419a58f3d1a06d6381f93"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="76beaae155c65796e580e922fc10cdb2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="5c7e65d4b2faac184097691e77e46b57"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="9df2ea203d9aeea43a6d450a1b403780"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="6aed180669f3c7751b58b6c6aac430b1"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="9e55629d9f9b47d682a17058997246e2"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="775f2b5b185dea356844293e9f732e97"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d6fcd1a5949c041035954a1604828f50"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="408cb50d7a9878fb017069d30a65170b"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="e91389aa6444e2d56be0925897709f6c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="14a5a61c8214ce5dd7d47f8cf3744edb"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="929a4d0435d84c06fd662ae80bf09b52"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="eb09203a1d3c74197beb5d52cf1eb794"/></dir></dir></dir><dir name="ConfigurableSwatches"><dir name="Block"><dir name="Catalog"><dir name="Layer"><dir name="State"><file name="Swatch.php" hash="6887e2af0be94e3cd1a7ae5ed7cf136a"/></dir></dir><dir name="Media"><dir name="Js"><file name="Abstract.php" hash="0efe6efa7f3b10f969d394786ec07ae0"/><file name="List.php" hash="610da3f155d02eefcb92a0a5148b62f8"/><file name="Product.php" hash="a21153887e119a79084a16ba05685ba0"/></dir></dir><dir name="Product"><dir name="List"><file name="Price.php" hash="9f444e14b4d91046919ba561aea953a7"/></dir><dir name="View"><dir name="Type"><dir name="Configurable"><file name="Swatches.php" hash="f2f57c18a3a8e3e28fe113ef4a040440"/></dir></dir></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="6e2e74df24270f8d2439248af8e1f6f2"/><dir name="List"><file name="Price.php" hash="07f06e13d39df55fb6ea4b4061b51530"/></dir><file name="Mediafallback.php" hash="49a9b43961336e4a559824d03ec80f2c"/><file name="Productimg.php" hash="2f54dbbd264875d55145002411a124a2"/><file name="Productlist.php" hash="b0a644f9a7696db14c44efcbaff2d325"/><file name="Swatchdimensions.php" hash="05e4dcd9530b050cd7b58496141bfef9"/></dir><dir name="Model"><file name="Observer.php" hash="8a14785bd5cd4a97238dd4eec5a70841"/><dir name="Resource"><dir name="Catalog"><dir name="Product"><dir name="Attribute"><dir name="Super"><file name="Collection.php" hash="cc8383320165c4b86b4d69dbb9dd9c80"/></dir></dir><dir name="Type"><dir name="Configurable"><dir name="Product"><file name="Collection.php" hash="a57bde9ef68e3e132bee8277ea2a1350"/></dir></dir><file name="Configurable.php" hash="9e962b8ce86d7759a98dee78ad695d21"/></dir></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><dir name="Catalog"><dir name="Product"><dir name="Configattribute"><file name="Select.php" hash="e62adfcf184e9a2122f1a19040dc21c3"/></dir><file name="Configattribute.php" hash="16aac641aaac0d4414bc6c184b39c9b4"/></dir></dir></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="89988fe030e4c09d2026f1bbf7660af9"/><file name="config.xml" hash="cfa742589e8e8ed4bd58fc3f79ead76e"/><file name="jstranslator.xml" hash="969a61359c6f119aad145803bd2a8c8b"/><file name="system.xml" hash="45153613a10f66eb03200863329f2a66"/></dir></dir><dir name="Connect"><dir name="Block"><dir name="Adminhtml"><dir name="Extension"><dir name="Custom"><dir name="Edit"><file name="Form.php" hash="76b93302a318c93964500d94b58ea4b9"/><dir name="Tab"><file name="Abstract.php" hash="17596eeb6b89b1224c4e231db7bf1d99"/><file name="Authors.php" hash="04a6a4f80bf35b812b94c2e1e968f447"/><file name="Contents.php" hash="e413c95985acb90a4b95fc9a07daa4e2"/><file name="Depends.php" hash="0d76887da37383555abed6e1864c29f5"/><file name="Grid.php" hash="e697766b63ee61b93a43cef718b4983b"/><file name="Load.php" hash="ebc124649980545035a84844a2ec26cb"/><file name="Local.php" hash="811fc83e338d7253c9b01cf0b42ddc68"/><file name="Package.php" hash="c104894bd8051f2bb116226cd13eb8d7"/><file name="Release.php" hash="72da8682ba77a0390283af960e0f6382"/></dir><file name="Tabs.php" hash="dc98a95db0627f6ea68098951ac62a0a"/></dir><file name="Edit.php" hash="065ab68977dea45f03106f9888b3163b"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="775c24dc230dd16d7c45d5aab8f8bc5f"/></dir><dir name="Model"><dir name="Extension"><file name="Collection.php" hash="7ba1af3c40d1c9178a2441087b552c9a"/></dir><file name="Extension.php" hash="4ec228deb98a7c0f73a053785b2e7baa"/><file name="Session.php" hash="83b7c65b6e95aa98be31fcf73c59c11b"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Extension"><file name="CustomController.php" hash="25b2c303170316f51ade98f9ed296771"/><file name="LocalController.php" hash="45c2e963cbf6971e79f7236f37b465e8"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="65d57a497ee09c0f55889a464e9e8ae2"/><file name="config.xml" hash="ea7d1fb7798ba51608b4b423baa769ec"/></dir></dir><dir name="Contacts"><dir name="Helper"><file name="Data.php" hash="01fd76d3de097833859238af70268c7f"/></dir><dir name="Model"><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="972d0ea115f2e748ff5ed306d2f86d93"/></dir></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="ad53ddc28af4e5f60402bde2187d14cc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="5a5412d8cd4ba0577b53483384304464"/><file name="config.xml" hash="d73ab097d6502eccb1d5b2d177a75ca6"/><file name="system.xml" hash="e675da38d1a140774e10e5eefcfce547"/></dir><dir name="sql"><dir name="contacts_setup"><file name="install-1.6.0.0.php" hash="89d25bebd151554fe3bbe3aa7c0dc919"/><file name="mysql4-install-0.7.1.php" hash="da95f978021d0b072b68dcd96b48e56e"/><file name="mysql4-install-0.8.0.php" hash="5cd7480fc89bd86f98ccaee703046616"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f65d6c63a1f7d8304809352e6b283c10"/></dir></dir></dir><dir name="Core"><dir name="Block"><file name="Abstract.php" hash="181c69bec880b301cf2a8f420bb29351"/><file name="Flush.php" hash="fd9dfb94528913c62cc7a4d7e5a1a517"/><dir name="Html"><file name="Calendar.php" hash="b101ca0e43d1dbc4e6880337bf01f083"/><file name="Date.php" hash="55f39c51369070b92407c353b450dd83"/><file name="Link.php" hash="52008b8eee4025fa3ce89afff820dab4"/><file name="Select.php" hash="94d45ec931414b391f8627fa79105a68"/></dir><file name="Messages.php" hash="b99feba6519e2e9a7f1392b19a852f05"/><file name="Profiler.php" hash="be9cad609a54f5a54858238aae217a92"/><dir name="Store"><file name="Switcher.php" hash="19f7c757077689e92c5072a24f843bee"/></dir><dir name="Template"><file name="Facade.php" hash="3b0217c0329aa8ce65805d794f97f0db"/><file name="Smarty.php" hash="3952590ec21561a967bc7ae4093e41a4"/><file name="Zend.php" hash="df09e4fa347b60978eea94bbf85070c4"/></dir><file name="Template.php" hash="6000e614c2e4f2dfa51c56feba11737a"/><dir name="Text"><dir name="List"><file name="Item.php" hash="1217b54e7a673f5362b93b801e8e47ec"/><file name="Link.php" hash="d2c7b7093cd7e73d1477ac9586ad630c"/></dir><file name="List.php" hash="4fd2bc96e9c37feb598eac4c4588eb8a"/><dir name="Tag"><dir name="Css"><file name="Admin.php" hash="f489191668ee974a3cd58249114c23a8"/></dir><file name="Css.php" hash="2df8967b6fb12467d2089156838d5744"/><file name="Debug.php" hash="45464fa97f1073305a54091c888c6595"/><file name="Js.php" hash="c2c209a6fe743d0a1e23c064b0da7f74"/><file name="Meta.php" hash="4be5ce7d98b752f78ce557e4615e09a4"/></dir><file name="Tag.php" hash="91fb5ed6bc5c86d81a164222dbe252a3"/></dir><file name="Text.php" hash="107c848b8a1445b448b0fb700b1f9a48"/></dir><dir name="Controller"><dir name="Front"><file name="Action.php" hash="68f128fb1eeac96a88ccadc9e6266031"/><file name="Router.php" hash="c2a39b4e6b0522a85e1e3c933379da10"/></dir><dir name="Request"><file name="Http.php" hash="9630c120fa5e6c9bb40dd834510e7394"/></dir><dir name="Response"><file name="Http.php" hash="611b9c20b0db52fafe10d982d1190729"/></dir><dir name="Varien"><file name="Action.php" hash="60099b82349b2d1a4f6b9c3e5b45164d"/><file name="Exception.php" hash="d61c714f6177c3113637e37492ae861f"/><file name="Front.php" hash="93246cc98978f42489f3b54085d3b6cd"/><dir name="Router"><file name="Abstract.php" hash="4e55cf4f93c0bf9511b39b5a58bfc125"/><file name="Admin.php" hash="77c9d603cd241af6979d42bf18aa569d"/><file name="Default.php" hash="3efe36835a5671227ede3b2995b3ee27"/><file name="Standard.php" hash="abf493b56ab8ecb0cdd377e282481e5d"/></dir></dir></dir><file name="Exception.php" hash="31ca7f9b564737aa0d9e44c40f8ae884"/><dir name="Helper"><file name="Abstract.php" hash="2fced038e5f6797b6b9c0871fa305fe8"/><file name="Array.php" hash="9f4a32af761a5183a2382967143bdb73"/><file name="Cookie.php" hash="1a7137d6315a204839964ca6ad14444d"/><file name="Data.php" hash="85874417ce74d48637b037793fbe8dde"/><dir name="File"><dir name="Storage"><file name="Database.php" hash="ed127be92b1accf150d16fccd36ef1c4"/></dir><file name="Storage.php" hash="03de906d7c74b5fbda3fba390e3d4466"/></dir><file name="Hint.php" hash="0a54b2a389f46b52e0e2ced66baa6583"/><file name="Http.php" hash="989506e44c5de4c5c38a5383989d59cd"/><file name="Js.php" hash="2a387f8aeeac68c505f7843151987dce"/><file name="String.php" hash="07ac63bfbea05a210fcf632d999adeaa"/><file name="Translate.php" hash="c96c535de4a30db514a0a611af6ef9d8"/><file name="UnserializeArray.php" hash="b14f0cf9a2676961650828bfbd52992c"/><dir name="Url"><file name="Rewrite.php" hash="1bef9c0835550ea3839306a23412b1ad"/></dir><file name="Url.php" hash="d0c40c0c2d5604d182c854c9adc32f4b"/></dir><dir name="Model"><file name="Abstract.php" hash="d1d1d3a5d98f1d740c11c28a504c42fd"/><dir name="App"><file name="Area.php" hash="ebc16a577260811a2a6a18af0076d974"/><file name="Emulation.php" hash="02c3d17d61e3cb4226b8529ca509328e"/></dir><file name="App.php" hash="e097bb0f10878f0fa813689889d28484"/><file name="Cache.php" hash="6b4502cb8f596f2c04b7e96416fd5ff5"/><file name="Calculator.php" hash="f7565ced7f75b5c0f38ca290ef4f6190"/><dir name="Config"><file name="Base.php" hash="3fd453d91eda0ee62b6d7d93780701e6"/><file name="Data.php" hash="a47121f002b901587af61db6672be643"/><file name="Element.php" hash="c9c49041d51f363957c63936c090b6da"/><file name="Options.php" hash="e582e00cf08bfe118d794fa86e592b88"/><file name="System.php" hash="c61e23bbeb5ceda5a6025e38bad1bbcf"/></dir><file name="Config.php" hash="5e214b2eb530121c0c984667ce7ee2f4"/><file name="Convert.php" hash="34cd7dc75bb4f0346c9bab88fb7f7d86"/><file name="Cookie.php" hash="29b5db1b3a93728e4686346ba0b0f93c"/><file name="Date.php" hash="dede2548cb32308a2a0a8a16b2bae1da"/><dir name="Design"><file name="Config.php" hash="df530eedf1f6feff7be7b637cb6813c2"/><file name="Fallback.php" hash="80bc720dcec5afcaf344c56058d2e7f3"/><file name="Package.php" hash="8175c48a6ac75c7ac1c18d5a177c4d27"/><dir name="Source"><file name="Apply.php" hash="47ba9fc0c45be610f95155e1ad6ef008"/><file name="Design.php" hash="9fc458c26da1d90754ed12477c99359a"/></dir></dir><file name="Design.php" hash="462b080e4d548675a0f765337c5da43b"/><file name="Domainpolicy.php" hash="6608467e7879164bf85e027b2a03bca6"/><dir name="Email"><file name="Info.php" hash="3a164cb67d10f6d04038f245fb55bccf"/><file name="Queue.php" hash="42e7e6abdfecf376752734d6e49d8111"/><dir name="Template"><file name="Abstract.php" hash="e358142e556d0cced3cc84b2a8f5f2f8"/><file name="Filter.php" hash="87fb084bc0c68d126da3ba5fa270779b"/><file name="Mailer.php" hash="6681e7b42df3281bfa7a8ee42b69c947"/></dir><file name="Template.php" hash="66676699de617c412441c3c28b9d8728"/><file name="Transport.php" hash="e4c9a71e9438e593ac59b8853d7501be"/></dir><file name="Email.php" hash="d807c53107619aac70f6be138daa693f"/><file name="Encryption.php" hash="cc2f535836d47868164b7b19a555fef3"/><file name="Factory.php" hash="a8329d328de0e5855513523407f7c146"/><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="7f70c39ebae0b69dd85f296375ba97d3"/><dir name="Database"><file name="Abstract.php" hash="8e02a5de6c912c8e7df8a4d56e6e3103"/></dir><file name="Database.php" hash="2e18119f9ce7fee1fb4cce71694d907c"/><dir name="Directory"><file name="Database.php" hash="12f974b3a4d9d5c2719e295358b6a381"/></dir><file name="File.php" hash="64f5cf70b7b2aac04ad2010e7726b2c0"/><file name="Flag.php" hash="fe629937cabf35ce797aa77a14534ec1"/></dir><file name="Storage.php" hash="1ee69792044faf29817a8555ab67fb40"/><file name="Uploader.php" hash="3d154fcb91174e16eeb04a229c6b6639"/><dir name="Validator"><file name="AvailablePath.php" hash="433fd6a4a8c419f7f86515298267554b"/><file name="Image.php" hash="b7fbcf231010f66273d3c907812f3050"/><file name="NotProtectedExtension.php" hash="14fae5d50b74784c586b54f2a91237e1"/><file name="StreamWrapper.php" hash="2966e45d4b779b006ff65afdc3d29fcb"/></dir></dir><file name="Flag.php" hash="5e9df0d7f21ec7ce6ad19a53f7273803"/><dir name="Input"><dir name="Filter"><file name="MaliciousCode.php" hash="9b87d312b7ad9882a418d58125280965"/></dir><file name="Filter.php" hash="527a8a30797a1451733d65666133510e"/></dir><file name="Language.php" hash="abe5b5349861e6eaba496c3418bf16ca"/><dir name="Layout"><file name="Data.php" hash="e353c25b8d41255b2b8f9333275d8a13"/><file name="Element.php" hash="9a1e14e44df962409655e23b8060c98f"/><file name="Update.php" hash="f5a5bd60a84b2215dbb53b32d0c6c70b"/></dir><file name="Layout.php" hash="f1a76bd7d8336aeb1e76075e0442b935"/><dir name="Locale"><file name="Config.php" hash="e297164e06185ca680c803e0226d66c1"/></dir><file name="Locale.php" hash="8cf95e8203a74b64f23ad5c3e98f45d9"/><dir name="Log"><file name="Adapter.php" hash="98ef08e1a2a2723107837369f2165f76"/></dir><file name="Logger.php" hash="763bd3ccd88755a381947852e2350f2e"/><dir name="Magento"><dir name="Api"><file name="V2.php" hash="8f482feb38b1cafca515884de54a950a"/></dir><file name="Api.php" hash="e4be9316b6bfc9f4b8e68aa5b9ef12dd"/></dir><dir name="Message"><file name="Abstract.php" hash="fce642f36593d58b30f9ee3be80c513a"/><file name="Collection.php" hash="88b98cebed98b1f99353152dd7f865ef"/><file name="Error.php" hash="655977a157fa50eb6b07b22f42c345bb"/><file name="Notice.php" hash="052f54af4d7689e6d22c07967138120b"/><file name="Success.php" hash="bffa6f6ebbe3d2de083d65a92884c671"/><file name="Warning.php" hash="32187b6734b82698bda722bfa4115db0"/></dir><file name="Message.php" hash="a95aa9f4a4b22d55849fb2402bcd3aae"/><dir name="Mysql4"><file name="Abstract.php" hash="3708704fae412a0d0247baf0224d1161"/><file name="Cache.php" hash="92c14ffee30326af3bc50a210ebded97"/><dir name="Collection"><file name="Abstract.php" hash="a7e6de8d9f759290881c80edac3b8b72"/></dir><dir name="Config"><dir name="Data"><file name="Collection.php" hash="f7dbe731a1f625a31603757c7300c8d2"/></dir><file name="Data.php" hash="130ed53184c7668ebf31e608294e091f"/></dir><file name="Config.php" hash="a3bf729bf497a384cbaeed34e6bac4b7"/><dir name="Design"><file name="Collection.php" hash="f7f10b12ebbfa86c1862b810ce6d93b6"/><dir name="Package"><file name="Collection.php" hash="b532dbace0f1a4275d73187bb183a4ec"/></dir><dir name="Theme"><file name="Collection.php" hash="c4ff4e160777903e9209130bd154167f"/></dir></dir><file name="Design.php" hash="3490465970f3eb4a00f5ce6278d6f6a1"/><dir name="Email"><dir name="Template"><file name="Collection.php" hash="05749d1d7446e51f63aa1faf663facdc"/></dir><file name="Template.php" hash="1ac03cd7ac86fbb73ae894de71c36fae"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="2a989b8aa3a1e2e880462ea9989a6f0f"/><file name="Database.php" hash="0645555755d39ca151ac4032506cf2e8"/><dir name="Directory"><file name="Database.php" hash="2210f93caf12401dc5f47d7ce46e1fd3"/></dir><file name="File.php" hash="772017c5419250a352d2841d09f8373c"/></dir></dir><file name="Flag.php" hash="94715a36f09bce0bed6ebe085285edb9"/><dir name="Language"><file name="Collection.php" hash="7f83183231ae71e38ec69209e583c127"/></dir><file name="Language.php" hash="db9c590813fe4c7da288b204269b3c88"/><file name="Layout.php" hash="9e3cb41d4c53be096099c997911175ea"/><file name="Resource.php" hash="843d7527e3908b9759bb16365e5e0bf3"/><file name="Session.php" hash="1a890927d43bdbae50314318d3117ffa"/><dir name="Store"><file name="Collection.php" hash="d425d0315f5a1977c5b6d6070f3d1a92"/><dir name="Group"><file name="Collection.php" hash="9113b6a4c8f90dd47b4886f7ca622586"/></dir><file name="Group.php" hash="8db5d7091ef1df0e95cb7674ce95a88f"/></dir><file name="Store.php" hash="d3ae0021d42acfd6a46af7059a67e65a"/><dir name="Translate"><file name="String.php" hash="61f98800fdea35f632ffe0d28c081f8d"/></dir><file name="Translate.php" hash="ecbe50a6490ae1c6381411fa149d4fd3"/><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="2aefce4731631e9465d0d23a19c779a3"/></dir><file name="Rewrite.php" hash="f349ed01f4fcdcd48dbd74bb13272315"/></dir><dir name="Variable"><file name="Collection.php" hash="199eca9e1659bfbcaa6c9460755f6b82"/></dir><file name="Variable.php" hash="d9262e41a163dd0c55fed55d3c6d7f8f"/><dir name="Website"><file name="Collection.php" hash="2a587a71bd36b68a77a4c8f02e2c2fcc"/></dir><file name="Website.php" hash="88ad625c889346e4cfe7c59e41233934"/></dir><file name="Observer.php" hash="094871e0c109142b4f68de0b281e5011"/><dir name="Resource"><file name="Abstract.php" hash="1caae9c8430ec6ce0c13606335894edc"/><file name="Cache.php" hash="48a7128434d90edd49485e90768c828e"/><dir name="Config"><dir name="Data"><file name="Collection.php" hash="cb889be83198c5b528e24316371d1883"/></dir><file name="Data.php" hash="639c91e3346b8a93cc361a942ccd5d14"/></dir><file name="Config.php" hash="bac269b45f33fce05eff8adcb63fb7ef"/><dir name="Db"><file name="Abstract.php" hash="192eb8200dc8a6a6c784cc5c57355457"/><dir name="Collection"><file name="Abstract.php" hash="bdcadbc916bfd95ef1a445803829aa35"/></dir></dir><dir name="Design"><file name="Collection.php" hash="d010ab011ac9e2d1ae73d9ea15dffdf2"/><dir name="Package"><file name="Collection.php" hash="b46bd0681a1468c4413aa917d10063ac"/></dir></dir><file name="Design.php" hash="f078ea6fed695c8f9f07468389001106"/><dir name="Email"><dir name="Queue"><file name="Collection.php" hash="8ae181824d19be3dd8d0e72279bf0d69"/></dir><file name="Queue.php" hash="a6a50894a43ce7189f14e1e7b4840ead"/><dir name="Template"><file name="Collection.php" hash="ca9653326c602a71e0a93c076e5e35b8"/></dir><file name="Template.php" hash="6ed0dee792b3bdfbe6531166d42b91b4"/></dir><dir name="Entity"><file name="Abstract.php" hash="c9e0bb6aa889ca36e2eaae296396a02e"/><file name="Table.php" hash="c06c09b2a03bcbbfd186c9aa98a634de"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="4d12a1ee3a12b35a1fd908588d207bd2"/><file name="Database.php" hash="770ed506ed0a2d82f4897b4a287ae694"/><dir name="Directory"><file name="Database.php" hash="7703449b22f643da8dd43712955fa6b3"/></dir><file name="File.php" hash="40d79daa54798cb4f810cf7e2a524728"/></dir></dir><file name="Flag.php" hash="82bc20374f8864d49b7293c1dc70a4f5"/><dir name="Helper"><file name="Abstract.php" hash="78e15036317fe2f704427e748e488696"/><file name="Mysql4.php" hash="555297623b7312cb4a5ee74014dcb33e"/></dir><file name="Iterator.php" hash="ec070c942fc8f7a67f4e26e5fcd08d66"/><dir name="Language"><file name="Collection.php" hash="50cf8598e78404829ad72d63c8388c66"/></dir><file name="Language.php" hash="7e23e3443583f40c7e3415d92a35730d"/><file name="Layout.php" hash="e8f6aeb0ba21e41d5067b4cb856dde9d"/><file name="Resource.php" hash="3eb9eedef05d21d0cc6c4e97142d1d9d"/><file name="Session.php" hash="88318f7f71df8fd9d82fd8b24ab7abed"/><dir name="Setup"><dir name="Query"><file name="Modifier.php" hash="813bd2670a0d73708b09ea92bbb9be86"/></dir></dir><file name="Setup.php" hash="4139a2d32143a8550f87ff50435e75a3"/><dir name="Store"><file name="Collection.php" hash="3320d22e0d1333d614ad290e0525d53e"/><dir name="Group"><file name="Collection.php" hash="1ac2b4c1de5e1903c26f4e3785e4e937"/></dir><file name="Group.php" hash="42e813bcbaf698881e1bf5a27c59f39e"/></dir><file name="Store.php" hash="fa3bf05b568294e02a6fe4c1c27cb9f8"/><file name="Transaction.php" hash="08fa1309658be97145d36d6f246d3775"/><dir name="Translate"><file name="String.php" hash="a2cb79ab5c6bc58a1d9f06b173c9b60c"/></dir><file name="Translate.php" hash="9a1a8fed6527f816b1b5eace64212c81"/><dir name="Type"><file name="Abstract.php" hash="5223eadca84d77cb2596c2776cb6d65b"/><dir name="Db"><dir name="Mysqli"><file name="Setup.php" hash="3fea549d4e4f8b68f0e576f6a12d17ce"/></dir><file name="Mysqli.php" hash="96292453517efdd07547eb8407d5f1dc"/><dir name="Pdo"><file name="Mysql.php" hash="c0ac5cf999e1d553f90c37e00e36e3de"/></dir></dir><file name="Db.php" hash="25034f3d1ae6ad136e39fae5d01ce0a4"/></dir><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="f8da7eb03c8fb8f83283e6314cd3c1c8"/></dir><file name="Rewrite.php" hash="fe8475fd925996ae8ab39258c85a53de"/></dir><dir name="Variable"><file name="Collection.php" hash="401b5e614ae732c5678a04a2b98879c9"/></dir><file name="Variable.php" hash="f84b3387796b375a8bf33c136d381dde"/><dir name="Website"><file name="Collection.php" hash="4ced4ca90dea76629bbc53f216421181"/></dir><file name="Website.php" hash="3521e6bba1c4688bc47d53f794cbebdb"/></dir><file name="Resource.php" hash="e7e6cf7f40b1a7c38a30e4cc0744b249"/><dir name="Session"><dir name="Abstract"><file name="Varien.php" hash="569c98dddeae79ca1cf6af5ae6de8a39"/><file name="Zend.php" hash="cfe635669d5b999b71fc6a2c0430158c"/></dir><file name="Abstract.php" hash="979ddef17c114d7f3f9b4ab43764381a"/><file name="Exception.php" hash="985b0f518cdeaa693ed2487bf0f6bc71"/></dir><file name="Session.php" hash="5290571c529b366f4932afdecc6aee34"/><dir name="Source"><dir name="Email"><file name="Variables.php" hash="9acd0ca901919230f0b04c6d37da62ee"/></dir></dir><dir name="Store"><dir name="Api"><file name="V2.php" hash="44da778a107458327526e71820b7b1ff"/></dir><file name="Api.php" hash="7fd2194a6736267ddf6990d01277433f"/><file name="Exception.php" hash="563bbd8d7ac0a433a77a456763c4c3e0"/><file name="Group.php" hash="1902252843de7b5774a4e81326e2fdad"/><file name="Observer.php" hash="63819493bcf83ad8e8ca370ca7f6aced"/></dir><file name="Store.php" hash="34c99c0b6717f26712d299e1a869a752"/><file name="Template.php" hash="fccd27ce17f7aa0afbcd52403221b342"/><dir name="Translate"><file name="Expr.php" hash="e9d7462a5fb8e7a393d5f54797d49235"/><file name="Inline.php" hash="e93b3c785268564f9c4c8407b20a3a10"/><file name="String.php" hash="0adb95a97362072d6e8ea38583887b59"/></dir><file name="Translate.php" hash="bc3e61e7886c80e4a27657083b7d73b3"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="2e681780b29fb80c8240c56c87f3d067"/><file name="Request.php" hash="5df0865b6561e78521ed01ac6b7d57c6"/></dir><file name="Rewrite.php" hash="a3390b9c5c1475415d8c5a274eba51ac"/><file name="Validator.php" hash="e3f18c399f4cc29dc71ec4b6bf79490f"/></dir><file name="Url.php" hash="12dfc1a9d4e7ed0958fd543a10d0295a"/><dir name="Variable"><file name="Config.php" hash="294323396e9d0cadc983c976033b2735"/><file name="Observer.php" hash="f202b59b429f4f2d02cb650f130e4258"/></dir><file name="Variable.php" hash="0e14c7251900724becb45597711ca75b"/><file name="Website.php" hash="4a6f6a97f9522c03590bb28e140f9885"/></dir><dir name="controllers"><file name="AjaxController.php" hash="a08f8290380cf11cf83500ca24bae20c"/><file name="IndexController.php" hash="f9ef6110cbc8a9666098fbef0e8e754b"/></dir><dir name="etc"><file name="api.xml" hash="86293f2f531b7a6ddf9bacc685c4fc5e"/><file name="config.xml" hash="403f77c0d3fe5be3d36acdf4a7026cdb"/><file name="jstranslator.xml" hash="b200108bfac41b69ee844c2bee267ec8"/><file name="system.xml" hash="99fadc897cd072625871d0a04231eada"/><file name="wsdl.xml" hash="79501d6ccf39846b5dd551e85880dcb8"/><file name="wsi.xml" hash="31fa195d527181c946019bcd44d819d6"/></dir><file name="functions.php" hash="361ce88daa9b8bb82caf26e5ba179245"/><dir name="sql"><dir name="core_setup"><file name="install-1.6.0.0.php" hash="99c037a0a1ac60718cd61bb66f2ce9b9"/><file name="mysql4-data-upgrade-1.6.0.2-1.6.0.3.php" hash="ab507b796172a81e53f7dea055f5747f"/><file name="mysql4-install-0.7.0.php" hash="5c744d9ec05924ba2a05443fc797c614"/><file name="mysql4-install-0.8.0.php" hash="d7eb01be2a8ae5c212a48e000cd0f2b3"/><file name="mysql4-upgrade-0.6.26-0.7.0.php" hash="4f20726fa1cf4822a6a8915dd427af4b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="a21956c396c1b967ede3ad976cfdf448"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="64a85f90819585aaaf7c5cbdf5ac9cf5"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="476423c81b0e11428d206f5a736bce3d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="337139e7657a6d1e7ef9fccddc23553d"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="57780327ffe3eba191534854bad676de"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b0f5f9f49140980d21565993f622ae81"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d4614e187cc7a85654ced0176b5688f3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="fe2ea548791820ac5c1801695b0f75ef"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="f42d281fce5121d5f411e6611c71e38c"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="0cfe8f124a171dd82663efad6127e14c"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="299207679a44c8d5ea8ac5754f8de98b"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="6fcd0f93e0d91905c073605aba88940b"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="4dbb9443f34a75b9f421b7b818446043"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="0de67179defca183bfb0b1c611a39887"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="a98d5c510f9e19ee903e957bf7eb3202"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="48eb471e3d57c8bd4c8e7f4c38d49d57"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="0d8dbd126c7140043695ceb63037324e"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="600c23395322527f7a0b9bf6955d72c1"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="f6830aa69a99fb2bf5c3e92f4cffcdf9"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="0fe329675e0340210bfe2a6fb4066377"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="1742e2c0c393bdb449636e2fbb35dcd2"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="ba27150f507d3def66478fb1be8a6f80"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="d43d803598bc07a5cc3622d7c4046efc"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="8050654374a57af43bd12d16fd5c8146"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="9fe12edd3f5a54bce363fb5c7c3a23a8"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="cb8112cd37d71d62e673e816623d1a9a"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="a57334d7c2206e31b7db077748949d43"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="69372713f802f2aa756d6c4e3b25706e"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="e82b56e0531638a1ccce30bc12cf6aa5"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="e8497ce884a5a14dacb68d6988e6db61"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="a825fb80da1068e176efc6559f8e3183"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="37d085e478c96b39c697b3b40506ae87"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="5cfd483b04eaccba4a2d509432c190bb"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="c9e92c9d8305a03222ab7562ea8ce2f9"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="38c349fc77a280f0d3ffedad22cc6d47"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="0ba1f78f11cf2d2cd2739cdd580def92"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7893e14572c2a1c90ef2a32b983b76bc"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="3688343c162f029654b67cfbc2387024"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="7cf54034cb33d05f707cd9db126a300b"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="de7f2c22f6094821ddcde05aee42933d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="015a4339c6e0d045fc73ed7864246a45"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="af573097ec2ebe58f82d4f4333bbc91a"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="d1a38f6c8e9d71dd44842a77cfdc378f"/></dir></dir></dir><dir name="Cron"><file name="Exception.php" hash="cf1dfad3794259101456ab530c5db5a4"/><dir name="Helper"><file name="Data.php" hash="27e5fd603d4ca44ff134f01c2204cd38"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Schedule"><file name="Collection.php" hash="82f4b5c141920cae628956674651e686"/></dir><file name="Schedule.php" hash="68a1f1d41f2881f5710794b74bc5fa4f"/></dir><file name="Observer.php" hash="ba0660d83c9189ba3f86b79d58a37b73"/><dir name="Resource"><dir name="Schedule"><file name="Collection.php" hash="1c4d160bf611d9e5d2ae329e718a5016"/></dir><file name="Schedule.php" hash="70b7a234326eb5f4a437d9c83c941a35"/></dir><file name="Schedule.php" hash="5af32d2624ad82e95d7ba0aaaeb69404"/></dir><dir name="etc"><file name="config.xml" hash="7f3d40612a48d9d5ff88aaa180db864d"/><file name="system.xml" hash="cf72373326f9de8c29898d577dec01ba"/></dir><dir name="sql"><dir name="cron_setup"><file name="install-1.6.0.0.php" hash="e880af79df0e64a24f25b9b6ca5a0a06"/><file name="mysql4-install-0.7.0.php" hash="f2fef9a649061718fced001da2d17ff6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="237886cabfccaf58b4baf26dc7d8173d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="6dd37c019fd015568fb404635e8fa3de"/></dir></dir></dir><dir name="CurrencySymbol"><dir name="Block"><dir name="Adminhtml"><dir name="System"><file name="Currencysymbol.php" hash="180872bd15491de4d7243f518637cc27"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="2268459f3c43056d7fd35adb8dfb2497"/></dir><dir name="Model"><file name="Observer.php" hash="844f97fd2d98a7a93c235421c7286567"/><dir name="System"><file name="Currencysymbol.php" hash="341a9557df26d4e1afd4f7eb4910214a"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="System"><file name="CurrencysymbolController.php" hash="0e2e34ce111da77949ddb67b21fb433a"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="e3b17991058dae47d0e9ff06418c3c01"/><file name="config.xml" hash="ea98c18686306119b6b936c5bb0d4b99"/></dir></dir><dir name="Customer"><dir name="Block"><dir name="Account"><file name="Changeforgotten.php" hash="8b663124bc516f05a5b6319db495e29e"/><dir name="Dashboard"><file name="Address.php" hash="aac0afce3651c4d72c76e28c43892ee7"/><file name="Block.php" hash="c956121184fb8d2f1ca3214293a86832"/><file name="Hello.php" hash="7fb0384b0f53cfe0eab7477130c036a6"/><file name="Info.php" hash="777950ea83313c7ccb2df5a632d95d79"/><file name="Newsletter.php" hash="fec02bad0bdb8016810da2f75d7af4e8"/><file name="Sidebar.php" hash="612e6c9109efddfcf09efab2bf19ad87"/></dir><file name="Dashboard.php" hash="669ca917a411643f2df70dedf77c7a03"/><file name="Forgotpassword.php" hash="4d4bb6faed3d7be132c6de8ba097d79c"/><file name="Navigation.php" hash="7814958a2f1504e592f60b94286fca91"/><file name="Resetpassword.php" hash="09f6699b3e8a5cfd801d9fce6be6caa4"/></dir><file name="Account.php" hash="43490efe5663f8252b0890dd67153725"/><dir name="Address"><file name="Book.php" hash="8dd1a6365d2cee386fa50f2bd9b67f95"/><file name="Edit.php" hash="93184bd1536389b9027bdc3b85738d87"/><dir name="Renderer"><file name="Default.php" hash="ffee9ef9dcf06f89ff6fa37881a09f5e"/><file name="Interface.php" hash="c3d67cdcde0d581ec8a884ae41320b9c"/></dir></dir><dir name="Form"><file name="Edit.php" hash="9681856afa02438569c99c4a39c71efe"/><file name="Login.php" hash="2f136fe58a89cddfdcae1c8a20374eb8"/><file name="Register.php" hash="dc2c0b46dba1b9d697e86f920f4b2b03"/></dir><file name="Newsletter.php" hash="4bbfc9637bcfd47df22a24d0ac332198"/><dir name="Widget"><file name="Abstract.php" hash="82d02521c1c154986f99a7cd5cc595bb"/><file name="Dob.php" hash="08eff27d1c12a2bdea2f02bb1beb9956"/><file name="Gender.php" hash="69ba0733ec5825d9c84aa2bd36518242"/><file name="Name.php" hash="2fe99449c98c4831c81499a996955bdc"/><file name="Taxvat.php" hash="f6a34e678cce8e9db4337a171e1eb5c1"/></dir></dir><file name="Exception.php" hash="84ed4a7311c3b067f5a9a2b4ebaf2701"/><dir name="Helper"><file name="Address.php" hash="b7d0e116bd13ee4040e4a3e7d7e10f54"/><file name="Data.php" hash="8b5c4cbf10617330771fb0179c3328a6"/></dir><dir name="Model"><dir name="Address"><file name="Abstract.php" hash="fa80923d3d564b19d139c8217d52c4db"/><dir name="Api"><file name="V2.php" hash="5264e405138723779708a01e0ad3a953"/></dir><file name="Api.php" hash="c625c51f21aebed93b312016d255a325"/><file name="Config.php" hash="81e4c387f3c84c6bbd6eeb85c6bb6415"/></dir><file name="Address.php" hash="4e2bdc078893483df4368f90ad9069ce"/><dir name="Api"><file name="Resource.php" hash="88a0a4742fcb4b506e0fe0bad02fbf42"/></dir><dir name="Api2"><dir name="Customer"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="6f3addc32e6948ff8b1427d8a5edfc6c"/></dir><dir name="Customer"><file name="V1.php" hash="ee1fa714d1b0d4c0089cdc8b78536901"/></dir></dir><file name="Rest.php" hash="dd7c4ad62e07cc33093b1825c91dc32f"/><file name="Validator.php" hash="68549f28fa41a68a9212ddb19c1e11cd"/></dir><file name="Address.php" hash="7763734d86e3092e92066cdecde510a3"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="df8b83b4419c9d7b00176578de386f3b"/></dir><dir name="Customer"><file name="V1.php" hash="15773c1ca13ed447f1734e30151d0aa7"/></dir></dir><file name="Rest.php" hash="13687d1d31f233b15bdd487a13e1c766"/></dir><file name="Customer.php" hash="075e0124ec757065f5343d92b66c74db"/></dir><dir name="Attribute"><dir name="Backend"><dir name="Data"><file name="Boolean.php" hash="432dd89c3a7c292b09f374d233ee88e8"/></dir></dir><dir name="Data"><file name="Abstract.php" hash="ce5306f1e0a22d3dcd993e5220fbb7ac"/><file name="Boolean.php" hash="f757034441c95c0c30917147e3899d7a"/><file name="Date.php" hash="c977b4c1e25a829d9dd2b56afb7e1ead"/><file name="File.php" hash="cff1562f1f09a1f77f446c15e9441405"/><file name="Hidden.php" hash="3d2815af68515718683db2cb2e2973ba"/><file name="Image.php" hash="65edcc06c39664fb4d244bd484543083"/><file name="Multiline.php" hash="6b16093b04c6724d52d294d8a7fda5a2"/><file name="Multiselect.php" hash="219e0b4179d1ff3fec774a53f8f9af34"/><file name="Postcode.php" hash="ba6c2c9e682d8720d7cfe3ec50177a42"/><file name="Select.php" hash="5e80c9f0c60d9173634b5fa0f287e328"/><file name="Text.php" hash="19c74a8d13af4e7a4862c4b89f954e27"/><file name="Textarea.php" hash="d4b77360bae2a6a748cf27367ea83d24"/></dir><file name="Data.php" hash="b02ad271accfaee388a7ad3bb222f09f"/></dir><file name="Attribute.php" hash="83f08943bca6efc1081de3af6d51d73d"/><dir name="Config"><file name="Share.php" hash="611a68be66eb8da9af205150c54e9fea"/></dir><dir name="Convert"><dir name="Adapter"><file name="Customer.php" hash="e803d6cb098208d70b601fc5593cde91"/></dir><dir name="Parser"><file name="Customer.php" hash="9d4b84d66f8d8b81ed939118a33be002"/></dir></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="b9bef0e5e64fa1bd9e390c99f3942281"/></dir><file name="Api.php" hash="167a33181ce2964937d5e7e73b9894d8"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="89c52c1b2f0bd8484df39ea7acb46b7b"/><file name="Password.php" hash="d3986a064f7d4cfefe4ff68332698665"/><file name="Shipping.php" hash="06ab66f794689e099ee95692283c12ce"/><file name="Store.php" hash="b0ef14e8531d2257a2b9de8fd180898d"/><file name="Website.php" hash="901f05d219245cb98170965bf8b014d7"/></dir><dir name="Source"><file name="Group.php" hash="0553e3010d7141c267a8749dcf4c1b39"/><file name="Store.php" hash="aec62dac295af5b5dd732c6ac1959764"/><file name="Website.php" hash="808118f1f0e66be0957876dbe8e9e57c"/></dir></dir></dir><file name="Customer.php" hash="9abb92d3d08028b277fda5db64f6bbbc"/><dir name="Entity"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="3662b45a02a564d622f1b570ab7aa2e9"/><file name="Street.php" hash="3d8358dbf971673582d68d977b2772af"/></dir><file name="Collection.php" hash="9b4b6effc2a69a7997605e3bd1bd9870"/><dir name="Source"><file name="Country.php" hash="681cded02921d688127cd30abab8efe3"/><file name="Region.php" hash="d6f544d7b9377c54b3e4f7546a3b2b38"/></dir></dir><file name="Collection.php" hash="bd986a57656ef8a1a39d9c66b927e451"/></dir><file name="Address.php" hash="8617ad0449bf5fa8eb64c37a08f6834a"/><dir name="Attribute"><file name="Collection.php" hash="b0d588d2382b7790638831b94ed26bfc"/></dir><file name="Attribute.php" hash="70d04a5d91848027fc7524f8abdc23de"/><dir name="Customer"><file name="Collection.php" hash="aa16d5336085baa3ba3eb2c1d312b7df"/></dir><file name="Customer.php" hash="f5d7eb3738e07eb83a334b2d4a4301c0"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="a7d64fa72682061c7e53586e866c7d9c"/></dir><file name="Attribute.php" hash="b02dec4db5d7fdc34d380f46793e47c6"/></dir><dir name="Group"><file name="Collection.php" hash="09b632cea0cf63a7340d570d7fc870a3"/></dir><file name="Group.php" hash="5546c3f3f4e4e576c99704a159181eb5"/><file name="Setup.php" hash="26ee35b14c5bc8cbd73cce9162aba1f4"/><dir name="Wishlist"><file name="Collection.php" hash="72b17e5c6b622a67428b49159d192676"/></dir></dir><file name="Flowpassword.php" hash="b37572d121efa8f7f5a6145220099c16"/><file name="Form.php" hash="5d6109e111b3246bdfa4fbae2eee62a3"/><dir name="Group"><dir name="Api"><file name="V2.php" hash="e41ba19167609e178625c837ffadcc0d"/></dir><file name="Api.php" hash="910ce41663a3aa1eb1bc5dec47f75c36"/></dir><file name="Group.php" hash="3434803d8e2a377e825534383e8827c7"/><file name="Observer.php" hash="8f3ad14644722c03bd6bfadd85f1a936"/><dir name="Resource"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="2480c7ff5479486acdc71d5c4041e5fb"/><file name="Street.php" hash="5df083ea021e34bfabaf561726310e56"/></dir><file name="Collection.php" hash="3407e94f14ea73174dee4ee51b1759fe"/><dir name="Source"><file name="Country.php" hash="8c31116b4df92372cb202bf015dcf110"/><file name="Region.php" hash="c8816ccc18de38c74aac9a0ee0fc736f"/></dir></dir><file name="Collection.php" hash="382ffc3ece33f6d97cbab480e876e4ad"/></dir><file name="Address.php" hash="47ea3ba9064ab22f183e7fa309ebac6b"/><dir name="Attribute"><file name="Collection.php" hash="dc11746c5e719d05443ab6abfc158f62"/></dir><file name="Attribute.php" hash="a6e8657bccc9b73bac42927538cd4cb7"/><dir name="Customer"><file name="Collection.php" hash="88d5a0089a3fa9f9d6f10ff7aa45e18a"/></dir><file name="Customer.php" hash="cc0f7b29dc56a062795a42cc0085e5e4"/><dir name="Flowpassword"><file name="Collection.php" hash="ef19c2c10862f6e5362184291436e5af"/></dir><file name="Flowpassword.php" hash="968e8244a0c27d8c67a2569f655ecb0d"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="9315c60166317f2ef4c5a8105d5741c5"/></dir><file name="Attribute.php" hash="160eef2ee2908ef291e4ebe34f1f15cc"/></dir><dir name="Group"><file name="Collection.php" hash="9db3838edca76b5984f6b8ee7a32c66c"/></dir><file name="Group.php" hash="d7eae76b439b0dfa8c07557f3cba28d9"/><file name="Setup.php" hash="a271ee2dfeea1fdd49d24faacfc6cbe4"/><dir name="Wishlist"><file name="Collection.php" hash="63dfa1eef06f3064f6f8321ddf4a8654"/></dir></dir><file name="Session.php" hash="19447307e588272469dff208c75ad4ab"/></dir><dir name="controllers"><file name="AccountController.php" hash="efc462f991abe87c53cbcb265def3a42"/><file name="AddressController.php" hash="f9b92db500258202d88fe74b567e43cc"/><file name="ReviewController.php" hash="b4220956b1abdb7d143ce458d1b72fe5"/></dir><dir name="data"><dir name="customer_setup"><file name="data-upgrade-1.6.2.0.2-1.6.2.0.3.php" hash="af7950ce248f9a9017052f7e1de00ac5"/><file name="data-upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="28ead7be0a5853812b0d0c5e57968990"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="692e9ed764e5480a906b6c5819113acb"/><file name="api.xml" hash="e7cf0b9531cdef20c4898881e22d9988"/><file name="api2.xml" hash="6156af439bc63e66ca40cf2a26080640"/><file name="config.xml" hash="2b831a3d541c36c78dabf3cfaafd2aef"/><file name="system.xml" hash="0f3ff65c4195a6bcfa2720f6d15f0faf"/><file name="wsdl.xml" hash="b31ebf1de4a58469781b383f455991f5"/><file name="wsi.xml" hash="4c81aee30c525677be5c38e078b98408"/></dir><dir name="sql"><dir name="customer_setup"><file name="install-1.6.0.0.php" hash="8b5aa8cc89e2641c6853319b9546675e"/><file name="mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="4872ec3fc02eb5eb00f103700aa77041"/><file name="mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="28a7c7051a1bcd86dc8309b852ea8c29"/><file name="mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="5ffb0490d8258a783e7ac941286d048b"/><file name="mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="f8c846cdbe95a76586d1ce92064015dc"/><file name="mysql4-install-0.7.0.php" hash="cd96a8f93ad9e49f55db79733320975d"/><file name="mysql4-install-0.8.0.php" hash="aa7e8a1483150b61f53a5d7c1578d6c2"/><file name="mysql4-install-1.4.0.0.0.php" hash="6a6c0b7b9460e1fb4c536a2aa0b2f5e5"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="3e2055145079f629026415a460010553"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f2cbbb1b7ec6902b75a9955e6abb0610"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b85fc366d0e7d0e087ddaf00f0705ff3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="35525103f1307dac9df768192fd2e9d9"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="37a2056b43079d14d0128e60566f8c52"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="3285eea05014e0c9b320e70e23de2ea9"/><file name="mysql4-upgrade-0.8.12-1.4.0.0.0.php" hash="d6feb52da70cb181bdddc8f33e1a16d1"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="4c7cf47f2f0324e2fa56ea6074e7eebf"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="46cf00d3651186a07a4129c23670c581"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="80d616f36e92d58504a08574115177a9"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="64fd262a2923be67f079266d36168a69"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="b52810769b33bdd85dd2efe64e4b3e56"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="4f5c33afe8389600c49ac4830de89ddb"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="62243eccbc11be32cf0c6627404bf5c5"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="0cdad1e573d83ddfa65de2e8bb1ca548"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="7950a9f2a7dacf4e4c485f403ef1f43f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="8fbc3cf7e2c7c9f0479c7a9733174f68"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="1fbc98105825cd6e2a74ad876693abde"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="3f4745fc93d60c54d0786994fed3c4d9"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="2aba57c96240a0d360c1592e0e1aef74"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="aedd52a3f2cc4cfe9425cc4603a712ca"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="a049b659f24e9ffee7a567dc02a49e64"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="8ffd9139acb5c755e97d3d6541ad6700"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="be0bbb074cd8e0a3a32f984ec7bd0a40"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f176af847c112f0928b51cc3083729c8"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="fdd18814b345085bf323079bb855573a"/><file name="upgrade-1.6.1.0-1.6.2.0.php" hash="84a048767e0b1123ce58fa66c9323963"/><file name="upgrade-1.6.2.0-1.6.2.0.1.php" hash="dd06b50b358acf47a2dc7b8cbf14637f"/><file name="upgrade-1.6.2.0.1-1.6.2.0.2.php" hash="d2ce3d712996dbe1f3ba7c282060d44c"/><file name="upgrade-1.6.2.0.3-1.6.2.0.4.php" hash="6bb3b5b87199ed5d39609dddd5ba9bfa"/><file name="upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="26b3352e206d19a1d317014b66a966a6"/><file name="upgrade-1.6.2.0.5-1.6.2.0.6.php" hash="18abac53655791f7eb8bb296463998c7"/><file name="upgrade-1.6.2.0.6-1.6.2.0.7.php" hash="97804c97f4ab9d2ae87c39f85c16aa0f"/></dir></dir></dir><dir name="Dataflow"><dir name="Helper"><file name="Data.php" hash="e08ebbc2fd4e1d69f37837bd6879e617"/></dir><dir name="Model"><dir name="Batch"><file name="Abstract.php" hash="7fdc20cf4337b2e8e6ec98996355851e"/><file name="Export.php" hash="44de5ec437a2e8f8962a30f6a0aa7fbf"/><file name="Import.php" hash="438a63fba93182fbb849695e7f14ec9c"/><file name="Io.php" hash="b5faecc9e049d11969ef6888e847301b"/></dir><file name="Batch.php" hash="14e83b5b30bede8dae90cfb6444bd09e"/><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="9a037b33e482074fa3d913e478597727"/><file name="Interface.php" hash="5451a3ae2d36340211f5db410cfbd618"/></dir><file name="Action.php" hash="133f901570f109f9af35ab17a7a7bf2c"/><dir name="Adapter"><file name="Abstract.php" hash="51fd62ea51d6e990429d3fdc6e870c6f"/><dir name="Db"><file name="Table.php" hash="a4f0bed5a537c6dd4f04a1875a3e5f29"/></dir><dir name="Http"><file name="Curl.php" hash="c62a57836e8e36d04621c2ec4f41adbc"/></dir><file name="Http.php" hash="6fed3d72666b24902601a4ce5b2478cb"/><file name="Interface.php" hash="d2f28a724dd13c880372397ead2416f7"/><file name="Io.php" hash="62e2beb0db33f5845d6221428d144325"/><file name="Soap.php" hash="1cb9b54a4968108f511e86da5c30b5b7"/><file name="Std.php" hash="5c9c797d238d5731484fed2669c4320f"/><dir name="Zend"><file name="Cache.php" hash="cb121f8c7129317b181b80dda9946fc9"/><file name="Db.php" hash="457dd7726d2a30ec193ed8f4e7116031"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="03d6e312e776303d9cf1dc8de1c77478"/><file name="Collection.php" hash="52edd435007eab55dd6c44b61cdd9841"/><file name="Generic.php" hash="2dcbb8dac8a4d8d68157d8c742f74b2f"/><file name="Interface.php" hash="99565c4df1b032f1276db130f99cb723"/></dir><file name="Exception.php" hash="076118f579fded6e5ee39631c8a74505"/><dir name="Iterator"><dir name="File"><file name="Csv.php" hash="e8d574afc2c3bdf922eea8387ea68b06"/></dir><file name="Http.php" hash="80d1c7d31b2641cef4d9b81dca74b07b"/><file name="Interface.php" hash="8a2e0ea004e8ec1c10163f73f96374bf"/></dir><file name="Iterator.php" hash="54bdd6114b22be7319333103fa3e8c76"/><dir name="Mapper"><file name="Abstract.php" hash="93ae0b13a5352a620825298c5ed66c05"/><file name="Column.php" hash="f392976ef13863f5f32f04a09ab6aba5"/><file name="Interface.php" hash="0437e7aacc6b135b6ae383b463616287"/></dir><dir name="Parser"><file name="Abstract.php" hash="3236fe8798302c48929726e03e141ecb"/><file name="Csv.php" hash="949f7e32e0199ea94577f670e273f1df"/><file name="Interface.php" hash="dd7760a2cf2b5e49ef67990189647ab7"/><file name="Serialize.php" hash="ae87fb54224bfddafd7efd95c87d9066"/><dir name="Xml"><file name="Excel.php" hash="cc4a18db41565711ec48b471ac7c55d6"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="0ddcfa647231d5e2a0d9fdfcb54419e6"/><file name="Collection.php" hash="406521382cf7603b8054c6ef4131fb72"/><file name="Interface.php" hash="a0a9fba52399f7946b7743d8011c3ebf"/></dir><file name="Profile.php" hash="834a4d150f1597dbdc251db0ef543e14"/><dir name="Validator"><file name="Abstract.php" hash="e765aea7e8f5193277899c5418a7578c"/><file name="Column.php" hash="1a5b7cffadecce6e2c687ad6e1606e57"/><file name="Dryrun.php" hash="edb950b748d40593f34594db0911715b"/><file name="Interface.php" hash="86f42e70518c14452d499c1d73884a1c"/></dir></dir><file name="Convert.php" hash="e125ca51eb5ea388a4226984e077bb55"/><file name="Import.php" hash="8838b197445f884cd96d210057768a6c"/><dir name="Mysql4"><dir name="Batch"><file name="Abstract.php" hash="2b6f51758706c99b5f5694c4bf59400b"/><file name="Collection.php" hash="6d31df66ebb4c838e937ced0950add33"/><file name="Export.php" hash="14e075cd437463318c4918c87d51f142"/><file name="Import.php" hash="6d7a15cc0ee4750440e27169f1458165"/></dir><file name="Batch.php" hash="8c72af2813e71735947b59224512fd7a"/><file name="Catalogold.php" hash="24ed373e2153ac1553a8f5213d1cb3db"/><dir name="Import"><file name="Collection.php" hash="931767370c3cd538c2d61137ef81c270"/></dir><file name="Import.php" hash="b1845aa3d075528f559e4278c0545c90"/><dir name="Profile"><file name="Collection.php" hash="667d27ab098a1cc0d7b63add7f846bee"/><dir name="History"><file name="Collection.php" hash="561468d39bea85e329273488cfd2e25c"/></dir><file name="History.php" hash="a671fb7398cc9013b5679924a9576121"/></dir><file name="Profile.php" hash="423f9c09e862da840aff3c1045671760"/><file name="Session.php" hash="9f2de6e0336f990f406c314f848d80d1"/></dir><dir name="Profile"><file name="History.php" hash="952111190cf3cf31c4a293ff30a42a1a"/></dir><file name="Profile.php" hash="d6f8175d00db20f1d44690a467d56a18"/><dir name="Resource"><dir name="Batch"><file name="Abstract.php" hash="adf8bd1d47bfb44429d1f22557e09c4c"/><file name="Collection.php" hash="a107007ee0f2e1d33a075b2042cac37f"/><file name="Export.php" hash="6de19c09e9b2cdfb339477eab9536cc7"/><file name="Import.php" hash="8b2ecc68b077493284aa7ea723b1f202"/></dir><file name="Batch.php" hash="31fa2a981414ba9cbb1d36d9fce80ac8"/><dir name="Import"><file name="Collection.php" hash="bc29b52fd643bba0973be87265fd32ed"/></dir><file name="Import.php" hash="cd5b7cd2631393c4606fae225ba5fdef"/><dir name="Profile"><file name="Collection.php" hash="c4d4a9004563e08fd051316dad4695ce"/><dir name="History"><file name="Collection.php" hash="2f30f6a4d76e22bffa55cc493b01cd29"/></dir><file name="History.php" hash="b7aebcdd049fb2be0481f25a058e592c"/></dir><file name="Profile.php" hash="b12abc950a618c3239ffd0b087fafb89"/><file name="Session.php" hash="24cba703ea2a3899f1ceaec111445da2"/></dir><dir name="Session"><dir name="Adapter"><file name="Http.php" hash="c3992d945b4f9e2cf948827ef4b97675"/></dir><dir name="Parser"><file name="Csv.php" hash="165232a998562cb26a5a5664c0ca06ba"/></dir></dir><file name="Session.php" hash="8bae06d98900fb274e96676edc00df20"/></dir><dir name="data"><dir name="dataflow_setup"><file name="data-install-1.6.0.0.php" hash="e8a25ff1d524d64663da553ac0bbe530"/></dir></dir><dir name="etc"><file name="config.xml" hash="d8bf8f4863632692e44a1ee692bb7874"/></dir><dir name="sql"><dir name="dataflow_setup"><file name="install-1.6.0.0.php" hash="d97858ba4c95f9baca0091f37df58654"/><file name="mysql4-install-0.7.0.php" hash="e6a1202a88b8be57424e537535bd8546"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="b031906d286d82ec0d22c3c00438a387"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9e7d95b914f360a1a342f7364886ed61"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0399490704f187860be377f3eca679d4"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="84740102452a11d71c2e94790d8c94e1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="8041c24d939a69eccc8da15b2a27b175"/></dir></dir></dir><dir name="Directory"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Currency"><file name="Base.php" hash="dcb443aff27519bec9c0fb1eadebddb4"/></dir><dir name="Region"><file name="Updater.php" hash="84e993fa8725770c162375474f6162fc"/></dir></dir></dir><file name="Currency.php" hash="a209e62973d545d82a06c3d37c3b2494"/><file name="Data.php" hash="814cd0a83516e4040436918d176e6b73"/></dir><file name="Exception.php" hash="ffe766fa980bcff2159ee53263c01805"/><dir name="Helper"><file name="Data.php" hash="339c9514b741d43f50db4f7a3a18353e"/><file name="Url.php" hash="67ccb2a02f260665556beb8946de1be7"/></dir><dir name="Model"><dir name="Country"><dir name="Api"><file name="V2.php" hash="f1f135eb3faa33d17f66ec80daa125a8"/></dir><file name="Api.php" hash="3ee2f9ed300a8728203243e70b1bce82"/><file name="Format.php" hash="f2f2ad752bcba7dc3297bf101157e8e0"/></dir><file name="Country.php" hash="e0e56529d3f42681f39f2d550c12d71b"/><dir name="Currency"><file name="Filter.php" hash="f70bbe7b70f72e3eba142ef51a2f53e6"/><dir name="Import"><file name="Abstract.php" hash="9438914132e0315803cf7411034a9f57"/><file name="Webservicex.php" hash="2c0f90fa66b24589ee74f3c67649a40f"/></dir></dir><file name="Currency.php" hash="53fbd10d7e037604c4b68b0afca9eb3a"/><dir name="Mysql4"><dir name="Country"><file name="Collection.php" hash="0d944c0a19c1a348d3ff86809697a289"/><dir name="Format"><file name="Collection.php" hash="b82c10c3e3bf81b493ffbab4dca55013"/></dir><file name="Format.php" hash="30e47385420534e5fcf5c5494ed50e4f"/></dir><file name="Country.php" hash="1fd1f772fdb465235910ff7b4db1573c"/><dir name="Currency"><file name="Collection.php" hash="53291e3cf2239398b21fb65843b9e8c4"/></dir><file name="Currency.php" hash="7e14f08f128342f007f48546924a0bd5"/><dir name="Region"><file name="Collection.php" hash="471cfe58eefc3b8051b3cfd8a53cbb6d"/></dir><file name="Region.php" hash="4b79281b66b206439339f899e008800d"/></dir><file name="Observer.php" hash="b6b3d68e879e2c2f4c9d1d28453dc7e7"/><dir name="Region"><dir name="Api"><file name="V2.php" hash="a741b57fb273d9b2e8ce4c7ea72eacef"/></dir><file name="Api.php" hash="281487c558f2a3dddb36958063951cf8"/></dir><file name="Region.php" hash="0d87c99bd12fc091889fce254c77e04c"/><dir name="Resource"><dir name="Country"><file name="Collection.php" hash="972013305c612d9c523559de14fd93d1"/><dir name="Format"><file name="Collection.php" hash="901c10028b32a68a938458b299355945"/></dir><file name="Format.php" hash="f39efabaf3ebdb0c45870b2a8b58333a"/></dir><file name="Country.php" hash="c29b853734688ee76e3745b1883336e5"/><dir name="Currency"><file name="Collection.php" hash="b7a063492f8b0521a0bb6f00ad06464b"/></dir><file name="Currency.php" hash="717ac0dfd9e752ec0c3737fe24fbe239"/><dir name="Region"><file name="Collection.php" hash="f75aac9e2cffc3d608977516f85e5de5"/></dir><file name="Region.php" hash="aa6161845be2b0c5d01d95b97aa236df"/></dir></dir><dir name="controllers"><file name="CurrencyController.php" hash="598938459dedac62bfb4195a2242fd8f"/></dir><dir name="data"><dir name="directory_setup"><file name="data-install-1.6.0.0.php" hash="66a3d2eaa39070958ca9809798102c3d"/><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="354710cadd7abd6dc5a10a2f6842b190"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="3207bee7088f4c11f6c57f2f9bb173dd"/></dir></dir><dir name="etc"><file name="api.xml" hash="78c8bdd46e7a897a74f6455ee688f419"/><file name="config.xml" hash="0ee1b74bccf3c7bba0cfad8326c6193b"/><file name="system.xml" hash="e7ced71e07c4449402bbeded8860a5db"/><file name="wsdl.xml" hash="cc488b81c0eae648a0ee360d6e2d9960"/><file name="wsi.xml" hash="66de37cc17e24c0c66f74c52e2df616e"/></dir><dir name="sql"><dir name="directory_setup"><file name="install-1.6.0.0.php" hash="97df790b958ebbedcba5764fe4dd1011"/><file name="mysql4-install-0.7.0.php" hash="a87b5313783e11a0dd0f0cf8be739ea9"/><file name="mysql4-install-0.8.0.php" hash="ecec00ae456029ca8822f18a20e42e47"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6c70b08a6df461765456c2ac2f026fcf"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0c0e79dfc15370c558cbbabc0d1f8b9b"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="49fd5e3faf9bf452bfa8b7ebe100f346"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="a19b84e51cbc261efec34caaa6f2df7b"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="e328f0f70c75b98ae002d51b4ea991d9"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="2fc37e8f57d83e61a8e2c79a66c26e4f"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="60e3b937063bfb51a4372641c1e7c2b8"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="85297cb10426b170b0d19d2bac8fdc25"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="1dc8216499faf835c7ed62970336fa04"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="39387527f2128086ef2400517a125591"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="8d899b7db31e1e8503d1e3e4ef688a15"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="bd555e1bdf284e094aa80ddac5406049"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="2ab87429050aac0a4df755873cb9b189"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="83bfdf5ef0248ece192862d9c92ddabb"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="2c8baba0cbab3ead3938c8448adf9138"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="572730242d7420bd723f775e67ec9c3e"/></dir></dir></dir><dir name="Downloadable"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Downloadable.php" hash="5544e55e911f0d9603563313d8a5ba88"/></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Downloadable"><file name="Links.php" hash="5464679fcaef509dba28069874a27e77"/><file name="Samples.php" hash="436ec7541c855576c7db3af0742e6e51"/></dir><file name="Downloadable.php" hash="717fb4bed3c4d7469ee3789cc7ffbb40"/></dir></dir></dir></dir><dir name="Sales"><dir name="Items"><dir name="Column"><dir name="Downloadable"><file name="Name.php" hash="08465b9e4605219116e890219740bc9f"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><file name="Links.php" hash="dc4eb48f451ba86bb70139315b481c05"/><file name="Samples.php" hash="6078e472cabebeb0cdc4a3a357034bf7"/><dir name="View"><file name="Type.php" hash="e68a8cf189a41520d5f0ad72dff79e9f"/></dir></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="5cc371580b1e272048c7a21340a3c708"/></dir></dir><file name="Success.php" hash="df0d8053cc9b3a78dcc97e8897d856ad"/></dir><dir name="Customer"><dir name="Products"><file name="List.php" hash="623c68e1145d21ec434ee61cbdc2a2eb"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Email"><dir name="Items"><file name="Downloadable.php" hash="e01c820dd9d434855510c3eb75e566c7"/><dir name="Order"><file name="Downloadable.php" hash="11f1993afc36f2382f9115178fc5d821"/></dir></dir></dir><dir name="Item"><dir name="Renderer"><file name="Downloadable.php" hash="d922d37364e371d75723b7a7ea2597ef"/></dir></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="cef93d38c9bf07a97c29b47db1cdbdca"/></dir></dir><file name="Data.php" hash="cce44b4432c3a168625e7e57932b18d9"/><file name="Download.php" hash="f9f893a3aae7ae404efb0c1543df2ff5"/><file name="File.php" hash="b288bd80241f90020a9fb606c572cd6a"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Downloadable.php" hash="106ce95f23424fec86b33737bc66ad6e"/></dir></dir><dir name="Link"><dir name="Api"><file name="Uploader.php" hash="6b4ff7b40832964c7beacea27513f349"/><file name="V2.php" hash="c4cc027f7ee0d8fcc4e850e55ff90652"/><file name="Validator.php" hash="64c1aa175dd35795f3d2e34efa349b29"/></dir><file name="Api.php" hash="c60626720f452220954577fec210e2a4"/><dir name="Purchased"><file name="Item.php" hash="1c448bd68d1307b8835a6033762d32a0"/></dir><file name="Purchased.php" hash="a7d59c19ef70336d8cc142bbbec8a9cb"/></dir><file name="Link.php" hash="0217b7584fef57c6954c16d6adcaa3b1"/><dir name="Mysql4"><dir name="Indexer"><file name="Price.php" hash="872bec0182625153cda0d1f1bf472c13"/></dir><dir name="Link"><file name="Collection.php" hash="77d4839d3861a3071e6d8396fdcd256d"/><dir name="Purchased"><file name="Collection.php" hash="c0d5586d288467fdaf479b7b0c911b7f"/><dir name="Item"><file name="Collection.php" hash="cf6773d1b912235af2ccdbab5dbb79c9"/></dir><file name="Item.php" hash="76cd2e07c02c2c2c964d7bddf4102aa6"/></dir><file name="Purchased.php" hash="1147feab13010c4719a84f1f767e822e"/></dir><file name="Link.php" hash="f11eaf4cd02f64961e5672751d4a166e"/><dir name="Sample"><file name="Collection.php" hash="fadf9932b2f36dd6813e7ab44b0ac474"/></dir><file name="Sample.php" hash="16e8fc69977438abcd8acdfed3dec4e8"/></dir><file name="Observer.php" hash="dbdb75ba95873d2af9f73636c140a2cb"/><dir name="Product"><file name="Price.php" hash="7ee60315804a76c4ac13a442fa75e546"/><file name="Type.php" hash="20db85d75642ce7fceb7f9354b6f139d"/></dir><dir name="Resource"><dir name="Indexer"><file name="Price.php" hash="ad05b2ed96af42e014e7e9056cd05215"/></dir><dir name="Link"><file name="Collection.php" hash="430a3e0f8cf92d1c2c2f1cf8ca3a22d8"/><dir name="Purchased"><file name="Collection.php" hash="ccdffcce054283303fa2b57f55bb2478"/><dir name="Item"><file name="Collection.php" hash="b72144d20dd7a94c491c484bca5993d2"/></dir><file name="Item.php" hash="1870b346f2c46e5501390aa6fcc6bd7e"/></dir><file name="Purchased.php" hash="e098613b94c59cd7ad0c86d305c4c6e3"/></dir><file name="Link.php" hash="c6f124b3611b837957d2a1b87e495308"/><dir name="Sample"><file name="Collection.php" hash="9e69c792b71ff1b74d4fd774e50ef8ff"/></dir><file name="Sample.php" hash="d40abfd991963a6dcf395d79a6994608"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="d66eb5e3f7cacd8f8f5be7278a700047"/><file name="Creditmemo.php" hash="2c16eefe0e064ecdb82bbcf48ccd9f0f"/><file name="Invoice.php" hash="b49d92df09b7cd688c98368227124c30"/></dir></dir></dir></dir><file name="Sample.php" hash="c0ef89aebd738dd0fb5d0953cbf54aeb"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Contentdisposition.php" hash="17876b9510afa671206c4ba1fdc85ac7"/><file name="Orderitemstatus.php" hash="10912ec89ce9a860dc65577b0ba3afc7"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Downloadable"><file name="FileController.php" hash="a0eb299dc9ef7811ca4c495b29ddddb6"/><dir name="Product"><file name="EditController.php" hash="4ae0fec76ce03173441bfe71f08a0327"/></dir></dir></dir><file name="CustomerController.php" hash="c4fbec7c76733cda3b1b5916a6f73ebf"/><file name="DownloadController.php" hash="f9e435211ad4d9552a5368649d30e881"/><file name="FileController.php" hash="870f184cd5cd1e2d7cad96b7d05e3bc2"/><dir name="Product"><file name="EditController.php" hash="30c279baf5ffe4a5902015780ad8630c"/></dir></dir><dir name="data"><dir name="downloadable_setup"><file name="data-install-1.6.0.0.php" hash="0856a374d51df586dc44049643d69c97"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="c3d749dddcef5a546dda075abce68322"/><file name="api.xml" hash="2a1e953ddd8fb42c48b0bd9199b16d5f"/><file name="config.xml" hash="f889323cbc6b12cd75f042a6da641de0"/><file name="system.xml" hash="1673c3db704574c12a117cbf51f1d235"/><file name="wsdl.xml" hash="b3935ff3bf7e2ca40ddd304b4c78577f"/><file name="wsi.xml" hash="7eef36b29c2abf88596e63b6a042626d"/></dir><dir name="sql"><dir name="downloadable_setup"><file name="install-1.6.0.0.php" hash="73025eb4881191a625ff8e4d1d4cad1f"/><file name="mysql4-install-0.1.0.php" hash="3f91840c8450bbecc18d9341d6f99e26"/><file name="mysql4-install-1.4.0.0.php" hash="7bcf4612674cdd43767c86d24fc9c91a"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="65cdda44f8abb16f5831193b0a894160"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="2e41ac0d97b013779f8aea4e9c660fee"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="d3fa7bb5ecfb83e0c1c492c895b963d4"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="108af92cb4d9c9e6bdf081789733c1d9"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="020a4ffe85262a22fda6a434a23c9d76"/><file name="mysql4-upgrade-0.1.13-0.1.14.php" hash="148e7cce3138f3880f2b3c66865f70a2"/><file name="mysql4-upgrade-0.1.14-0.1.15.php" hash="23f6349cd7cdb4851518b60c7e429056"/><file name="mysql4-upgrade-0.1.15-0.1.16.php" hash="e00c6062b8353456aa06352dcc1a5e8f"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="dc74191e6087ea0d6a00d6af0c9fc58b"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="540575730433e088edc3dc0cbbe6f943"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="4c2065c26097a369bc666e82dbaff7ae"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="bcdf26984f17320f3a1336b69f99fd94"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="9b026da94cd3b6b45ab968ef3214fd86"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="c440e7df19344e1d439538e5c55da8db"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="b13ea4ce5555f4e0665abe5742cdfe2c"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="fd75df74eca07dd8b6fc2cefe64f4257"/><file name="mysql4-upgrade-1.3.9-1.4.0.0.php" hash="1f9d156b0cbd54eb0eeb2eeae8d24150"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="07e2648baa8a10a806458e82ebbcd0d8"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="1bc757aced95279cd466f815c1285b48"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="4c9892da7cb86c07246592c6f47b8ca5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="27359d8b56d13b44bbeca5eeaa839c2c"/><file name="mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="b0b63d81f9e951a28608a5cf35691a9d"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="5a18214628e2734e899e21632229d814"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="3f5a16909ebda690210c9be08dbe1859"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="e807d4c8365f32b0a4aab3d0552cc1a6"/></dir></dir></dir><dir name="Eav"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><dir name="Edit"><file name="Js.php" hash="8002101c678b99ac6f8b59eb03d2382b"/><dir name="Main"><file name="Abstract.php" hash="a7a149707b945eca823a2ca098adb59f"/></dir><dir name="Options"><file name="Abstract.php" hash="e0b64d061e2fcd87526641c2ec6f6774"/></dir></dir><dir name="Grid"><file name="Abstract.php" hash="d5c599e249678648d293cb9ed83e2249"/></dir></dir></dir></dir><file name="Exception.php" hash="692892ea4ef5d5e1b6da23cbabe22d38"/><dir name="Helper"><file name="Data.php" hash="469b64a28f1b7ea088989d1d45803204"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><dir name="Inputtype"><file name="Validator.php" hash="47eac458550c8af64457669f0ac3d9f6"/></dir><file name="Inputtype.php" hash="b67a8dbd70de6eb89cdb1479f1387339"/></dir></dir></dir></dir><dir name="Attribute"><dir name="Data"><file name="Abstract.php" hash="18b807dbce7f4e21dfb7d226b481cf48"/><file name="Boolean.php" hash="448ffc80b75e90aec463ba51e050aa48"/><file name="Date.php" hash="7a2cc647db45fbcabc84d98c71ba1940"/><file name="Datetime.php" hash="b7e86e04808abb6740f77da62852d5c0"/><file name="File.php" hash="d4a0899d5d9b3b1daff4eb7e18b584fc"/><file name="Hidden.php" hash="5cabcb3cc942d369d485498abb15a27f"/><file name="Image.php" hash="23813e4f849dd850a42ffb317805ccb2"/><file name="Multiline.php" hash="9e2c79401a1ddf91f7635ca1e891b1d1"/><file name="Multiselect.php" hash="6d3a8e7d0bdadf02122a7c93b7bbff86"/><file name="Select.php" hash="1bb3420d77077d7f4fd1f5eb1b586695"/><file name="Text.php" hash="70ebf479764a19c96d0de26bc6b82485"/><file name="Textarea.php" hash="30f51d262e78a9fab2199555732e009f"/></dir><file name="Data.php" hash="7bdccd4e5d8ee6d29f5c7e4b99bbe561"/></dir><file name="Attribute.php" hash="7b68850f63e3de9fedfb181d44baabf7"/><file name="Config.php" hash="f57eadd2adb757beb19123576734e006"/><dir name="Convert"><dir name="Adapter"><file name="Entity.php" hash="7655752075b807bed3af49cc549faa50"/><file name="Grid.php" hash="ac7a302dc3a2b9c392a440a2db37dc34"/></dir><dir name="Parser"><file name="Abstract.php" hash="1057d89923122d529e273dffcf5f4a0f"/></dir></dir><dir name="Entity"><file name="Abstract.php" hash="8eee99942b9582fa010e040a875d7c1c"/><dir name="Attribute"><file name="Abstract.php" hash="4efa349be932010e7b6cb566de9114c2"/><dir name="Backend"><file name="Abstract.php" hash="9a640786c043cde90f01f6dbb1a35d96"/><file name="Array.php" hash="0a711643fa35be28798dc184c627e700"/><file name="Datetime.php" hash="dde5423ae42ddbf1935ba015f2e1002a"/><file name="Default.php" hash="0d67f3e45c2837cf97cab5ea4332e569"/><file name="Increment.php" hash="27e72f5a631fe9e8317b6e97173fbbad"/><file name="Interface.php" hash="70a21176e2194e7b2494f50954c4b178"/><file name="Serialized.php" hash="1d30c28c6ddb374758a9a189035c3ec2"/><file name="Store.php" hash="f1a93a8001c7b9a943fbe8bda205983f"/><dir name="Time"><file name="Created.php" hash="a7c20601a78ca7dbf51ad0a8847e972f"/><file name="Updated.php" hash="21a98e318fca4efc9d360a5e08990e57"/></dir></dir><file name="Exception.php" hash="794a727bc18b5bd60b349a2a858fef79"/><dir name="Frontend"><file name="Abstract.php" hash="2fad37d0d105191e3e764af900f793cd"/><file name="Datetime.php" hash="9c434461bc5f2b9800a072d040b29465"/><file name="Default.php" hash="991f8adc6ee272e59749753e021fcbfb"/><file name="Interface.php" hash="7f8db3081bac40a4411b219ed4c86b15"/></dir><file name="Group.php" hash="2da22de349ceb7b41b4df05e3e63bfb9"/><file name="Interface.php" hash="cf6e7cdd174f51cfc7f7e62d37aca049"/><file name="Option.php" hash="1a4439116682f14f492d0e155aa5adf5"/><file name="Set.php" hash="67c868057c968a2806890122a9d0bd84"/><dir name="Source"><file name="Abstract.php" hash="4f2f467815b3f475038d60bcbca97c6b"/><file name="Boolean.php" hash="60c477201e65a1dfd8bd6026c92e2905"/><file name="Config.php" hash="2e7a518ddb3c8e61489de5f11620c319"/><file name="Interface.php" hash="5895a4fb491b6d0190ecf2f179a34480"/><file name="Store.php" hash="c3d40f6aacc4977a98261d64f67d170e"/><file name="Table.php" hash="a13af459d41f4e38fca0494f5b0cdd36"/></dir></dir><file name="Attribute.php" hash="e41967fbcb581b0082d9f4ce4ac04f01"/><dir name="Collection"><file name="Abstract.php" hash="abe40e0d6c5f48e82410446329eab621"/></dir><file name="Collection.php" hash="dd3182d0409c9dfef8703a04d05ce6bf"/><dir name="Increment"><file name="Abstract.php" hash="88913be1b543278355276369c687cf2c"/><file name="Alphanum.php" hash="55dd05c0cd441d15e16d44e7824846cc"/><file name="Interface.php" hash="8a3cd897b1d0f8da29cf529362384570"/><file name="Numeric.php" hash="7aaac9e675d0e684fdfb0090a3f86251"/></dir><file name="Interface.php" hash="6492dcc4320e059b4dcfbbef7cd3660f"/><file name="Setup.php" hash="765e2c9b0391ced119e70b51041c6fdb"/><file name="Store.php" hash="9b190b04359b1055cc38f14ec34bf210"/><file name="Type.php" hash="48b9da0b09cea5525ae11e66eeeeecef"/></dir><file name="Entity.php" hash="a43519b11a54664e6f567d6c64cb7566"/><dir name="Form"><file name="Element.php" hash="958c9fe3092b2cb584fb6fd367f65e4d"/><file name="Fieldset.php" hash="9d541ea5e7fa884a5aef36b358f4584e"/><file name="Type.php" hash="297b10819a97e098e398dafce6bf9e2c"/></dir><file name="Form.php" hash="1f3db6caa1e69d6fa7d0270d125b7fa4"/><dir name="Mysql4"><file name="Config.php" hash="88ddce2de8762b473e5f11ee15863ea5"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="f4bad2b7c97aff236c4d59ab9d11d80b"/><dir name="Group"><file name="Collection.php" hash="e5e8ae843ffab0d11e7306ecb3f76d36"/></dir><file name="Group.php" hash="b034badccbbc0e7102f085ac7d788b40"/><dir name="Option"><file name="Collection.php" hash="17e9bb8286b55de90c59cfe7da7d5f7b"/></dir><file name="Option.php" hash="3a058b88276a2fdd8b34cc39c7b66993"/><dir name="Set"><file name="Collection.php" hash="5d5f48626da06576b673c039de164606"/></dir><file name="Set.php" hash="01e30e73fbae7885c6808ee532f15e12"/></dir><file name="Attribute.php" hash="0bc50d42a753a0d38b027ed6e8125cb9"/><file name="Store.php" hash="022bb925298448ce0515c8902c950ae2"/><dir name="Type"><file name="Collection.php" hash="bc9361e0e15cea6007ddd2ff3756e906"/></dir><file name="Type.php" hash="563ecb5bc3160660ee2cd981db54e83f"/></dir><dir name="Form"><dir name="Element"><file name="Collection.php" hash="b5c98a418630ef3df9ab3f94c7b675a0"/></dir><file name="Element.php" hash="c8ad10c8cc7a5871ee92b972111cbabc"/><dir name="Fieldset"><file name="Collection.php" hash="daa73b54fa5aeb8ab5a310f910e64d80"/></dir><file name="Fieldset.php" hash="bc071d0b1c94bdc5a1dcd0a8496f051c"/><dir name="Type"><file name="Collection.php" hash="0196365ca85575c2f188fcf564906647"/></dir><file name="Type.php" hash="8ae370004548e992999bf7d1c5b8bf72"/></dir></dir><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="884adb14175e8728ee1757184d595297"/></dir><file name="Attribute.php" hash="977d832c7bf13354773879120e02a47a"/><file name="Config.php" hash="0c92be60b44d8f3f3872598662b484f0"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="c5dadd8439567c5ce0bdebfea23a3cb7"/><dir name="Group"><file name="Collection.php" hash="df9ab23eec5d042f5f44019dff458faa"/></dir><file name="Group.php" hash="3d732769aff3b8cc4af392346edb4f6d"/><dir name="Option"><file name="Collection.php" hash="fd5336332f8520dafc0213ef56d46f46"/></dir><file name="Option.php" hash="ef41db5b623b60125f36dd3166a73694"/><dir name="Set"><file name="Collection.php" hash="a218c8eaeb97080247c1f33f6763ce6d"/></dir><file name="Set.php" hash="ce0178c652fe12485b7e93ab22bacd5a"/></dir><file name="Attribute.php" hash="b35cfacaeda83f88f4ffabdcd637e9e3"/><file name="Store.php" hash="c922ae9b3f5ea5dc1cbabda637529252"/><dir name="Type"><file name="Collection.php" hash="f5ac2bd4f51c6a5caf49fb17526474d0"/></dir><file name="Type.php" hash="63c0bca51b1a0022c55fd4991f048981"/></dir><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="b0ce3e921c386fdc8127a7cf632fc9bf"/></dir><file name="Attribute.php" hash="b3aa3ef3de1bfc985d5b0dff837435c2"/><dir name="Element"><file name="Collection.php" hash="ed90d49ac06f3c6fbb8db1c5e93e70fc"/></dir><file name="Element.php" hash="cc8254b4f9231e1ef8bc62c7961c952f"/><dir name="Fieldset"><file name="Collection.php" hash="25e2bbc43a6a3f717687ab2f02ce3908"/></dir><file name="Fieldset.php" hash="d53c80a906104fe1c027e523230d8693"/><dir name="Type"><file name="Collection.php" hash="bb1bbec0dbabd0d2d1c384b7cd664e51"/></dir><file name="Type.php" hash="2ab9c6d0e36d4df5ad949b9a647b4e19"/></dir><dir name="Helper"><file name="Mysql4.php" hash="640baca7f4fed199db4f3be9229b997a"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="0ce463f61644eee879ef38dcff13de24"/></dir><dir name="sql"><dir name="eav_setup"><file name="install-1.6.0.0.php" hash="bbe35ca1128ad7dfcfce6b549a659920"/><file name="mysql4-install-0.7.0.php" hash="7f785666cb5dc104ba63eb2dbf2c57a2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ec0c99ae4cbf859972139d00f6e728c1"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9393b28c723fb6167bd688303cba8059"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="ad12f666f57394e5636bb0ba4379b445"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="89b66b6c969e6dc8bdc12956942c009b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="f471ae0351ea4f1127b40a299e937881"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dde737bbb90c59b57dd29cbfad286f32"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="4e210a99ea80498b338a7e533056e627"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="1aed43be7928f84ad7412e2df09eeae3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a760b5658978091af5a9dfeb5388969b"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="565d7aa6ef731bad0e3c836a5e6a3a21"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d53449b41c1fe3670909ffdbb2d66d30"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="b0497e262a4bc2ceede93bd6ef5cabfb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="d46637cee88d0cff61ab92a67485c141"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="b9cb4c015ee2e6f7aeb171c7326920cb"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="6784ed5afa90ba51e354e85c24cb4717"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="4929c7c613e6c07343551b83efe1cde5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="d5402afc2fa0f998be3ac372ea6cfd05"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="cb254f182f6e7c6f47fb2c5508499111"/></dir></dir></dir><dir name="GiftMessage"><dir name="Block"><dir name="Adminhtml"><dir name="Product"><dir name="Helper"><dir name="Form"><file name="Config.php" hash="86d11101a35df5731e8a4dc3a8e3dcab"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Create"><file name="Form.php" hash="548ab4b117fadee4331d5d00b0b231cf"/><file name="Giftoptions.php" hash="194289650bcccaf4483bfe3fb08ea933"/><file name="Items.php" hash="ef73476667ab8864ce6b65c5c0f3d1ae"/></dir><dir name="View"><file name="Form.php" hash="7b686e304e00f3da4a47c46362ccc5ad"/><file name="Giftoptions.php" hash="6c876c5fcbfc4e8204405b36c97865ec"/><file name="Items.php" hash="b7024780e706585ca268cd2522424946"/></dir></dir></dir></dir><dir name="Message"><file name="Form.php" hash="05dda3c7407fdf1bea7786218d99e529"/><file name="Helper.php" hash="5674ff6321c3b9502799786ad0bc45e9"/><file name="Inline.php" hash="3ea27c962a3bbb24da93694e7c3187af"/></dir></dir><dir name="Helper"><file name="Data.php" hash="bb0cda0f10afc6b6f736387f2a42db5c"/><file name="Message.php" hash="ad71d72f75008e1ae2b478a519cb57af"/><file name="Url.php" hash="e4e08bb1c1beda2657e17f4736b32579"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="f98276d7e1d2b4fe7d3cb742a18de8b2"/></dir><file name="Api.php" hash="26bb46739aee15f2398f2878c1150656"/><dir name="Entity"><dir name="Attribute"><dir name="Backend"><dir name="Boolean"><file name="Config.php" hash="f8f406d90bc9932c7b0e524c6403e465"/></dir></dir><dir name="Source"><dir name="Boolean"><file name="Config.php" hash="1e172c45ecdfe20d430f47e325470a8b"/></dir></dir></dir></dir><file name="Message.php" hash="5dfb4882a1a9b17ace6c4e17e5dae1ac"/><dir name="Mysql4"><dir name="Message"><file name="Collection.php" hash="1fd013a786ec1689feb96cf55fe8640c"/></dir><file name="Message.php" hash="4808d235da64c332355a757e6b2b1484"/><file name="Setup.php" hash="789d8e3ce35e92b8397a047c4dc10d90"/></dir><file name="Observer.php" hash="0e5d615565c62715ab68880aada4b619"/><dir name="Resource"><dir name="Message"><file name="Collection.php" hash="c973909813993d83be31e54742148e39"/></dir><file name="Message.php" hash="a78200d1df9b33523802f1dfd28285d8"/><file name="Setup.php" hash="165848ac03e71df30203c50a7bca0736"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="c4fdd6ed77fbd0ed2a72dc4d6be5508d"/></dir><dir name="etc"><file name="api.xml" hash="0cd624a5a4b2992eab91bab7db9c1a54"/><file name="config.xml" hash="934f6208ca8ebdb88531557d83c9fab6"/><file name="system.xml" hash="38ddfe6859cffc50f20bb4a0c5f0e808"/><file name="wsdl.xml" hash="b99aaaac0126c6e09a7ba59fa4dbcf30"/><file name="wsi.xml" hash="ab77c7cfecb0f5d6cb7b07c0b5abc1d1"/></dir><dir name="sql"><dir name="giftmessage_setup"><file name="install-1.6.0.0.php" hash="374dd23fc10fb776a6e7f846e5790330"/><file name="mysql4-install-0.7.0.php" hash="d63d56da8d880d297f1599a627e71fb3"/><file name="mysql4-upgrade-0.1.3-0.7.0.php" hash="05728dfb17eae1882e1a61ae3a571201"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5bfa3f68a0c188afcbec03f564f2c19c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f3c3dcb39ffd2293e252c66677ece0a7"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="cb6e77e20e91cdd2497c91dc6f751c8a"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ba851bc9df9c5a6a6430e1670116870c"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d4b64697af7b1b59edeab9120245c546"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="616ecca5d7296f027061084f550936bf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ee1e9039080b7cf8fbbe72a5781b1257"/></dir></dir></dir><dir name="GoogleAnalytics"><dir name="Block"><file name="Ga.php" hash="d2e0e76bf461805d7efa3504ba40778b"/></dir><dir name="Helper"><file name="Data.php" hash="d1e53e2c360d075b464fd9de2c564821"/></dir><dir name="Model"><file name="Observer.php" hash="16fa8e062f7aa80cb58c229d4cc4c27d"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Type.php" hash="27d5bbdac178313b3305c6308cc85565"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="7609f9a30ebed87c2cc808090733f522"/><file name="config.xml" hash="09a0c00775ae054bc1f6c2d93c426b47"/><file name="system.xml" hash="850dae8ed5870d335ece5cb8fedc9844"/></dir><dir name="sql"><dir name="googleanalytics_setup"><file name="install-1.6.0.0.php" hash="e484246fe4b335068b52afebc226ae6f"/></dir></dir></dir><dir name="GoogleBase"><dir name="Block"><dir name="Adminhtml"><file name="Captcha.php" hash="8ffb81bcaac1a9364c7dff92029209a0"/><dir name="Items"><file name="Item.php" hash="daf200d9b85bcc045c94d3922c97b247"/><file name="Product.php" hash="7e331a3ca0ca01b963e24772a821daf9"/><dir name="Renderer"><file name="Id.php" hash="1b72b62226dab4a38740f1e76a58252c"/></dir></dir><file name="Items.php" hash="85998c466c9bea59a59fc7ab3b890e6d"/><dir name="Store"><file name="Switcher.php" hash="2286a7c57c5b3c6068a63588bc083e4a"/></dir><dir name="Types"><dir name="Edit"><file name="Attributes.php" hash="ac180cb7663f5cc2e32990f83dad0cbf"/><file name="Form.php" hash="ad97b610567b0d3443f8cae9107ca766"/></dir><file name="Edit.php" hash="498601bd79e9965875f081a4d728750a"/><file name="Grid.php" hash="2acaadd9464546bbec77f5d9815f831f"/><dir name="Renderer"><file name="Country.php" hash="74417b955dac939a295eaa7ae64ce979"/></dir></dir><file name="Types.php" hash="96fc7c42735308df6bdd6f5d400e1afc"/></dir></dir><dir name="Helper"><file name="Data.php" hash="37dc22c51575825470397f02a1497b8a"/></dir><dir name="Model"><file name="Attribute.php" hash="de7147676dc2b9efc9e3b2ebe3f2dfde"/><file name="Config.php" hash="186ad497d6e756dafb7ab1e683c1fddf"/><file name="Item.php" hash="5c34a976ae0bc4979e1c77a3521045ea"/><dir name="Mysql4"><dir name="Attribute"><file name="Collection.php" hash="0ac995159720299072572e59b3f56703"/></dir><file name="Attribute.php" hash="0db990e969d8f15ca0202651b16d869b"/><dir name="Item"><file name="Collection.php" hash="6ab601ff75fbb3c02080067924940893"/></dir><file name="Item.php" hash="65aa28e83d4a2d8f56608db3f8e31765"/><dir name="Type"><file name="Collection.php" hash="acba8831466758db65e6a1a47a7147cb"/></dir><file name="Type.php" hash="0b063bc2ce8d0855771db6e4c0f74d41"/></dir><file name="Observer.php" hash="4ee39b5218f1fed7dbaaa36d9a29db6f"/><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="03615a6272451f12f8b43804e99ee5d6"/></dir><file name="Attribute.php" hash="92d0b4aa81e38442e1efb2dbb1d34258"/><dir name="Item"><file name="Collection.php" hash="9dca709ca6c169cd79b7b5ead827a08b"/></dir><file name="Item.php" hash="bfb7069e9a061e2ed5b0e0da2b2d01a0"/><dir name="Type"><file name="Collection.php" hash="64ce489b343309f3f39140a4f4cd7583"/></dir><file name="Type.php" hash="76003cbab0af46881bbd98bb957b66f8"/></dir><dir name="Service"><file name="Feed.php" hash="309cdd632278bb8bc5c29c0e2be1e360"/><file name="Item.php" hash="530d7616fc9ce908de7db459fc322015"/></dir><file name="Service.php" hash="24af7082a46a4932cbe03ed0bd6b6166"/><dir name="Source"><file name="Accounttype.php" hash="ce9af7fa322b94b4ec2e47cc6e6c1ec7"/><file name="Authtype.php" hash="b994b36c46031fedfff7b57f612f55a6"/><file name="Country.php" hash="0203b52aa4a28c0254d65a9b920efda8"/><file name="Statuses.php" hash="22ee2dba81cd494972b1fa7ece5b315b"/></dir><file name="Type.php" hash="76076f761fdfd28d59ff8b5577aabadb"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Googlebase"><file name="ItemsController.php" hash="c6de78715aa3017758bbc536b7afb095"/><file name="SelectionController.php" hash="9dfdedde2800187671c629f47971f2d0"/><file name="TypesController.php" hash="2fe00008ed2b55db767718ab1d5c0103"/></dir></dir><file name="ItemsController.php" hash="ee346770e2d88bcb674115d38e7949cb"/><file name="SelectionController.php" hash="8b96306c9cc7321029936c92737b3ccb"/><file name="TypesController.php" hash="709cecf3c0315f9a9063b31f318692a4"/></dir><dir name="etc"><file name="adminhtml.xml" hash="91b17d231331e23446d66dd5a2ac10b9"/><file name="config.xml" hash="26f5d7d23b12a0ca718d897b2595001e"/><file name="system.xml" hash="f31a03a47863c57e568f032001c6bef9"/></dir><dir name="sql"><dir name="googlebase_setup"><file name="install-1.6.0.0.php" hash="bc2387664571480a407c5182ca69a67d"/><file name="mysql4-install-0.1.0.php" hash="b1f74e7e4dc785db8c4821a7f9853659"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="37f586dcf8833a97e9fe0e992a5cf6cb"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="b060d55e1f64d3f672ff025af945dbc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="60867115973ae9449f221d742b319ae0"/></dir></dir></dir><dir name="GoogleCheckout"><dir name="Model"><file name="Payment.php" hash="982c96bcbfa5311070d550a8f8a1f948"/></dir><dir name="etc"><file name="config.xml" hash="c4d1bccf03be132b9dcb2c6822bf76be"/></dir></dir><dir name="ImportExport"><dir name="Block"><dir name="Adminhtml"><dir name="Export"><dir name="Edit"><file name="Form.php" hash="1d2694e45c6ad541957c42ee3eb1782a"/></dir><file name="Edit.php" hash="0666e8af99efef7ab7761b129ce09442"/><file name="Filter.php" hash="2b0d68c9414048ea234afe4d9d1ce8c6"/></dir><dir name="Import"><dir name="Edit"><file name="Form.php" hash="c47eeda645e5a6b54f7841a5528f8b03"/></dir><file name="Edit.php" hash="ca6507375bc594466a773a1530ee7abf"/><dir name="Frame"><file name="Result.php" hash="0a30864c11e996bdc9c66a0b8280b808"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="384c6172dc31bae831d96dd3569df8a8"/></dir><dir name="Model"><file name="Abstract.php" hash="5a230ebd046c2cd899ed245bc79706ef"/><file name="Config.php" hash="435812ed04e558d4a74963b8ab7796ee"/><dir name="Export"><dir name="Adapter"><file name="Abstract.php" hash="414836b6ded4008e9655417472429c1b"/><file name="Csv.php" hash="8f1f89d704be424c63c2e1e44437e224"/></dir><dir name="Entity"><file name="Abstract.php" hash="04a03c5b7fcc6b4849cef58a27b98f0a"/><file name="Customer.php" hash="eb5f630dc3ecfa946626a420046ceedb"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="908f6355594c01b95316e7bd14f1a568"/><file name="Configurable.php" hash="8df99a951ecdaa8ce418a8c147d1dc98"/><file name="Grouped.php" hash="14d26d03645a505f4516e65b65da1d58"/><file name="Simple.php" hash="90901b89f0cb6cfc465333f8f102af2e"/></dir></dir><file name="Product.php" hash="e2ecef0dc27574f76ee24f5bafe3ff31"/></dir></dir><file name="Export.php" hash="19776fb654cfc20955e253b83882a902"/><dir name="Import"><dir name="Adapter"><file name="Abstract.php" hash="28a61f3dd03568c018026619ad87d49c"/><file name="Csv.php" hash="ce14a1f5d90265a12fe0dc10ddf44b87"/></dir><file name="Adapter.php" hash="fd89afe4e1be5fbc2389d31d7a51e5a3"/><dir name="Entity"><file name="Abstract.php" hash="79006dccac27958e000d88020097a5b4"/><dir name="Customer"><file name="Address.php" hash="b8237c9fe5dba6466339393c3b000d08"/></dir><file name="Customer.php" hash="6871e8a4a23051a1e218aace81406d22"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="ffe2e9103a1e2693edd6891d3e83d47a"/><file name="Configurable.php" hash="fe9623029e842b6472369433b53d243b"/><file name="Grouped.php" hash="a6e1f3c1f9faa1739de0ac23318b846d"/><file name="Simple.php" hash="3a777da7bab161878964364b415080ac"/></dir></dir><file name="Product.php" hash="0397765d44718b3b4395da27b6d483a7"/></dir><dir name="Proxy"><dir name="Product"><file name="Resource.php" hash="06e6798c23ceb6319383e0120d5a571b"/></dir><file name="Product.php" hash="3050c471b6b0192716ea1cc51b4ef3ce"/></dir><file name="Uploader.php" hash="cc526896e36375ed0321e7fb5a80c9f4"/></dir><file name="Import.php" hash="c6c7206c1ec35924116392b6182e21b0"/><dir name="Mysql4"><dir name="Import"><file name="Data.php" hash="1088760a7325fc7a0e0f26427dfa4e03"/></dir><file name="Setup.php" hash="80bc724ecc0f935c2d5ebee1e3c2ad60"/></dir><dir name="Product"><dir name="Attribute"><dir name="Backend"><file name="Urlkey.php" hash="f9990ba2139c5bc3ec895b7bd339bc24"/></dir></dir></dir><dir name="Resource"><dir name="Helper"><file name="Mysql4.php" hash="4f156d994d5e68ce68dd7d2f95a7fc89"/></dir><dir name="Import"><file name="Data.php" hash="0235fb91f691b156680c160c68837ab2"/></dir><file name="Setup.php" hash="9dc5c3f7624900b8850a6e846f1e4f9f"/></dir><dir name="Source"><dir name="Export"><file name="Entity.php" hash="7eba440adcde3b91c888c21318f72447"/><file name="Format.php" hash="13d3a2ddef316c63a973541b299e3aa5"/></dir><dir name="Import"><file name="Behavior.php" hash="d923c67f2a43f414e9dd40eb13dcd10b"/><file name="Entity.php" hash="0970c1703c08c869269728ff3d2b634a"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ExportController.php" hash="46827924b3eee05f89aabcd67a4163a6"/><file name="ImportController.php" hash="be2058650aa5bb4a70b19665e6c92c86"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="91d91549fa6eed9d051fe0483b72df42"/><file name="config.xml" hash="f136ecdde7858eb0e921dc9689c8f560"/><file name="system.xml" hash="26aee9169d1cecd5def38f997c36d959"/></dir><dir name="sql"><dir name="importexport_setup"><file name="install-1.6.0.0.php" hash="440ecd2e1477d34e5cae67e86dac1b9a"/><file name="mysql4-install-0.1.0.php" hash="429e13933993d2ea22656edcdbf5ef55"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="c22f7d3f8c739ca64843cf2d45fcd73f"/></dir></dir></dir><dir name="Index"><dir name="Block"><dir name="Adminhtml"><file name="Notifications.php" hash="922e03c645be00419e2d8e5844d062e3"/><dir name="Process"><dir name="Edit"><file name="Form.php" hash="0cdf857a98eb42c9b579667a8678afdb"/><dir name="Tab"><file name="Main.php" hash="331b2a59a8d978f81c5b8a05b72e54ca"/></dir><file name="Tabs.php" hash="de2c47f1acf23d9360772ae00c8a859e"/></dir><file name="Edit.php" hash="ce7d7d368479e54c2b01b77dd3886b1d"/><dir name="Grid"><file name="Massaction.php" hash="aaa57991d6610fb6d00077818d532128"/></dir><file name="Grid.php" hash="f81a407a489b12d8ed8ea9c4b2e434c7"/></dir><file name="Process.php" hash="0a14d84d462e2cb2401ef3819389e7ff"/></dir></dir><file name="Exception.php" hash="a1dbeaf5fefc1d31b558fe93f9f73d1a"/><dir name="Helper"><file name="Data.php" hash="8d867f1179f6b39c5f7acdf175784a92"/></dir><dir name="Model"><file name="Event.php" hash="0f4c9a287f5a8679762952b86b8f8677"/><dir name="Indexer"><file name="Abstract.php" hash="cd9c4708d9a38c4c1afc672d04357030"/></dir><file name="Indexer.php" hash="d5143bacc2a4eaa4f6daf9c5cab5dc86"/><dir name="Lock"><dir name="Storage"><file name="Db.php" hash="0c22416871c8f81efa730ace6d992ac9"/><file name="Interface.php" hash="58327d8efcf1dcda6d5ec9c9c1cc1ac7"/></dir></dir><file name="Lock.php" hash="1c6666fe4cda94096d3668bcb8dfc9a8"/><dir name="Mysql4"><file name="Abstract.php" hash="5f9e45269f0beb215a04b7a5cbd7c01c"/><dir name="Event"><file name="Collection.php" hash="63dc340d2fcd37ec6993c171e6a112a6"/></dir><file name="Event.php" hash="720b92789910ef0c519e9e475b683a06"/><dir name="Process"><file name="Collection.php" hash="20ef6b9356da622286766d7acd1d929c"/></dir><file name="Process.php" hash="785aff05f0ac621b6d9a1a845cb1655e"/><file name="Setup.php" hash="c1ddc6c82badb71770af13c90d0cb812"/></dir><file name="Observer.php" hash="b9886ab72e3bd3db214ef31e464a2f1b"/><file name="Process.php" hash="e8bb4432a50efd682dd9419c0a82ef4c"/><dir name="Resource"><file name="Abstract.php" hash="ac3749b23996a6429c36ca137638ad02"/><dir name="Event"><file name="Collection.php" hash="1b03f9d9680463e2e60358052d8b82f8"/></dir><file name="Event.php" hash="d29ee78ac7d82ac16d32bcb7ef28d881"/><dir name="Helper"><dir name="Lock"><file name="Interface.php" hash="4bc86572aea98f639d4babf2ef538cc4"/></dir><file name="Mysql4.php" hash="ccc14816287dc75db167ca32ff5593cf"/></dir><dir name="Lock"><file name="Resource.php" hash="b2f87d6274785e35c8f06f966bf09f66"/></dir><dir name="Process"><file name="Collection.php" hash="82885a920f616ebbc109ca797efb232b"/></dir><file name="Process.php" hash="192269bd7cd4c37abfb4ee71303e0801"/><file name="Setup.php" hash="1464247cd3a97ccd6647a29262c1dde5"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ProcessController.php" hash="c60849c043f9fb2a8ed433ed63288dc0"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="838e8a8273f5f72317ac60721dfa9b03"/><file name="config.xml" hash="738fe1d9e58823a3ad48dff298540bb5"/></dir><dir name="sql"><dir name="index_setup"><file name="install-1.6.0.0.php" hash="fd7edf27ce1ab3e2d8604e13482c7e75"/><file name="mysql4-install-1.4.0.0.php" hash="73f12feb17accae95d4edef62c916a17"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="fac3d6ccb754170d8a8d7554bb6fa3d6"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="4e1513cafc48d3d1c51e39bad877b88b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="58861d9d24e1b40f78e4a0e8b6a23839"/></dir></dir></dir><dir name="Install"><dir name="Block"><file name="Abstract.php" hash="2dee98d086c168ab90698e8161f57066"/><file name="Admin.php" hash="efb15900c41ed3f02e39283193d391ee"/><file name="Begin.php" hash="659b15e410b828a97c6dfd9bae429ad2"/><file name="Config.php" hash="99dbd0a1160a5438c1b7ceb10a917d15"/><dir name="Db"><file name="Main.php" hash="5c56f37b937236cecc7cd22b065273b0"/><dir name="Type"><file name="Mysql4.php" hash="c20eb4b3c95316815677d5fbc4884b11"/></dir><file name="Type.php" hash="51040fddc22a85428577619c0b977464"/></dir><file name="Download.php" hash="52051c99cb5c5f99e6012d1f25f66074"/><file name="End.php" hash="16f06df1910ea6c4f49a6aec46ae086f"/><file name="Locale.php" hash="22c2f158faa1a3f13003a0c503faa2d5"/><file name="State.php" hash="24efc1866c5f33f0a0b993bedadbb8a4"/></dir><dir name="Controller"><file name="Action.php" hash="b682d197f541961e81213972c7244013"/><dir name="Router"><file name="Install.php" hash="8f69b3ce427d0fc0dceebd0030577e0d"/></dir></dir><dir name="Helper"><file name="Data.php" hash="9e855f685abce78835481bc484328719"/></dir><dir name="Model"><file name="Config.php" hash="dc4ee654173a7d2ef41e6a93199d70d5"/><dir name="Installer"><file name="Abstract.php" hash="4e0e0c729c308107360de80096e19540"/><file name="Config.php" hash="057a8c084c4476ae13a2d1fcf92c1f12"/><file name="Console.php" hash="f85d1f5d4880c7f4a50c8a98b398fd50"/><file name="Data.php" hash="3d90094a839ba4eadaf686cf2f9b56da"/><dir name="Db"><file name="Abstract.php" hash="1ba6d04a4d72970398883f7253263b17"/><file name="Mysql4.php" hash="e8cbc16eca193558c741eb22ac1c60f8"/></dir><file name="Db.php" hash="b67daec31cea6f3375db1ed7e56e4a7f"/><file name="Env.php" hash="639d6290361f4c1c4d5412229773e4f3"/><file name="Filesystem.php" hash="8b12da553f8a2b883da4bd4e19b7c33e"/><file name="Pear.php" hash="201cb7f98f8c34e96ced050fa828cf87"/></dir><file name="Installer.php" hash="e6e46a2976a552552306dc215ba865c2"/><file name="Observer.php" hash="8e6bffd30e9cb2e8a2eb696cf9ac5a68"/><file name="Session.php" hash="ed74c7aa62da86885edcaf79ca9bed8e"/><file name="Wizard.php" hash="c3489d3ad1292e06af7c3844f310aecf"/></dir><dir name="controllers"><file name="IndexController.php" hash="20e64a56f684c04619511846a99cc400"/><file name="WizardController.php" hash="7a00f69b6de90423d3ab53c9964b1492"/></dir><dir name="etc"><file name="config.xml" hash="fdcd1dd42be74df06a8419d8029023f8"/><file name="install.xml" hash="3d9ab17da44031cdc16c5d93e7b60773"/></dir></dir><dir name="Log"><dir name="Helper"><file name="Data.php" hash="8e1ea37dfdb3eb2127ae32b73117b934"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><file name="Loglevel.php" hash="6bc16da4c393f8244728accef3152b3e"/></dir></dir></dir></dir><file name="Aggregation.php" hash="10552339d8cb158c9b119bc060a0dbb6"/><file name="Cron.php" hash="f834b2b13b33226ef9da72a88cc5874f"/><file name="Customer.php" hash="702b0517de7e854d1700dd4ee045052b"/><file name="Log.php" hash="d44fe18e726aa473d7a0cbe329222965"/><dir name="Mysql4"><file name="Aggregation.php" hash="559d0acec067d9f127f84fcd34eb9696"/><file name="Customer.php" hash="79fbe550b2e61a2b05770265256ce170"/><file name="Log.php" hash="dda701b3c34ef8ce11d3dc30ac96b75c"/><dir name="Visitor"><file name="Collection.php" hash="8d7620ed8c7aeee03683108eca7617c4"/><dir name="Online"><file name="Collection.php" hash="55fd5d38e12430dfd58daf87f9b72d52"/></dir><file name="Online.php" hash="d7c1ce6bd2ceebc4f3f1b1206c4dc67b"/></dir><file name="Visitor.php" hash="755c2ff87d1df51e12e66fb285087c81"/></dir><dir name="Resource"><file name="Aggregation.php" hash="66ec9a927a8fdd273851cf5842ee477d"/><file name="Customer.php" hash="33684fd547fcfa2051fc3d950fe8173f"/><file name="Log.php" hash="1344865f7b485fff14925a226938d6d8"/><dir name="Visitor"><file name="Collection.php" hash="edd5b89c8bd514761aecd16574e9bc3a"/><dir name="Online"><file name="Collection.php" hash="6a059f3701221bcecc2e14d2689624ae"/></dir><file name="Online.php" hash="0b67cc2b5a714f8d76931574745ddbaa"/></dir><file name="Visitor.php" hash="e0a81fc458bc333f4de45282426b4716"/></dir><dir name="Visitor"><file name="Online.php" hash="f227139761c63b469710a03562dcc5ce"/></dir><file name="Visitor.php" hash="6eef64209506c68e05cac75702b8f09f"/></dir><dir name="data"><dir name="log_setup"><file name="data-install-1.6.0.0.php" hash="3e1982a81ee050ddec1949bb6a893c07"/></dir></dir><dir name="etc"><file name="config.xml" hash="eba13997054a59d8b5c1658c2999a4e3"/><file name="system.xml" hash="e333f423f247ee85fe09df20458fe362"/></dir><dir name="sql"><dir name="log_setup"><file name="install-1.6.0.0.php" hash="dc7295d342fda0d6cbcf4157a197d4ec"/><file name="mysql4-install-0.7.0.php" hash="d575dd42f8c7472d4d8ea8b1d90d8f9a"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="34b5ec712445eb9387594ca1f75fd87f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="129b7e5e5c06180fd48a218db32c7ea0"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="3a12eac2f81c762507914389c904618d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b78cb4e596f7f1be79f12b3e746c4db9"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="fd33161e285e2a0c8b3d6b5607f73273"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="6d3b11e2e5a4aa4b41aae94b68384d60"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7eca6d3b4caf1bdd7372f5ff95039d1f"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="bce437dd6f47db768f109624c4fb60d2"/><file name="mysql4-upgrade-1.6.1.0-1.6.1.1.php" hash="f8726e38a05a6cc876982e61cce65217"/></dir></dir></dir><dir name="Media"><dir name="Helper"><file name="Data.php" hash="a1f43339bdd5d2955ccec8e961f7d44b"/></dir><dir name="Model"><dir name="File"><file name="Image.php" hash="ef90f58f95934ece51b84add82393dbb"/></dir><dir name="Image"><dir name="Config"><file name="Interface.php" hash="2ec657e2417a814d9865c04ebddd2cdb"/></dir></dir><file name="Image.php" hash="cd22c32eaf0da58d4439c238b06947a1"/></dir><dir name="etc"><file name="config.xml" hash="ae68c69fff953c068f256fc2ed885794"/></dir></dir><dir name="Newsletter"><dir name="Block"><file name="Subscribe.php" hash="28e440fb31532edcc299b24c25fad0b2"/></dir><dir name="Helper"><file name="Data.php" hash="b6883b716785a6ae298ae474923bec8c"/></dir><dir name="Model"><file name="Message.php" hash="1750703765bb9f7376f8cd7afef95bdf"/><dir name="Mysql4"><dir name="Problem"><file name="Collection.php" hash="6de593241173f716441cd525a60b29ac"/></dir><file name="Problem.php" hash="5e980ad89adc06f1a064d88264db41c8"/><dir name="Queue"><file name="Collection.php" hash="560faac4ebac5cbdf08b20ce11419564"/></dir><file name="Queue.php" hash="f7f3bb7fa9173b6e51a6cc726c6c03f5"/><dir name="Subscriber"><file name="Collection.php" hash="f6e8ad8d1f24c2614ea758c7a683511f"/></dir><file name="Subscriber.php" hash="28a84169e8bf4563ee77d9a8795ea864"/><dir name="Template"><file name="Collection.php" hash="1385706b684c75f98c575beb981f2988"/></dir><file name="Template.php" hash="343c97a25be170240522e7cf682dab37"/></dir><file name="Observer.php" hash="34aa358337b40b41e062250a37ada85e"/><file name="Problem.php" hash="b84eab3f567814c02ddffd94224c2a9c"/><file name="Queue.php" hash="130624a59c5c70fde0b59d810a7f1917"/><dir name="Resource"><dir name="Problem"><file name="Collection.php" hash="73d5c8ac0bc852b1797deec496552102"/></dir><file name="Problem.php" hash="bc291b49df5cdabea16ef9ed3061a487"/><dir name="Queue"><file name="Collection.php" hash="245e312c2cd091994ad9f45838632360"/></dir><file name="Queue.php" hash="ea511beb43d47d27a98e3aaeaecc4474"/><dir name="Subscriber"><file name="Collection.php" hash="36c88e4f143f94d5ab8963df2f9cd32f"/></dir><file name="Subscriber.php" hash="e3edbe990f15e0e1893f351a3dbda922"/><dir name="Template"><file name="Collection.php" hash="c5ca290fa43abb9fc4748930b3a9d1bb"/></dir><file name="Template.php" hash="0309012892a386b48535d9a59c6d6b25"/></dir><file name="Session.php" hash="f5eb66ba88eb752da13607d4e031dd01"/><file name="Subscriber.php" hash="81525dee3bbd0db4bf1e584e0e6a1a43"/><dir name="Template"><file name="Filter.php" hash="bde6a148d876981d2a36ff0959f86e89"/></dir><file name="Template.php" hash="2cdca2731d3bef3098acca40bbfc7417"/></dir><dir name="controllers"><file name="ManageController.php" hash="5d567820c8d976ce8defd9b1b0da5206"/><file name="SubscriberController.php" hash="3fc6fdadccd2afa4692f0ab6b1bbd488"/></dir><dir name="data"><dir name="newsletter_setup"><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="b7a3d19fbaef5a6fdf37fe71176047df"/><file name="data-upgrade-1.6.0.1-1.6.0.2.php" hash="6c8c4e7d435bb50eddd6e7dbb14249cd"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fe2493b1ef093e63bb504edc5bd2ccd2"/><file name="config.xml" hash="2c22e3965d2256f71fc152e081e34527"/><file name="system.xml" hash="e37205b0b99e719c7623ffa5258b37bb"/></dir><dir name="sql"><dir name="newsletter_setup"><file name="install-1.6.0.0.php" hash="3c620e075f2a9298d52f36bec4ef92b9"/><file name="mysql4-install-0.7.0.php" hash="e81ce4f738b532d5435bfc8008293b8c"/><file name="mysql4-install-0.8.0.php" hash="bafb7e57fb822c4aca123fa6b9ed5920"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="c054de290c7c5fa3e116aed41eff4f17"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="663667dd1923f3890b855fc691375908"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="848b4eb72c16c4e2ac5cd2e12236b326"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="13ef7177c48460bb04dad80c456837a1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0367dc658bd286502e97f7b648fd6d04"/></dir></dir></dir><dir name="Oauth"><dir name="Block"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><dir name="Token"><file name="Grid.php" hash="faf7492adfcdb46928d76030eff74f65"/></dir><file name="Token.php" hash="ce4dddfe298fc02b2b381a7c6469092e"/></dir><dir name="Authorize"><file name="Button.php" hash="1c81a60de78cc606e79a1d8be57bb869"/></dir><file name="Authorize.php" hash="8f4665e6545dde37434ed9c10b3645a7"/><dir name="AuthorizedTokens"><file name="Grid.php" hash="cb6f809f97a7bf7d46b932e13aadff99"/></dir><file name="AuthorizedTokens.php" hash="85a9f2d4d7e7d12aa7d6b4eebfe9a0a2"/><dir name="Consumer"><dir name="Edit"><file name="Form.php" hash="26442ba5d70ad3bcee2f2787d3032191"/></dir><file name="Edit.php" hash="69ea6261b2de4c0179720f16d771b81e"/><file name="Grid.php" hash="5295e58ea863f40074ce4c590990118c"/></dir><file name="Consumer.php" hash="2a43bb7b1a6ec96fafa2fb0d2b850993"/></dir></dir><dir name="Authorize"><file name="Abstract.php" hash="3e3aba461e6008ecdd38749558530364"/><file name="Button.php" hash="6dd4651aa52e7094c95ca40aa40fe559"/><file name="ButtonBaseAbstract.php" hash="0d30faefc4fd63c756ce97c699e530d2"/></dir><file name="Authorize.php" hash="12557ebc607496441344055642e1fc89"/><file name="AuthorizeBaseAbstract.php" hash="c7286fab6fad35da2af69251df23c927"/><dir name="Customer"><dir name="Token"><file name="List.php" hash="ab6a503fd7351a57ae0c38ab7cbe1bc7"/></dir></dir></dir><file name="Exception.php" hash="f2cce047a249d5042a8196eb2eb1188b"/><dir name="Helper"><file name="Data.php" hash="3cdfd4b295606df93d44cb6e97b453eb"/></dir><dir name="Model"><dir name="Consumer"><dir name="Validator"><file name="KeyLength.php" hash="41a23ef35ba4f1ecb26430a0b15e90b1"/></dir></dir><file name="Consumer.php" hash="48e78ecd656ce1caf445eb7d07c7fa37"/><file name="Nonce.php" hash="c6fbea1ee4b0853402b34214e5a4e7c2"/><file name="Observer.php" hash="af0fe3ecee5ee39ac6f20a34b162b3ac"/><dir name="Resource"><dir name="Consumer"><file name="Collection.php" hash="6a0ae20a1d9598df8cc13c66ff7857df"/></dir><file name="Consumer.php" hash="71aa68f1f659032f19fed5bd7f16954b"/><dir name="Nonce"><file name="Collection.php" hash="a6145078c6830243e6c35521467de6ff"/></dir><file name="Nonce.php" hash="0c2fc104df8c98ef3bf10a06c82c9e4f"/><file name="Setup.php" hash="664fcc4e6ce0c5de4aada29f49ef283d"/><dir name="Token"><file name="Collection.php" hash="c2c31414bdf93a1bf642de15be611a25"/></dir><file name="Token.php" hash="083a0594d61845cb68e28cc118b7bb17"/></dir><file name="Server.php" hash="9468c0b29cc165fc0ef20cd95d47e6f6"/><file name="Token.php" hash="ee05a1801416a8bb440d3d7c8d004dd6"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><file name="TokenController.php" hash="c2435d97eb91f835014d403354354ec6"/></dir><file name="AuthorizeController.php" hash="659b7948384ab393209f296f5be15b43"/><file name="AuthorizedTokensController.php" hash="bb7df560a7595deaeec96ae63a7e9b2b"/><file name="ConsumerController.php" hash="8e3244262dc3a34a89cf54984b2ec74e"/></dir></dir><file name="AuthorizeController.php" hash="9536f67c302706a93b5a844f6826d870"/><dir name="Customer"><file name="TokenController.php" hash="f9f9ed1f0041c5ae518005f2e90e78f6"/></dir><file name="InitiateController.php" hash="7bc4b0605282cfc629011ca094863175"/><file name="TokenController.php" hash="3a734ab905de6197146e7de47376de6f"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c3c51c34ae5979c2e0df148ddbec7113"/><file name="config.xml" hash="446b689f37981498a1dc86f5ab1bb0e3"/><file name="system.xml" hash="38bcf79677c20f5821bf6f54dcfe6297"/></dir><dir name="sql"><dir name="oauth_setup"><file name="install-1.0.0.0.php" hash="7d70d6610ebf50a9782337e6f3d0f5ef"/></dir></dir></dir><dir name="Page"><dir name="Block"><dir name="Html"><file name="Breadcrumbs.php" hash="1fe5ffca8e5b2f2f2b7aa78700217c6c"/><file name="CookieNotice.php" hash="f70b0a12cfccafcaa7125478dbd6a8d9"/><file name="Footer.php" hash="77f2fb87201b33dc34fdb7fae4ffc030"/><file name="Head.php" hash="cb019fb8e30bbd8064c3418f6c291a47"/><file name="Header.php" hash="2cbf7f560f06289367d825e99a784355"/><file name="Notices.php" hash="7782add14339c49bbbfa074baff2bcae"/><file name="Pager.php" hash="e946ed0f6a5deb4021ddd415e3dcada2"/><file name="Toplinks.php" hash="be7cbec75d231b5f40cecc45ce6aced9"/><dir name="Topmenu"><file name="Renderer.php" hash="f6df51661c07d24a2cd45ada7a195c16"/></dir><file name="Topmenu.php" hash="7fa8066846bd784d4da25a7638ff83c9"/><file name="Welcome.php" hash="c588210d17985afdd4b70016862a3f58"/><file name="Wrapper.php" hash="c43925e6af41f952a246d38de7acd924"/></dir><file name="Html.php" hash="ebff82d47412ade15f091533080a8cb0"/><dir name="Js"><file name="Cookie.php" hash="97ad94ecbdfb73f1523169f105148de6"/><file name="Translate.php" hash="5b3273d29f989c8348d93788dcbc4d8b"/></dir><file name="Redirect.php" hash="d8b5ddb87a79497acc2136d117aa4cb8"/><file name="Switch.php" hash="92e0ee78127e737abc1d0de28aa39668"/><dir name="Template"><file name="Container.php" hash="58c4e09110863b559c899e766689db3c"/><dir name="Links"><file name="Block.php" hash="a1fd263db9149683be177f12b3d21403"/></dir><file name="Links.php" hash="d3563e74d4e9be5ca574d26980f87ae3"/></dir></dir><dir name="Helper"><file name="Data.php" hash="643200eb25af3286d89295821ccd215f"/><file name="Html.php" hash="ff435cfd6fa058784e5047bde5059cc0"/><file name="Layout.php" hash="68a7da8957b6bf38391076c6dc1d8b89"/></dir><dir name="Model"><file name="Config.php" hash="d3353eb7388747f28106cc422b7c0178"/><dir name="Source"><file name="Layout.php" hash="f6c47751ce94f1202f51f74240576f16"/></dir></dir><dir name="etc"><file name="config.xml" hash="093b9598b2072c232feaed596cdae921"/><file name="system.xml" hash="b639cd00ba12888b93846adf7b7a06ce"/></dir></dir><dir name="PageCache"><dir name="Block"><dir name="Adminhtml"><dir name="Cache"><file name="Additional.php" hash="980caec50a3cbf58f41da2327a565021"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="3b8e9e8eb1d3c56bcb47f4b3eecdb7cd"/></dir><dir name="Model"><dir name="Control"><file name="Interface.php" hash="fd10161bdb54026cff06db39a4dbb5c2"/><file name="Zend.php" hash="21b1db8392b9f2f3d078705e2ec26ba4"/></dir><file name="Observer.php" hash="537fb8952f611b797e394e4569de1ffa"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Controls.php" hash="ea5031f742689bca2a1b08144ea39cd0"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="PageCacheController.php" hash="a4905697051657f96098ec4076fdfe2b"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="97661944ee637ba8e00a6596bdba3969"/><file name="config.xml" hash="c3e7a37ca8c0a930bea08751ad362a2e"/><file name="system.xml" hash="f8301b232c7614412428a0fb526bf5bc"/></dir></dir><dir name="Paygate"><dir name="Block"><dir name="Authorizenet"><dir name="Form"><file name="Cc.php" hash="d657a3be38a02106dde73a4892b0c77e"/></dir><dir name="Info"><file name="Cc.php" hash="378841b3fcda8fbec605b62c3fe7a9c8"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="008e92608958a3a7ac08ade7ad142ccf"/></dir><dir name="Model"><dir name="Authorizenet"><file name="Cards.php" hash="d81581da931610d0e8868b4accb3690b"/><file name="Debug.php" hash="977a9c8240e3f572bbb64d6a6f238b87"/><file name="Request.php" hash="ba5a4763ece9bf688257ce424212b459"/><file name="Result.php" hash="219a7a26b1ebfb4c58da9f287f386d6a"/><dir name="Source"><file name="Cctype.php" hash="93635248391f764267488c9584d9690b"/><file name="PaymentAction.php" hash="7dbc905942c6359af597c5dc9c80094f"/></dir></dir><file name="Authorizenet.php" hash="dba6893ddc37660cc8e1a09a7953130d"/><dir name="Mysql4"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="75ccb15a446e4a32e853f2fcba210ab3"/></dir><file name="Debug.php" hash="71d0f733c94f22dbcb887d64dc27d16a"/></dir></dir><dir name="Resource"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="2bbfd8a9516e70297630bb01a52f6f50"/></dir><file name="Debug.php" hash="e21392b38f8cb291d1803ce24400a886"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Paygate"><dir name="Authorizenet"><file name="PaymentController.php" hash="267d17f09c387babc09a9b065cd145ca"/></dir></dir></dir><dir name="Authorizenet"><file name="PaymentController.php" hash="7943c655501133002d695e8dd980d62e"/></dir></dir><dir name="etc"><file name="config.xml" hash="e8090f4993067b18e61a600994d704a5"/><file name="system.xml" hash="4b712d693e127e77f876a4497c399e24"/></dir><dir name="sql"><dir name="paygate_setup"><file name="install-1.6.0.0.php" hash="512f727b16737444feae450851679a7e"/><file name="mysql4-data-upgrade-0.7.0-0.7.1.php" hash="bb83ae3d9fc7ade47467ca1fadaab284"/><file name="mysql4-install-0.7.0.php" hash="40b964a9db67dc645b20735a0d69d586"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6f2857623a2baa373fb4d01d8cdf597d"/></dir></dir></dir><dir name="Payment"><dir name="Block"><dir name="Catalog"><dir name="Product"><dir name="View"><file name="Profile.php" hash="725706ecf3c9f45fa76a43aed9f4fd0e"/></dir></dir></dir><dir name="Form"><file name="Banktransfer.php" hash="a8065e642e9b9d36d7b0ed5f333dc152"/><file name="Cashondelivery.php" hash="a3704a4d200caff8a596736650bae112"/><file name="Cc.php" hash="145d796f6c98a11a230cb4292cb683ea"/><file name="Ccsave.php" hash="c25e2aa496f3665a7d22ebaa0046041e"/><file name="Checkmo.php" hash="0e34baf58c26715ab229e2053736a5c6"/><file name="Container.php" hash="7e93316090e0517da04392d2db08623b"/><file name="Purchaseorder.php" hash="4ee06729fdce364077a746e10ec016ca"/></dir><file name="Form.php" hash="08da59955c049b2a436a92c86c42a71a"/><dir name="Info"><file name="Banktransfer.php" hash="8253079b2a3f295e9212ffd471f1fb8c"/><file name="Cc.php" hash="0bc912ea4a40f5f413f501866900f2b9"/><file name="Ccsave.php" hash="c99aac57be0c839c3761bf63b42f9b63"/><file name="Checkmo.php" hash="bdfa5eb12e51b24dfa520d2ce9df0878"/><file name="Container.php" hash="8b24dd8c3fc825879faaeaddda23bdf6"/><file name="Purchaseorder.php" hash="97c4838b60a46f7a2ae9938b1f02e1c4"/></dir><file name="Info.php" hash="df4007e93b95af8440adca3d7a2f003a"/></dir><file name="Exception.php" hash="2f764ffbd8d0325189157a5166961ce0"/><dir name="Helper"><file name="Data.php" hash="4bba6d904ff25cf084a34bc5e67e9562"/></dir><dir name="Model"><dir name="Billing"><dir name="Agreement"><file name="MethodInterface.php" hash="40affb7dbc6e36c9d412acf3752d49ad"/></dir><file name="AgreementAbstract.php" hash="cb98bd16da8df19373a4e2fb4d695c45"/></dir><file name="Config.php" hash="5e882d7781c0b77ae07556af497a0237"/><dir name="Info"><file name="Exception.php" hash="9e329becc170b4510db0a958b85d9992"/></dir><file name="Info.php" hash="f1a313479034fa1cd9cc4a55c754de07"/><dir name="Method"><file name="Abstract.php" hash="e540ef077370453a0caf0f043bf20ee2"/><file name="Banktransfer.php" hash="2c3cef4f19d6c50cfbcad2417881e506"/><file name="Cashondelivery.php" hash="ba5a710d5848130b9bc853fcb5975387"/><file name="Cc.php" hash="936a4c4e2a4ec708d1f7b9a904955a67"/><file name="Ccsave.php" hash="d23c43b145c29936b4f0270f2bd5461b"/><file name="Checkmo.php" hash="e9e42a8a7e6fac87ba540707b971f721"/><file name="Free.php" hash="dbb00b6ca11ff0b713028460fdb4c7fe"/><file name="Purchaseorder.php" hash="5ac8af393668e8293d99edd49448e5fc"/></dir><file name="Observer.php" hash="60a511f336a4e4929f0d493c35ae8a0c"/><dir name="Paygate"><file name="Request.php" hash="6bc7e8cd45e164af3323eb8555334474"/><file name="Result.php" hash="2e4a62d1d983538db34bce670dec9139"/></dir><dir name="Recurring"><dir name="Profile"><file name="MethodInterface.php" hash="7c3753a6b14e1f405bcdb6e9842cdba6"/></dir><file name="Profile.php" hash="a619cf76b0eb8846919935ed8c644995"/></dir><dir name="Source"><file name="Cctype.php" hash="4aa5f460d8dbd3365a37d5a777833284"/><file name="Invoice.php" hash="94cf713138fce0d1e839aff0f4835640"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2ffac8b147628b2f2a905c7c6863f873"/><file name="config.xml" hash="8088a0540e8f4c16af7cdde7f6114397"/><file name="system.xml" hash="73d212e7b1a6299a5aeb3252036481f8"/></dir><dir name="sql"><dir name="payment_setup"><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="8a85b32c4db60c3f8841f3e4a54b9b95"/></dir></dir></dir><dir name="Paypal"><dir name="Block"><dir name="Adminhtml"><dir name="Settlement"><dir name="Details"><file name="Form.php" hash="6ddcb1cc4019de3b6959bca28115ac36"/></dir><file name="Details.php" hash="7ac366f7c6119905719aec713aec003e"/><dir name="Report"><file name="Grid.php" hash="85f1eaa79a7efedcc68b2b55a2996fb4"/></dir><file name="Report.php" hash="36bb9f80863bb5a1475ea1558c474b27"/></dir><dir name="System"><dir name="Config"><file name="ApiWizard.php" hash="0bc7455b8a819c2d72639ea6bbe37e4c"/><file name="BmlApiWizard.php" hash="090124ca3d6b8a7871676c057abbdcde"/><dir name="Field"><file name="Country.php" hash="4c60e38dd22c3b9fb23e3a0ca9a7cb6a"/><file name="Hidden.php" hash="e069a192a35b54b1bc29f9e8b03b06a1"/><file name="SolutionType.php" hash="889a1b47c5fdfb1a8d56e618afffc83a"/></dir><dir name="Fieldset"><file name="Deprecated.php" hash="01f954b46d2bf35bbcb4181fbdc18a37"/><file name="Expanded.php" hash="5feb995a9b9368a7335645cd659e0069"/><file name="Global.php" hash="2edadea19ce037b63b5b9d5f43e0639a"/><file name="Group.php" hash="10a1bd0c6519d110c1da6cf34f2f3e88"/><file name="Hint.php" hash="1b39b3d40b5602d53ddb83aa96285623"/><file name="Location.php" hash="ba3f315238325790ca09dbfe1f3c98b7"/><file name="PathDependent.php" hash="125f5c38eba04b953f6c770de5794982"/><file name="Payment.php" hash="47d6650b3d19fa72cd0be0799a4bc58c"/><file name="Store.php" hash="f3c73d65c6a3830dd320a252b9719c37"/></dir><dir name="Payflowlink"><file name="Advanced.php" hash="c9504cc07b7e8dd2b53b7732ccea5f37"/><file name="Info.php" hash="452702b941cd07c4604d27744768927f"/></dir></dir></dir></dir><dir name="Bml"><file name="Banners.php" hash="b3eec8eed2340570b3992dc5cc91c3eb"/><file name="Form.php" hash="e18437ec63789b079fcee9da6584a6bf"/></dir><dir name="Express"><file name="Form.php" hash="c638da5fe28a9499e97ae54912b39814"/><dir name="Review"><file name="Billing.php" hash="b5b3816f3de318c64cf64c90f56b8c0e"/><file name="Details.php" hash="93b80e5b28ba63323a3e7f1121e56c26"/><file name="Shipping.php" hash="81ad721a1affbfe1e5e1b149819e9399"/></dir><file name="Review.php" hash="accd58014e0a151ad8b9dfcfaa43a57e"/><file name="Shortcut.php" hash="b0e47e3854c9249353b08634818fe367"/></dir><dir name="Hosted"><dir name="Pro"><file name="Form.php" hash="a5cf9e2d9706c4d51f52ecca876cc51d"/><file name="Iframe.php" hash="a6631c676e7b70c2f3c98e37fb4c7938"/><file name="Info.php" hash="66918e15ea5383ae03982360a7d3395c"/></dir></dir><file name="Iframe.php" hash="d9dbf2ed604febfdc93d7ec861416959"/><file name="Logo.php" hash="c1d496b3c83f9b048fc6a6fec17868b8"/><dir name="Payflow"><dir name="Advanced"><file name="Form.php" hash="a53c2c390019833e86255d468ea00ce5"/><file name="Iframe.php" hash="d004c0ecd462b5bd3aa40e60f0eaa98f"/><file name="Info.php" hash="d8b493ddca4388198d58de4f29928575"/><file name="Review.php" hash="e76212ba90c607a6fb4e8937e15157b1"/></dir><dir name="Link"><file name="Form.php" hash="cd8607afb8baf8e7076414aa80af47b9"/><file name="Iframe.php" hash="9fa8a536ea14470f7edbd6542e345361"/><file name="Info.php" hash="adeb4b8a88c9744ea7e7a135b6cf92e9"/><file name="Review.php" hash="79fe2f6d55f6c77ff499e900b8aae56a"/></dir></dir><dir name="Payment"><file name="Info.php" hash="ff95d5e77f8273c3df147339dc2a809a"/></dir><dir name="Standard"><file name="Form.php" hash="74f3f12f2f645bf65d4c7cbd07b41bb4"/><file name="Redirect.php" hash="29dbaaac7d961dbedb27b22ff50a6fd5"/></dir></dir><dir name="Controller"><dir name="Express"><file name="Abstract.php" hash="200daa8f5bfd9cc60308e1c70b48fdfc"/></dir></dir><file name="Exception.php" hash="fcdfd6d4dac7c1f3bf1fd539eb7f7769"/><dir name="Helper"><file name="Checkout.php" hash="615868ddf2e733a90a1530ca7f76e76a"/><file name="Data.php" hash="8bfe0b91a3782f2a3a2589cbff79c789"/><file name="Hss.php" hash="a214dc03517c059962b4b0ae0b3062d4"/></dir><dir name="Model"><dir name="Api"><file name="Abstract.php" hash="83fa994337a3ea71000be3929819339f"/><file name="Nvp.php" hash="9afffc68e2b7f5b088368cfcf852095d"/><file name="ProcessableException.php" hash="3912a3f9f4916ada603c2903f8195a6b"/><file name="Standard.php" hash="6025fea50bc134ae53d7a7253e40a849"/></dir><file name="Bml.php" hash="c8ef5747ef0e41edff08224c8b09780e"/><file name="Cart.php" hash="606f045a4c3441fc3f2a43127840f9be"/><file name="Cert.php" hash="dec38db38574e00681a0171e2ddcbdf7"/><file name="Config.php" hash="8f8e36240b38e64509ba5c14c774e9d0"/><file name="Direct.php" hash="c2a94320efb7745eee4db1ccc22822f0"/><dir name="Express"><file name="Checkout.php" hash="341134b019a81f5132df773034b11ffa"/></dir><file name="Express.php" hash="bb9d000176a507ee2f8f189e2a0cde1d"/><dir name="Hostedpro"><file name="Request.php" hash="349a1a20f529fa148d557b655618b5b8"/></dir><file name="Hostedpro.php" hash="fc7b44c2d2b7a6b2e16555ca779e3cec"/><file name="Info.php" hash="841b30d7eebbf3df26fe71937243c4e3"/><file name="Ipn.php" hash="992d9a3d7eac13cc92e4006bd82cf6d6"/><dir name="Method"><file name="Agreement.php" hash="024ff9253ccbd340ab4d3e1df3b462ec"/></dir><dir name="Mysql4"><file name="Cert.php" hash="cc765655e8978b4a65343cf307e3fd7b"/><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="57ebccbb3c85463714004f17b5944ffb"/></dir><file name="Row.php" hash="f73aa04ec3103f999023738fb56f3efc"/></dir><file name="Settlement.php" hash="c2a3667e985551055c032ceb3269843f"/></dir><file name="Setup.php" hash="d332223394ea48a9316ece62f9d87c2b"/></dir><file name="Observer.php" hash="921ff85011967dace873135b17c4473d"/><dir name="Payflow"><file name="Request.php" hash="bce9a2a096c7948d82f8b376e2a2a178"/></dir><file name="Payflowadvanced.php" hash="7bb0e3274015050ae2fc9c56057b2cb4"/><file name="Payflowlink.php" hash="a5808cb2562f13ad2430c2150a28e023"/><file name="Payflowpro.php" hash="71d8794bc0c48b63cf31312b1dbef978"/><dir name="Payment"><file name="Transaction.php" hash="fa8636d02751123e68d3907326dc3844"/></dir><file name="Pro.php" hash="4f2c1c4e4175db48b24dfd5d074c78f3"/><dir name="Report"><dir name="Settlement"><file name="Row.php" hash="d6c2cd48c2cc14acd7807ae0ecc075b9"/></dir><file name="Settlement.php" hash="4a116d46a8a412baf390b4f660092e85"/></dir><dir name="Resource"><file name="Cert.php" hash="dc4fee682268206f22c450f11ee77ab6"/><dir name="Payment"><dir name="Transaction"><file name="Collection.php" hash="a738465839e6bc7060399d4ea1018811"/></dir><file name="Transaction.php" hash="fc74fade61f3ed060dfd1908d0f3568c"/></dir><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="b86233296208bf48edf315e76af3841a"/></dir><file name="Row.php" hash="b5f4467774406898083bc0a3b381e4a2"/></dir><file name="Settlement.php" hash="00be4934c8645f49be6dfb2f95c2df6e"/></dir><file name="Setup.php" hash="72ee97eac0bf6dd489e87a90f0739f94"/></dir><file name="Session.php" hash="01e89821d349210313e7601a52163253"/><file name="Standard.php" hash="e64d7379830e18577f72f07c2b1bcbcc"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Cert.php" hash="39dee3020d56b4d99acf2dbaac2d8313"/><file name="Cron.php" hash="b9f70827fcf4a140a0dd93d1a6377f32"/><file name="MerchantCountry.php" hash="d8fc9fa97b38b8e5d6e59a10863903fe"/></dir><dir name="Source"><file name="AuthorizationAmounts.php" hash="0c3a38379dc3cf8d7822a91df9bd2fea"/><file name="BmlPosition.php" hash="df2ad0b79c16fdc21b28442544ca6021"/><file name="BmlSize.php" hash="e80300a818111d09ca8c84a535508516"/><file name="BuyerCountry.php" hash="d897c4000b9d38da67e649b1552120c6"/><file name="FetchingSchedule.php" hash="07344b50f6ca9f10e9be3234d57e8957"/><file name="Logo.php" hash="ae5253ff2eb86d72a9d4a48eefd71516"/><file name="MerchantCountry.php" hash="ef1e498e5aad6a3c0af03a5ed5f4faa8"/><dir name="PaymentActions"><file name="Express.php" hash="bab12455a570699163625c6452458116"/></dir><file name="PaymentActions.php" hash="c2593f853dbab0a41dc5175c020b3d3c"/><file name="RequireBillingAddress.php" hash="b73a2c1762c33aad94c8878bfec02eff"/><file name="UrlMethod.php" hash="52cdf00f20176c80a1c099e5f635a8f2"/><file name="YesnoShortcut.php" hash="cad52eb5e45fe480327631f6272f907e"/></dir></dir></dir></dir><file name="UnavailableException.php" hash="aa39aecb2766d59f98b32030254d34fa"/><dir name="controllers"><dir name="Adminhtml"><dir name="Paypal"><file name="ReportsController.php" hash="5c6bf3de5a00da49b48565f92afedec7"/></dir></dir><file name="BmlController.php" hash="b8b1d029fdd2d73ff389c9a100f30054"/><file name="ExpressController.php" hash="5733d778477b5a08dfd3e64992320f77"/><file name="HostedproController.php" hash="0152fbfc438e30b70c7f647278701d75"/><file name="IpnController.php" hash="563d93416c1482581dee5112ab0aebb1"/><file name="PayflowController.php" hash="1a303bea93bcdd01445e5efc7ea2691b"/><file name="PayflowadvancedController.php" hash="640e848bfe279f7585bb877b9571415a"/><file name="StandardController.php" hash="1e8b7292120096b0b9fb38c94b1e314b"/></dir><dir name="data"><dir name="paypal_setup"><file name="data-install-1.6.0.5.php" hash="31f40b7d79be358edb0a9cc0e9b103db"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="c42ee4ee4739cb2ea92a422fd0b404fc"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="a8bf81ac635dfd2bd045904a25c64da6"/><file name="data-upgrade-1.6.0.5-1.6.0.6.php" hash="ebee289417ad5f5c222be7b1af256393"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5d13ccd9736705a6b2eb7f6de4f833c3"/><file name="config.xml" hash="83aaa17324edbd5bef47af753ea350de"/><file name="system.xml" hash="114ca5f13f1da5b517f023e332d03a01"/></dir><dir name="sql"><dir name="paypal_setup"><file name="install-1.6.0.0.php" hash="2090e14614dbdce1ff27be6516bc594c"/><file name="mysql4-install-0.7.0.php" hash="378e4be279f4bbc8d04cbdf861094b21"/><file name="mysql4-install-1.4.0.0.php" hash="14d77731070a888c43bf107f45756d76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="10e54e4c72b929cca1c933fda6f08ada"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="781db6012e61655eb559c282e49601dc"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="bb99253212b7a2593936f557c434b370"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="56e09db439d9d5cfa73e06beffd5fc3a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ab6fa9235bae2eedf82869e288af1b83"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="5ef1829af7dfb20fc92b3dbdcbea82a7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="37589fcebf8a761344345ae9fb7850b4"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="bca45a121f607c44b0f63975db8cbc03"/></dir></dir></dir><dir name="PaypalUk"><dir name="Block"><dir name="Bml"><file name="Form.php" hash="3c0edcbe9705ed2744098b851d3fba7a"/></dir><dir name="Express"><file name="Form.php" hash="d256cb349d523a2321e1597cfab93939"/><file name="Shortcut.php" hash="e69f67262822e930f82394a4f0bbc89c"/></dir></dir><dir name="Helper"><file name="Data.php" hash="90c53b8383f4258113adfc5ef79af65a"/></dir><dir name="Model"><dir name="Api"><dir name="Express"><file name="Nvp.php" hash="651c60d497003cb572dbb69a1eaffa17"/></dir><file name="Nvp.php" hash="4e46dc410d3afb2f18da008e45411d1d"/></dir><file name="Bml.php" hash="1e160b4ef8f118a09d8cb4263f96a01f"/><file name="Direct.php" hash="ccd3c98de05755972fb5d89fa806767a"/><dir name="Express"><file name="Checkout.php" hash="17089c92caeb7c8c6fd3059e0bd1a0a2"/><file name="Pro.php" hash="f0c3e779d8623d4f27706dda66decab4"/></dir><file name="Express.php" hash="7e5fa1857cb0696aa9297ceb0f6546ca"/><file name="Pro.php" hash="e8311225b0d975ef699328964807165f"/><file name="Session.php" hash="21a99ed402af561bbb41f6c62bc4ea3e"/></dir><dir name="controllers"><file name="BmlController.php" hash="7386a0d6715cc32a3f07888f3f42b0d3"/><file name="ExpressController.php" hash="a0e8d1669b5e48b3b038fc1cfd8d8b66"/></dir><dir name="etc"><file name="config.xml" hash="4a88d9c97e7fe9ed8ac729813eb02768"/></dir><dir name="sql"><dir name="paypaluk_setup"><file name="install-1.6.0.0.php" hash="778b39aed49df6932c24b93b90de5374"/><file name="mysql4-install-0.7.0.php" hash="04d22ff231e6052b2a7045ceed56e823"/></dir></dir></dir><dir name="Persistent"><dir name="Block"><dir name="Form"><file name="Remember.php" hash="6938ee73ae4b23175929291352627c1d"/></dir><dir name="Header"><file name="Additional.php" hash="fe21d5ba74ee87c8fd1f078820862459"/></dir></dir><dir name="Helper"><file name="Data.php" hash="74c064583b94e204e3d2a9ebb531e83a"/><file name="Session.php" hash="30ec18375b1721d96e419ba1ae51bfd6"/></dir><dir name="Model"><dir name="Observer"><file name="Session.php" hash="26f1f3914a611968042f33448b29493e"/></dir><file name="Observer.php" hash="9c8fc1d64e5475e7999c9adb951b9227"/><dir name="Persistent"><file name="Config.php" hash="97c699aab82390187319a99d6fd8d397"/></dir><dir name="Resource"><file name="Session.php" hash="73fee31ec3e22f4ef5fe35d8572a8086"/></dir><file name="Session.php" hash="f60ed020730dae8723e95b9a7c4f910e"/></dir><dir name="controllers"><file name="IndexController.php" hash="dbe7fb77826b94758eb83510a3f824d5"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ee4a02d8045e01f972d7a819fcb534df"/><file name="config.xml" hash="1556d41acedff911c7eb7f7984bfdb0c"/><file name="persistent.xml" hash="3b9b7c3c2c765d6c999ce496a1712dce"/><file name="system.xml" hash="a551b1dbfd9b4932f1902233199f388e"/></dir><dir name="sql"><dir name="persistent_setup"><file name="install-1.0.0.0.php" hash="087ca130d306aa6b3ff8213a45f39dfc"/></dir></dir></dir><dir name="Poll"><dir name="Block"><file name="ActivePoll.php" hash="0efc7679648818186af612d4783d656d"/><file name="Poll.php" hash="27d6ea8ad7f802de02180374f9d25f6f"/></dir><dir name="Helper"><file name="Data.php" hash="9ace323d9bbe7107ecf78d55bf368f52"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="fcff690bfd2b25a997d966a3ad215d57"/></dir><file name="Answer.php" hash="5b008cec3bd71a09124ec5122d125a47"/><file name="Collection.php" hash="9abdf28422a7199aa63d51c5ac08b0b8"/><file name="Vote.php" hash="4cc3b62377628d468f70de60c7225838"/></dir><file name="Poll.php" hash="5af07cffe3ab1047d194a88db092bb35"/></dir><dir name="Poll"><file name="Answer.php" hash="9ee53f75ee1cb0730a56bab3ca65b051"/><file name="Vote.php" hash="bdde76ff3dc7fa32a2a34aba8bbf0cee"/></dir><file name="Poll.php" hash="04c789d42b6b6195e760d641869a5c9d"/><dir name="Resource"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="ad2c1626fa1a4efb5b6b7cc8f8a87299"/></dir><file name="Answer.php" hash="d54f1545c087c996dc4cc8265935efec"/><file name="Collection.php" hash="1f92a6035921131de16b08c77f16a15d"/><file name="Vote.php" hash="3556ee4ac6bc5c48ec5b46ff3c229a13"/></dir><file name="Poll.php" hash="79cc676bf96e3eea566be1b271155ca1"/></dir></dir><dir name="controllers"><file name="VoteController.php" hash="75a4dc065025244db68fdde35dc27b23"/></dir><dir name="data"><dir name="poll_setup"><file name="data-install-1.6.0.0.php" hash="81bc077023380193b961ae812b755e28"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="bebf784876fa408411acba8347fd07c3"/><file name="config.xml" hash="fbe5e0b634f3890830c99d1e19571fa4"/><file name="system.xml" hash="fee2ec0817191ecc52699b6bef1cf5bc"/></dir><dir name="sql"><dir name="poll_setup"><file name="install-1.6.0.0.php" hash="517679e2f811306884b81b50f1ff9153"/><file name="mysql4-install-0.7.0.php" hash="e7e4bad7b4e74accd4ebb402f2d0aeed"/><file name="mysql4-upgrade-0.6.0-0.6.1.php" hash="58897150966041bfc0e59485b3f03712"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="61d60cfd460cf5bebd9937631fb99985"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0f5c35f33dc93513a5f795502a7256c3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="5d4d2334726cb8f948f6b9ed8ef48405"/></dir></dir></dir><dir name="ProductAlert"><dir name="Block"><dir name="Email"><file name="Abstract.php" hash="d4584e39cf64f1519770dc136c4ed161"/><file name="Price.php" hash="c696a8a63f39e8a52d2e79fdded85022"/><file name="Stock.php" hash="ca4bf9d8aa0e94555fe07717d143ad30"/></dir><file name="Price.php" hash="ebe9e1281e2bdabe74dfb394a0847220"/><dir name="Product"><file name="View.php" hash="eadba6f14baa5ec9809405b19c6df677"/></dir><file name="Stock.php" hash="9fbb5d57defc5b98978cff84db56b362"/></dir><dir name="Helper"><file name="Data.php" hash="41646f457da8ca144d27aaf0a6f92b6c"/></dir><dir name="Model"><file name="Email.php" hash="a9fb2a4d7235b1d68dfcd57b81cfe148"/><dir name="Mysql4"><dir name="Price"><file name="Collection.php" hash="88a48bedb0107bcd757e7aaac39a6f62"/><dir name="Customer"><file name="Collection.php" hash="5943e6821711e0e9e0266e0b415c467c"/></dir></dir><file name="Price.php" hash="a91bce1d6069a5c25e6dbcbd8f9bb8b2"/><dir name="Stock"><file name="Collection.php" hash="e2af3546fff475cde3bb9df4cc5e2578"/><dir name="Customer"><file name="Collection.php" hash="e11445992cd1db1bb3f4935d3c5794b5"/></dir></dir><file name="Stock.php" hash="eebeb5ce217c58b557f10eda30911313"/></dir><file name="Observer.php" hash="d1c3f4359a48e887c91ad80791f7db36"/><file name="Price.php" hash="c96bd123fb217872e6f24fb1414c710a"/><dir name="Resource"><file name="Abstract.php" hash="2544041fe5c5be4af7a084afdfdd228c"/><dir name="Price"><file name="Collection.php" hash="e3cc13eb4fac8731b1da5b82b3adc3b7"/><dir name="Customer"><file name="Collection.php" hash="30a328daac7a1dff800060817b47f299"/></dir></dir><file name="Price.php" hash="ecc8828fb2d20b0d4ab06861c987694a"/><dir name="Stock"><file name="Collection.php" hash="1c5d42dbe9c792490dd89928aca889e4"/><dir name="Customer"><file name="Collection.php" hash="f81d09b722478c8ea10f507bea29e889"/></dir></dir><file name="Stock.php" hash="db05538712e2f718318195ac5a4e69d3"/></dir><file name="Stock.php" hash="3f5bd3faf55a0978fe76958ea5592642"/></dir><dir name="controllers"><file name="AddController.php" hash="967cdb1b04d2c534c222232be1346613"/><file name="UnsubscribeController.php" hash="fd8b03509b6c9ca09ad802504c1994d8"/></dir><dir name="etc"><file name="config.xml" hash="8c76943b68ac296be813ba5fd7249c15"/><file name="system.xml" hash="8b462f95ac48ac5350d3aad9bb3b0324"/></dir><dir name="sql"><dir name="productalert_setup"><file name="install-1.6.0.0.php" hash="0241d37ef70e2a735100a50cd07164af"/><file name="mysql4-install-0.7.0.php" hash="1b86eaa23d5d830e157515c848c2bc66"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="1c2c5e094b3773c400177de03e13fdbd"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="18bbf5de2c4f24dcb6dbfff25ab9db8a"/></dir></dir></dir><dir name="Rating"><dir name="Block"><dir name="Entity"><file name="Detailed.php" hash="c337400133e34ad71b6857e4cb9dc7aa"/></dir></dir><dir name="Helper"><file name="Data.php" hash="aa08b748843d918a4f64801a34fb1155"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Rating"><file name="Collection.php" hash="bf5daff55dfd9638ad4068100e9f9801"/><file name="Entity.php" hash="2b8b613f66fb4f0d194530a2e041f90d"/><dir name="Option"><file name="Collection.php" hash="bc1d8b91473af46272fd5ad54d974072"/><dir name="Vote"><file name="Collection.php" hash="b7a023cb71d55d3bcb1ad4c4f71b1eb4"/></dir><file name="Vote.php" hash="88291cb4df65fb6305440350a1e1d569"/></dir><file name="Option.php" hash="e061db0760437a11256d92612ac599f9"/></dir><file name="Rating.php" hash="3b873eddd0c4d3f94274ba13c76f30bf"/></dir><file name="Observer.php" hash="2b1375aadc070ee4dc237b5ee0bbc626"/><dir name="Rating"><file name="Entity.php" hash="e92cb9b2f7d48d365bd58a2a579bb115"/><dir name="Option"><file name="Vote.php" hash="a7ee8de255dd46e91c1aa2d412cb4b22"/></dir><file name="Option.php" hash="c1b61fdc362c81d9a838b301a4307f47"/></dir><file name="Rating.php" hash="53a1e432211ada9a75b7b19016f8e154"/><dir name="Resource"><dir name="Rating"><file name="Collection.php" hash="f5d06f8dbc8a3f5bd10da9c6c6ba3fdc"/><file name="Entity.php" hash="5d7027e01a7c430c159064c74f957502"/><dir name="Option"><file name="Collection.php" hash="f9ac2b03c8abdc7b4728c500948923a9"/><dir name="Vote"><file name="Collection.php" hash="fde61681ae5f8d35e2f6777fb4303e77"/></dir><file name="Vote.php" hash="bf1e516fc97e7266a07cd0cf1f2ef398"/></dir><file name="Option.php" hash="c5072273eb4611d4c7f93873801433f5"/></dir><file name="Rating.php" hash="b67c23b781c0971d2a196d070923a466"/></dir></dir><dir name="data"><dir name="rating_setup"><file name="data-install-1.6.0.0.php" hash="12900433b5a26cbe769bde7ddc66f2e6"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="74579ad431dac104175d33ff02c10822"/><file name="config.xml" hash="2cdae0e1ff2a7e3a63dd7c42805fdb1d"/></dir><dir name="sql"><dir name="rating_setup"><file name="install-1.6.0.0.php" hash="b957611e9c176b0800c472f7d51a73e2"/><file name="mysql4-install-0.7.0.php" hash="a4263d1dacf3e8ea82371fc2aa00288d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5b2fda173988176fc92e242667b48a76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0903ea1ed5a6fc1a926dce7d7c0c3a34"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="221a4e86db85c68e5b5e7a3db40f59b3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="366c0d1c4af6b53d486505665270ad7f"/></dir></dir></dir><dir name="Reports"><dir name="Block"><dir name="Product"><file name="Abstract.php" hash="9381d2f3817997e6b12bf6d1fb59a571"/><file name="Compared.php" hash="9401b0b87c2bcbbffafb8d27bf7160ac"/><file name="Viewed.php" hash="5cc5ea78c4dada735baa33fa470c99f3"/><dir name="Widget"><file name="Compared.php" hash="35b6e1c66895d7e5f972827daf8345cb"/><file name="Viewed.php" hash="e5ec75a90229bc827323e0101ddf1a99"/></dir></dir></dir><file name="Exception.php" hash="608a94b2ffadf371f1b5a92df71441fa"/><dir name="Helper"><file name="Data.php" hash="2808507ba066be921f54fade9f7f7360"/></dir><dir name="Model"><file name="Config.php" hash="8ac452add42e1efa4653842fb351bb06"/><dir name="Event"><file name="Observer.php" hash="38c5a6b2f62648efc5bd900c804f1131"/><file name="Type.php" hash="1bd1bee7108cdf48005b522da3b4e5c1"/></dir><file name="Event.php" hash="b1a4de5241ff78cd457fcfb25cf50b1b"/><file name="Flag.php" hash="74831f5918109873c14eb9bdcef76419"/><dir name="Grouped"><file name="Collection.php" hash="8adb854bcd467bca3afc6a932c61024f"/></dir><dir name="Mysql4"><dir name="Accounts"><file name="Collection.php" hash="6384e2c0b0d981921ec0b04178008278"/></dir><dir name="Coupons"><file name="Collection.php" hash="a8a142a4a3c3b6a34e8938b2cad17c6e"/></dir><dir name="Customer"><file name="Collection.php" hash="41d4be8a6c9daae9f5bb7dea2e4d3137"/><dir name="Orders"><file name="Collection.php" hash="99d08265d68e69bdb7eec18c65fa6ea5"/></dir><dir name="Totals"><file name="Collection.php" hash="e2440c39383c54276dc5122651ece92d"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="10850a1bb4d3106d61a97c35f3e72b35"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="f5a8b4cd57f1cad485ad148902e74a34"/><dir name="Type"><file name="Collection.php" hash="52b034d02ac4fee39387ebf6afa30a16"/></dir><file name="Type.php" hash="4e168e5eb91c2357424e1c59ba48db6f"/></dir><file name="Event.php" hash="f8485c5e772ce4820d914a2d430c598c"/><dir name="Invoiced"><file name="Collection.php" hash="b55329ae04cba3ecc78633ae1666624b"/></dir><dir name="Order"><file name="Collection.php" hash="7c9906ac0c28aca240db23a70d7aaf14"/></dir><dir name="Product"><file name="Collection.php" hash="5e2511ee63229e9c481701d3e8ea81bd"/><dir name="Downloads"><file name="Collection.php" hash="a7a59e694fdd839bd5e7c95f1034ed6d"/></dir><dir name="Index"><file name="Abstract.php" hash="8351ce388ded1083578edd5b61697b30"/><dir name="Collection"><file name="Abstract.php" hash="ec2f7042e58fe0d135e2fc22880006ea"/></dir><dir name="Compared"><file name="Collection.php" hash="95153672ccc9044236c7220e3805f864"/></dir><file name="Compared.php" hash="f9a0ab36e1d389b869057426ce5757a6"/><dir name="Viewed"><file name="Collection.php" hash="f84f3c7fb46a5976a1e676355efd41f8"/></dir><file name="Viewed.php" hash="ee216881da4db2c3e0578768749240b3"/></dir><dir name="Lowstock"><file name="Collection.php" hash="129cda12e29ee74730dcd9f00f280309"/></dir><dir name="Ordered"><file name="Collection.php" hash="8a04b617e9c1a99aa5e632044079f1f8"/></dir><dir name="Sold"><file name="Collection.php" hash="2423be35980f9f6ee1684a6c52862a83"/></dir><dir name="Viewed"><file name="Collection.php" hash="7a65fa98452f67e8ead531b27c4ec7c7"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="4f412c1b59c80f980c2758b04800aaa9"/></dir><dir name="Refunded"><file name="Collection.php" hash="272cc7c309b60ced27a8bf05e4732a21"/></dir><dir name="Report"><file name="Abstract.php" hash="9074336e20298296f48160e7d4e7f88c"/><file name="Collection.php" hash="5981974079e5479aa0eb59977617bdb8"/></dir><dir name="Review"><file name="Collection.php" hash="b19a21cd5373bd77b4508236fc175a63"/><dir name="Customer"><file name="Collection.php" hash="9c7cced8de4d055915d4d94bd5a86571"/></dir><dir name="Product"><file name="Collection.php" hash="b84410ab5000133b9bf3b9e819993641"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="5bc46c5198f98b78d50da2387c58b368"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="5d45215574659235c1e54b01fffec62c"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="7df40ab2b4df1591c691e1eee5ffafb1"/><dir name="Customer"><file name="Collection.php" hash="08398ac0f332002c23d326ec580e2a05"/></dir><dir name="Product"><file name="Collection.php" hash="911eb9cc4fe1c260a1cb6c2b8f6d1623"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="667d111f18687a46988da9b17290c929"/></dir><dir name="Wishlist"><file name="Collection.php" hash="8e57527ad0cf1166cc7e4559a67ab727"/><dir name="Product"><file name="Collection.php" hash="de66493523d35c12fcd0a3ba31a652b6"/></dir></dir></dir><dir name="Product"><dir name="Index"><file name="Abstract.php" hash="354eaa0207964474411899338d9b9585"/><file name="Compared.php" hash="019eb677e0a89b1770cdb5c077330c7d"/><file name="Viewed.php" hash="9095d81fcc6cc892cb67709beac5aeb3"/></dir></dir><file name="Report.php" hash="f5dc6494cff99fb052875b882b702fb5"/><dir name="Resource"><dir name="Accounts"><file name="Collection.php" hash="ac257f532f927cc28943690e7fc8ba6a"/></dir><dir name="Coupons"><file name="Collection.php" hash="5abde4f7b922579e593b868d76c4ca5b"/></dir><dir name="Customer"><file name="Collection.php" hash="ba5e14a4cf75c59ed5baf2099fa2f1d2"/><dir name="Orders"><file name="Collection.php" hash="60dd7f21909c02a2bc1c8d60c6cbf481"/></dir><dir name="Totals"><file name="Collection.php" hash="b91fbcadb349f8762f45a9f8a53547e2"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="1136c8a67e6a1057b17476d0c7d85966"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="ac353d066d90d4c6f25f2e8770e9247d"/><dir name="Type"><file name="Collection.php" hash="8382b58a7462573c16432e0445d76d4b"/></dir><file name="Type.php" hash="3cbccf5eab8cde3bbda74004cefcc618"/></dir><file name="Event.php" hash="0a692a6a09ffc5fdb317d2cff1385291"/><dir name="Helper"><file name="Interface.php" hash="eb1b4518956d271e57dfca77652960ee"/><file name="Mysql4.php" hash="45f718471263a3d85b823488046944ed"/></dir><dir name="Invoiced"><file name="Collection.php" hash="5e7bf13e329243d88d2ce5572eb7f43c"/></dir><dir name="Order"><file name="Collection.php" hash="c961a023b52f2fc6ea28ff161bbe0967"/></dir><dir name="Product"><file name="Collection.php" hash="ed3780d956f83154f218e62970414c4e"/><dir name="Downloads"><file name="Collection.php" hash="641329ba2982601f084b07b8693b2871"/></dir><dir name="Index"><file name="Abstract.php" hash="88e2dc2b27500d435b8e22280943efd1"/><dir name="Collection"><file name="Abstract.php" hash="71630411364a2552ac383b63e0fbf831"/></dir><dir name="Compared"><file name="Collection.php" hash="696b12dd05e1f0d23a7e3a75949ce668"/></dir><file name="Compared.php" hash="f5dbc6ea9aa23b8fac130be6bacc2ee4"/><dir name="Viewed"><file name="Collection.php" hash="636cf44005f888d8bb62b07f9eb6e370"/></dir><file name="Viewed.php" hash="95171e2b6d01fa477231c9f427307ccd"/></dir><dir name="Lowstock"><file name="Collection.php" hash="8e1d09a3d67337acb37305948a37f7ae"/></dir><dir name="Ordered"><file name="Collection.php" hash="9efdf0700de6cab7243a7a88c20a1559"/></dir><dir name="Sold"><file name="Collection.php" hash="5e3d829af728da0bde83e50d9b581dcc"/></dir><dir name="Viewed"><file name="Collection.php" hash="481d4fa98830ab3f42cee09a2c9aaee0"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="9f3b12f7d20632fbd52dcc33ba37a467"/></dir><dir name="Refunded"><file name="Collection.php" hash="66e1f3f5767dbe8833f3e15d3636468e"/></dir><dir name="Report"><file name="Abstract.php" hash="d67e66718893814b9659b0e9ea8b3e6a"/><dir name="Collection"><file name="Abstract.php" hash="f604fff5aca66711811461d9824fc1e0"/></dir><file name="Collection.php" hash="5fcde9791b16799d130e54ac1819dcb0"/><dir name="Product"><dir name="Viewed"><file name="Collection.php" hash="09cd77b4152936ffb6c807f786207077"/></dir><file name="Viewed.php" hash="99cffde7efbb7cfd449505f83b843b06"/></dir></dir><dir name="Review"><file name="Collection.php" hash="da8c3edf5aed4c1cf2bc5109ec3f1ec5"/><dir name="Customer"><file name="Collection.php" hash="2839e9b309c2750b569d64b872e02dcb"/></dir><dir name="Product"><file name="Collection.php" hash="9edc35ef7f987d4fcc89a88ed501e5bb"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="17cb03c7cc5109b4a6f99610a60dbb22"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="44dcf5437f060c0ed58efaba9d16d665"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="cfd6e0454369ff72e419bc232ac3dedf"/><dir name="Customer"><file name="Collection.php" hash="11d7ae7f503e1272fd80face588c543d"/></dir><dir name="Product"><file name="Collection.php" hash="6f2a8754391eac9cd12f0510bccb0853"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="34cf644c296e126f26d20ee0d86e3520"/></dir><dir name="Wishlist"><file name="Collection.php" hash="3389d8396885176702e0b5ac2bef8de1"/><dir name="Product"><file name="Collection.php" hash="965402449bb92e67c3addcec8b2dda62"/></dir></dir></dir><file name="Session.php" hash="c318347dd17ef625e851fe821f59a037"/><file name="Test.php" hash="1c65ee41eff9c26a65ba571d1036282c"/><file name="Totals.php" hash="9a52631051f75ea9436b42febf8c5373"/></dir><dir name="data"><dir name="reports_setup"><file name="data-install-1.6.0.0.php" hash="5d87abb48aedfc1019383ba77ae9d424"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="ade02826599b06c791beb38e752a0a54"/><file name="config.xml" hash="50bc806c9348a42d1413533d68ec4ccf"/><file name="system.xml" hash="2404876dca1c4a1dbc45ea99d0e143aa"/><file name="widget.xml" hash="87134e1fe691d2bf377ef3159e043329"/></dir><dir name="sql"><dir name="reports_setup"><file name="install-1.6.0.0.php" hash="dc8d574c567ff98a0c27768b2f721342"/><file name="mysql4-install-0.7.1.php" hash="6058a42394e2a6d1f3884d08b01d036a"/><file name="mysql4-install-1.5.0.0.php" hash="ad670ce1011e84d3027a29458499603b"/><file name="mysql4-install-1.6.0.0.php" hash="08c55d04a829df9b1bfced10dd7abdb6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ed4fa0f6004262fe49db95861e721c06"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="16440bfbbc893acaa2ff39192c639690"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="e4d91582c78cf488b6762b8c02452319"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="085cc5b0cffb7c3ae5bd087648ad519b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="47e81be68ed4a18b2a6f72c18dca7d5e"/><file name="mysql4-upgrade-0.7.5-0.7.7.php" hash="e056f1c250f5a831587539c10b533f80"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="8edf4a8b3eb12800e15c7f829747267c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2a2af08d7a93fec5d949c9fe52d69fcc"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="beb5107a2beb2b4f8c23495b4751fbdf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="020dd3cc9ea0a3a47db93fef4bc2cf78"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="989fba539a23d744efe24bf3bbe1f704"/></dir></dir></dir><dir name="Review"><dir name="Block"><dir name="Customer"><file name="List.php" hash="75258599abbf2981862edf563aa80e24"/><file name="Recent.php" hash="1a913d3169511e51882470cd0d5c8853"/><file name="View.php" hash="24b8876f7614500ceee5695de6c0171e"/></dir><file name="Form.php" hash="578aa1bb652f5a4cc1acbbd3dbc8bf67"/><file name="Helper.php" hash="e0f2826aba59b1fadc3a3e98cbb45db2"/><dir name="Product"><dir name="View"><file name="List.php" hash="a1ef1ac325677b79f7bff957e3940867"/></dir><file name="View.php" hash="47e6c007eb6e024c888289c9350420c9"/></dir><file name="View.php" hash="c2c3227084a3c4d5dd1a380b926d2582"/></dir><dir name="Helper"><file name="Data.php" hash="cde72b775603ee4b6d144baf55d4d0b2"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Review"><file name="Collection.php" hash="36e926d673bcce527ab001ef75ac6d59"/><dir name="Product"><file name="Collection.php" hash="c57f813e17f672eab2bf5f4f33157b3e"/></dir><dir name="Status"><file name="Collection.php" hash="d79e8912b6077609e6bcd7f939c40c70"/></dir><dir name="Summary"><file name="Collection.php" hash="712e89eda07241326bd73eba5cfce3ee"/></dir><file name="Summary.php" hash="a19372cb153ef832ec65c799f30f8fd5"/></dir><file name="Review.php" hash="be633fb27d76ae1805b218e8e2dfa4f7"/></dir><file name="Observer.php" hash="f2fb97c8b99a01000322c87e8b506209"/><dir name="Resource"><dir name="Review"><file name="Collection.php" hash="f187a2386bace27e55ea8caf311b9f6e"/><dir name="Product"><file name="Collection.php" hash="12961346f71a630ecfefd64f7e6eeae5"/></dir><dir name="Status"><file name="Collection.php" hash="dd5a3e9a6e99ecb95d9946a1a161b46e"/></dir><file name="Status.php" hash="62b11d858f207ba1b81fbf9a86e47d7f"/><dir name="Summary"><file name="Collection.php" hash="292ec5a712b7f3bbcce63a8d8a0de40e"/></dir><file name="Summary.php" hash="2f46abb517f3f4b4c9a72f0055827bbb"/></dir><file name="Review.php" hash="b1432744f6df1fd38df903080602cc44"/></dir><dir name="Review"><file name="Status.php" hash="bfa530e158e2a41abad88448a5cfa75d"/><file name="Summary.php" hash="195a6570b452f499010b89aa29f43117"/></dir><file name="Review.php" hash="32401cc14dc04763601bca8aef509241"/><file name="Session.php" hash="f53a5a0528a2d93ac879b4a0a43e626f"/></dir><dir name="controllers"><file name="CustomerController.php" hash="8ad4aae4ebf43ba61a20be80c3ba971c"/><file name="ProductController.php" hash="944b7de015c7b693aa633a0967ac8012"/></dir><dir name="data"><dir name="review_setup"><file name="data-install-1.6.0.0.php" hash="36aae8d61319eef243cd891db00a91e2"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="643914e5212e3f7fa45185b5261eb6a8"/><file name="config.xml" hash="748472a893d4fb83fb1a1f327342607a"/><file name="system.xml" hash="a45dcfcb2a455add5f1204551109a3c6"/></dir><dir name="sql"><dir name="review_setup"><file name="install-1.6.0.0.php" hash="9bffc27b2df8f5d8b31da8b1130b659f"/><file name="mysql4-install-0.7.0.php" hash="63f50ba59bcd3126e2035b564c148fde"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="345e05077ab1f31240cbd2a97ed65c02"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="4aa3caf337afd47178a7723f7c7c1417"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="4cf527e131117f1b4cecf3c8d4101744"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="dc9e6a7b04391d3aff8b1d0e9a8d2e96"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="7260cb9368214b9ec23e6cef126978d7"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="324a8629ce44e1630819999498b198af"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="897902ad56188bb2119eb082e64f5465"/></dir></dir></dir><dir name="Rss"><dir name="Block"><file name="Abstract.php" hash="78b1e316fa251bd9072e370c69671bab"/><dir name="Catalog"><file name="Abstract.php" hash="0c04f1d3b359467765db675efbdb8db5"/><file name="Category.php" hash="639e02c0987dcae62f5767bf19014764"/><file name="New.php" hash="cc0b203243fa96d7205287276722dac4"/><file name="NotifyStock.php" hash="6dec5508cce929a912eb1d62784894fd"/><file name="Review.php" hash="a2d3ec4e7237a7ea9bff9543439e6b0d"/><file name="Salesrule.php" hash="935c030eb4e0e7e78ed606f3c4762154"/><file name="Special.php" hash="2ad46b236308cf322ea230c2dad2cdcb"/><file name="Tag.php" hash="1569866597c7998a8df5795c4655654a"/></dir><file name="List.php" hash="4cfbf0ecee48a0b3aea463e087f98522"/><dir name="Order"><file name="Details.php" hash="2ad732aa559d4378096c344e45ac8739"/><file name="New.php" hash="236c63a10c0b4fa74b3b93d89c0e58d1"/><file name="Status.php" hash="814d72fab5555894ec00e4233731249a"/></dir><file name="Wishlist.php" hash="0e41bb7a1d52eb4b292267ada80d1a85"/></dir><dir name="Controller"><file name="Abstract.php" hash="800fef71c54dbaa4ee5d14def6ad374c"/></dir><dir name="Helper"><file name="Catalog.php" hash="72b3e51589b9a45c4b79624e2e9e63a8"/><file name="Data.php" hash="784c8bbf33cb18724bb2e89376a6d3f9"/><file name="Order.php" hash="db4a311a8a8e449e551dfef72d49bb19"/></dir><dir name="Model"><dir name="Mysql4"><file name="Order.php" hash="a714c74aa9b2b08eaa25025ed8bae861"/></dir><file name="Observer.php" hash="91f50bed4e811ba74dfe1b6706fe88c5"/><dir name="Resource"><file name="Order.php" hash="06e83d676c21c78a978c5204eb299999"/></dir><file name="Rss.php" hash="b82ec9f4706f3cd88e47d44c69148107"/><file name="Session.php" hash="88190872a65a7b8cc6c0f97b87117fe1"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="77af8de35a234eca3f85eb3eab1c74c3"/></dir></dir></dir></dir><dir name="controllers"><file name="CatalogController.php" hash="b0f5ff39a3ea319af8f1cb7dc72c64f5"/><file name="IndexController.php" hash="4aa833fe228b6f1347f0f03c3b0e3968"/><file name="OrderController.php" hash="4a78ace5090f6e43da34a47bde93f05a"/></dir><dir name="data"><dir name="rss_setup"><file name="data-install-1.6.0.0.php" hash="4a3e745f2b06780b810168f41e465fbb"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="719cc211ae152410041b215441302c96"/><file name="config.xml" hash="670a8d9348a1b9e5b5507713df1d8c87"/><file name="system.xml" hash="9992a900459d27147cb07a3617340659"/></dir></dir><dir name="Rule"><dir name="Block"><file name="Actions.php" hash="6610fb70932429b38248d2a2cb64833c"/><file name="Conditions.php" hash="ce8574b771220536f394089ee2beb6f6"/><file name="Editable.php" hash="cde8b6b2ba9a6d446813f5add9d50ec9"/><file name="Newchild.php" hash="d7c60ffcfac3a6019e08d30ef1d513dc"/><file name="Rule.php" hash="051685923b2392615c1594414c87fc98"/></dir><dir name="Helper"><file name="Data.php" hash="805f12fa0f9b45188625c45b682d0059"/></dir><dir name="Model"><file name="Abstract.php" hash="15333fa84757f9392b98ed5c0bd8cd8f"/><dir name="Action"><file name="Abstract.php" hash="337ba9c8479e1f8608137d0d4406c947"/><file name="Collection.php" hash="8373977869aae94fed30607913586599"/><file name="Interface.php" hash="a303f317f385252e6e394e99d4bb35c1"/></dir><dir name="Condition"><file name="Abstract.php" hash="1f683530e9348e26a9413f9bbb978b3e"/><file name="Combine.php" hash="c12fe8c3c64a58eedf81c9c9d54e0546"/><file name="Interface.php" hash="4e255c250a249f3c71fd5e0ad51fdce7"/><dir name="Product"><file name="Abstract.php" hash="befc50797a7c2ffa464a389cde6208a1"/></dir></dir><file name="Environment.php" hash="e01cb8bcbed1e56dcc51a42c9c15a5bc"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="c62062f2104b04e8f42da83bdd7fb630"/></dir><file name="Rule.php" hash="923f75b95afee693b39d8024acdef931"/></dir><dir name="Renderer"><file name="Actions.php" hash="cd8b6ec25840af7dac2ba99414c4a93c"/><file name="Conditions.php" hash="ca49f7b765b420cd490f2219cf8fb602"/></dir><dir name="Resource"><file name="Abstract.php" hash="d412ec94e493e31b0d052686f9fc5741"/><dir name="Rule"><dir name="Collection"><file name="Abstract.php" hash="aaa0a5c1b5db55160f9b6d78b3bfa45f"/></dir><file name="Collection.php" hash="69a1dbbf809f3a956c60006688ef46e7"/><dir name="Condition"><file name="SqlBuilder.php" hash="2bfce51eaf1077c49eb14b010e72607a"/></dir></dir><file name="Rule.php" hash="60161377f1ba79604a8385ade41b5ec7"/></dir><file name="Rule.php" hash="ee5ca4e39044fac00f020c1850c88e16"/></dir><dir name="etc"><file name="config.xml" hash="0308eb30269e8277974478f8b6f8801a"/></dir></dir><dir name="Sales"><dir name="Block"><dir name="Adminhtml"><dir name="Billing"><dir name="Agreement"><file name="Grid.php" hash="fef66ee16f00b29c84027c10aba81a52"/><dir name="View"><file name="Form.php" hash="1a86a3173f4d954b0c585a03f1f8a041"/><dir name="Tab"><file name="Info.php" hash="7dcce2f205c6f2da7a2383bed74760ed"/><file name="Orders.php" hash="9da38e7f7d07a4a8c6613924f8ed209f"/></dir><file name="Tabs.php" hash="bf8f53c4af65b488ec7d1b248088609f"/></dir><file name="View.php" hash="b8bf13cce32b6e719c7f87843f7a2a7b"/></dir><file name="Agreement.php" hash="4083da4fe5031bb1d0b8287912e1c82a"/></dir><dir name="Customer"><dir name="Edit"><dir name="Tab"><file name="Agreement.php" hash="a65e2d4a78d1006988d708b34d8cdad0"/><dir name="Recurring"><file name="Profile.php" hash="78ef77388e6c8ffc9bea8bd47a87d57d"/></dir></dir></dir></dir><dir name="Recurring"><dir name="Profile"><dir name="Edit"><file name="Form.php" hash="9279e2d6dbae446d2cb949f773a88211"/></dir><file name="Grid.php" hash="0d32af9ab885a9df05ac6f5eb6f339b2"/><dir name="View"><file name="Getawayinfo.php" hash="b9f496477acceadfd22adf5639854e57"/><file name="Info.php" hash="c525974a9aa0487e294eabca4f5b4113"/><file name="Items.php" hash="d0a4335bf5e22e83a1c75d59d100de86"/><dir name="Tab"><file name="Info.php" hash="4e895b956b76697afe0721b8f7c4e8ea"/><file name="Orders.php" hash="e1f95a70f025194e0d550daa520a8f14"/></dir></dir><file name="View.php" hash="b307b50baa307fc74e0f4b6c8a3219e7"/></dir><file name="Profile.php" hash="95f367babe1d664f0d6bac9fb07b7df0"/></dir><dir name="Report"><dir name="Filter"><dir name="Form"><file name="Coupon.php" hash="42d5d95abc0c3fe1817253a86e0c013c"/><file name="Order.php" hash="f4177c41f2f0d34a4124ae04fc91e619"/></dir><file name="Form.php" hash="b9b8ac502065c6f95a7a6b155284319e"/></dir></dir></dir><dir name="Billing"><dir name="Agreement"><file name="View.php" hash="34806b08430353c0c752c67573239728"/></dir><file name="Agreements.php" hash="149bc6329618f80fa1c82f614abc8fa3"/></dir><dir name="Guest"><file name="Links.php" hash="fbf86ecd7a9c3faf3e238a15b364cadf"/></dir><dir name="Items"><file name="Abstract.php" hash="6423bc55cc7e7c5aaeac666743f81b42"/></dir><dir name="Order"><file name="Comments.php" hash="a033815154ae896efc6e6947a109ff6c"/><dir name="Creditmemo"><file name="Items.php" hash="d9409c330900ac3fd50a6e0b6573d8a9"/><file name="Totals.php" hash="f97a4c171b571bbf4c999d07d29fd716"/></dir><file name="Creditmemo.php" hash="33b366b6894ecaf805a021c97a7ddba1"/><file name="Details.php" hash="9e117a5f8963fc689bfd34f6fbc57390"/><dir name="Email"><dir name="Creditmemo"><file name="Items.php" hash="c3abe3d0f0bafbc0f8a02167f60315aa"/></dir><dir name="Invoice"><file name="Items.php" hash="f122cb0a8c0909415883094ebaa76d1f"/></dir><dir name="Items"><file name="Default.php" hash="393e76596db55f0cab3db8622df19464"/><dir name="Order"><file name="Default.php" hash="d71a2b453dfd0f288694fb7a35610ad1"/><file name="Grouped.php" hash="7d18cecbcee39d9fd29befc8cc10ff12"/></dir></dir><file name="Items.php" hash="7b721ab6a462b662304b8d79e077df6c"/><dir name="Shipment"><file name="Items.php" hash="ec02e251e375e75f899d517a22aa44a8"/></dir></dir><file name="History.php" hash="174769627458bd9e71f9d8318c77a4cb"/><dir name="Info"><file name="Buttons.php" hash="04c841c1f16a53a09c6fe0b7ee4c495d"/></dir><file name="Info.php" hash="f48808e8c857b62578d75666964f59bd"/><dir name="Invoice"><file name="Items.php" hash="e836090b717d386e2938652a690d410a"/><file name="Totals.php" hash="585c8b5346a6a881f651ae2c85d960cc"/></dir><file name="Invoice.php" hash="061c0fad24390ee4fab4531721196b6e"/><dir name="Item"><dir name="Renderer"><file name="Default.php" hash="cbdc1858cc4c72c35f1fb6d3b0306f84"/><file name="Grouped.php" hash="7934d30462776f4eaa056cbb59f42559"/></dir></dir><file name="Items.php" hash="6f0636e12a64c5212f26f928711046e0"/><dir name="Print"><file name="Creditmemo.php" hash="02f0f0fa58e7441e59944ebb88264719"/><file name="Invoice.php" hash="e54128f7afc117787aa623a4d0b8af00"/><file name="Shipment.php" hash="35380109c64056fbe0ecc004a103d579"/></dir><file name="Print.php" hash="878669c71c801bd08cb288fbff97c93a"/><file name="Recent.php" hash="33fca43621bc85a175f50ba238c73376"/><dir name="Shipment"><file name="Items.php" hash="622048f99d9f7e266737d3ff52227de2"/></dir><file name="Shipment.php" hash="f77ffdd6745c19c233da4c733c5d3abb"/><file name="Tax.php" hash="16083f37a2591b8f488f5ae3a9cc3a1b"/><file name="Totals.php" hash="03225737c81193a65bb8580e81f3e847"/><file name="View.php" hash="850fd65e3a39b1876100de48ea2541a2"/></dir><dir name="Payment"><dir name="Form"><dir name="Billing"><file name="Agreement.php" hash="cd0b1ff96a419f14dcd7b0ff321724d3"/></dir></dir><dir name="Info"><dir name="Billing"><file name="Agreement.php" hash="3214efb275f83c788f5efc31b582ebaf"/></dir></dir></dir><dir name="Recurring"><dir name="Profile"><file name="View.php" hash="6b22675cfefa43d6f1733648b7985630"/></dir><file name="Profiles.php" hash="3ad863e0afda8cf52abb65bd0db1d5d3"/></dir><dir name="Reorder"><file name="Sidebar.php" hash="46a27506c5829e0542ee45aab3ca0672"/></dir><dir name="Widget"><dir name="Guest"><file name="Form.php" hash="c2967b98e93ab61a7a094d7b5284c078"/></dir></dir></dir><dir name="Controller"><file name="Abstract.php" hash="1f0ffd7a63f093d9164432d5d6b24a7b"/></dir><file name="Exception.php" hash="b2c312840dbc62b8dbc7723b3c7a42b1"/><dir name="Helper"><file name="Data.php" hash="1004e1652fa50e93a21e8a58823141e0"/><file name="Guest.php" hash="d35fedc9902ec64bbba80052187f48a6"/><file name="Reorder.php" hash="7092ac100d733a48a6b2c3a68cbb7cce"/></dir><dir name="Model"><file name="Abstract.php" hash="07efb83eb2281c9abadc549f84df6c56"/><dir name="Api"><file name="Resource.php" hash="6bdd0361747d25ca846832c96a749eef"/></dir><dir name="Api2"><dir name="Order"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8f1aba6fae933a2b4bd6e3bd4f6c5389"/></dir><dir name="Customer"><file name="V1.php" hash="efad7a521ba151226ef438fe30405d6e"/></dir></dir><file name="Rest.php" hash="54c33502d2bfec77aa5735f0e8f23a5b"/></dir><file name="Address.php" hash="51702d27c5eefb9219ae08303b7f98fe"/><dir name="Comment"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="f2c0511ff538c27f5eab792c05792759"/></dir><dir name="Customer"><file name="V1.php" hash="73f856dcdaf15db656a80b533bcf0b4f"/></dir></dir><file name="Rest.php" hash="e2baaffd28d5ee0ea25418b0a7375387"/></dir><file name="Comment.php" hash="6c2b51994d77f1dbba28592e393c131b"/><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="fdb4f6c87f633b80e9a733503209041e"/></dir><dir name="Customer"><file name="V1.php" hash="f6bec0def4d992e1207aca7dfc267912"/></dir></dir><file name="Rest.php" hash="4d34daf2e2f0fa6a6685f1e0083d70e3"/></dir><file name="Item.php" hash="989a4f2e3ce1cee2666bc91894ed4c71"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="080cbf5d63dfdb0fa74615ccf9f16c46"/></dir><dir name="Customer"><file name="V1.php" hash="ca9b754da5e11e2ab7449d2a8bdc8e00"/></dir></dir><file name="Rest.php" hash="b129022f37d1dfbe3fd34e17de97ca3a"/></dir><file name="Order.php" hash="bf8448d9cbd2b1ae4dc776d05f91e73c"/></dir><dir name="Billing"><file name="Agreement.php" hash="dc3110bfcd5aa6a10ff5881d7fbb670b"/></dir><dir name="Config"><file name="Ordered.php" hash="39b93b978aa3db28068ef8ddd33fd1a5"/></dir><file name="Config.php" hash="648e93992a3d7a83147332be1b3e86ba"/><dir name="Convert"><file name="Order.php" hash="bc2f1e45d6a5b02c7617f1fb23901297"/><file name="Quote.php" hash="0d299e87306356a2936c72e313055969"/></dir><dir name="Email"><file name="Template.php" hash="282e7d7486a63eeedc56d213e17294bb"/></dir><dir name="Entity"><dir name="Order"><dir name="Address"><file name="Collection.php" hash="1f912f0f6afaf7f0c97388eb817dcf99"/></dir><file name="Address.php" hash="6c7dc37688bcb3543ed7fb51e60f08b7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="861bfe37e0e2a3e8d397a7fef2b79e60"/><file name="Child.php" hash="32e2e2f27bfa2d6228a5e5ea52e95a0d"/><file name="Parent.php" hash="d0c59f53b0fd3b31019c4880bef0236c"/><file name="Shipping.php" hash="174751e68b10d15292fd4781ef2b9b2b"/></dir></dir><file name="Collection.php" hash="2837a7f5177feee8ed29c2752cf661b8"/><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="9f781f34dd65a08fc2cc0393b8cf828e"/><file name="Parent.php" hash="7e56c2cb6ee40e91311fde8c75a72802"/></dir></dir><file name="Collection.php" hash="a320322759710dfe01b2a22fd79bc860"/><dir name="Comment"><file name="Collection.php" hash="c98f05f953d0bfb92abe7c48fd1c0706"/></dir><file name="Comment.php" hash="cf31a5278f7ae28cb40396279456d781"/><dir name="Item"><file name="Collection.php" hash="31cc31022439310311152f81706d8b06"/></dir><file name="Item.php" hash="44b44e47e85ac4defbce067f2a5efbbc"/></dir><file name="Creditmemo.php" hash="fa9d7d9e5a182aaf5be33f57ffa96fb9"/><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="17d2f6acddf70955340cd16ca123f790"/><file name="Item.php" hash="350b2e92d565e1ca8f136341f9dd13e4"/><file name="Order.php" hash="71b4e11cd8ce30f4e849daf82bda36f9"/><file name="Parent.php" hash="17014ef1c8c55460d585792240589b30"/></dir></dir><file name="Collection.php" hash="e4fd5d1f010a81a38d0f69e1e69999e9"/><dir name="Comment"><file name="Collection.php" hash="39bf207a29d25f4026cf562e32514eb7"/></dir><file name="Comment.php" hash="6c0a8c3af07163bbc67f1e455fa2e795"/><dir name="Item"><file name="Collection.php" hash="6fb21806efade3609d74ac362340e202"/></dir><file name="Item.php" hash="af4e2b636b26ad8552e9a39e7bb14ff2"/></dir><file name="Invoice.php" hash="9244fb3d79789b51056af4ca334bdd27"/><dir name="Item"><file name="Collection.php" hash="d0f1974f5df6d4d4ad8118a7a4a33331"/></dir><file name="Item.php" hash="ebfb18aa744fb65cd0bb4bcbcd3b0159"/><dir name="Payment"><file name="Collection.php" hash="f86601c550633f0b86184558fa65edb8"/></dir><file name="Payment.php" hash="017b137b936fff5560dc52ff7be4db19"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="485af88c697482dfdeb660fba19aba1d"/><file name="Parent.php" hash="0d5463f462b0d95c35de762516ec8d71"/></dir></dir><file name="Collection.php" hash="de45615f732677a52bfd52c37cb6303d"/><dir name="Comment"><file name="Collection.php" hash="95845b75c54ea2360803a22bf1547511"/></dir><file name="Comment.php" hash="7f635292f8d94b496d5d9a924e679797"/><dir name="Item"><file name="Collection.php" hash="ea423b588ed1cf35b7893260d85e5010"/></dir><file name="Item.php" hash="3400a881edb8ddbc6392fa8c4a2f31af"/><dir name="Track"><file name="Collection.php" hash="79151ee6ffe9fe4fa66036d1d549db63"/></dir><file name="Track.php" hash="cf89f156c74844a3fc5becf420270301"/></dir><file name="Shipment.php" hash="522f8dc832513471f7f187053e1d1faa"/><dir name="Status"><dir name="History"><file name="Collection.php" hash="9d3587f093d4f5f985571df4115ed8d6"/></dir><file name="History.php" hash="574b5234e98cdf2dd6c887956169efd7"/></dir></dir><file name="Order.php" hash="ab0a6a94a06aad7663068783775ea885"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="8a7d48caa3ebfe50e244016ffa8f6d51"/><file name="Parent.php" hash="c1b6a8ce250c28503037d446ebeb675f"/><file name="Region.php" hash="00e741ec4cc5a131e1227c87de3ba781"/></dir><file name="Backend.php" hash="47a248dade8bfaafa1aa8d9613c6c7b3"/><dir name="Frontend"><file name="Custbalance.php" hash="da8e0105b25c2db53884eabf680e51c5"/><file name="Discount.php" hash="461fc93850f71621932c0ace20c42c1c"/><file name="Grand.php" hash="5f1bb2676fed3d05e45b524fa331473e"/><file name="Shipping.php" hash="7dfb3b96b2fff10b016e6e38d84bd3ef"/><file name="Subtotal.php" hash="f6dec9c5f5033e17b497aa4d7403827b"/><file name="Tax.php" hash="e97883a76f504a91e3b2e25ac589c916"/></dir><file name="Frontend.php" hash="68416b77686a2cbaa742dafc35b97c6b"/></dir><file name="Collection.php" hash="0d1effb4746b5ef2731f8a3db77591d8"/><dir name="Item"><file name="Collection.php" hash="2b23c9b0fa7bc8a568ac10873fe644ea"/></dir><file name="Item.php" hash="3a359de393d4a2481eefad5ec951a6fe"/><dir name="Rate"><file name="Collection.php" hash="0a9e1a909e6dedf3fd011711ceeb6819"/></dir><file name="Rate.php" hash="d98592762b0bb5dbd074438cdf274e4b"/></dir><file name="Address.php" hash="6c57625623ba17c72f936dafcf354542"/><file name="Collection.php" hash="00b7beb8a10a8717031b80932582ab62"/><dir name="Item"><file name="Collection.php" hash="e706b468a9fc83aeb90c87231e73b808"/></dir><file name="Item.php" hash="0263186f0984a5776acaf8597b9f6bf8"/><dir name="Payment"><file name="Collection.php" hash="0c68fd9376d580ba31b083a9e05083ca"/></dir><file name="Payment.php" hash="3920ade27c8d49d90ccaa37785f3385f"/></dir><file name="Quote.php" hash="b35dbb3c3ad4f1d557ee3b48137f0c8d"/><dir name="Sale"><file name="Collection.php" hash="a05db285ef3378e726ecab7b7c610098"/></dir><file name="Setup.php" hash="d3b20ae6df83b255f7803e0ec1ddcbca"/></dir><dir name="Mysql4"><file name="Abstract.php" hash="b0db47393634ae2f2e3e43f731996aa4"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="877605c9d028346183f66a166fb80d97"/></dir><file name="Agreement.php" hash="a17834c35bf457593b1fd608c18ba20f"/></dir><dir name="Collection"><file name="Abstract.php" hash="2f9b09bf0929b54b6ed60f032fd6ef2f"/></dir><dir name="Order"><file name="Abstract.php" hash="3ee44859719a0d126f4f16dbe99546ad"/><dir name="Address"><file name="Collection.php" hash="6f9fd6530a6e0ab930a26e99787a1e62"/></dir><file name="Address.php" hash="d530f4c4bf6c216f13904b8f871111e7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="ccdc5106fea0b1d175a143442aa706e9"/><file name="Child.php" hash="ce3206207546abbc4e7e2d65ca268872"/><file name="Parent.php" hash="253a2ab63e2c7ba62a483764da207119"/><file name="Shipping.php" hash="5b41a69cbea2e558ccf12b15b95b916e"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="47f8ca61139eef629c833a69f0dc9425"/></dir><file name="Collection.php" hash="3b3cdd03bd52c7a6c662b8d81250a416"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="d7eae0947befb3406727cc6371bd5bec"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="90eeba23e00c6a7815baefe8c9f033af"/><file name="Parent.php" hash="9e1d0f68e5b5713fd554233b70a2cac3"/></dir></dir><file name="Collection.php" hash="13620d383b2db66173b8f0e28ab361bb"/><dir name="Comment"><file name="Collection.php" hash="93c787446d443e1fb947bc3eafc8f11b"/></dir><file name="Comment.php" hash="3efd0d6b04ff71dbe8747f8557010899"/><dir name="Grid"><file name="Collection.php" hash="8514c0d2572f47668736e9622cb1b747"/></dir><dir name="Item"><file name="Collection.php" hash="32078954b6ba46954b8bb76bb1fb7e9e"/></dir><file name="Item.php" hash="ca5e729c4f28926815cb2d35716dcd01"/></dir><file name="Creditmemo.php" hash="30a6bfe52bfd4c758c851f630a3ca79a"/><dir name="Grid"><file name="Collection.php" hash="d7621e63dc0f77fa94882507b558bf05"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="a29d3787865836132e83d266e79a8260"/><file name="Item.php" hash="40dc8b6364b0eb4742b55105331d8544"/><file name="Order.php" hash="ec82a177d214c96512f3556d11845b69"/><file name="Parent.php" hash="d2f24bdd157fe64e74177d3b8693e09b"/></dir></dir><file name="Collection.php" hash="8362cd59b4a7208afeae25642c921fbd"/><dir name="Comment"><file name="Collection.php" hash="2d3e26e2c5df7481c226d5fd9dc3e0b7"/></dir><file name="Comment.php" hash="4d68aca8967d97f04d462ff3bcba3f11"/><dir name="Grid"><file name="Collection.php" hash="6982b6cb3d2314cc9c9c9afda713327c"/></dir><dir name="Item"><file name="Collection.php" hash="09dda6d9c226fdad0bcb3d94de00216e"/></dir><file name="Item.php" hash="ee70addd50a7f6ac3719ceded067d40d"/></dir><file name="Invoice.php" hash="3da796261362ff3520542e936ac72d9d"/><dir name="Item"><file name="Collection.php" hash="5886223d56b9c5985913b035e9cbf789"/></dir><file name="Item.php" hash="8a97d0b600df39519ee5ffe53ccf48f6"/><dir name="Payment"><file name="Collection.php" hash="85a071a0702bec16e9280ad975b9e197"/><dir name="Transaction"><file name="Collection.php" hash="8970c3547e1966c415f8202d11d58c12"/></dir><file name="Transaction.php" hash="8f33aa78a64fe29bb1a2e8334fbd6b4f"/></dir><file name="Payment.php" hash="3c4c9266744a0fad5e4f2455a5722974"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="99d6cab63a21092408dff773054b9d93"/><file name="Parent.php" hash="50b6a40f22b9125e0a5f36e86db458fd"/></dir></dir><file name="Collection.php" hash="a059e54adb61bae5bfed655322ebde46"/><dir name="Comment"><file name="Collection.php" hash="b774124e32109950bbac93dea4588423"/></dir><file name="Comment.php" hash="f1dc455fe288891112e443a79bf53c18"/><dir name="Grid"><file name="Collection.php" hash="577564a98b72b6cd085165675705175f"/></dir><dir name="Item"><file name="Collection.php" hash="b6603794026494fd06fb5a4c45148fdc"/></dir><file name="Item.php" hash="711002d18fe28027f06ebc7a957aaabb"/><dir name="Track"><file name="Collection.php" hash="7611e9e72c1c8a3ab6e28bd69e4c7535"/></dir><file name="Track.php" hash="79e07fcce0ec1703777145ec544d0192"/></dir><file name="Shipment.php" hash="03d47ab43f685ece425f5638da9272fc"/><dir name="Status"><file name="Collection.php" hash="9f192ee27d9025ff9b4a767216c54d00"/><dir name="History"><file name="Collection.php" hash="48cfde1f1aa77484801117b25d14cce0"/></dir><file name="History.php" hash="d87bb0bf7e67f97ed88d574a1e934b94"/></dir><file name="Status.php" hash="21c7c1bc5c1a569118464f453f759c22"/><dir name="Tax"><file name="Collection.php" hash="9eded0afa051a25402911d17f881c659"/></dir><file name="Tax.php" hash="ccc2f221d2dfa06b63358daacb92bc52"/></dir><file name="Order.php" hash="c18b134589da38ec43c3bb0d82f9a91a"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="323ba6a863a0028ce315abead027d842"/><file name="Parent.php" hash="57dea111c8a4c38aa883c40cd5393e82"/><file name="Region.php" hash="657ab14d9fd351a8a047ba3ed756d13a"/></dir><file name="Backend.php" hash="20a973dec7d179b85d998275f1e06299"/><dir name="Frontend"><file name="Custbalance.php" hash="01da6eeb31194f578368e20e97bd1ce5"/><file name="Discount.php" hash="39955e5fe27a3668f5823859a8177cfc"/><file name="Grand.php" hash="ec54ee5503816d1ac68b77df348fb475"/><file name="Shipping.php" hash="24cbc84a2cef6b7579f6928f677f5ea2"/><file name="Subtotal.php" hash="0f576ad50ae1e87f41af1be267f7a970"/><file name="Tax.php" hash="a71555e6e0b97bc170fc2e5768b4f643"/></dir><file name="Frontend.php" hash="e9b14b0517b6dd3b202d19c039aedc45"/></dir><file name="Collection.php" hash="698f91405eac99e675da2ec5b0725f79"/><dir name="Item"><file name="Collection.php" hash="353e572a64eae0c4dd41247071a3bf9c"/></dir><file name="Item.php" hash="862d09a82f154ce69aa987eb072753eb"/><dir name="Rate"><file name="Collection.php" hash="94586c57fab25507f25517375b3fd6f9"/></dir><file name="Rate.php" hash="995bd0134fff2787b0b8582834b468a5"/></dir><file name="Address.php" hash="a0ce255d1e4df344e6a1cebb02b69d25"/><file name="Collection.php" hash="a54e42a302459a2ec0526d661ba3140d"/><dir name="Item"><file name="Collection.php" hash="5249b32713d5d80d6e419cc1e41abaed"/><dir name="Option"><file name="Collection.php" hash="7a08c0e8746cf374b68c6f4848b7ac52"/></dir><file name="Option.php" hash="7bbd8559002aa7cf3184a0ea60f7f02c"/></dir><file name="Item.php" hash="054f02aaac27f775de7286c652959d89"/><dir name="Payment"><file name="Collection.php" hash="a36deac36cd4cf30ed2c7ec66d4d082e"/></dir><file name="Payment.php" hash="c707e36f7b26fd5a1df4492fd7bf3243"/></dir><file name="Quote.php" hash="3694a2ec87135cb2f294dca9031a39b8"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="a2f16ce21d1d54bf58494eb7d889ee6e"/></dir><file name="Profile.php" hash="d79c55769f48e85709e6ed188d5a2fcd"/></dir><dir name="Report"><file name="Abstract.php" hash="251869ae0d7fab61e0f4398a0ee87216"/><dir name="Bestsellers"><file name="Collection.php" hash="ee0d2208c210d6a9cf8ddaf83c44328a"/></dir><file name="Bestsellers.php" hash="9176061a9d47038adf11bd5fc970f2a9"/><dir name="Collection"><file name="Abstract.php" hash="84c33f81cd1a5506b5989f296676e6fd"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="7fe5d21618431a6a48683b36c6898018"/><file name="Order.php" hash="d7a0958f14b0ae6d7469666505a32639"/></dir></dir><file name="Invoiced.php" hash="e6abb2a9f77d1951fd2433c44b8af3ee"/><dir name="Order"><file name="Collection.php" hash="d69baf4a6a4d2e47d2dc7b35cea0db63"/><dir name="Updatedat"><file name="Collection.php" hash="a925704447a04862aa6e760bc1c18106"/></dir></dir><file name="Order.php" hash="788ac7cfa70e0eeb2684c0675eb3b043"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="58420cb4a9e359195f587616d2379e6c"/><file name="Refunded.php" hash="37412528117ce7ae9544b5d2bf3264cb"/></dir></dir><file name="Refunded.php" hash="263fb59ceda14e4d836a3c544ff8857f"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="cec5e052f66d42a13cde5e36ab9a27b3"/><file name="Shipment.php" hash="c9581b73a854aa2f09df26d20e9b1141"/></dir></dir><file name="Shipping.php" hash="17c9236ac60fc0b991efdfbea2c7d630"/></dir><file name="Report.php" hash="77e1cf47540bb466e47447de3a972793"/><dir name="Sale"><file name="Collection.php" hash="d3d918f2b86c04b05244235c618d04c0"/></dir><file name="Setup.php" hash="034dd3a9f5b6b11ba008db9da36a3c96"/></dir><file name="Observer.php" hash="88b74b05c1d9c20a33ac3e09c5e35f37"/><dir name="Order"><file name="Address.php" hash="8916c4a42f48f388704a4facc5fee598"/><dir name="Api"><file name="V2.php" hash="53aecd75b1462122c4a5d80b6163cc50"/></dir><file name="Api.php" hash="9c7c6e95ff9d4808e31e9af6a9a8afdd"/><file name="Config.php" hash="7b62138f46b25e0f7ac47fdc02a59259"/><dir name="Creditmemo"><dir name="Api"><file name="V2.php" hash="33173dce34ec581719a9e1938d75037e"/></dir><file name="Api.php" hash="38f6d8318a71da652818390cb75d4bc3"/><file name="Comment.php" hash="cfe413b370dd450ef53986b75260b95b"/><file name="Config.php" hash="6df18821a105e506024d96cd383e73b2"/><file name="Item.php" hash="375c60679803b76dff4562329b8c5317"/><dir name="Total"><file name="Abstract.php" hash="46960310e82267bbb570745478b973cc"/><file name="Cost.php" hash="41b7062e0d7db18066d6b8634f3f33c4"/><file name="Discount.php" hash="2b70875f83ce8b84d55261a3e36ca75a"/><file name="Grand.php" hash="5480cb990680b2713db61ff7b3314e78"/><file name="Shipping.php" hash="efd1231c25d2b746d7edcafdeb466535"/><file name="Subtotal.php" hash="92e4788b748de21fc935430aa4a0c738"/><file name="Tax.php" hash="4b4d88cb5f840ba2099a1c3a654e7dce"/></dir></dir><file name="Creditmemo.php" hash="742ab7fc0bbcb80afd3e6e5964effabd"/><dir name="Invoice"><dir name="Api"><file name="V2.php" hash="3900df4ccc52977228c30c3e8b906034"/></dir><file name="Api.php" hash="fecb5690f768fc84ecdc296aee40ff73"/><file name="Comment.php" hash="df87e2a5bfd53856ee6280973f9fd99b"/><file name="Config.php" hash="cf03f276ce0dafd479bdd58aa06f53b4"/><file name="Item.php" hash="11425073c24ebf9eb613f123a0a32d52"/><dir name="Total"><file name="Abstract.php" hash="00ea50a41ad21f922b95cd08a5c8731f"/><file name="Cost.php" hash="3efa402ade37898b38b74f84adb89f7f"/><file name="Discount.php" hash="1529a1e0bf4a85474e17bec098339673"/><file name="Grand.php" hash="acc0bc6c08b724cd7d3d6fa0ab19cd48"/><file name="Shipping.php" hash="98c2805c93e8e1c89d3b3aefbf5ed7c3"/><file name="Subtotal.php" hash="7bdd77b2c41d4b74d45c9cbbc58ef80e"/><file name="Tax.php" hash="f092d289deca0c49b99ca6f368ca22bd"/></dir></dir><file name="Invoice.php" hash="0aa1fa01567a69372f75fa041c5d421d"/><file name="Item.php" hash="e6699d0a2621e12e151c26b9c38f6ccb"/><dir name="Payment"><file name="Transaction.php" hash="387b5696d397809fa31d850e92c43116"/></dir><file name="Payment.php" hash="86fca1ca2b2b314d7dbb0cd12f0aa1ba"/><dir name="Pdf"><file name="Abstract.php" hash="1efbaf2a4c3c19857662423556eaf6d1"/><file name="Creditmemo.php" hash="054630d48a754d8e9b83cdd22a92e2fe"/><file name="Invoice.php" hash="b2fc61c9816a9c7486cad2612efdf61a"/><dir name="Items"><file name="Abstract.php" hash="a87743efef9cc641171c700c086d6c92"/><dir name="Creditmemo"><file name="Default.php" hash="d7d0b9417f57164c3b760911aebc3f1b"/><file name="Grouped.php" hash="8a2ac12006fe8ed7ad728646f115f8c8"/></dir><dir name="Invoice"><file name="Default.php" hash="802dd4b102870533abefc3d7cb971d42"/><file name="Grouped.php" hash="b881d57c8e647a7a65dbdeb16a55abd1"/></dir><dir name="Shipment"><file name="Default.php" hash="bcdd58a6b6909374eb49814affd3d71d"/></dir></dir><dir name="Shipment"><file name="Packaging.php" hash="15c3cacfd1811f8e6fe7249ca987e617"/></dir><file name="Shipment.php" hash="4c64a7963af25e192d96a7fc11042521"/><dir name="Total"><file name="Default.php" hash="2405a97489855173f3df6a212dec9fe5"/></dir></dir><dir name="Shipment"><dir name="Api"><file name="V2.php" hash="7da2711d8341b3d03c58ec0a147516a2"/></dir><file name="Api.php" hash="6733ac7ae00096ef48e80f7ae8d96c7b"/><file name="Comment.php" hash="6ba3d5f7fd14212d41e75c510bb54658"/><file name="Item.php" hash="dd558f3d378bfd1b06c38e320eb0aca8"/><file name="Track.php" hash="0d132e1caaa80ea2b1e23cb3ff17a13a"/></dir><file name="Shipment.php" hash="9563c1a893b2e490dc0fcc6538a40576"/><dir name="Status"><file name="History.php" hash="56c69ef7957d32fac4e53fed47f672cf"/></dir><file name="Status.php" hash="d1c61f6ce1621935d9f2652cf2dddee4"/><file name="Tax.php" hash="adcc923fa9c2c6e2f862cefa1445ec51"/><dir name="Total"><file name="Abstract.php" hash="31cb81413da3aa688c15f2d31763561b"/><dir name="Config"><file name="Base.php" hash="7a30dcb898e00ad6dbd1044dceba54d9"/></dir></dir><file name="Total.php" hash="70d33c7cf4e96e3d5042f54a1304945f"/></dir><file name="Order.php" hash="05337465ddb568649d304c818d2d8814"/><dir name="Payment"><dir name="Method"><dir name="Billing"><file name="AgreementAbstract.php" hash="858f28ccdb7efb39531e48b6086dc1f7"/></dir></dir></dir><dir name="Quote"><dir name="Address"><file name="Item.php" hash="13167c8797b8d40f7624503edb80c42b"/><file name="Rate.php" hash="3d8160aaa1535a5ecc3bbddc3e5cf60b"/><dir name="Total"><file name="Abstract.php" hash="998eb1780efd04ae4fb2dfeb9b1da06d"/><file name="Collector.php" hash="bd9e85908788e72d1bfdd391caf9c4c5"/><file name="Custbalance.php" hash="ffaef95a9108f670fc8e25628b69da14"/><file name="Discount.php" hash="8d636214de72db05ba44c1a4b9896ef9"/><file name="Grand.php" hash="aa41c6640092a0a48ef4dd6feb0eaa03"/><file name="Msrp.php" hash="fff13c6912b5ae52cf139fc08733331b"/><dir name="Nominal"><file name="Collector.php" hash="953c4bd896cffa053253ae9bd46d7413"/><dir name="Recurring"><file name="Initial.php" hash="60476d4d1380a5bbb33be228b5e1b125"/><file name="Trial.php" hash="81e47180d95ee44b26761c2488763d67"/></dir><file name="RecurringAbstract.php" hash="068fcca6018196d6c9a4a8dab5cbfea8"/><file name="Shipping.php" hash="c6a723be5898cb394f5c5ece5ca93b2b"/><file name="Subtotal.php" hash="149b0984813abbcab03ebf4cdd78ce78"/></dir><file name="Nominal.php" hash="8328b2300cf771afa0f5f84a681d5f20"/><file name="Shipping.php" hash="bd4dd3b11a26f2e810f66d55953fb030"/><file name="Subtotal.php" hash="81110672832ae415ca383a900844ed2a"/><file name="Tax.php" hash="8faf93c094702542955ab4baf50cfe2c"/></dir><file name="Total.php" hash="d836886553dda5c5c26265c8ac0ea359"/></dir><file name="Address.php" hash="ae8cf173f9312f2add53a18783ef7933"/><file name="Config.php" hash="cc48d9cfb97d5b05e2df40e82cf97ac7"/><dir name="Item"><file name="Abstract.php" hash="35895a3a1c1492a971bcb03ba3983ba6"/><file name="Option.php" hash="505a1627ea636d6b84604ba6d05562a2"/></dir><file name="Item.php" hash="40debc8bc6fbc6082920941891de8fb5"/><file name="Payment.php" hash="f2f75f09e0ec0b96510f4151be8969c7"/></dir><file name="Quote.php" hash="c7b11d2b08b94f0a0a3c9e711487a325"/><dir name="Recurring"><file name="Profile.php" hash="6523889790dbc100ab3c90ca32785eaa"/></dir><dir name="Resource"><file name="Abstract.php" hash="06798d2bae372e5d5744318e627a7d76"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="3a69e98730657ebf9b9da9086a225c6b"/></dir><file name="Agreement.php" hash="8e9efd873709fdd8ae6cf0f6f4fa162f"/></dir><dir name="Collection"><file name="Abstract.php" hash="ce9aec922526609215f1038782f9e777"/></dir><dir name="Helper"><file name="Interface.php" hash="03049c9d6a48a70a6ff3d2c1ff64cde1"/><file name="Mysql4.php" hash="387b0b29e187a32aeb3cf47b2706f5cf"/></dir><dir name="Order"><file name="Abstract.php" hash="c6bcdf9d41e749010b4fff0262f98390"/><dir name="Address"><file name="Collection.php" hash="b92fd2f5b157dd6546763dc83e50e00c"/></dir><file name="Address.php" hash="c6f6b1f5bb03ce120aac229a9e10181c"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="d8a6abf75315b4230695e17706d1e22c"/><file name="Child.php" hash="a17ee5ee0ce105ba44fe088f778c8ba3"/><file name="Parent.php" hash="94a1d88f86e59d4256164d592876cca0"/><file name="Shipping.php" hash="18ca118303231681e53ece31d15d549c"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="4dc3ee4846909bcf704476a2785ce51d"/></dir><file name="Collection.php" hash="15582c6d423aa21d838709eb80bd0732"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="8e4c6ca0755eb57a6787eb92ea690bbb"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="43d42de1f5b84c38f65f0848fd489a37"/><file name="Parent.php" hash="78274d33ccf1d07c9552c791d2ace796"/></dir></dir><file name="Collection.php" hash="c5de7575c4e7f77e45f5e32ff930f418"/><dir name="Comment"><file name="Collection.php" hash="b6ce7282472670bc07ed65db12ad0c4e"/></dir><file name="Comment.php" hash="55125fc902f1b341d8d55d0a5197ac5b"/><dir name="Grid"><file name="Collection.php" hash="c2d7c0562273dea783196cfdebd1a0de"/></dir><dir name="Item"><file name="Collection.php" hash="9ea88230bb081da061d0c950eb32f015"/></dir><file name="Item.php" hash="d2bfc4c13fa06d03ccbff896522d8470"/></dir><file name="Creditmemo.php" hash="ad7a44336cf27fecbdb0b0e42168b259"/><dir name="Grid"><file name="Collection.php" hash="b97470cd6f0d203e5e18912b614f08fd"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="7c361107c04f9622b2404ded426b3931"/><file name="Item.php" hash="808ee216324a1342f4188cc1642c00cb"/><file name="Order.php" hash="9b25cb53b48355c923674af68226e44e"/><file name="Parent.php" hash="74f2d01b5b0c72e3303318bd56617401"/></dir></dir><file name="Collection.php" hash="22a1357726e3c914d38fe54ab9981543"/><dir name="Comment"><file name="Collection.php" hash="9177dbc3dd739beddacd6cd531d91d9a"/></dir><file name="Comment.php" hash="e7df04fca8aa7c24ec56bc8560c503ae"/><dir name="Grid"><file name="Collection.php" hash="bed2f149ed5df505d6a196d68b5b1301"/></dir><dir name="Item"><file name="Collection.php" hash="e3360d66615e407be221d97d179fe044"/></dir><file name="Item.php" hash="57bd03e9b419fc15edb75b04c09004a2"/></dir><file name="Invoice.php" hash="4ce11cd9dd6d5ee7bb373cbc958b521e"/><dir name="Item"><file name="Collection.php" hash="af905f388ddae3eec6b1ab297379205b"/></dir><file name="Item.php" hash="512defaeaed0f1a8d00804df39e3aec6"/><dir name="Payment"><file name="Collection.php" hash="02da4d7775cc4013e9c16aabe3589997"/><dir name="Transaction"><file name="Collection.php" hash="bf937a25f0c7df1031a09433c9842c4b"/></dir><file name="Transaction.php" hash="1a64212246c615d53b8a8afd0eb8d932"/></dir><file name="Payment.php" hash="f6aad82c2999d65ff80acf09fb23a7cc"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="3bc1895d0f5e7ca581ee4e8d0fff6bb8"/><file name="Parent.php" hash="8b03ebab28ae10bcabd87b464cf02ab1"/></dir></dir><file name="Collection.php" hash="f87c1eba0c18fe329589998ca3516b73"/><dir name="Comment"><file name="Collection.php" hash="1b28c7f3ae35c30a413e69138ce56791"/></dir><file name="Comment.php" hash="e9a097c3f151fc3499455278f6f151da"/><dir name="Grid"><file name="Collection.php" hash="b419fb2d905b2ce911c304641b586c8c"/></dir><dir name="Item"><file name="Collection.php" hash="f8fbd616c36db514ce5280388d157c53"/></dir><file name="Item.php" hash="3a693ede88944e180463e241c3bf1d75"/><dir name="Track"><file name="Collection.php" hash="f092f45120fb61b7eca9b31a5c45350f"/></dir><file name="Track.php" hash="886bdcdfd193a9a233428f471e7f3831"/></dir><file name="Shipment.php" hash="afc9386f4ebb3ca7a5a4b4762f5101b2"/><dir name="Status"><file name="Collection.php" hash="8c9bbd30a771da83c9874b334c7020a5"/><dir name="History"><file name="Collection.php" hash="e94c4590c682e89d57fd22d3464a9b29"/></dir><file name="History.php" hash="26fe553862db8065db57c697ae82cfef"/></dir><file name="Status.php" hash="f49eee0230598a22e8985ccd5700e29c"/><dir name="Tax"><file name="Collection.php" hash="4ae4b3ee863688a1ebc506443a6d2606"/></dir><file name="Tax.php" hash="c1a9f6c1b5d5d73182d0d932f7300e59"/></dir><file name="Order.php" hash="0fa2698612cf4622c07e36e087b3cd8d"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="fb22141b138c5e0e50513f15bc26a7ac"/><file name="Parent.php" hash="16d8bd420feca1b901d5e04d773ad618"/><file name="Region.php" hash="e6a34fade1af2de288cfdbac10923a5a"/></dir><file name="Backend.php" hash="91e5c98cda7d74c18ce94468049a4d9b"/><dir name="Frontend"><file name="Custbalance.php" hash="d3bb99b3eb04a9015acb64818d348156"/><file name="Discount.php" hash="1ac67dd5a166a2beebd5e5e28a3cdfa3"/><file name="Grand.php" hash="5390b3419a7b7ffbdfea5a5d461a74b0"/><file name="Shipping.php" hash="b90e09fbec681375c4fe797f5ba05e1e"/><file name="Subtotal.php" hash="b548298ef6284d214b77ce28bbcd105f"/><file name="Tax.php" hash="a0bbbd4cd0a823a1a03b6d2b6d05c75b"/></dir><file name="Frontend.php" hash="3e145300f6c2bbc7da8065ed2127b7fd"/></dir><file name="Collection.php" hash="614c9e681787b9e07926a8b2db538fe9"/><dir name="Item"><file name="Collection.php" hash="717fce4bb8b5be14d6804931fdedbea2"/></dir><file name="Item.php" hash="df52f7b5f964f968d2a2cbab2a20f850"/><dir name="Rate"><file name="Collection.php" hash="b1a6d36d4d0deb3514e1a710ba0964e2"/></dir><file name="Rate.php" hash="73c20b025222353dcefb33539c84a496"/></dir><file name="Address.php" hash="2b3cff37667b5609b9b93165d48dc5d7"/><file name="Collection.php" hash="c808ab68be9ead5f47720c82a60f78a7"/><dir name="Item"><file name="Collection.php" hash="666f34fcb64d15b4d64cae4266980547"/><dir name="Option"><file name="Collection.php" hash="2920aea6b88281281aeb58884e44ce54"/></dir><file name="Option.php" hash="d34f1dc3bc8eb9f3bb7bbd1f4e198924"/></dir><file name="Item.php" hash="abca577432cfb2cc219ccce735c11f5e"/><dir name="Payment"><file name="Collection.php" hash="50e02948cdcb847c5ba330fcf4a0a736"/></dir><file name="Payment.php" hash="c8aa350b64846464e465b959007382dc"/></dir><file name="Quote.php" hash="63add8e0f1afbf189ec39289b93ce644"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="c86282d515fe55cec5d91d121d6b2fe0"/></dir><file name="Profile.php" hash="354252e2618207c5aae3e77845da39cf"/></dir><dir name="Report"><file name="Abstract.php" hash="42e7075a7e81c8d013fa51f8dc8d8fb7"/><dir name="Bestsellers"><file name="Collection.php" hash="308e0ea60f24f45a5fb6ccf8a321b29f"/></dir><file name="Bestsellers.php" hash="ec935ec54f750a3337955d11124acb73"/><dir name="Collection"><file name="Abstract.php" hash="4d979463398fa003e2bd7245be2a2349"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="9f3886e190425851e71520cc7128eb36"/><file name="Order.php" hash="42db6ff58f5e6e5c73a09c2ec946d9f7"/></dir></dir><file name="Invoiced.php" hash="73005cba3e5df382cea54947a09a535b"/><dir name="Order"><file name="Collection.php" hash="734498dccb843dc88715bc0a3b83f04b"/><file name="Createdat.php" hash="fa0b3c1186587c6fca3fe7a84fd040c5"/><dir name="Updatedat"><file name="Collection.php" hash="dab368a79fc05593c94d52367641feb5"/></dir><file name="Updatedat.php" hash="94f641b4589c3a81286c926689500b69"/></dir><file name="Order.php" hash="c87912b9d48633e6520d586319d0cd77"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="41df56a612e9ac30fb1f23bab73679d6"/><file name="Refunded.php" hash="fad2658a14ad11de6be64791f1962387"/></dir></dir><file name="Refunded.php" hash="300935148418cb44d7303908d3377e57"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="88f0441418c4588c6f9cf4c4f3388a77"/><file name="Shipment.php" hash="4c320e03fbfbd7f64347015a3746d682"/></dir></dir><file name="Shipping.php" hash="8ee5cc8cd06446c300316ea80ba6bdc3"/></dir><file name="Report.php" hash="00e8090be521bae44556e85278a8a50f"/><dir name="Sale"><file name="Collection.php" hash="72c86de402df84a75807c5ee1808138e"/></dir><file name="Setup.php" hash="16b2ee3f2c3251ce26b9bf0202ca0bed"/></dir><dir name="Service"><file name="Order.php" hash="79c00b67105e67eed86edfa5c3989704"/><file name="Quote.php" hash="96c5e6a97ce62533f351d4959b400c42"/></dir><dir name="Status"><file name="List.php" hash="a95825954b50003525fb82228a9292de"/></dir></dir><dir name="controllers"><dir name="Billing"><file name="AgreementController.php" hash="6fbfc7001982d36aa06483c90898b0ed"/></dir><file name="DownloadController.php" hash="49594a42bf13124463382faf965394fb"/><file name="GuestController.php" hash="728699f2a41bbb6a026ef8e2e55653ff"/><file name="OrderController.php" hash="673ae998510996c015ae21e18da60958"/><dir name="Recurring"><file name="ProfileController.php" hash="0cc8c8d91d19ea96a1419fddc432d5b1"/></dir></dir><dir name="data"><dir name="sales_setup"><file name="data-install-1.6.0.0.php" hash="6ab71ddde7cb62e41cd3978f77ab7b2b"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="24bc0e8094427988f236bbfb8998e5ae"/></dir></dir><dir name="doc"><file name="invoice.txt" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="order.txt" hash="5dce876530c94ebbedbba7a234c23846"/><file name="order_actions.HTM" hash="b955e61bff753ea0534f907ef6ba9bb6"/><file name="quote.txt" hash="55ecfbdd576958ff1b1fbf16957ba9df"/><file name="test.php" hash="75f5888687bd149423ad2262dc6be83d"/></dir><dir name="etc"><file name="adminhtml.xml" hash="64f3215b378e7cce530d2bbc1b5770ec"/><file name="api.xml" hash="20eba043e5bc0f7d826378f9239da63a"/><file name="api2.xml" hash="2dd8189de81a1cee9acccdb63d6dfd3f"/><file name="config.xml" hash="decb9d37095adc9aa779c392c77d9ad7"/><file name="system.xml" hash="cbe84ff8e194da1d5f619f88618e52aa"/><file name="widget.xml" hash="1ea392cd1357530eb3fb76396fde54b4"/><file name="wsdl.xml" hash="ed13de1dde6408ab508892374ef57b81"/><file name="wsi.xml" hash="6aba2f44765955ec8bcd1afcebfb0800"/></dir><dir name="sql"><dir name="sales_setup"><file name="install-1.6.0.0.php" hash="2c287c2fe9601ef04ff961b56c2967f9"/><file name="mysql4-install-0.7.0.php" hash="7d0d1fea503a57617f35fb7d4321e64e"/><file name="mysql4-install-0.8.11.php" hash="0f7b7ad16927275d67466655799f63f5"/><file name="mysql4-install-0.9.0.php" hash="df39d6b00a00297dde8bb809a3ce8d36"/><file name="mysql4-install-1.4.0.0.php" hash="ab55fbc1f42b45f62a8e25b00f3f8ec0"/><file name="mysql4-upgrade-0.6.2-0.7.0.php" hash="4b377082c213d2bd5fc011024ce5d38d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="66dab89a7376dd328305a3c2c4363484"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f626b8de75933ed846c8fc1ab7989b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="faf0a62c9033c06dc4142661630347f0"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a582cc340f96512440da05c34d4efdc3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="4386c0a34c4ab15be88788dddd68eff4"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="b829b43451acd8d04045ec093c8b4dd2"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="328d56f9f7ebabe79ade0a1621e41d71"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="d2b6362bd9f351691adc12b4319351ed"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="17900afa4f64d66a9ac672f276912ea8"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="5ee57dce22f85605a6a6102faba2d90a"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="baec5a1400bf8826769266e1322503a0"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="f9cd2aecddc0fb919155cf2b7b62be10"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="f120725f256959ac634271b2352c0683"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="8076b36a75778b6545d82d7c0eb75576"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="8792c0f1b2e7545e52d0b8549ce11739"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="d1861afa10be4a63b988775d63b89eac"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="e41a5cb53beb7bdf5f85906af0e64af3"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="cdfd46b4c76f91d81832bcbac76d1f7e"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="1ef6d4fc564bef1e8883d9c55dda1d9f"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="8cd0c4b432833a8480e855822e182db0"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="36548ad7e5f7008c4feebc1ca0125449"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="7fb800a27788be2681a07dcb9e7138a3"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="eb14adbff9fc9add9d41ee53b80e3f1f"/><file name="mysql4-upgrade-0.8.28-0.8.29.php" hash="acb795a8927fb7eb42e26cc631b9eb9b"/><file name="mysql4-upgrade-0.8.29-0.9.0.php" hash="51700bb3315b81683d5297393915ba5c"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="6f76404ed26c596214b76cfa7acbd2fd"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="291a933edceb5b0d0bf820d889a41dfd"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="d1d401880667acde9910dbd94baf45df"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="a08c394d9ee9e3b603271c87d9cdccaf"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="eee0131d0c1ff81d6a8217024328fd93"/><file name="mysql4-upgrade-0.9.10-0.9.11.php" hash="7dcad0f3276ab1c90aec34066cdf9af2"/><file name="mysql4-upgrade-0.9.11-0.9.12.php" hash="1419527e1368381becf382e165974eca"/><file name="mysql4-upgrade-0.9.12-0.9.13.php" hash="106cc11270541b4ad03bcf01da097a08"/><file name="mysql4-upgrade-0.9.13-0.9.14.php" hash="9a544c38081d67a9bf7ada5eea628ae6"/><file name="mysql4-upgrade-0.9.14-0.9.15.php" hash="3d94dfc65777523496ba202ac5481a32"/><file name="mysql4-upgrade-0.9.15-0.9.16.php" hash="288e17dfff62ec6e15de30218d96a4f3"/><file name="mysql4-upgrade-0.9.16-0.9.17.php" hash="a269dc8079c9566e5be0f4bab75379bd"/><file name="mysql4-upgrade-0.9.17-0.9.18.php" hash="c0a0fdde0cbb71fd548d2965e01ab3ea"/><file name="mysql4-upgrade-0.9.18-0.9.19.php" hash="be7b8ccda6a3e658ea86e0f2d99ee020"/><file name="mysql4-upgrade-0.9.19-0.9.20.php" hash="f6272f05d9077b84f9e9c5724c84b783"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="b6240c3ae6f61375f6723735345f3c7a"/><file name="mysql4-upgrade-0.9.20-0.9.21.php" hash="80230b5d45321b886002b4783a1178c5"/><file name="mysql4-upgrade-0.9.21-0.9.22.php" hash="9c2be0b2fd92f326dcff1a2425d255a6"/><file name="mysql4-upgrade-0.9.22-0.9.23.php" hash="71dc008ec0b1e195f853113329944b6c"/><file name="mysql4-upgrade-0.9.23-0.9.24.php" hash="ad08f3386682ab27c86fc9bfbd91f8e3"/><file name="mysql4-upgrade-0.9.24-0.9.25.php" hash="1dc0d317074dea066f265a40d00ed6f7"/><file name="mysql4-upgrade-0.9.25-0.9.26.php" hash="d69e73a174d61eefe0034c148cd09472"/><file name="mysql4-upgrade-0.9.26-0.9.27.php" hash="58353aafa8bcdb32a6d64184b6a3d60b"/><file name="mysql4-upgrade-0.9.27-0.9.28.php" hash="0213f58c16ab8bf2485bae528140ba69"/><file name="mysql4-upgrade-0.9.28-0.9.29.php" hash="da5ef2d5d6e6cfd6ef0d5e44136029a5"/><file name="mysql4-upgrade-0.9.29-0.9.30.php" hash="5c376558e9f329281c8363322f05e45a"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="fb67ff85b5b8e395e0e11598f2e202b7"/><file name="mysql4-upgrade-0.9.30-0.9.31.php" hash="0e4bc71fab792ede8edb992839b7fa66"/><file name="mysql4-upgrade-0.9.31-0.9.32.php" hash="59aa185b9b61d345081a24913f67d87c"/><file name="mysql4-upgrade-0.9.32-0.9.33.php" hash="f742c43458fbbe3cc4ecaf9679b444b9"/><file name="mysql4-upgrade-0.9.33-0.9.34.php" hash="ed2650dacba9c9c315b1bd15399ce8c2"/><file name="mysql4-upgrade-0.9.34-0.9.35.php" hash="4ea762659260ddb6ef8521fa1ea59af3"/><file name="mysql4-upgrade-0.9.35-0.9.36.php" hash="43ebb2aa25a9302eaad2fe67e29e187f"/><file name="mysql4-upgrade-0.9.36-0.9.37.php" hash="5eef7f246dc3135de09fa4ad63668236"/><file name="mysql4-upgrade-0.9.37-0.9.38.php" hash="7f1264d789044b4e0d53d88d6fae9aad"/><file name="mysql4-upgrade-0.9.38-0.9.39.php" hash="394b1c87ec14026fc9ec73a7aed8d164"/><file name="mysql4-upgrade-0.9.39-0.9.40.php" hash="f525b598b5e6a411e0fbf78f3e698b97"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="ae0c33db1187c63db22e3abb9b135e92"/><file name="mysql4-upgrade-0.9.40-0.9.41.php" hash="9606fd627ca520b83a8cbaa1af210f36"/><file name="mysql4-upgrade-0.9.41-0.9.42.php" hash="e3f73f0616866b38d27b455a29c884ef"/><file name="mysql4-upgrade-0.9.42-0.9.43.php" hash="86ae3db2278241132ecf0d78e94e4a6b"/><file name="mysql4-upgrade-0.9.43-0.9.44.php" hash="634530214656d52e0ebf1bc1796ba820"/><file name="mysql4-upgrade-0.9.44-0.9.45.php" hash="0ef1f74e5ff76cbdb77ef5c1cf1cff54"/><file name="mysql4-upgrade-0.9.45-0.9.46.php" hash="c836ec8263903c699810ed331018cdf2"/><file name="mysql4-upgrade-0.9.46-0.9.47.php" hash="c57f7c39b85e675a294487970842bf96"/><file name="mysql4-upgrade-0.9.47-0.9.48.php" hash="b15d0fe3d2da3fd72f11960ebe3944f4"/><file name="mysql4-upgrade-0.9.48-0.9.49.php" hash="2a21dddd1ee15ae790005478066c7e24"/><file name="mysql4-upgrade-0.9.49-0.9.50.php" hash="6cdb649f2797ab3dbe3609f64a2940fe"/><file name="mysql4-upgrade-0.9.5-0.9.6.php" hash="be8975bf7f0e7304212c2aaff5d9b23f"/><file name="mysql4-upgrade-0.9.50-0.9.51.php" hash="9a624fe9a93a011ea20fdc38f5dab386"/><file name="mysql4-upgrade-0.9.51-0.9.52.php" hash="97a685809fe84907429291f0d8a7da21"/><file name="mysql4-upgrade-0.9.52-0.9.53.php" hash="6b592cc19f7243afedefec86dcb2a314"/><file name="mysql4-upgrade-0.9.53-0.9.54.php" hash="67a7688245f2021ed2b9a421e483cc53"/><file name="mysql4-upgrade-0.9.54-0.9.55.php" hash="673b59dd7062eb7610d5a4f1237ad7a1"/><file name="mysql4-upgrade-0.9.55-0.9.56.php" hash="5665cbaa78fc32405f927db451b57b1d"/><file name="mysql4-upgrade-0.9.6-0.9.7.php" hash="6075078eb301b31f123ac710e0a2a0d9"/><file name="mysql4-upgrade-0.9.7-0.9.8.php" hash="a6087a1421def6bbe443c54ed7c85a8b"/><file name="mysql4-upgrade-0.9.8-0.9.9.php" hash="a803ee3e2911b1f245dd0549369ecc9f"/><file name="mysql4-upgrade-0.9.9-0.9.10.php" hash="2639b36ba32deb87f752d022d588078f"/><file name="mysql4-upgrade-1.3.99-1.4.0.0.php" hash="709b954c683e80cf4526303870128d82"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="6e96cade5538a2e661b1cdf8c08a7d44"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="c63f548243fce20ee961f6f80435bea3"/><file name="mysql4-upgrade-1.4.0.15-1.4.0.16.php" hash="88f689b208a1702ec4facf6e2b5ab134"/><file name="mysql4-upgrade-1.4.0.16-1.4.0.17.php" hash="3f5527bc6f1c015e3007ec2b43f25f95"/><file name="mysql4-upgrade-1.4.0.17-1.4.0.18.php" hash="a21261050a55e7b580ef646d1a0bd314"/><file name="mysql4-upgrade-1.4.0.18-1.4.0.19.php" hash="8d99789daac557da4ced224d36635e00"/><file name="mysql4-upgrade-1.4.0.19-1.4.0.20.php" hash="6f339125108f34c0b5477d214963d32a"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="740256606f0d22e7d2d4a1f8896c0b52"/><file name="mysql4-upgrade-1.4.0.20-1.4.0.21.php" hash="25cc7a47798177c4f52cf387a67125f7"/><file name="mysql4-upgrade-1.4.0.21-1.4.0.22.php" hash="f2ec84706e64018a70c0198a560bb917"/><file name="mysql4-upgrade-1.4.0.22-1.4.0.23.php" hash="9c6771fc168bece647cfc6c9fd4b478e"/><file name="mysql4-upgrade-1.4.0.23-1.4.0.24.php" hash="49febdd803be93c62dc09e51bdd330f0"/><file name="mysql4-upgrade-1.4.0.24-1.4.0.25.php" hash="d5fbae1bd7d9d45a6a284f8e93ae8314"/><file name="mysql4-upgrade-1.4.0.3-1.4.0.4.php" hash="303dd6693f7160546d6c1aad96d1348c"/><file name="mysql4-upgrade-1.4.0.4-1.4.0.5.php" hash="68ddd54ec15ac6f60213215682176f37"/><file name="mysql4-upgrade-1.4.0.5-1.4.0.6.php" hash="784a77ef434acf0ebe803805a213876c"/><file name="mysql4-upgrade-1.4.0.6-1.4.0.7.php" hash="2c560f9f57454ec7130e6c293cbf5266"/><file name="mysql4-upgrade-1.4.0.7-1.4.0.8.php" hash="357db82d9b817ecea185abaaeb70d317"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.15.php" hash="cdcd4d6492a5c27b73b5b1b3b9ac8d4a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e8356d6a48d76369b34f6e8bd27dd816"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="dfd84a2a8044c259c6f6e7feea9a5de7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="6ac3f9c8119c28fd6796dc98ec54e82a"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c83205c28df3a6063f268f11195d27a8"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="3bbd8e0ff9448fa2d0bba25ac87b8492"/><file name="upgrade-1.6.0.4-1.6.0.5.php" hash="3b963ab1fa610c36577e8e43b279471d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="0d6e967b2a6bc110e143171210c80e54"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="2eaf612b1ddcf939fec17e441c29c08e"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="ef8e890ad206740f2c9d72803f30d063"/><file name="upgrade-1.6.0.8-1.6.0.9.php" hash="9d5a988492bd42371c47ee69186f7150"/><file name="upgrade-1.6.0.9-1.6.0.10.php" hash="40feccfa23344470891176db52fb26ba"/></dir></dir></dir><dir name="SalesRule"><file name="Exception.php" hash="462c8803b4baa19dc11ed76cf231a786"/><dir name="Helper"><file name="Coupon.php" hash="01e644f9fe0632bfb43cc46139af99f2"/><file name="Data.php" hash="0de3ba8633aa6d88b2696a28727b47eb"/></dir><dir name="Model"><dir name="Coupon"><file name="Codegenerator.php" hash="d8ac08012695de7a731cd66de91c6257"/><file name="CodegeneratorInterface.php" hash="af2ace052c52d6a73801866cc77db152"/><file name="Massgenerator.php" hash="37cea27a50d91b2aa86986e52231d31e"/></dir><file name="Coupon.php" hash="27ddc5154f825c75ca366042e2385ae5"/><dir name="Mysql4"><dir name="Coupon"><file name="Collection.php" hash="334608369ac389b1b67def7ada1aa5e0"/><file name="Usage.php" hash="40be9a4493b0936c1111ea7991f912b2"/></dir><file name="Coupon.php" hash="7844b0bc3fdb9de95382c1b12421123d"/><dir name="Report"><file name="Collection.php" hash="384fe7d3e3777b6233791bcb7a0e5a2e"/><file name="Rule.php" hash="7b9f3131640951ab7ddfcf8316ba78b0"/><dir name="Updatedat"><file name="Collection.php" hash="fc1d0841db7b9eebe8c15a18f694a742"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="8b5900d5125b47cbb540a6e2ccf47f41"/><dir name="Customer"><file name="Collection.php" hash="9cd01232278163f711a5c5283f94a21e"/></dir><file name="Customer.php" hash="4d45597acba3e88a0eb04b69349b9c68"/><dir name="Product"><file name="Collection.php" hash="4cc4b5b1fdf0b3a832bb7859288b303e"/></dir><file name="Product.php" hash="53b758f2c61474ba10c87c256e108314"/></dir><file name="Rule.php" hash="eb958a1b99441e8912d1d46510feeaf4"/></dir><file name="Observer.php" hash="4364e6fa8639634d504f66bbcc3cf808"/><dir name="Quote"><file name="Discount.php" hash="e41ec653892d0e8ecf82d9a52b62c676"/><file name="Freeshipping.php" hash="b035df813ef118ff1a1fb5ed875083f3"/><dir name="Nominal"><file name="Discount.php" hash="68a50a271796a47f8f55f2e7bad7d28a"/></dir></dir><dir name="Resource"><dir name="Coupon"><file name="Collection.php" hash="31b1a8e0fa51a8923ead28d407bf9c05"/><file name="Usage.php" hash="d7b327e2e3222cef7a55fd4f9e682e44"/></dir><file name="Coupon.php" hash="15b26e3aa1646ee2878b6bf46ab7bbae"/><dir name="Report"><file name="Collection.php" hash="e9236e12f64f8cdcaa8d8fb2a1224be4"/><dir name="Rule"><file name="Createdat.php" hash="d4d03fad7d85d3691dde82114687797a"/><file name="Updatedat.php" hash="5dfd0e8a15d115a4c14b2973415f0825"/></dir><file name="Rule.php" hash="505b8920f90d7af5cf09e815e5730a93"/><dir name="Updatedat"><file name="Collection.php" hash="a0f90a993ed70fd1adda36dc1a66ed1e"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="771b2c8b33d233eb6d9bce7a7f880e7a"/><dir name="Customer"><file name="Collection.php" hash="bc371db1391974074a8aa8a8b719c4bb"/></dir><file name="Customer.php" hash="bb7ce9191d72f004a44013641bf38ac4"/><dir name="Product"><file name="Collection.php" hash="a8a62df60340b9a20035fb5c88872457"/></dir><file name="Product.php" hash="743ac84f509801340ac92952d97521ef"/></dir><file name="Rule.php" hash="c972025412fb5f531b709b8339a4867d"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="fad48a1e0d172cf50015cfed489df9a9"/><file name="Product.php" hash="899cfda115a181f3ed1e7f7dc320f017"/></dir><dir name="Condition"><file name="Address.php" hash="57556435014163ba73961cb8b2413f74"/><file name="Combine.php" hash="776e2fb5e3f152e70c3280d476011f76"/><dir name="Product"><dir name="Attribute"><file name="Assigned.php" hash="d981c3f7486bb60becc566329267d7d5"/></dir><file name="Combine.php" hash="ef7cc6d43ca96c3a0cf35095801e91a1"/><file name="Found.php" hash="351ebe3769717330a8b9ef971319e2b5"/><file name="Subselect.php" hash="56844666a23899ed9454aeadfe236e7a"/></dir><file name="Product.php" hash="44f952d096aa380ffcd16669eef5fa8f"/></dir><file name="Customer.php" hash="c67ccf31dc11f70be34803c04199debd"/><file name="Product.php" hash="48d130bb0e52c6eed39917b0e6e8ec41"/></dir><file name="Rule.php" hash="0095ccf926ee7550cf5811744a481774"/><dir name="System"><dir name="Config"><dir name="Source"><dir name="Coupon"><file name="Format.php" hash="00a3d50d33a25ead7adcb8b78b6a11bc"/></dir></dir></dir></dir><file name="Validator.php" hash="a77360dd111bb67dc3ff3ab8e19eb118"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f1d641409e95b4a606cf7ae575243cd4"/><file name="config.xml" hash="8fb7fdc054daf869b4adca215adafeda"/><file name="system.xml" hash="62888a487f9a077a97e962f9f5fe363f"/></dir><dir name="sql"><dir name="salesrule_setup"><file name="install-1.6.0.0.php" hash="4ff588a3f0c4ccf35fa2397c8b91a1e1"/><file name="mysql4-install-0.7.0.php" hash="a23c56ff9cbdac7509024202840d23c6"/><file name="mysql4-install-1.4.0.0.0.php" hash="a39e70beef1c7ea3e75ff031168c9d00"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="997f2d5225bc7918a86cfbb7046e3208"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="bcb109871d08fe03746b2d099d3f7e2e"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="2a33766197a359ff0069b9402cfe63ae"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="ca200dc284898ef45e3bea7d3e119db3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="10e7b1b34289ff835d99eecb9a61dfec"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="aea3f32ffa01c60ddfc3925aa7ec3778"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b966df9afad448c96c16cb7c78a9eaac"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="0db66744ac0846c22876582edee3c9e7"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="0517c2de9b809c31167d808c9939d185"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="2485c3b72c509b73892dfacb03f148a3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="bbbd8c952701e3893076386e453e2f81"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="e5519218dcf0950044bb7c0d6028187f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="ac46d45460c5c897c5a7facaa3e4b8d7"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="e0b75159537f13c2b75b1f83fbfc2083"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="253ca68169f6f044f04b18fafd74d540"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="b11964330203c4e34192b34e86d65b21"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="004721ffbc5a2d380a14864f08611b56"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="941b4b839bfe16a1f3874ba67f14f419"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ac7e333071eb428749527e640bcd2c1e"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="27ce0d5d1598027bad1ace2feada0bb8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="18fa5d2dad035852fca429b986df8a4d"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="ae38a3fb75abc1a3dafb3b5278f27e0d"/></dir></dir></dir><dir name="Sendfriend"><dir name="Block"><file name="Send.php" hash="d0900cc748ef56c40c3551157156b6e3"/></dir><dir name="Helper"><file name="Data.php" hash="c8282d8b6b3610c761db46736e08fc8b"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Sendfriend"><file name="Collection.php" hash="122b8c8b50c55b13d867759cbdbaa9c6"/></dir><file name="Sendfriend.php" hash="61244da4dcae30c16dbb8d52fe2571f8"/><file name="Setup.php" hash="7b9ed257cc9bd891bae4bff716f22d0c"/></dir><file name="Observer.php" hash="301aa366775afba3bccc67529bdd0e65"/><dir name="Resource"><dir name="Sendfriend"><file name="Collection.php" hash="432e0466d874a74b3e1f4e10f1919b78"/></dir><file name="Sendfriend.php" hash="e5d542480b994ea78db380743bd782a0"/><file name="Setup.php" hash="6cb8411f99ae31fb4c7277675e3e26a9"/></dir><file name="Sendfriend.php" hash="0ccbc1ee40bc4796c2a3639399f891d9"/></dir><dir name="controllers"><file name="ProductController.php" hash="546740ca17ac1742f3e083e95c1541b0"/></dir><dir name="etc"><file name="config.xml" hash="5b71c820ab10d80f54460b6727687c4c"/><file name="system.xml" hash="3a06ef185cd518ca05a43eb3807bca55"/></dir><dir name="sql"><dir name="sendfriend_setup"><file name="install-1.6.0.0.php" hash="8337cc0478de35a6cbb12b2adfa46782"/><file name="mysql4-install-0.7.0.php" hash="495330536e267ecff7803b69d6a6ce58"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="db5bbae44f93fefeca37bc5f4a7ad02f"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="46cba5f2ec5161773cd2de5d40bb50be"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="905ed91131d6469ea8f8fc9b95b3c15a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e699566eab2ede860af95c67836e0c1d"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="0321ede85958c89dff2672b3122fa975"/></dir></dir></dir><dir name="Shipping"><dir name="Block"><dir name="Tracking"><file name="Ajax.php" hash="60eb152db709b70af3a1301d7578c572"/><file name="Popup.php" hash="b3827ba58f592e3e378ba645db89b88d"/></dir></dir><file name="Exception.php" hash="c37e69239674d32986f8ff04caf09ba8"/><dir name="Helper"><file name="Data.php" hash="b176cad5e70504b035065f8790f56a33"/></dir><dir name="Model"><dir name="Carrier"><file name="Abstract.php" hash="1da2a6fe120aea258289b491a177b39f"/><file name="Flatrate.php" hash="b963278ed8e6f9a2c2d772b635d2a401"/><file name="Freeshipping.php" hash="6d35e8d3cd6ec02b1996435c87ed8d82"/><file name="Interface.php" hash="ec7d94e778fc9b56da5033417630587e"/><file name="Pickup.php" hash="3d6461ff7539d666ac8a91fa86ef6907"/><file name="Tablerate.php" hash="e26312f735d0740f7fe67700099314f4"/></dir><file name="Config.php" hash="e287066af283499ef8a2094963d4ac84"/><file name="Info.php" hash="49da8bcfd1fb2588bf3f358bbb595fa2"/><dir name="Mysql4"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="eb37ac0e4242114d7efc067ab84fa86d"/></dir><file name="Tablerate.php" hash="c1c7891ed4d60eaa07c2031050c118e4"/></dir></dir><dir name="Rate"><file name="Abstract.php" hash="c8120b50d7bd267a1cd5c2d709e17efe"/><file name="Request.php" hash="f0fb6eb354e53d6462614a2c219d3635"/><dir name="Result"><file name="Abstract.php" hash="e02a769764e6d75ef60ca85f8bd0b8a4"/><file name="Error.php" hash="ac860d8dff2e14d66bcdc3340d5be70b"/><file name="Method.php" hash="daae81ee20835511b24ca7367bf9f5f1"/></dir><file name="Result.php" hash="98ed87516d9efb709b14c395631bb9bf"/></dir><dir name="Resource"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="7265d1074c2edb0e64bf4a6fae8a74d0"/></dir><file name="Tablerate.php" hash="95421d9235b9935dcff724af1bfb061d"/></dir></dir><dir name="Shipment"><file name="Request.php" hash="e4efe7c8ad51ff44bf51b928b41d293f"/><file name="Return.php" hash="d4a688c26c39df16e3c22c526994d9d3"/></dir><file name="Shipping.php" hash="e3a8c48c31b9db700d0675f431773f75"/><dir name="Source"><file name="HandlingAction.php" hash="5b208e34e6b351c9aa7cff2b13983047"/><file name="HandlingType.php" hash="814c09576fde7947ef0cadffdf74aaec"/></dir><dir name="Tracking"><dir name="Result"><file name="Abstract.php" hash="159774fea23b004463db2ee8a9a60bcb"/><file name="Error.php" hash="dcfb4279dc5396c4e0b62b4e5c127e6d"/><file name="Status.php" hash="80df6a16b056bb8d87acdc1719824a34"/></dir><file name="Result.php" hash="bae51d8ec387de5741b61fd8638074bd"/></dir></dir><dir name="controllers"><file name="ShippingController.php" hash="1b3e10d476e8fe5d2e2d5fc62c4f3d57"/><file name="TrackingController.php" hash="fa19d9a3587e22e4027aaf0638470af1"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3c1d155b5a034afb2250d25a8e3deb5f"/><file name="config.xml" hash="fd973e156b9c7525451d89bb19642035"/><file name="system.xml" hash="fc9f6b3f95040d578b12221fc8253f21"/></dir><dir name="sql"><dir name="shipping_setup"><file name="install-1.6.0.0.php" hash="36e7362e400987cecc8f40cedc89b207"/><file name="mysql4-install-0.7.0.php" hash="40a1d235256297f5b8356646b5d44b27"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0cb07570004b1b9c15aae9fc53b3b3ef"/></dir></dir></dir><dir name="Sitemap"><dir name="Helper"><file name="Data.php" hash="0d1da1f7efa331833eea2e8d05ae2ef1"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Catalog"><file name="Category.php" hash="7cb44704862831285f1fb3024fe7bdc5"/><file name="Product.php" hash="8819b5bac443d29058a0caf7f36d6903"/></dir><dir name="Cms"><file name="Page.php" hash="c31f3e6eedbd0abbac79a0eca5f5c978"/></dir><dir name="Sitemap"><file name="Collection.php" hash="c9e5b30798bcf9de29efe6753a818c46"/></dir><file name="Sitemap.php" hash="080840f73523fc3c0cfbc26ef936f1ea"/></dir><file name="Observer.php" hash="0c525f0c8827adf6d45977abb0402997"/><dir name="Resource"><dir name="Catalog"><file name="Abstract.php" hash="ddeadf2425c985b44414fa19bdefde0c"/><file name="Category.php" hash="0805c996fb090101c66dbb187cc7a2dd"/><file name="Product.php" hash="3cb064607f3f8fbda715703fbd45c35b"/></dir><dir name="Cms"><file name="Page.php" hash="4f45f86704cdf27e8692bf92a07f38ec"/></dir><dir name="Sitemap"><file name="Collection.php" hash="f8f4b4c5c5227b4f2f2fc81ec39f47c6"/></dir><file name="Sitemap.php" hash="3ead76a8aaa778f199ba6a8846e9a46d"/></dir><file name="Sitemap.php" hash="15c53139c1f7417e58af0e0a50bd62dc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="1af1c3ddee5195d95d8d2c6b4f7751e3"/><file name="config.xml" hash="e2e449e864d63173cd0decd800a1976d"/><file name="system.xml" hash="b2fd807782eb88310235daa07b9289a5"/></dir><dir name="sql"><dir name="sitemap_setup"><file name="install-1.6.0.0.php" hash="baa0c6a53cde49b484eda4027d249f5f"/><file name="mysql4-install-0.7.0.php" hash="2f99e2e6056dcb50bb50b16dd3adf6c3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3eea98e870b7a12f972b711972a41187"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="b7a5bf92b87d01f5fc7da34dcf779e08"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="b08a230d237e71d5c4d14113515c7b1b"/></dir></dir></dir><dir name="Tag"><dir name="Block"><file name="All.php" hash="9c586fa6c438210796b468861f021367"/><dir name="Customer"><file name="Edit.php" hash="48d9e49362f4d5624122a0c349a9da81"/><file name="Recent.php" hash="39a93ccd93d60d313ddba2430eb14278"/><file name="Tags.php" hash="575bb1a6e7321d4c07c80e85c1e536db"/><file name="View.php" hash="c51497ef2e787f5ed2d76ff31d297f94"/></dir><file name="Popular.php" hash="5e5aca7c58279a31ac8b7d819068c5d3"/><dir name="Product"><file name="List.php" hash="61bed3264fee80e1d495d705c78e3d96"/><file name="Result.php" hash="46df943675b8b838565df0df27834aa2"/></dir></dir><dir name="Helper"><file name="Data.php" hash="63d5f8bac429ec76ded751f08f199ea7"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="41c01c559d89f06ee8023984e39f341e"/></dir><file name="Api.php" hash="8c474827c3bd4085e3555e5b15518362"/><dir name="Entity"><dir name="Customer"><file name="Collection.php" hash="8d3f5a320ff6b9d8043dce39a6b00e28"/></dir></dir><dir name="Indexer"><file name="Summary.php" hash="da30d3f02de6867f52c02f74e5555c43"/></dir><dir name="Mysql4"><dir name="Customer"><file name="Collection.php" hash="b15f6d56b7a0370e8c36960e37c40ad8"/></dir><dir name="Indexer"><file name="Summary.php" hash="1677838d9e08726293ffdcc1a2a6a85f"/></dir><dir name="Popular"><file name="Collection.php" hash="e4b4a4d0a72ce42fba06b8d4df7cf881"/></dir><dir name="Product"><file name="Collection.php" hash="1b9c603a27674640553f8dddae1c3f61"/></dir><dir name="Tag"><file name="Collection.php" hash="195c1947f180ecd78bd8cc847a1c7541"/><file name="Relation.php" hash="74f25bf44aa6b8cac257e1563d5d2c0d"/></dir><file name="Tag.php" hash="efbd45b16d9062b73bee4e08732a6b2d"/></dir><dir name="Resource"><dir name="Customer"><file name="Collection.php" hash="ccef3608754c4bcfa32f17bae739d8ac"/></dir><dir name="Indexer"><file name="Summary.php" hash="363aaf754a1fef7684d995eaaa22c28c"/></dir><dir name="Popular"><file name="Collection.php" hash="656a1074cce99c835368a024ba45b58e"/></dir><dir name="Product"><file name="Collection.php" hash="71615e51db871bbf120514b12b456769"/></dir><dir name="Tag"><file name="Collection.php" hash="44a1ed8a1bff0c2b03dffcce228e4212"/><file name="Relation.php" hash="c80e4c0ba17e7f652c1dab298a07b615"/></dir><file name="Tag.php" hash="59dfe8a1e9621b64d8931b3b8a2f3157"/></dir><file name="Session.php" hash="b368fc576c8007cc36fcb51a28bb9a0d"/><dir name="Tag"><file name="Relation.php" hash="46200ffd008a5c7a40b620efe55b9272"/></dir><file name="Tag.php" hash="f6a664777ff027c6ff42fe3490125280"/></dir><dir name="controllers"><file name="CustomerController.php" hash="1e1bf9cb8bb6bd08e4b323673f6f0df7"/><file name="IndexController.php" hash="b3af6f013465abf3f0919b1bee6edf36"/><file name="ListController.php" hash="6d959bda65cdcb6f4d42a64e0c158f13"/><file name="ProductController.php" hash="9d02acffcfb4fe104f4c968bb4c3a7a6"/></dir><dir name="etc"><file name="adminhtml.xml" hash="87ff7b15b28edcfe304e4e5e68181339"/><file name="api.xml" hash="f5d2a45711c4a0dc4a7a53b7a0073769"/><file name="config.xml" hash="551ae7849f99b711c7e803e84e7800d9"/><file name="wsdl.xml" hash="e87343a710e0068dcc555ffc4b302a9b"/><file name="wsi.xml" hash="1d31787826a686590acf89ec2703b76e"/></dir><dir name="sql"><dir name="tag_setup"><file name="install-1.6.0.0.php" hash="c20cb71c35fc2bf52e63d91ffb03ab85"/><file name="mysql4-install-0.7.0.php" hash="ef39d408e4238c387220c3f03fe0a2f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3ac5fb48d5d88cfe81eddbecd5999840"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="421fe4350055fe9d9cc0e344215a3191"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0e9ffe30aa58782b7d98db353edd7b43"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="15ab9bc5f0b17b294442748151f589c7"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="5eabbeea53bdb58142c8e77c35ada312"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="8d4b452e1f4a48eca7cee4d93ac57ad4"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="11efa2e8721861477941822c798799c0"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="65b46e90600a4da74ddf399dd6d566b9"/></dir></dir></dir><dir name="Tax"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Region"><file name="Updater.php" hash="beb7c108a4d58bf1807da68347e998ed"/></dir></dir><file name="Notifications.php" hash="877b42a681cb850d2f810b3c537b0b25"/></dir><dir name="Checkout"><file name="Discount.php" hash="f6b150a93995ffb864e841dd0c8da3a0"/><file name="Grandtotal.php" hash="18984bad028645b775779fdcd0d1ece1"/><file name="Shipping.php" hash="9af18eb97f235ed93a29b0cf9d60c525"/><file name="Subtotal.php" hash="62c887dc953d0cb81e82c20b50f6d53a"/><file name="Tax.php" hash="d100b6329e5c2109c995eaa0e0bed2ec"/></dir><dir name="Sales"><dir name="Order"><file name="Tax.php" hash="824870e67250cef4dad26ff4d5ad3163"/></dir></dir></dir><file name="Exception.php" hash="0288092bf16f117a251a68cd4615da1f"/><dir name="Helper"><file name="Data.php" hash="f00cd6b47d65f6cc4491af4dc8b77579"/></dir><dir name="Model"><dir name="Calculation"><dir name="Rate"><file name="Title.php" hash="eb8738069f4b44b0a4ef8848cf76fc10"/></dir><file name="Rate.php" hash="598d9df4f531764c227bac73584d787c"/><file name="Rule.php" hash="bddc2fa731b7233bc5fbedf45b97940b"/></dir><file name="Calculation.php" hash="b5519c3f29d263d9f0cee6b9aa3b20a2"/><dir name="Class"><dir name="Source"><file name="Customer.php" hash="0bd655313bcc6173ef8a567738eace67"/><file name="Product.php" hash="67cc75ab50a0dc7c2fe4a7161c082b5c"/></dir></dir><file name="Class.php" hash="1998d3c9588d16ba5a09142e76cf08ba"/><dir name="Config"><file name="Notification.php" hash="7208ba27883fd27e2806501d6259c2ba"/><dir name="Price"><file name="Include.php" hash="9415f30261fd589c0eab19d01a8e49ed"/></dir></dir><file name="Config.php" hash="d76e7f2c21563f450be0ad26e979ec03"/><dir name="Mysql4"><dir name="Calculation"><file name="Collection.php" hash="aaaf63f8d359ae9db2e7e211c6362d63"/><dir name="Rate"><file name="Collection.php" hash="8101da309f4bec11d9fff4afcd712379"/><dir name="Title"><file name="Collection.php" hash="6e50bf3eb1876c57b38745540fbb48d7"/></dir><file name="Title.php" hash="2a7c7e0ba65a7ea3a7af60941c1d464d"/></dir><file name="Rate.php" hash="9d8c18fa37a08f999ba9b22802d79aa9"/><dir name="Rule"><file name="Collection.php" hash="930edbdf3be5e2639a6d36ce5ca3da83"/></dir><file name="Rule.php" hash="221b5b00fff11e724cfc0cbdababa293"/></dir><file name="Calculation.php" hash="36495ff2315c6f8de48d4f28067ed567"/><dir name="Class"><file name="Collection.php" hash="77fdc197709c96c363fbf0d99dd71e8c"/></dir><file name="Class.php" hash="a13f5209537394288b026be6e04a105e"/><dir name="Report"><file name="Collection.php" hash="3e81ba620644a90f092bd0bc49366aa2"/><file name="Tax.php" hash="a5f9f107397fbc625105e7320c727c67"/><dir name="Updatedat"><file name="Collection.php" hash="a957bc0a2e1b24154ec184459c776178"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="077b167b7c0f031bc5113663d8880869"/></dir><file name="Tax.php" hash="d4702750f1bf5998e5056fb3dee8ed8f"/></dir></dir><file name="Setup.php" hash="e47b718538ded1126b82b9602d681d41"/></dir><file name="Observer.php" hash="d7efde9dd0cf39008662e2a8fec7a1a1"/><dir name="Resource"><dir name="Calculation"><file name="Collection.php" hash="1c569680aecbe5eab48ac45d05bdb6d2"/><dir name="Rate"><file name="Collection.php" hash="502be4d7ff30a162b7fa6368ab2112cd"/><dir name="Title"><file name="Collection.php" hash="aa43e7ad8084224399c9c066151bf705"/></dir><file name="Title.php" hash="8775240533d3a739b9b2fa9cd9482954"/></dir><file name="Rate.php" hash="d87edc2b2de1d830769bf91f72130ac8"/><dir name="Rule"><file name="Collection.php" hash="076e02339bd518be4fe9be6b3fbbff5c"/></dir><file name="Rule.php" hash="32803fa33d812af96fe1b9ceaab4abc9"/></dir><file name="Calculation.php" hash="688202244165823959d54e9d4b6363ab"/><dir name="Class"><file name="Collection.php" hash="5b47f5009f103c633bde387ac7adea4f"/></dir><file name="Class.php" hash="332c61fe7cb39e8203e55ae0f0d99fad"/><dir name="Report"><file name="Collection.php" hash="8bcdfc9f2d9211061822dfc870b98f62"/><dir name="Tax"><file name="Createdat.php" hash="d50b75e5628b6986f83479c6de48c369"/><file name="Updatedat.php" hash="069f0f7f45a8491b1eb51b1329674919"/></dir><file name="Tax.php" hash="e608ad7cfdd88ea1f9b6c7295708527e"/><dir name="Updatedat"><file name="Collection.php" hash="45bc6713a12931c6c43417182a5e6d67"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="4798023eae71bac870b9bf164f57c21c"/><dir name="Item"><file name="Collection.php" hash="801e5275a9825c988327d6a1e0b55681"/></dir><file name="Item.php" hash="76adc830a3be5a27cf1bf1306221809e"/></dir><file name="Tax.php" hash="b1ff6195e235e016961f77cdaaf0cbed"/></dir></dir><file name="Setup.php" hash="dbdaed9eebb4822bda049ed4817a88af"/></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Item.php" hash="1b581b47646f91bd1b98532595d6e44f"/></dir><file name="Tax.php" hash="9d4682194bcbbb567b6955b5e1ebe5c7"/></dir><dir name="Pdf"><file name="Grandtotal.php" hash="107952415d87c39e57cb64b34e4808bb"/><file name="Shipping.php" hash="1e86efcc35e93d89a13f239ee6b909b0"/><file name="Subtotal.php" hash="67ad16e534c7a6cd9cd2ea403b104460"/><file name="Tax.php" hash="d50ccdb4ae7f9f6f4cee8881740cf0d5"/></dir><dir name="Total"><dir name="Quote"><file name="Discount.php" hash="68e59646d4b3ed53cbef37278cb7fbbd"/><dir name="Nominal"><file name="Subtotal.php" hash="4f93a5807d975b92dad5b352f016697b"/><file name="Tax.php" hash="c809da9b571e1261579fa4e71ca1792f"/></dir><file name="Shipping.php" hash="1d0b5484d1912fc947ad4ab0527ea34a"/><file name="Subtotal.php" hash="5bb1ed31fd267d596f755d01a959a65e"/><file name="Tax.php" hash="10de0057288a63ed198dd29b5385dc84"/></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><file name="Algorithm.php" hash="347f5adebdd1619f6959cd3cc134f939"/><file name="Apply.php" hash="53d1f5b5c4a08070a783db8b72caeffd"/><file name="PriceType.php" hash="57c083bbde3ebd93602c6a40d2a6202e"/><dir name="Tax"><file name="Country.php" hash="12331f21e79b44fef3d6e9b1c0b34acd"/><dir name="Display"><file name="Type.php" hash="fcfcb7a434ea1fa9db79cd09cbac31b1"/></dir><file name="Region.php" hash="4b59757baeba8007f3809864d360f62e"/></dir></dir></dir></dir></dir><dir name="data"><dir name="tax_setup"><file name="data-install-1.6.0.0.php" hash="94b4f10de8f7a5a83fe087f06ac92739"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="4468e87f67dfbf16d33b9b2707ee26ad"/><file name="config.xml" hash="350957182c80c7d5e65451b96518fcbe"/><file name="system.xml" hash="bc6897ce79eacc48bd78a78c05828dc0"/></dir><dir name="sql"><dir name="tax_setup"><file name="install-1.6.0.0.php" hash="e0be5cd38897e0a29101a479a3c46576"/><file name="mysql4-install-0.7.0.php" hash="7fe22036e27e3228ef62c1b33ec84dd1"/><file name="mysql4-install-1.4.0.0.php" hash="9dec0361305355dc82b262882ccd81a9"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="d10c616c3450a99a2a070bd82be749d3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8ca3ac7b724434fc4580e89544ffc74c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0d67a01efd09ef2052d61e0c5e7bd980"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="8bbdcaf5614446a39c3cf669a45aa607"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="76a54f836cacb813942ffffc0f6cde04"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="579ed14c0fe3b95f41853eaef2d37374"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="c2dd0bdfccdc77a0a29d555a9b625ae3"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="e72fc20271969d7dc72fd6e11c87e562"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="326b3250a99912852647ae1f1a617f0b"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="2044ce6c72fa421cebbc936cdc3b9551"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b4345cee38819d7335f8a4ac43a719c5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d81466fa4aafe13fa8b643b9d9604a8f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="005cb7ce377789522ee6113cc6faaf01"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a45ecf83147580fd0b205cc5ba8ceb93"/><file name="mysql4-upgrade-1.3.9-1.4.0.php" hash="51c32172a42fe9bfb70246891955f7ac"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="1f40a8d2e8e62f6c7a5c6a801dcefec5"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="38940a651a3ccd71d6b51f2c56292df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="99f59a5a323d2ab93979bd978a71596b"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="c7b5e7a2c05c6bb645b16677ad022aa7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="c40b4ac8f47a6e66aed870bc548424fe"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="39a4fa13ba11365822088398b51e5d7c"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="a4fc58b853d6f51e1984160027bb54aa"/></dir></dir></dir><dir name="Uploader"><dir name="Block"><file name="Abstract.php" hash="3e4c27fef40ca4b4d06e9fbade2fc708"/><file name="Multiple.php" hash="6ad3435e9621366e3002f0fffdbb87a5"/><file name="Single.php" hash="6b7a9c61b8638188d753fd3d61326019"/></dir><dir name="Helper"><file name="Data.php" hash="9d9fe520b988530cf96c9d63df4e0273"/><file name="File.php" hash="74ec342ff936338e70a26356dd7a7008"/></dir><dir name="Model"><dir name="Config"><file name="Abstract.php" hash="9c894362a1fe640a42d12e2ab9dfd8d6"/><file name="Browsebutton.php" hash="33d4e27b9df48a99becd6b4804236ddd"/><file name="Misc.php" hash="f329b6490eec11bbfacb36becfd0331c"/><file name="Uploader.php" hash="458ca8fd03fb3358c8d44c551dec43b1"/></dir></dir><dir name="etc"><file name="config.xml" hash="910b0e0ba92f5510fb8a8de346fc9b47"/><file name="jstranslator.xml" hash="40957bd0383e10b88d3d245e7402b432"/></dir></dir><dir name="Usa"><dir name="Block"><dir name="Adminhtml"><dir name="Dhl"><file name="Unitofmeasure.php" hash="10997c949618283fcff3700837ddc369"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="558952e017a826983a6520f46e055ff0"/></dir><dir name="Model"><dir name="Shipping"><dir name="Carrier"><dir name="Abstract"><dir name="Backend"><file name="Abstract.php" hash="f69a281efe5ecaa85da5aec4b006f76c"/></dir><dir name="Source"><file name="Mode.php" hash="778451ea932baa5cf37697361ba5cae7"/><file name="Requesttype.php" hash="bb39b74b50887b170b0e9d838b5e2c66"/></dir></dir><file name="Abstract.php" hash="e1907149de0a3216004d3b4afa7afcb4"/><dir name="Dhl"><file name="Abstract.php" hash="0efbaa4bd4be9577339b213e882c548b"/><dir name="International"><dir name="Source"><file name="Contenttype.php" hash="e5359c32016f64a446917a655febd027"/><dir name="Method"><file name="Abstract.php" hash="ec7de521c44ed74b7a2803e3b81b1731"/><file name="Doc.php" hash="e58bed061386ca4a31f5c3520880b59a"/><file name="Freedoc.php" hash="f8ff29721fd591b809e51386a6ddbb9d"/><file name="Freenondoc.php" hash="655f111e076d1df9e9ba2a28397b561f"/><file name="Nondoc.php" hash="ce6ff2b22825d59552add3e3b3447c9a"/><file name="Size.php" hash="7b6e56c60b13a2dda8cf36ca4e1dc9ce"/><file name="Unitofmeasure.php" hash="9439cef75a91f110f5bec57c9677f545"/></dir></dir></dir><file name="International.php" hash="1aa74aea3c781fad751eb0721d8c5a70"/><dir name="Label"><dir name="Pdf"><file name="Page.php" hash="e66a0164e6463860135a132dc7895f01"/><file name="PageBuilder.php" hash="5bc6169b5bb68bc2da765e22cef408b4"/></dir><file name="Pdf.php" hash="46552005b344e2ad2daa13c2d8425177"/></dir><dir name="Source"><file name="Dutypaymenttype.php" hash="411ea53d37b0f580aef05290e7c69418"/><file name="Freemethod.php" hash="27aa2a02f19a892afec2bdfd862ea345"/><file name="Method.php" hash="841058d6dc0799bfacf30117871b0bc9"/><dir name="Protection"><file name="Rounding.php" hash="5107a44097c80fe3cbdbd833e7aa05d9"/><file name="Value.php" hash="14acb56219a067f77d7a3eab5406ac0b"/></dir><file name="Shipmenttype.php" hash="1305407602b8d6dbe650a32615bea321"/></dir></dir><file name="Dhl.php" hash="1525b3a3027bcaa419070242fb169599"/><dir name="Fedex"><dir name="Source"><file name="Dropoff.php" hash="aa425f98db3ba3bf9db264c20f2bf416"/><file name="Freemethod.php" hash="4eb4e8853d7f22f520c9d9b45ce27bca"/><file name="Method.php" hash="ac3c72ee7ca1ed4ac173660962e5b0b2"/><file name="Packaging.php" hash="e1111b6983c3a17869a51acd2d0f66cb"/><file name="Unitofmeasure.php" hash="7a5a94c0b97a5edc53782429b3927e86"/></dir></dir><file name="Fedex.php" hash="96d58629ed7b43932590a2a1d1c2e8e7"/><dir name="Ups"><dir name="Backend"><file name="Freemethod.php" hash="578cfe6da0fc52a9ccbf6896c7814030"/><file name="OriginShipment.php" hash="9f63eb33f4d0b9049a99d0d09251a974"/><file name="Type.php" hash="63f031871c1afd0ad464739002d6d18f"/></dir><dir name="Source"><file name="Container.php" hash="49f0d3eb8e52d5f8475a46f1952f52e5"/><file name="DestType.php" hash="fa1e1c6fcb60164ad648354e4648c6d0"/><file name="Freemethod.php" hash="7001561ea932cab7850b2136639c729b"/><file name="Method.php" hash="d1764d9b630f3306457384f87d262b79"/><file name="Mode.php" hash="6cbed4f0cfc486d75e35a7f9fca2a682"/><file name="OriginShipment.php" hash="5984b00f373bc8e95b344b32c3ae8d3a"/><file name="Pickup.php" hash="0b71e6481183c757ee6f3838bd7d146d"/><file name="Type.php" hash="5cd443e78fc2b12b8f96ad35b2cbc488"/><file name="Unitofmeasure.php" hash="8638b87440d4879ad2f5ee66898350cf"/></dir></dir><file name="Ups.php" hash="6454a3a22b8c6c6a8b8d3e38c7e2e1e1"/><dir name="Usps"><dir name="Source"><file name="Container.php" hash="ee6ba442e8ef11d24e53863075076575"/><file name="Freemethod.php" hash="57a6bcdc91fd3349d9f3a9544b7104fb"/><file name="Machinable.php" hash="eee52b5666bd94d3715b57346c1e0c32"/><file name="Method.php" hash="8efa1defbf4156700d26d60fbde252d5"/><file name="Size.php" hash="945f74071f8d37f367c5401cd90ea637"/></dir></dir><file name="Usps.php" hash="7c7a5d30b09e9f79d2e15ca492ad5d96"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f1246bda795b64de06487596bb03afde"/><dir name="dhl"><dir name="international"><file name="countries.xml" hash="8d254d9563909fbd3e7f103efb4b4cee"/></dir></dir><file name="system.xml" hash="f93f4300a2166bd43f9f208e79098e39"/><dir name="wsdl"><dir name="FedEx"><file name="RateService_v10.wsdl" hash="352ed0cd739b31d42d206aba31bf4c31"/><file name="RateService_v9.wsdl" hash="5e698519a3b3ae3dcea2105545053763"/><file name="ShipService_v10.wsdl" hash="4e661e70491a1af695c27878610054e2"/><file name="ShipService_v9.wsdl" hash="9c3779aa87540dcae41b43b16b724df6"/><file name="TrackService_v5.wsdl" hash="89cc7077a8fc439446e70bac0ca0f0c1"/></dir></dir></dir><dir name="sql"><dir name="usa_setup"><file name="install-1.6.0.0.php" hash="60c7ae9339249f390863deb05fe47784"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="1d01eca26e39ae48c0d3e427cfa1ab34"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="2ea78f90b818e7cd228e83b8537b41e8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="1e2088d771a4e0b83d6e93891517b6f1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="758ef4152248dd60f9b3d941cbfd5026"/></dir></dir></dir><dir name="Weee"><dir name="Block"><dir name="Element"><dir name="Weee"><file name="Tax.php" hash="fd0f736c3d8545402e22118356162592"/></dir></dir><dir name="Renderer"><dir name="Weee"><file name="Tax.php" hash="3e6e14e572b75bd7294f08492fcf2402"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="fd44707f27deb17645e7751740474cc6"/></dir><dir name="Model"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="84e0853d03e58f02dcfe8516110d4507"/></dir></dir></dir><dir name="Config"><dir name="Source"><file name="Display.php" hash="dd9b92f8467686bbea476a3ff1bfdcaf"/><dir name="Fpt"><file name="Tax.php" hash="3a4856fc7ef23c693b9e80ca535a0e70"/></dir></dir></dir><dir name="Mysql4"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="860cc567b8fc31a75afd88aba680a725"/></dir></dir></dir><file name="Setup.php" hash="07f6c26a85349e879b1ed3cbc5404ab4"/><file name="Tax.php" hash="d401f1ab63bd5f3a8f7bc821ccb394d4"/></dir><file name="Observer.php" hash="b513b4d768c5ba4adc809485fdae6f24"/><dir name="Resource"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="77a42d4f015dceb9c8f4417415264b21"/></dir></dir></dir><file name="Setup.php" hash="fb6cd54cce66fa17c1830c238e29f377"/><file name="Tax.php" hash="c56763433b9e30cb95098e87ed696397"/></dir><file name="Tax.php" hash="32cd2697d7378f1eb60338b50aef134f"/><dir name="Total"><dir name="Creditmemo"><file name="Weee.php" hash="c56a76968ee4caa1864464fd29cefad1"/></dir><dir name="Invoice"><file name="Weee.php" hash="209638b57ec140cd66d5ac20a0cde1c7"/></dir><dir name="Quote"><dir name="Nominal"><file name="Weee.php" hash="8ae9e90a10b8dafab07435b26448bd99"/></dir><file name="Weee.php" hash="2f8c089417d978dcaaa3d656753e5952"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f157980d75f3045c3a3a37ba7f6946f5"/><file name="system.xml" hash="43de9ea6b63cc96ab3e604e05ccb3247"/></dir><dir name="sql"><dir name="weee_setup"><file name="install-1.6.0.0.php" hash="a034deb1eddaa3d760f78ac3eb89dc4f"/><file name="mysql4-install-0.1.php" hash="2be73cb26708c54b64e7ed7165871924"/><file name="mysql4-upgrade-0.1-0.2.php" hash="200335244e836f11760a34534644126a"/><file name="mysql4-upgrade-0.10-0.11.php" hash="d2f31b8932743ebc6d497b910a106c83"/><file name="mysql4-upgrade-0.11-0.12.php" hash="98b5c962ad1991f4d698141fb41f212a"/><file name="mysql4-upgrade-0.12-0.13.php" hash="834fefba3bbf0cc63fb9997963ff1589"/><file name="mysql4-upgrade-0.2-0.3.php" hash="742e6f9e862bc4ebce15fa024805759e"/><file name="mysql4-upgrade-0.3-0.4.php" hash="4862530eb12a216c98dadb26793ff88a"/><file name="mysql4-upgrade-0.4-0.5.php" hash="0f301cf23c99e77c07649927172588bb"/><file name="mysql4-upgrade-0.5-0.6.php" hash="7b3bc07ac584ec31d163e9dd6c35d750"/><file name="mysql4-upgrade-0.6-0.7.php" hash="6dcd142adc03c785556a68679e4499f5"/><file name="mysql4-upgrade-0.7-0.8.php" hash="e0c094146fd1441de27c04c25e7c5e37"/><file name="mysql4-upgrade-0.8-0.9.php" hash="3b45b9510084a408c5370a6b9d323807"/><file name="mysql4-upgrade-0.9-0.10.php" hash="38844cce782c07afea0fe477a24c1fcf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="bbb550408e834459dc0c24e395e301f3"/></dir></dir></dir><dir name="Widget"><dir name="Block"><dir name="Adminhtml"><dir name="Widget"><file name="Chooser.php" hash="f41f4a5d4abbb5317de07d76c0af9ce5"/><file name="Form.php" hash="2f430de2e4b79346ac15bc2db84a6086"/><dir name="Instance"><dir name="Edit"><dir name="Chooser"><file name="Block.php" hash="35b0a2189584bd507cba9273413713bf"/><file name="Layout.php" hash="4a3c6e4105a35ca9469b83a677a15aab"/><file name="Template.php" hash="d5bff7a35634d46aec79c838ef8028c7"/></dir><file name="Form.php" hash="e5c088065bbcc2f34b6b921a29434873"/><dir name="Tab"><dir name="Main"><file name="Layout.php" hash="4f72e2287ef012ae37a7d7ef1e56ecac"/></dir><file name="Main.php" hash="856e66104b67ba24ac31f8db4d90d36e"/><file name="Properties.php" hash="a03aabc3764bb85938af96b9f8865a8b"/><file name="Settings.php" hash="66721fb67187c4d84a064349697b4383"/></dir><file name="Tabs.php" hash="cd9abdda69b86e35e80d62282d7c083b"/></dir><file name="Edit.php" hash="e44bea2b39f359f75cccec1996681143"/><file name="Grid.php" hash="fc2f183e4fdb3120aa8132f3f045fe71"/></dir><file name="Instance.php" hash="2d2368b22010c6aa68698b61d9412702"/><file name="Options.php" hash="0ee8355dd026bf75ca4026cd5e6eb3a3"/></dir><file name="Widget.php" hash="0efda79c01989b1b371be56f094df65d"/></dir><file name="Interface.php" hash="7e8e943dbf9c350738e0c7b87bf33873"/></dir><dir name="Helper"><file name="Data.php" hash="fb9cd633320087c35b78e251572d4a3d"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="fb7c16f16ca147b4b0277f705264615e"/></dir><file name="Instance.php" hash="33b19185739fa245b0ab24743f0da1ff"/></dir><file name="Widget.php" hash="669f7241dfd0a221866b183488d5d676"/></dir><file name="Observer.php" hash="3da4b54327a1f24dff9d479ea39d4004"/><dir name="Resource"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="e07e92d933818e5ca96c67778a3f9286"/></dir><file name="Instance.php" hash="531253749642a5e9d5038879d48bab57"/></dir><file name="Widget.php" hash="ac5884a08704af82ca4b8a0dcbc61127"/></dir><dir name="Template"><file name="Filter.php" hash="72fd9c6fbcb49e145fc78728fb927ea0"/></dir><dir name="Widget"><file name="Config.php" hash="f439b671f2f89ca440a7f9ea3e01c60b"/><file name="Instance.php" hash="c5d1e18924f417073eb5ee65917cb7e4"/></dir><file name="Widget.php" hash="d691a3d871172a98fa64684d2c6e4910"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Widget"><file name="InstanceController.php" hash="63939b7121ca34e33ec7c5c303ec79ab"/></dir><file name="WidgetController.php" hash="5296aaec9297cc6a5eae90ddeb423ba5"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2d49ebc683d76e660e80f670aa824cb3"/><file name="config.xml" hash="d513372267bcab378f3490305c74aac7"/><file name="jstranslator.xml" hash="33ef3294aecd2ecf7d7918a12b8ccbd2"/></dir><dir name="sql"><dir name="widget_setup"><file name="install-1.6.0.0.php" hash="ee2405ce1bda7a5fd724c6e6579e6c23"/><file name="mysql4-install-1.4.0.0.0.php" hash="303d557b443da9a0b648e0b489db8df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f26a2433a7568fdcc02a348d95efb285"/></dir></dir></dir><dir name="Wishlist"><dir name="Block"><file name="Abstract.php" hash="d41153ea1f2fd24037aa23ea1b02bbb0"/><dir name="Customer"><file name="Sharing.php" hash="693a4499b8c54044686c0450eb624f4f"/><file name="Sidebar.php" hash="c5a5f3501e9e4d95835da6beb107b569"/><dir name="Wishlist"><file name="Button.php" hash="9116b58cbcd737532fa9ab1368226915"/><dir name="Item"><dir name="Column"><file name="Cart.php" hash="1abc6a7fbce4370166aede5f704efcdf"/><file name="Comment.php" hash="411e2ffd53fecd487f416e8c97466be7"/><file name="Image.php" hash="e4fea81d458007fff38347b281f46016"/><file name="Remove.php" hash="183986e5e3c1ade450540b0061cfe184"/></dir><file name="Column.php" hash="ffd2c66332126dd318f30a5e285c3fe2"/><file name="Options.php" hash="3113081b2adcc919ce92a727ed83bd8e"/></dir><file name="Items.php" hash="d2bb5dff0a7138d97df7819fa1755149"/></dir><file name="Wishlist.php" hash="e80f560419ea9dc2ea0d3a9216638a8c"/></dir><dir name="Item"><file name="Configure.php" hash="3e9b9a068f1d885f7ba02c5d941529bb"/></dir><file name="Links.php" hash="25b1030ea691741332070314c09507e1"/><dir name="Render"><dir name="Item"><file name="Price.php" hash="9b022ae29781b7b542130588ad72e080"/></dir></dir><dir name="Share"><dir name="Email"><file name="Items.php" hash="d6a9ed3eb79687ba3fd613a80b0b77cb"/><file name="Rss.php" hash="49efbf8d871afeba9f65b5fcc0dbcd1b"/></dir><file name="Wishlist.php" hash="1d541e90a5793b84fe6eaca98dcbd49f"/></dir></dir><dir name="Controller"><file name="Abstract.php" hash="8645269d5466e6bd4b5e4e875a9d2216"/></dir><dir name="Helper"><file name="Data.php" hash="86851e022187af87ad203e235da38d53"/></dir><dir name="Model"><dir name="Config"><dir name="Source"><file name="Summary.php" hash="7a2b80db4fe6a978b5786e76a5c904fc"/></dir></dir><file name="Config.php" hash="2b2911baaf1c7185c3326e0ce0557a31"/><dir name="Item"><file name="Option.php" hash="6dd700cd04aab1da4261c3482b314bf2"/></dir><file name="Item.php" hash="1c0f79a254b69e888c6a59d781aa2c44"/><dir name="Mysql4"><dir name="Item"><file name="Collection.php" hash="ee47fa47f801be5897e46cb6a1b414e4"/><dir name="Option"><file name="Collection.php" hash="1d69f4047866ceba682ebba1760b7882"/></dir><file name="Option.php" hash="e8d6eb6783c0d110e1fb9019c18ae1bb"/></dir><file name="Item.php" hash="ed1dee8fe9f393fbbc09080bec44bb0e"/><dir name="Product"><file name="Collection.php" hash="d0d3b256caa2f2cf82b6749e71a1e250"/></dir><dir name="Wishlist"><file name="Collection.php" hash="f0de345db6724cf0f2215ca3d6e2c55a"/></dir><file name="Wishlist.php" hash="847ae12dfb58e6a7cfce9f225aa3c208"/></dir><file name="Observer.php" hash="2d1514b092fc4e0bc9476950f56d2e98"/><dir name="Resource"><dir name="Item"><file name="Collection.php" hash="1cb2d243a6a5f3e0a68fd3adad2ad37a"/><dir name="Option"><file name="Collection.php" hash="d0929064f2c7a8342fda1e353d672e1c"/></dir><file name="Option.php" hash="689b388fdb474b0a070a0e855e09aabc"/></dir><file name="Item.php" hash="21a88028b07b955f2bf263f17c2442d2"/><dir name="Product"><file name="Collection.php" hash="e83f7c166b796125b3b85ae4acb6642c"/></dir><dir name="Wishlist"><file name="Collection.php" hash="b88d95c758cf27ae03a3c9a4bbfbb943"/></dir><file name="Wishlist.php" hash="6f5081c171d93eb92a9c2920b0e0c67c"/></dir><file name="Session.php" hash="d2ae560ea5c56b10055d49fd4e66ebc3"/><file name="Wishlist.php" hash="b1fe5e818d5b092c37559f30437cb05e"/></dir><dir name="controllers"><file name="IndexController.php" hash="409f16b88fdceb021f5bdb3be84d44cd"/><file name="SharedController.php" hash="fa0c415383e783f70014b0f9376b60eb"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9213f2e94f8cab90211fb80826a700c2"/><file name="config.xml" hash="34fc8f3562566125f8f093f4a165726d"/><file name="system.xml" hash="ee72b4a7f5247c4b29e3b4d94b4054ad"/></dir><dir name="sql"><dir name="wishlist_setup"><file name="install-1.6.0.0.php" hash="5d61c25439596c2594416b8eaebe9009"/><file name="mysql4-install-0.7.0.php" hash="932ebcea937b1affa6567809f946df3e"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="648bf1ff930a83ce088b2cb881d43758"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f65eaaf98841a9840acc3b3e5209c1"/><file name="mysql4-upgrade-0.7.2-0.7.4.php" hash="b4f3216bd940240253079c6899aeea46"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="15e4be127414d41faeabb193b044f543"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="11f60666b29d10381c810f39dd64fa1b"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="04074c4d3e41a0fb1eee82feba0537b5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="7e43180e183e6236eea1a75c471d24ac"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="cf7c5d37479155a28c180252f3222bc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="afc76dcb77fca764870c502db86d244d"/></dir></dir></dir></dir><dir name="Zend"><dir name="Controller"><dir name="Request"><file name="Http.php" hash="92d5e6e2538a8c23af43faae8200c60b"/></dir></dir><file name="Date.php" hash="95bf218944785f606f22c2ea0c077f5d"/><dir name="Db"><file name="Select.php" hash="28f3efa5f9797af22f899fb525dbb44f"/><file name="Statement.php" hash="4b5b39a1e1c651ab9d6db332c882fdf7"/></dir><dir name="Filter"><file name="PregReplace.php" hash="1b5bbd52c2b2d17f19db273606e5ddfc"/></dir><dir name="Form"><dir name="Decorator"><file name="Form.php" hash="fbd6a6687ef13a8b7ba416c1ca50dd38"/></dir></dir><dir name="Locale"><dir name="Math"><file name="PhpMath.php" hash="a95d7d3d0d7220b47d0e518ffad508f7"/></dir></dir><file name="Mime.php" hash="f216d84221e3d7601822b4c95948aeaf"/><dir name="Serializer"><dir name="Adapter"><file name="PhpCode.php" hash="d19044ca7b67e672bb9627f572f1a069"/></dir></dir><dir name="Validate"><file name="EmailAddress.php" hash="e04917b783b4880bdc984e7774abf7a6"/><dir name="File"><file name="Upload.php" hash="a5de679b71a82a061dbddd3afde626b2"/></dir><file name="Hostname.php" hash="08c032ea8831e62e79c792e274220aa9"/></dir><dir name="Xml"><file name="Security.php" hash="7366a7b9e2dab5551b557f49d900d6a1"/></dir></dir></target><target name="mage"><dir name="app"><file name="Mage.php" hash="83a4cc5f50ce35888e567e4cefa8ddeb"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name="bootstrap.php" hash="5692f824efc22a75246f10e88b1bd3b7"/></dir><dir name="."><file name="cron.php" hash="52235435ed8bf309f9fbbf2c47e80f04"/><file name="LICENSE.txt" hash="59563e7be45096d0833dade102989042"/><file name="index.php.sample" hash="a605f93d48608b283696e2473319f32a"/><file name=".htaccess.sample" hash="971c336db60ac86ae96b5c5871be1e8c"/><file name="LICENSE_AFL.txt" hash="45a399f2095030865fb962263ccd7506"/><file name="LICENSE.html" hash="caf0a79ffb5e4719f9f4de286f253a61"/><file name="cron.sh" hash="64e5df07f32d93c83a0c986bbce6bcc3"/><file name="install.php" hash="c9154ce64d8ce2c96aea25b242b7b077"/><file name="php.ini.sample" hash="d7412c2f78440a96fc2d9378ccf460cb"/><file name="get.php" hash="0e147e2a291707ab75091fe1b0f764e1"/><file name="RELEASE_NOTES.txt" hash="5a3d5fce3e536ce74dbff0ed9afc2a21"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="api.php" hash="2605aef23c3d1030ab6a10f91c7cbdd2"/></dir><dir name="errors"><file name="404.php" hash="557eebe76671c3f51ef07b0892802c67"/><file name="503.php" hash="5843bd0da9d8a0ef173154a81dc89305"/><dir name="default"><file name="404.phtml" hash="fd358b5b2dba922be64b1d711648c309"/><file name="503.phtml" hash="8b7b63a9e1c2a23179280af48e6b3633"/><dir name="css"><file name="styles.css" hash="730771c6f889a40e64e712541a909012"/></dir><dir name="images"><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/></dir><file name="page.phtml" hash="09c7f4694acf2c1936e15e1304965840"/><file name="report.phtml" hash="e9dfdea4409fc2e8463de932b3a6147b"/></dir><file name="design.xml" hash="7bf4d647bade27485007ceff382c77eb"/><file name="local.xml.sample" hash="8c65e80b446b4b52592a216c2a4b9d8b"/><file name="processor.php" hash="34adac569448ace7ab4b33ad977e960a"/><file name="report.php" hash="2c28c37e5a006ce64946150a1c12168c"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/></dir><dir name="var"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="shell"><file name="abstract.php" hash="3e9ed270d023a86541744119c8588fb7"/><file name="compiler.php" hash="0b90e3996b5f315e133a71b5613b957f"/><file name="indexer.php" hash="b80a6c7b2f641e98e487662eb5d1aaa6"/><file name="log.php" hash="0c2c4db2ac3b778106070484edf5b951"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="lib"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="media"><file name=".htaccess" hash="08de5b2f5ea1ce6f51f40a19bacbf42e"/><dir name="dhl"><file name="logo.jpg" hash="68500df59e568e01333ba078a262ca27"/></dir><dir name="downloadable"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="customer"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></target><target name="mageetc"><dir name="."><file name="config.xml" hash="cd99effb308b25632010f59726b1894c"/><file name="local.xml.template" hash="ff798ff56329f93e4d253ee50083e07f"/><file name="local.xml.additional" hash="8504141dcf1d0b1f2e2ed54b19c902d3"/></dir><dir name="modules"><file name="Mage_All.xml" hash="fa6a5ea2883abbba8e96b84c96f2cfed"/><file name="Mage_Bundle.xml" hash="9c247f8a5d4a6fd39ed58ab6f4722058"/><file name="Mage_Api.xml" hash="48d6e1dee18721bd3048da0918ac246d"/><file name="Mage_Downloadable.xml" hash="6f0c7caf9bab79db23c43fd8f9bb4827"/><file name="Mage_Weee.xml" hash="5448953a4ace9de652ab42dae4836154"/><file name="Mage_Widget.xml" hash="751d506bebd89db6ff302f3cb5926875"/><file name="Mage_Connect.xml" hash="0df11e64ef7a39ffa53f65bbbda70d7d"/><file name="Mage_ImportExport.xml" hash="16908a3f3cdaeac311ea90dabec3c80f"/><file name="Mage_PageCache.xml" hash="4f7b1d28d3d6c002ed3b7d3923affcc5"/><file name="Mage_Persistent.xml" hash="5055d23f9ad54f04e64a8b54a304b25d"/><file name="Mage_Authorizenet.xml" hash="e4267c93799b07c3dcb2f192f51bdfda"/><file name="Mage_Captcha.xml" hash="c2f88e068ccee9bb077e02dd80299abf"/><file name="Mage_CurrencySymbol.xml" hash="7c0400eafc6d0f44e456852491f5476e"/><file name="Mage_Api2.xml" hash="c106f0994020cf2c392d6ba6732b8909"/><file name="Mage_Oauth.xml" hash="28c9f32075749d7711720fc73c20060e"/><file name="Mage_ConfigurableSwatches.xml" hash="3ca495f8c747f71eab4f15a892f75211"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Varien</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Google_Checkout</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.18</min><max>1.51.1.18</max></package><package><name>Lib_Js_Mage</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Phpseclib</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Locale_en_US</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Mage</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Magento</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Pelago</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Unserialize</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_IDNA2</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Mcryptcompat</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Downloader-1.9.4.0.xml b/var/package/Mage_Downloader-1.9.4.0.xml
deleted file mode 100644
index d2a1607..0000000
--- a/var/package/Mage_Downloader-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Downloader</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Downloader</summary>
-    <description>Magento Downloader</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:12</time>
-    <contents><target name="mage"><dir name="downloader"><dir name="js"><file name="prototype.js" hash="3766aeff5778b54f74f93670322ca0df"/></dir><dir name="Maged"><dir name="BruteForce"><file name="Validator.php" hash="e069b1af7148efe26a918ac9225deb81"/></dir><dir name="Connect"><file name="Frontend.php" hash="4fb58e748e68dc9a724f20e94b9f3f29"/></dir><file name="Connect.php" hash="886dc69525312ea3588bfd6b2e2c9505"/><file name="Controller.php" hash="482c54d564f37b3f0cb09ca787194b5f"/><file name="Exception.php" hash="22bdaa1e2923c77b8d1aabc7767d2875"/><dir name="Model"><dir name="BruteForce"><file name="ConfigIni.php" hash="1935321c98f6be5748e39c0cb4905848"/><file name="ModelConfigInterface.php" hash="7a84c5ce27d4ede6ed9190040b7f4ed2"/><dir name="Resource"><file name="FTP.php" hash="94985f1c1548daa07cdd26aecbf4fbd3"/><file name="File.php" hash="8515b75daceed039dfdcab1c697c1ac0"/><file name="ResourceInterface.php" hash="1c217ef936960724b1e3b2de11232be2"/></dir></dir><dir name="Config"><file name="Abstract.php" hash="30365c47b1af63f6d6b3c392ce78e845"/><file name="Community.php" hash="a6b79a5a248b11b51fa6a05e963fe919"/><file name="Interface.php" hash="33d921215bfb8e9ff7214bfc355b2c19"/></dir><file name="Config.php" hash="a1f3bbb64503cad2a5801c24cc7b9e90"/><dir name="Connect"><file name="Request.php" hash="113c3d2e0afbdf9b1e7bdc9e67ae6f45"/></dir><file name="Connect.php" hash="1fd793d4642826abbdc1517816353934"/><file name="Dowloader.php" hash="fa0e99055534c6c6cbc2c2dd6dc555d0"/><file name="Session.php" hash="264b1c5fd12013f082fb0384508e7ef8"/></dir><file name="Model.php" hash="4387f98b652d73716e2432827d82ebe3"/><file name="View.php" hash="fc141538b3aaa91540d8b876465fe2e9"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="skin"><file name="boxes.css" hash="c11c2a895c4059441b2c8ebcccbe7886"/><file name="ie7boxes.css" hash="336ffbdd43e7a06700ee92034b343b14"/><file name="ieboxes.css" hash="c178c04d5d5aece3e538740a1fc955c6"/><dir name="images"><file name="Magento_Connect.jpg" hash="20e1378c09506fdc5723abc0115d5f57"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="header_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="logo.gif" hash="5eb089ecea67d82311d7c91898460104"/><file name="nav_bg.gif" hash="1cb1366f03a9efad6b17e4483aef20cf"/><file name="nav_separator.gif" hash="492011a7de2de84a9c7837bfd879ab95"/></dir><dir name="install"><file name="boxes.css" hash="b8699cb958c92555b463cda59fc3caa7"/><file name="clears.css" hash="2e7bd70ec9da32330f44ffba7a6f1e3d"/><file name="ie7minus.css" hash="a3481034dce2436323f6876a925007b8"/><file name="iestyles.css" hash="ea88e14c32cced73fce9c8a357f346d2"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="logo.gif" hash="073a947a39b967af678455a5c7f66e90"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir><file name="reset.css" hash="51580e87ff713eec672a0b364e00121b"/></dir></dir><dir name="template"><dir name="connect"><file name="iframe.phtml" hash="5518f6d1624388e512fe3d20a75e6d30"/><file name="packages.phtml" hash="4802a619698604407e1b2f7f0720edc6"/><file name="packages_prepare.phtml" hash="1ccf6ef001d1d72378d41a10bad27563"/></dir><file name="exception.phtml" hash="d7559437cea821c2b4ab8504767cea24"/><file name="footer.phtml" hash="20e012f224e187ae9f049e59e04ecd35"/><file name="header.phtml" hash="9e7a1da616e1fc788031892d14d0e1eb"/><file name="index.phtml" hash="aa3aa55f6015dc87dc4aa1eff5cabeb1"/><dir name="install"><file name="download.phtml" hash="f5628e0b9cfd0d2758e0417e24d4072d"/><file name="footer.phtml" hash="9de8976ea003732961478c3eca63c51e"/><file name="header.phtml" hash="7c1d89aeda59b956ad3520f0394d3ee8"/><file name="writable.phtml" hash="55142cd8f6d2198e276292d6975a1c01"/></dir><file name="login.phtml" hash="54831d9f4445d88bc7e6e14e4f40a660"/><file name="messages.phtml" hash="e5bfd22e6cb409a894e995d5fefda56a"/><file name="noroute.phtml" hash="6968e31c6e7de3dde2e45910f9601a07"/><file name="settings.phtml" hash="89d4b871915adac450a41ccf24603e79"/><file name="writable.phtml" hash="eb76e591e645ec017d98a197002c982d"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="index.php" hash="74e1f933c81ebcd5b07b31b8c9aaae4f"/><dir name="lib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="7219e31d44a1ad2263795f24f80fd557"/><file name="Bz.php" hash="ddda0a3dfbb7b81ce9a6e69c6b44e540"/><file name="Gz.php" hash="385b2740aacefcd317273448ed95ef83"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="e6066c9ad90a71d015329ee2ad342702"/><file name="Gz.php" hash="13c15537156d0293cc86588cca629267"/></dir><file name="File.php" hash="314284e414f094c7e7ea81ffe8f6a9ee"/></dir><file name="Interface.php" hash="212679c1c16ad7e35eff39e55c2ec510"/><file name="Tar.php" hash="1387e79bba7f05f479062113d9c74b49"/></dir><file name="Archive.php" hash="4c21f386cc1e86939e2ef13d6b5944c1"/><dir name="Autoload"><file name="Simple.php" hash="3d7ff27e8bc9e9fbb6acc94d710ed3f0"/></dir><dir name="Backup"><file name="Abstract.php" hash="c3de48d5961070832d1ed0f7177ee4a2"/><dir name="Archive"><file name="Tar.php" hash="8bd53f96d6ba93d5887b0e7aa72f9269"/></dir><file name="Db.php" hash="89f62bd52b21db1dd708a02ae4347248"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="4f53c1142257ab85784198a402d2f425"/><file name="FtpConnectionFailed.php" hash="5fefd3d3b8be727781a6f5fdb138852f"/><file name="FtpValidationFailed.php" hash="cec68f36cf698a50e41471d46722d57c"/><file name="NotEnoughFreeSpace.php" hash="ccdd5e27479a58a1b3866c64533822c1"/><file name="NotEnoughPermissions.php" hash="3afd5fa76513cc11b55082bab2ebeb26"/></dir><file name="Exception.php" hash="d75dc453d7950a04329ba6309da002a9"/><dir name="Filesystem"><file name="Helper.php" hash="6a1f92a6c37f2c7cc19f5cd17a5a7b24"/><dir name="Iterator"><file name="File.php" hash="c85c788b168fc0a4645a4cdaf10caa80"/><file name="Filter.php" hash="174deec59e7fe57014725a3a623b074c"/></dir><dir name="Rollback"><file name="Abstract.php" hash="271c9e6032f86e8d71e660b9778e71a9"/><file name="Fs.php" hash="c6ca689d7bfd4c0fe4101ccb74a96c97"/><file name="Ftp.php" hash="413393e9b1ba8402a584e0236b839232"/></dir></dir><file name="Filesystem.php" hash="a2ac0ad741f06e862da5cc2a8d0c3a36"/><file name="Interface.php" hash="2550d86498a20a3d5d83672415ae7f91"/><file name="Media.php" hash="dd1f7d5304b53206c6d770ae668d254b"/><file name="Nomedia.php" hash="1d7f11e8507fbba3893be459d331891b"/><file name="Snapshot.php" hash="d3b7c974ed49905937cde4b69075ab4e"/></dir><file name="Backup.php" hash="951e7982ed239d7799e7722ac67435eb"/><dir name="Connect"><file name="Backup.php" hash="09eb3c5d221813cc7c2d57e4314a1722"/><dir name="Channel"><file name="Generator.php" hash="b3dbdf1fdd1d5a462a522c68627d2bba"/><file name="Parser.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="VO.php" hash="38e61a3a3b877639cdeb427f8746ced1"/></dir><dir name="Command"><file name="Channels.php" hash="c13a8190309ee8b816eb044422d02dc4"/><file name="Channels_Header.php" hash="ef497284ed4c24aa7234dbfe48d238dc"/><file name="Config.php" hash="491a98103bd35dbb31a2fb23c55518e4"/><file name="Config_Header.php" hash="11b772152974cbd6be72b76335a91896"/><file name="Install.php" hash="73e0ac5946823c865427df4625e0622f"/><file name="Install_Header.php" hash="5bd1465e62f45dc30cb8f249c399a65e"/><file name="Package.php" hash="e7f21efe6fd8cc46f78d5ab5d6dc40cc"/><file name="Package_Header.php" hash="5997e0606e551537d7f08c32f1a19135"/><file name="Registry.php" hash="1d542d1ed603f768470e70759e63b2e6"/><file name="Registry_Header.php" hash="99724f9b7288ce74ba690b440cbdfe5f"/><file name="Remote.php" hash="49196c939723bc4accca3a54ceb7a804"/><file name="Remote_Header.php" hash="27419e6e322ce60848994cc45bc71bcd"/></dir><file name="Command.php" hash="74cf48a2aa1e2df9e12d1a6c2fdb5b7c"/><file name="Config.php" hash="744d7c6fad41ca12b6e7536b07f6ebeb"/><file name="Converter.php" hash="fea5425f9074136c9fc10d6d7b15a4f8"/><dir name="Frontend"><file name="CLI.php" hash="12ca52168cf666fcdd676d84d2131c9f"/></dir><file name="Frontend.php" hash="dc3c8f852c7c455659010d5073ceceff"/><file name="Ftp.php" hash="24de96a815ff507fb1292fbb4dd69418"/><dir name="Loader"><file name="Ftp.php" hash="fd0e1437083204dfb19f927844a1041d"/></dir><file name="Loader.php" hash="774dfb7d205c130982d6fa6d9894ed4f"/><dir name="Package"><file name="Extension.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Hotfix.php" hash="31f281c8485a8c010230eebc64d2fdc9"/><file name="Maintainer.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Reader.php" hash="94dd06082e803182e7d54a9b6a3a9117"/><file name="Target.php" hash="3769c486343cee9e9c20ab0a7d211288"/><file name="VO.php" hash="bfbe38745c9f36fe9b79aa1c0bf3c106"/><file name="Writer.php" hash="eed2a978a7a7b38aa996116e46a5a6d3"/></dir><file name="Package.php" hash="57bf1ef36925720afee7772a1a8e4d83"/><file name="Packager.php" hash="031af74dbbf15c06446d8a217af83f22"/><dir name="Repository"><file name="Abstract.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><dir name="Channel"><file name="Abstract.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Commercial.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Community.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Core.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/></dir><file name="Channel.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><file name="Local.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/></dir><file name="Repository.php" hash="f4bd67eec5dc2f2deb2c0a800521662f"/><dir name="Rest"><file name="Builder.php" hash="479d68770edd8163ad7f74f5d6d8bb4c"/><file name="Factory.php" hash="474f3a6be5b6d615cb00d81f75e05823"/></dir><file name="Rest.php" hash="e0654ec5cf5fdf39371c5d93096d9656"/><file name="Singleconfig.php" hash="8b736510d2f16c7d33badcc386dd8e5d"/><dir name="Structures"><file name="Graph.php" hash="907ec31e395ed931d3468bab30c8a865"/><file name="Node.php" hash="bfa5cc71b8e0787ddf41917faaa8d859"/></dir><file name="Validator.php" hash="f7dd429ef7b6d3495745377d94506af7"/></dir><dir name="DB"><file name="Exception.php" hash="1651c02af32d13cb09f18e55fe41a454"/><file name="Mysqli.php" hash="1afea21a74a5c95afb3aa0fac88dd8f1"/></dir><file name="Exception.php" hash="77e6ab75c4d3375d41ab444205a401be"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="05ae5ab9cdd02bbee50db4f35108bf44"/><file name="Socket.php" hash="2403f0c937a01759262eca2bd838b13a"/></dir><file name="Client.php" hash="8370d8998e874e5833747eb0085775ca"/><file name="IClient.php" hash="1bb87d5c7b0027db0288a58d2691c1f8"/></dir><dir name="System"><file name="Args.php" hash="c95ce3451a31af33ed0a0987fc007a80"/><file name="Dirs.php" hash="3069e59e595fdd0b30d953c7ea0a291d"/><file name="Ftp.php" hash="044097653f0fad93fdacd5e2a3fe777e"/></dir><dir name="Xml"><file name="Generator.php" hash="dbbf15cac6bef48830f921ece90b4382"/><file name="Parser.php" hash="4dab68fb16c447bf58897b57a9e7f589"/></dir></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="config.ini" hash="a52ba98e71ab19de387b3af1a04c6102"/><file name=".htaccess" hash="520cc012c84739584526b8a9ff098e23"/><file name="mage.php" hash="24b532702775ce1ce3ae1646047d861e"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="target.xml" hash="b0f5bc47ce412f7ba12303676dbfce37"/></dir><dir name="."><file name=".htaccess" hash="242b96ab8c820ff12b9e610a8f4352ec"/><file name="index.php" hash="8e678a85bf749549a1f507374bedc273"/><file name="mage" hash="24869e556de9dd46ec8fda89e649af79"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Mage_Downloader-1.9.4.1.xml b/var/package/Mage_Downloader-1.9.4.1.xml
new file mode 100644
index 0000000..e44d86b
--- /dev/null
+++ b/var/package/Mage_Downloader-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Downloader</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Downloader</summary>
+    <description>Magento Downloader</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:58</time>
+    <contents><target name="mage"><dir name="downloader"><dir name="js"><file name="prototype.js" hash="3766aeff5778b54f74f93670322ca0df"/></dir><dir name="Maged"><dir name="BruteForce"><file name="Validator.php" hash="acc8254ffef60b0f441d2d90630ddf15"/></dir><dir name="Connect"><file name="Frontend.php" hash="408ec3c9963658780ff6abb42f94e1ac"/></dir><file name="Connect.php" hash="b4e74db8600ef82d72fa9d717fa78f67"/><file name="Controller.php" hash="d9333ca9c4ae423851d7dcce523801f1"/><file name="Exception.php" hash="ee26ba26af45f0a19656c452d53b8b6a"/><dir name="Model"><dir name="BruteForce"><file name="ConfigIni.php" hash="0a3fa333a35f3a223428fb5858d06523"/><file name="ModelConfigInterface.php" hash="c44f9f441fc64a35e17570d6cd142633"/><dir name="Resource"><file name="FTP.php" hash="06ef49748467877f5b58d3829c009587"/><file name="File.php" hash="91e2fa34bd140f11812216ee2bfe7a8c"/><file name="ResourceInterface.php" hash="c161e47a2c0bca4fae5630e749c25c5d"/></dir></dir><dir name="Config"><file name="Abstract.php" hash="53e5b1fc2ba051c52a8d713ff09088e1"/><file name="Community.php" hash="14294db527329c9b9772b1b7ed4215f1"/><file name="Interface.php" hash="9307087300464de5e797bc4ed83bd767"/></dir><file name="Config.php" hash="df5675930420d807d079b4329377ea8a"/><dir name="Connect"><file name="Request.php" hash="0bcabb3426028ef8782e4f0687c82f70"/></dir><file name="Connect.php" hash="fad1ef28d8df62b56a21d8ba643c6d81"/><file name="Dowloader.php" hash="8ea77759c21c4ed786763768b8e26267"/><file name="Session.php" hash="c5b09315bf2bb8bd39fabca81db0671b"/></dir><file name="Model.php" hash="1aaf2230d70385a8cc495949e754e313"/><file name="View.php" hash="505d920dbde496a83e62be417839d14d"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="skin"><file name="boxes.css" hash="20ae147246f9524ba94f886a5d5fa51a"/><file name="ie7boxes.css" hash="b89283355db186307bd9ddbc99b48a9f"/><file name="ieboxes.css" hash="3f37d81e3641aca52dcaf38ad64ae4bb"/><dir name="images"><file name="Magento_Connect.jpg" hash="20e1378c09506fdc5723abc0115d5f57"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="header_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="logo.gif" hash="5eb089ecea67d82311d7c91898460104"/><file name="nav_bg.gif" hash="1cb1366f03a9efad6b17e4483aef20cf"/><file name="nav_separator.gif" hash="492011a7de2de84a9c7837bfd879ab95"/></dir><dir name="install"><file name="boxes.css" hash="a8405daa1ad5b91c8952a2635c12189c"/><file name="clears.css" hash="b8216c54e90dd07482b519829aa7577e"/><file name="ie7minus.css" hash="1e74b90a2be87129de22a2d984254eea"/><file name="iestyles.css" hash="d01e1190b28afa379e5417b9e2a18f06"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="logo.gif" hash="073a947a39b967af678455a5c7f66e90"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir><file name="reset.css" hash="b6c9331f99c5980bba301ef2b225a360"/></dir></dir><dir name="template"><dir name="connect"><file name="iframe.phtml" hash="8d3e133dee30a8709081edcce534f75a"/><file name="packages.phtml" hash="0e11a582d7c24814034b547206a846ed"/><file name="packages_prepare.phtml" hash="2af685540d77fc84c0b0261ed7f7cc95"/></dir><file name="exception.phtml" hash="a6ca67c868177500370d6dd2c7a715a7"/><file name="footer.phtml" hash="5357c5d470fdecb8bd55e59f1f4f9862"/><file name="header.phtml" hash="abd0f8678805cecff97b818c0ebf3f6c"/><file name="index.phtml" hash="749c434b0a31738035ffbfdcad9daeba"/><dir name="install"><file name="download.phtml" hash="4d31173d99b724a4d71204d471a1140d"/><file name="footer.phtml" hash="16a6e4ffba022dad5a3a0c1b66caddb0"/><file name="header.phtml" hash="2b535e452e9a38c73674533fdfd20fcb"/><file name="writable.phtml" hash="5955552da9cc58975de006d7548d6245"/></dir><file name="login.phtml" hash="68b37c7bea381dc21cdc543a152377d8"/><file name="messages.phtml" hash="62b14d82ec912106fe0c8bd1742f3252"/><file name="noroute.phtml" hash="a137d82354c54ef3ecd042979335f3d5"/><file name="settings.phtml" hash="563130e568a9d54a7989975538bfb028"/><file name="writable.phtml" hash="051690dad77d27fd9b868798094aa9eb"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="index.php" hash="751c9e6c5ea6dad527b5e17743580683"/><dir name="lib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="c5e243e597744bb215c68870a7afdf08"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="bcf5c54d43deaa20c96f6f54042578c4"/></dir><file name="Archive.php" hash="57f041e79f6374fffdff1a78aa93f1e6"/><dir name="Autoload"><file name="Simple.php" hash="63356064ece27da0a19a7fbf14f6f298"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="c7673366523f3f507ae2775a5801bef0"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="d77622ce2c019ff20214c144f7fa4e1a"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Connect"><file name="Backup.php" hash="833a7437bff426efaefc44038c6b8299"/><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="74e6d9a8fddd6e293a3bc7ab1ee4e45e"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="fc1058b9c34921304afab39427541bb4"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="315b9b27c014e07271e808dc5df2483c"/><file name="Package_Header.php" hash="ed6fdd0037b6174e3a4db13c970a5037"/><file name="Registry.php" hash="137eff5218c4eac3700932a5e0b7de6e"/><file name="Registry_Header.php" hash="d291f8de7a407b8ca203a851b418b29d"/><file name="Remote.php" hash="ebc849e801e4df6fa318c22127336dce"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="1811c8b0bd15ec6d036f5538a380626d"/><file name="Config.php" hash="5d1de3361e853b0e0717268a009caac8"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="e962e532a8a319fc53b0665b37bdbda0"/></dir><file name="Frontend.php" hash="1ce669251eddea02964fc6f7f3c59292"/><file name="Ftp.php" hash="5f396f76dca69111c101236221e06f1a"/><dir name="Loader"><file name="Ftp.php" hash="3c28cffc500fae3dabd6762105fdbf3b"/></dir><file name="Loader.php" hash="63f4b94910ebea3d6210c43ce4313d07"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="3e5a54d74712928a640484cde25d5b0a"/></dir><file name="Package.php" hash="2a094d3964e012850e16f5514f8b8672"/><file name="Packager.php" hash="ff0a2ad9acbb35f7b6b8417953de6bea"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Rest"><file name="Builder.php" hash="6e04022fe762c4f67b35f906a93f0ded"/><file name="Factory.php" hash="0678655546bcdc692c4f31656be39f15"/></dir><file name="Rest.php" hash="7099cb876a1f6139666cafc1a444988c"/><file name="Singleconfig.php" hash="12d91ef1355c32bc30a0fa7e0ab558a5"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="42debf7c91b968ca832744eb60436ddc"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="399803c8e3dcceff1912c57397b5399c"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="e7e77a18e571129707b047d8c2997c5c"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="fc0720d6fd51b2e84b35226e045743e8"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="6e1ad19d742fbd22ee7f93db98fa483d"/><file name="Ftp.php" hash="bd6dd1f4eb9abdc5db20dcc5971d2bea"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="config.ini" hash="a52ba98e71ab19de387b3af1a04c6102"/><file name=".htaccess" hash="520cc012c84739584526b8a9ff098e23"/><file name="mage.php" hash="6b7de4cba72be38ba43378be38da4ec1"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="target.xml" hash="1674cd8105fdeccc8831b9d7071b5013"/></dir><dir name="."><file name=".htaccess" hash="242b96ab8c820ff12b9e610a8f4352ec"/><file name="index.php" hash="952234cc3415f3856800a588a3ce32c0"/><file name="mage" hash="f9cb2c3303b77bc760b585f616856f98"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Mage_Locale_en_US-1.9.4.0.xml b/var/package/Mage_Locale_en_US-1.9.4.0.xml
deleted file mode 100644
index 70b9609..0000000
--- a/var/package/Mage_Locale_en_US-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Locale_en_US</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>en_US locale</summary>
-    <description>en_US locale</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:12</time>
-    <contents><target name="magelocale"><dir name="en_US"><file name="Mage_AdminNotification.csv" hash="e240a88785e337747afb4d0bc83ccaba"/><file name="Mage_AmazonPayments.csv" hash="00494825779e0ae3f0db0abd30e666b7"/><file name="Mage_Api.csv" hash="5a8919e82128dbd894c8f22c8238384d"/><file name="Mage_Api2.csv" hash="bc4b31da02edb34d29274da37a0a0f60"/><file name="Mage_Authorizenet.csv" hash="56def78c56270d23b57c1c17d3304288"/><file name="Mage_Backup.csv" hash="7fb40353a4c161de2a92edd8dcb35587"/><file name="Mage_Bundle.csv" hash="8a0263be85d7ac77e54d6044dcfc6420"/><file name="Mage_Captcha.csv" hash="de6aef08396245ed644b213ecfcf309b"/><file name="Mage_Catalog.csv" hash="975c73c165ccfc226d1032dc64c4ba96"/><file name="Mage_CatalogInventory.csv" hash="d3692d562e917fd71b5944aa050648c7"/><file name="Mage_CatalogRule.csv" hash="c7dcdd7d6192fbbbee177aaeb56b1685"/><file name="Mage_CatalogSearch.csv" hash="9a4687677cd0ff4ce75ead38b69fc2fc"/><file name="Mage_Checkout.csv" hash="a547d47e61822e2e35d2a7dcac41da74"/><file name="Mage_Cms.csv" hash="9a538e344acce7afa686fbed65082c63"/><file name="Mage_ConfigurableSwatches.csv" hash="8d9ad57fa2b4012dbb49e6dfebfeadba"/><file name="Mage_Connect.csv" hash="8cd1b22e3bb2b18a59b6bfb6a7e4e7f9"/><file name="Mage_Contacts.csv" hash="7e367e9a924c19b6df2fa5c8adca9be4"/><file name="Mage_Core.csv" hash="8e371f5da90492ad33e359981efbbdd5"/><file name="Mage_Cron.csv" hash="f963e0b41f877519fd8f6e723f25ee3c"/><file name="Mage_CurrencySymbol.csv" hash="2cc13530e2f9387349c6a162d4d22bc9"/><file name="Mage_Customer.csv" hash="9e21dccf81d5f27d3e7ec3ced9b8e65f"/><file name="Mage_Dataflow.csv" hash="342acf10a1911a335f112133bd31b3f5"/><file name="Mage_Directory.csv" hash="83f83f81a84aafce6f0d8e731e87653e"/><file name="Mage_Downloadable.csv" hash="05085f8d10c4df507ad96790a0f4f31a"/><file name="Mage_Eav.csv" hash="1fd5bcd482e23bffd25b979c4eb8985f"/><file name="Mage_GiftMessage.csv" hash="6cd672267af7f7183f47c58450c2779a"/><file name="Mage_GoogleAnalytics.csv" hash="c8a08b1e094bdf42d8222c97241296c2"/><file name="Mage_GoogleBase.csv" hash="453420e7b2a7c67d983436cd07c3f1c1"/><file name="Mage_GoogleCheckout.csv" hash="218bdb6351129bc11f5fbb7abeff7e18"/><file name="Mage_ImportExport.csv" hash="7f6895b2225a808013a8caeeafb47ffe"/><file name="Mage_Index.csv" hash="a12d6e56dec19a45380375e7ea3f7a7c"/><file name="Mage_Install.csv" hash="ff1231e1db62fc550cac4674d0ba5190"/><file name="Mage_Log.csv" hash="302d7736324e74584e23ea35289e5593"/><file name="Mage_Media.csv" hash="9d16c10b1ba6569a972018353d17f471"/><file name="Mage_Newsletter.csv" hash="85bd38e7b398fed22997f9bd87f7afa1"/><file name="Mage_Oauth.csv" hash="53c0c0f9390456fd1be2df79ed995a61"/><file name="Mage_Page.csv" hash="2938aceaf2a5a590db264da9ed4ca14f"/><file name="Mage_PageCache.csv" hash="365e8f2f9dace7313711e9a27d27cd97"/><file name="Mage_Paygate.csv" hash="311566b283975d5c481046346023026b"/><file name="Mage_Payment.csv" hash="4f42a6296fada9e8a3dbccf19d143fce"/><file name="Mage_Paypal.csv" hash="1df7ff2e0a9957243cdef854551fad70"/><file name="Mage_PaypalUk.csv" hash="d9d163d9c022d37e6bef2bf231469572"/><file name="Mage_Persistent.csv" hash="8df1299e4ddacadd638b7dd2f66749da"/><file name="Mage_Poll.csv" hash="01084dbcb43b1da9de35c5730fabd692"/><file name="Mage_ProductAlert.csv" hash="8ceb95248eeb2e4611d01767a7331840"/><file name="Mage_Rating.csv" hash="88db484c67afdb565255d210044bd034"/><file name="Mage_Reports.csv" hash="c49ae3155e93f7eff90b3058ec8e7b40"/><file name="Mage_Review.csv" hash="a251b73a3f358bcdd93cfde7f0a2f10f"/><file name="Mage_Rss.csv" hash="56b9be44d2cb98a43bf0e04007fa98d6"/><file name="Mage_Rule.csv" hash="a6a968b628d92b7f172801ce05755962"/><file name="Mage_Sales.csv" hash="d819588fd9a0eccc737b8a70ecac6cbc"/><file name="Mage_SalesRule.csv" hash="1703499a655a66855f2fa13597c09587"/><file name="Mage_Sendfriend.csv" hash="b1e310cf2fdaf674de1e7604826146e9"/><file name="Mage_Shipping.csv" hash="1c64b4423ab6fd12c0c9e2d05a80c570"/><file name="Mage_Sitemap.csv" hash="4837691c0e5c8cfbc4d75b10f196eb65"/><file name="Mage_Tag.csv" hash="d37771ca3a2321a6f1dd6c59a378981b"/><file name="Mage_Tax.csv" hash="a0665ad32147d01fec271dc8d2ee12d1"/><file name="Mage_Uploader.csv" hash="044e66927e4a70710e2d5e27105ad308"/><file name="Mage_Usa.csv" hash="dedc63b54ae93cb0f0bb82364e937425"/><file name="Mage_Weee.csv" hash="60f8a4821b2733ba6b16cba691d3ada6"/><file name="Mage_Widget.csv" hash="01127964a87c48113af4b8969e795aa6"/><file name="Mage_Wishlist.csv" hash="b870b694148efc6a75fcc29a88a86924"/><dir name="template"><dir name="email"><file name="account_new.html" hash="c7516c316c9fd94aeb4a007adb42b47c"/><file name="account_new_confirmation.html" hash="c404affe58ec3947379beabf6cf2dee9"/><file name="account_new_confirmed.html" hash="19223ed36f7076dee12a8fc6f542f00f"/><file name="account_password_reset_confirmation.html" hash="f5d6538ff20ded76d73ef6dbc34c94b0"/><file name="admin_new_user_notification.html" hash="08ed9ba46dc26ef22e4d97f7350564b8"/><file name="admin_password_new.html" hash="e0cb7a16e03f1e57fc42fa3b60920bb2"/><file name="admin_password_reset_confirmation.html" hash="385547f1fd11e85b6cd818e91f519bfd"/><file name="contact_form.html" hash="ee7a957b249d9bf8d2f84787d9276958"/><file name="currency_update_warning.html" hash="be68b2b00692c3071942df42d206575f"/><dir name="html"><file name="footer.html" hash="72d4ef13825ca2143557f5baf67c27cf"/><file name="header.html" hash="739a3ea8e07bbe3be76e4c93237bc5d2"/></dir><file name="log_clean_warning.html" hash="36eb1af6eca088bdafe6e91c5a355a98"/><file name="newsletter_subscr_confirm.html" hash="cc7849aaa2ada032e0d0cbcdc4c15222"/><file name="newsletter_subscr_success.html" hash="83fc3c7d1cae23c24561f803e41ea988"/><file name="newsletter_unsub_success.html" hash="3bd611af2d1fae78622e6217ff2b189e"/><file name="password_new.html" hash="e633e5d80e81549e29b239960f5187cb"/><file name="password_or_email_changed.html" hash="26ce55df2b817a5ed2373c71feff3652"/><file name="payment_failed.html" hash="693051923f748ed9e695c0b300597034"/><file name="product_alert_cron_error.html" hash="8ea80affba71491f4371b0524d0c3399"/><file name="product_price_alert.html" hash="18ff254fcaea714647caf21b39d36e9b"/><file name="product_share.html" hash="02c76a3380f98aaaa9c3ac6a86da3545"/><file name="product_stock_alert.html" hash="6a0fc4ef5203e195d1a0957accc1fca3"/><dir name="sales"><file name="creditmemo_new.html" hash="c487a7c825477974835891019d2b55bd"/><file name="creditmemo_new_guest.html" hash="47dc131ea102b0cf72d1e8bb50df2514"/><file name="creditmemo_update.html" hash="4dd0fedbe075abc51dd3647bedbf051a"/><file name="creditmemo_update_guest.html" hash="d805b77120143a070d44a01866df8f3f"/><file name="invoice_new.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_new_guest.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_update.html" hash="1ced4397da53d8a73bfa854b1ce60c24"/><file name="invoice_update_guest.html" hash="f8e7d66c9d607f3a349a9c21544c9854"/><file name="order_new.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_new_guest.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_update.html" hash="8d8d3f6a5831909532984817afc81647"/><file name="order_update_guest.html" hash="04ffcc29c74931d5f46b6ecb25cc049e"/><file name="shipment_new.html" hash="1a8e314cada334caffe213efd1e5ce31"/><file name="shipment_new_guest.html" hash="6ba64b3b35a39bfcc4c3d0ff4acc6fad"/><file name="shipment_update.html" hash="4425c3dfceb25ea1a5b80fd054a0f79f"/><file name="shipment_update_guest.html" hash="45b6f10c6853a36879b17f86e761edbf"/></dir><file name="sitemap_generate_warning.html" hash="7eb47e4ddd7eab22272397cff8c9441d"/><file name="token.html" hash="71f392398f6f80481b2e0edba7cefc78"/><file name="wishlist_share.html" hash="8d4d4838c76468c2be6149f5314b27a6"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Mage_Locale_en_US-1.9.4.1.xml b/var/package/Mage_Locale_en_US-1.9.4.1.xml
new file mode 100644
index 0000000..9b9e347
--- /dev/null
+++ b/var/package/Mage_Locale_en_US-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Locale_en_US</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>en_US locale</summary>
+    <description>en_US locale</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:58</time>
+    <contents><target name="magelocale"><dir name="en_US"><file name="Mage_AdminNotification.csv" hash="e240a88785e337747afb4d0bc83ccaba"/><file name="Mage_AmazonPayments.csv" hash="00494825779e0ae3f0db0abd30e666b7"/><file name="Mage_Api.csv" hash="5a8919e82128dbd894c8f22c8238384d"/><file name="Mage_Api2.csv" hash="bc4b31da02edb34d29274da37a0a0f60"/><file name="Mage_Authorizenet.csv" hash="56def78c56270d23b57c1c17d3304288"/><file name="Mage_Backup.csv" hash="7fb40353a4c161de2a92edd8dcb35587"/><file name="Mage_Bundle.csv" hash="8a0263be85d7ac77e54d6044dcfc6420"/><file name="Mage_Captcha.csv" hash="de6aef08396245ed644b213ecfcf309b"/><file name="Mage_Catalog.csv" hash="975c73c165ccfc226d1032dc64c4ba96"/><file name="Mage_CatalogInventory.csv" hash="d3692d562e917fd71b5944aa050648c7"/><file name="Mage_CatalogRule.csv" hash="c7dcdd7d6192fbbbee177aaeb56b1685"/><file name="Mage_CatalogSearch.csv" hash="9a4687677cd0ff4ce75ead38b69fc2fc"/><file name="Mage_Checkout.csv" hash="a547d47e61822e2e35d2a7dcac41da74"/><file name="Mage_Cms.csv" hash="9a538e344acce7afa686fbed65082c63"/><file name="Mage_ConfigurableSwatches.csv" hash="8d9ad57fa2b4012dbb49e6dfebfeadba"/><file name="Mage_Connect.csv" hash="8cd1b22e3bb2b18a59b6bfb6a7e4e7f9"/><file name="Mage_Contacts.csv" hash="7e367e9a924c19b6df2fa5c8adca9be4"/><file name="Mage_Core.csv" hash="d1dbc0bea321a9b809f9bc8bb1dac9b2"/><file name="Mage_Cron.csv" hash="f963e0b41f877519fd8f6e723f25ee3c"/><file name="Mage_CurrencySymbol.csv" hash="2cc13530e2f9387349c6a162d4d22bc9"/><file name="Mage_Customer.csv" hash="9e21dccf81d5f27d3e7ec3ced9b8e65f"/><file name="Mage_Dataflow.csv" hash="342acf10a1911a335f112133bd31b3f5"/><file name="Mage_Directory.csv" hash="83f83f81a84aafce6f0d8e731e87653e"/><file name="Mage_Downloadable.csv" hash="05085f8d10c4df507ad96790a0f4f31a"/><file name="Mage_Eav.csv" hash="1fd5bcd482e23bffd25b979c4eb8985f"/><file name="Mage_GiftMessage.csv" hash="6cd672267af7f7183f47c58450c2779a"/><file name="Mage_GoogleAnalytics.csv" hash="c8a08b1e094bdf42d8222c97241296c2"/><file name="Mage_GoogleBase.csv" hash="453420e7b2a7c67d983436cd07c3f1c1"/><file name="Mage_GoogleCheckout.csv" hash="218bdb6351129bc11f5fbb7abeff7e18"/><file name="Mage_ImportExport.csv" hash="7f6895b2225a808013a8caeeafb47ffe"/><file name="Mage_Index.csv" hash="a12d6e56dec19a45380375e7ea3f7a7c"/><file name="Mage_Install.csv" hash="ff1231e1db62fc550cac4674d0ba5190"/><file name="Mage_Log.csv" hash="302d7736324e74584e23ea35289e5593"/><file name="Mage_Media.csv" hash="9d16c10b1ba6569a972018353d17f471"/><file name="Mage_Newsletter.csv" hash="85bd38e7b398fed22997f9bd87f7afa1"/><file name="Mage_Oauth.csv" hash="53c0c0f9390456fd1be2df79ed995a61"/><file name="Mage_Page.csv" hash="920443fbde0f505cb3e1fb5df1c7fa86"/><file name="Mage_PageCache.csv" hash="365e8f2f9dace7313711e9a27d27cd97"/><file name="Mage_Paygate.csv" hash="311566b283975d5c481046346023026b"/><file name="Mage_Payment.csv" hash="4f42a6296fada9e8a3dbccf19d143fce"/><file name="Mage_Paypal.csv" hash="1df7ff2e0a9957243cdef854551fad70"/><file name="Mage_PaypalUk.csv" hash="d9d163d9c022d37e6bef2bf231469572"/><file name="Mage_Persistent.csv" hash="8df1299e4ddacadd638b7dd2f66749da"/><file name="Mage_Poll.csv" hash="01084dbcb43b1da9de35c5730fabd692"/><file name="Mage_ProductAlert.csv" hash="8ceb95248eeb2e4611d01767a7331840"/><file name="Mage_Rating.csv" hash="88db484c67afdb565255d210044bd034"/><file name="Mage_Reports.csv" hash="c49ae3155e93f7eff90b3058ec8e7b40"/><file name="Mage_Review.csv" hash="a251b73a3f358bcdd93cfde7f0a2f10f"/><file name="Mage_Rss.csv" hash="69782e132cf7ba76069b975978857b10"/><file name="Mage_Rule.csv" hash="a6a968b628d92b7f172801ce05755962"/><file name="Mage_Sales.csv" hash="d819588fd9a0eccc737b8a70ecac6cbc"/><file name="Mage_SalesRule.csv" hash="1703499a655a66855f2fa13597c09587"/><file name="Mage_Sendfriend.csv" hash="b1e310cf2fdaf674de1e7604826146e9"/><file name="Mage_Shipping.csv" hash="1c64b4423ab6fd12c0c9e2d05a80c570"/><file name="Mage_Sitemap.csv" hash="4837691c0e5c8cfbc4d75b10f196eb65"/><file name="Mage_Tag.csv" hash="d37771ca3a2321a6f1dd6c59a378981b"/><file name="Mage_Tax.csv" hash="a0665ad32147d01fec271dc8d2ee12d1"/><file name="Mage_Uploader.csv" hash="044e66927e4a70710e2d5e27105ad308"/><file name="Mage_Usa.csv" hash="dedc63b54ae93cb0f0bb82364e937425"/><file name="Mage_Weee.csv" hash="60f8a4821b2733ba6b16cba691d3ada6"/><file name="Mage_Widget.csv" hash="4bf276ac67557290beeb7ea3dd68113c"/><file name="Mage_Wishlist.csv" hash="b870b694148efc6a75fcc29a88a86924"/><dir name="template"><dir name="email"><file name="account_new.html" hash="c7516c316c9fd94aeb4a007adb42b47c"/><file name="account_new_confirmation.html" hash="c404affe58ec3947379beabf6cf2dee9"/><file name="account_new_confirmed.html" hash="19223ed36f7076dee12a8fc6f542f00f"/><file name="account_password_reset_confirmation.html" hash="f5d6538ff20ded76d73ef6dbc34c94b0"/><file name="admin_new_user_notification.html" hash="08ed9ba46dc26ef22e4d97f7350564b8"/><file name="admin_password_new.html" hash="e0cb7a16e03f1e57fc42fa3b60920bb2"/><file name="admin_password_reset_confirmation.html" hash="385547f1fd11e85b6cd818e91f519bfd"/><file name="contact_form.html" hash="ee7a957b249d9bf8d2f84787d9276958"/><file name="currency_update_warning.html" hash="be68b2b00692c3071942df42d206575f"/><dir name="html"><file name="footer.html" hash="72d4ef13825ca2143557f5baf67c27cf"/><file name="header.html" hash="739a3ea8e07bbe3be76e4c93237bc5d2"/></dir><file name="log_clean_warning.html" hash="36eb1af6eca088bdafe6e91c5a355a98"/><file name="newsletter_subscr_confirm.html" hash="cc7849aaa2ada032e0d0cbcdc4c15222"/><file name="newsletter_subscr_success.html" hash="83fc3c7d1cae23c24561f803e41ea988"/><file name="newsletter_unsub_success.html" hash="3bd611af2d1fae78622e6217ff2b189e"/><file name="password_new.html" hash="e633e5d80e81549e29b239960f5187cb"/><file name="password_or_email_changed.html" hash="26ce55df2b817a5ed2373c71feff3652"/><file name="payment_failed.html" hash="693051923f748ed9e695c0b300597034"/><file name="product_alert_cron_error.html" hash="8ea80affba71491f4371b0524d0c3399"/><file name="product_price_alert.html" hash="18ff254fcaea714647caf21b39d36e9b"/><file name="product_share.html" hash="02c76a3380f98aaaa9c3ac6a86da3545"/><file name="product_stock_alert.html" hash="6a0fc4ef5203e195d1a0957accc1fca3"/><dir name="sales"><file name="creditmemo_new.html" hash="c487a7c825477974835891019d2b55bd"/><file name="creditmemo_new_guest.html" hash="47dc131ea102b0cf72d1e8bb50df2514"/><file name="creditmemo_update.html" hash="4dd0fedbe075abc51dd3647bedbf051a"/><file name="creditmemo_update_guest.html" hash="d805b77120143a070d44a01866df8f3f"/><file name="invoice_new.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_new_guest.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_update.html" hash="1ced4397da53d8a73bfa854b1ce60c24"/><file name="invoice_update_guest.html" hash="f8e7d66c9d607f3a349a9c21544c9854"/><file name="order_new.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_new_guest.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_update.html" hash="8d8d3f6a5831909532984817afc81647"/><file name="order_update_guest.html" hash="04ffcc29c74931d5f46b6ecb25cc049e"/><file name="shipment_new.html" hash="1a8e314cada334caffe213efd1e5ce31"/><file name="shipment_new_guest.html" hash="6ba64b3b35a39bfcc4c3d0ff4acc6fad"/><file name="shipment_update.html" hash="4425c3dfceb25ea1a5b80fd054a0f79f"/><file name="shipment_update_guest.html" hash="45b6f10c6853a36879b17f86e761edbf"/></dir><file name="sitemap_generate_warning.html" hash="7eb47e4ddd7eab22272397cff8c9441d"/><file name="token.html" hash="71f392398f6f80481b2e0edba7cefc78"/><file name="wishlist_share.html" hash="8d4d4838c76468c2be6149f5314b27a6"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Magento_Mobile-1.9.4.0.xml b/var/package/Magento_Mobile-1.9.4.0.xml
deleted file mode 100644
index cf03c44..0000000
--- a/var/package/Magento_Mobile-1.9.4.0.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Magento_Mobile</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Mobile Xml Interface</summary>
-    <description>An integration Magento with mobile applications (e.g. iPhone, Android, iPad)</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:12</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="XmlConnect"><dir><dir name="Block"><dir name="Adminhtml"><dir name="Admin"><dir name="Application"><dir name="Edit"><file name="Form.php" hash="18be6ffdd7c355412d449f81ac516a82"/><dir name="Tab"><file name="Settings.php" hash="3b0f287a051dd8474da4251133c874af"/></dir><file name="Tabs.php" hash="f4f17bd4fc16c3c43c2e5948b58a83f2"/></dir><file name="Edit.php" hash="0f8abb2894eb707e68f4cd89d0fb1506"/></dir></dir><dir name="Connect"><file name="Config.php" hash="87b56d12ae88dd3c07944956add6b567"/><dir name="Dashboard"><file name="BestSellers.php" hash="7134d111d21dd9e81eff4caea27eea93"/><file name="Customers.php" hash="e28988ad7a57f37c8305e0421cd80f22"/><file name="GraphAmountsData.php" hash="eb85575aca52720dd210214e5ba93f44"/><file name="GraphDataAbstract.php" hash="c1bc1a5e031a2025e9f6c439b244b67f"/><file name="GraphInfo.php" hash="c0d817f3e595611be18b41c4105abcb5"/><file name="GraphOrderData.php" hash="94793bf7b079d8425d85a1763335cd89"/><file name="GraphTotalsData.php" hash="1f28a4db91fae0f6b6d83be17619a154"/><file name="LastOrders.php" hash="52841de8394d8ddf950ca75e2aa40d3d"/><file name="LastSearchTerms.php" hash="9ef7916ca93ac249c0e88695abc5ab4e"/><file name="MostViewedProducts.php" hash="7199f30aa2988b3d7cd3e0b7b82231f1"/><file name="NewCustomers.php" hash="e4ee586b7bff72f6dc7272d769115273"/><file name="SalesInfo.php" hash="73ea564da26d72a3d9e0f696605b85eb"/><file name="StoreSwitcher.php" hash="8474457e0c27f3237ab5897c0e7c16e8"/><file name="TopSearchTerms.php" hash="77cab704afffaecc2de1fa426e2b9b99"/></dir><file name="Dashboard.php" hash="c94c16a9043a5cafefaac9dee1883ee5"/><file name="Loginform.php" hash="6d9e82f37f99d50ad9b5733a0ad373b4"/></dir><dir name="History"><file name="Grid.php" hash="b50dcdf47d14b2c1e74b2373051a33e8"/></dir><file name="History.php" hash="9b85bb8d93eeb36d1ec6f1d89479a492"/><dir name="Mobile"><dir name="Edit"><file name="Form.php" hash="b39335871f93126f4c6777012083a1be"/><file name="Submission.php" hash="fed2d742709704afdd431e14c7150ab2"/><dir name="Tab"><file name="Cache.php" hash="d027acb7bbc0523c6e7b98be0380bc17"/><file name="Content.php" hash="2f0dcf3822603c30e19473f499bbac2a"/><dir name="Design"><dir name="Accordion"><file name="Images.php" hash="23892e279d0b704a196746ffa31a0563"/><file name="Tabs.php" hash="d61b92dfa34f8400e4e3634491a90a87"/><file name="Themes.php" hash="c99774552cfb7c3a9900aea547e08097"/></dir><file name="Accordion.php" hash="a3ac8ebe1b141388d66fbc1427013ab6"/><file name="Images.php" hash="8a8aa7d3071d5b2c897d963b9241530b"/><file name="Preview.php" hash="0c09f94658ad2ce54eff498ddbc22d0d"/><file name="Themes.php" hash="ccdfbfb55b1a6546f1a4a6c63bd31fb4"/></dir><file name="Design.php" hash="ce325c4f2a7b4f710c1811ad5af6cfee"/><file name="Flurryanalytics.php" hash="4d5e17172aae5aed0446e01e672e1ae7"/><file name="General.php" hash="0e2874a5f47ca792a71b1c320ea2da4e"/><file name="Notification.php" hash="68989b0f6d1a09c87d1a87a080773a0c"/><file name="OfflineCatalog.php" hash="667ea36b4072d5f05aa6947a28fc99a3"/><file name="Payment.php" hash="da614bd47891075e3b6799c08649d468"/><file name="Settings.php" hash="c145920bbe669e21d1295e1c08ad7163"/><file name="Social.php" hash="c7f35dc8337786a143acd4348ecce7e8"/><dir name="Submission"><file name="History.php" hash="f615d12065b9ac60a7de1dc996dfab0b"/></dir></dir><file name="Tabs.php" hash="8e10429333aa0f9533ccbc015f46b4ba"/></dir><file name="Edit.php" hash="32c191dfd9f0f630b9aaa9a5adb94e44"/><dir name="Form"><dir name="Element"><file name="Addrow.php" hash="2de7e669a33605ada631a1277964aa67"/><file name="Color.php" hash="6ddc0bb0f5101e2d725ca8d48c5bf756"/><file name="Country.php" hash="adb6eddd4501270afcffa02bedbbc112"/><file name="Datetime.php" hash="4d180c7761cec12eb3c7b5d1330e378d"/><file name="Font.php" hash="bedae4f4b7e006cc9a6695dba5a208bf"/><file name="Image.php" hash="828fedd806faf6e7674a8fa12bcdda80"/><file name="Page.php" hash="e4d9a146374e6840440a804b3488951d"/><file name="Tabs.php" hash="68fc1c371a04180873cde4af547a9342"/><file name="Theme.php" hash="4d188f42b28f49119e0bb4a84012c8d4"/></dir></dir><dir name="Grid"><dir name="Renderer"><file name="Bool.php" hash="625dd7a22b19f31639b8ef0ec0c20f4c"/><file name="Type.php" hash="b48290e352e4df28481a162cb631de67"/></dir></dir><file name="Grid.php" hash="87e2b69ee002065bb02beaf39dda089b"/><dir name="Preview"><file name="Content.php" hash="3aa56cd03743ce213aae3a5925f4a08e"/><file name="Tabitems.php" hash="ca925de201e3dc8af3177d130fb87a74"/></dir><dir name="Submission"><file name="Form.php" hash="ec1ceeea6a087983e49651eef19a6dd9"/><dir name="Renderer"><dir name="Country"><file name="Androidmarket.php" hash="4140c6b311419a88e4446411c77f863d"/><file name="Istore.php" hash="ca9c9d39c4685fc93416540ca47eb7b8"/></dir></dir><dir name="Tab"><dir name="Container"><file name="Submission.php" hash="ca2ed4e535597a4dc0dc5f71b03fc390"/></dir><file name="Container.php" hash="3d893b8aaf1b6c0e0966faedacc3e5c2"/></dir><file name="Tabs.php" hash="98d6bf6dccc749544311f23c581a3111"/></dir><file name="Submission.php" hash="490ca37478730072e3f3cb10580d0e0c"/><dir name="Widget"><file name="Form.php" hash="9526cf41e8ab9781fd2a28cf4dbe2bfa"/></dir></dir><file name="Mobile.php" hash="c1960a31775120c9499f1052bb775250"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="e9efb1f673b2f21da26446852bd68310"/></dir><file name="Edit.php" hash="c82e2bbee5fd3cf15567d1748ec012bb"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="f1cab5df3efeb224b90ab076dfed9550"/><file name="Application.php" hash="41e1376368264c68cd0cc8332cde0730"/><file name="Id.php" hash="4defece4c272caf2720f2ab0d0c1f0ac"/><file name="Msgtitle.php" hash="d4b69d6a657e7772451ef65c63235ae7"/><file name="Pushtitle.php" hash="948ccdc09722aeb7b5287ae775a218ac"/><file name="Status.php" hash="5591fa63b3b160171d79e71d8d350f1a"/><file name="Template.php" hash="143aaa66af7b276d6d973a904c7cd175"/></dir></dir><file name="Grid.php" hash="d32c1f8686f862f9507db824f06b816b"/></dir><file name="Queue.php" hash="9f0f8ecaffd50949409ea126f56a2e88"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="dc40630afad3ea8a9dc4ed7b87277716"/></dir><file name="Edit.php" hash="0aa025f155eb299044e3dae8b5ee5579"/><dir name="Grid"><dir name="Renderer"><file name="Application.php" hash="b44b72d5a06cf8e380fefc5edbdf35f5"/><file name="Name.php" hash="9248874c8e7775513a341d5b7e3125c7"/></dir></dir><file name="Grid.php" hash="4b766a3d51516cb3cfed39699d760a14"/><dir name="Preview"><file name="Form.php" hash="9eecc83db65aac8cc0a085dee84ecb50"/></dir><file name="Preview.php" hash="305dfd65e73a3ed898893b170cc12732"/></dir><file name="Template.php" hash="e7220052fb9a0f7ee17a7e007ad80c87"/></dir><dir name="Cart"><dir name="CartTotals"><file name="Default.php" hash="e81662723cc554bf93bb8868dd41b6b1"/><file name="Grandtotal.php" hash="7907f67687320c770cda36f72a26252b"/><dir name="Nodes"><file name="Default.php" hash="982d082903f48e68bb91165a4a5182d8"/><file name="Giftcardaccount.php" hash="0131a57dc306dd6f7280bba3182304d9"/></dir><file name="Shipping.php" hash="181b533a57f48147dce4eafeecb7c5f8"/><file name="Subtotal.php" hash="e42e0617841c0ba3892f781aacddbf1d"/></dir><file name="CartTotals.php" hash="f961282950d5aeb2e4a859ecd89c7f02"/><file name="Crosssell.php" hash="0a83b72fa16d79b63dc4c9fcba0c37c3"/><file name="Info.php" hash="7af98f3c441217e4735a13dcc8d13342"/><dir name="Item"><dir name="Renderer"><file name="Configurable.php" hash="aa04ba5fb52c5b1a858d1e6b14c2d5db"/><file name="Grouped.php" hash="36a290b9624eeea299b4e1f09370ccda"/></dir><file name="Renderer.php" hash="427a01fd7cb099a823f666e0459b92d0"/></dir><file name="Items.php" hash="90094a7c8709cd0f76517e3fe1b8c16d"/><dir name="Paypal"><dir name="Mecl"><file name="Details.php" hash="3474c0cba2c95c53151bee9f782c6c70"/><file name="OrderDetails.php" hash="e700c7004c137aed7770ce99ef112fa3"/><file name="Review.php" hash="ca5ec99a17d2844ad41fab85408e0331"/><file name="Shippingmethods.php" hash="dfd7048ac79b89c984d4d65c2f08de42"/></dir><dir name="Mep"><file name="Totals.php" hash="84f440f6613ee644a12f7585eab02db2"/></dir></dir><file name="Totals.php" hash="5719f0a9c2a79c41fc0b60b40f987d24"/></dir><file name="Cart.php" hash="5b77cf7f3d7bf6ac31b2cab1376a72d5"/><dir name="Catalog"><dir name="Category"><file name="Info.php" hash="fe12a230101c361a41b3d9cd6758f094"/></dir><file name="Category.php" hash="c4583d3ef50819761144f1158b5b2b6a"/><file name="Filters.php" hash="5916239aaa999dfedff7145525ad3ac2"/><dir name="Product"><file name="Attributes.php" hash="352ea45e2818bd8775421a88966378aa"/><file name="Gallery.php" hash="54ad61285abcc3b29d11a237a7f41b78"/><dir name="ItemPrice"><file name="Bundle.php" hash="934691fb8c805ac45a7112a8268be658"/><file name="Default.php" hash="bbed8ec56060f70dd0bb4466390a2098"/><file name="Giftcard.php" hash="39cb9ef1fae797bab979b414da2697b4"/></dir><file name="ItemPrice.php" hash="01aa1b430438c1422ddd9e864e2401d4"/><file name="List.php" hash="8dd1e301a4c00895d6987a60b424f1ab"/><dir name="Options"><file name="Bundle.php" hash="0b55a73ccb10bd0296d10d6c31811712"/><file name="Configurable.php" hash="832f951702911ed9f7dbb6ab1b95184d"/><file name="Downloadable.php" hash="0555d353b7fef2a23bab5c62237bc816"/><file name="Giftcard.php" hash="e4f9f5deae7ec418a2ccf210738811d0"/><file name="Grouped.php" hash="f47c95399047ca31fe7b124dafeb2336"/><file name="Simple.php" hash="cf5df8515ada2bdcbde11c5c4f3bc1c0"/><file name="Virtual.php" hash="d779fb0b7c5a3a36eb949725f6066de6"/></dir><file name="Options.php" hash="26b51c5e2349d5714ef1ac11166200bb"/><dir name="Price"><file name="Bundle.php" hash="3c5664b73fd679722e28210cb45b4e1a"/><file name="Default.php" hash="93b76d312b7c403dc99653752628ea38"/><file name="Giftcard.php" hash="f7d79e2d2384c732c33d77831d669f58"/></dir><file name="Price.php" hash="e6272f9b2c349ed9aa7c0bbc4e14ba1a"/><file name="Related.php" hash="5a426f5e5cfa50680766ce585732d450"/><dir name="Review"><file name="List.php" hash="6b2d364d67f3ff46478d0512027bb198"/></dir><file name="Review.php" hash="876a30958acdf8f4597335807c8f1814"/></dir><file name="Product.php" hash="e045c7a7b2490e814cb83f889bc76433"/><dir name="Search"><file name="Suggest.php" hash="97341e9253e8b53008849bc18b4d9c15"/></dir><file name="Search.php" hash="2799e12ea33e91c79c737755115953ab"/></dir><file name="Catalog.php" hash="2c2954ced5c922ac6fbb2a7ed94feb02"/><dir name="Checkout"><dir name="Address"><file name="Billing.php" hash="235ece5a9acefc903bf26a449f7696c2"/><file name="Form.php" hash="c50b6b1f7a04f1710d26aa76bdb83b20"/><file name="Shipping.php" hash="6b2b3df4296b82504c91789300336b7d"/></dir><file name="Agreements.php" hash="248e853db9436b7353e2823cb37d3e24"/><dir name="Cart"><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="35c5daea28048a29f025cd483e846638"/><file name="Configurable.php" hash="718da5a76f2fb30c72a3b87d42f088a2"/><file name="Downloadable.php" hash="333e998a37991e7d66324b56d75d003a"/><file name="Giftcard.php" hash="ca7535b1cbf6fd929da88c1eb55e9fab"/><file name="Grouped.php" hash="258a71d41ea9c8d9305c18a86f6db427"/></dir><file name="Renderer.php" hash="dc0070a52a5ddedbfb6d9d81bfb5091d"/></dir></dir><dir name="Onepage"><dir name="Address"><file name="Form.php" hash="f51cf393e7a88ddf07fb6689ac0131f1"/><file name="List.php" hash="aaa1389a6374653b6870a803162a0962"/></dir><file name="Address.php" hash="071bcf36fc462d10497c6b78af6d1f89"/><file name="Review.php" hash="9f1f63c81a4ba8c23f9bdbb2b328d29a"/></dir><dir name="Order"><dir name="Review"><file name="Info.php" hash="68e610e2236ac0ed526f5a6d76d9aea7"/></dir><file name="Review.php" hash="795a47724af069613738848478df714b"/></dir><dir name="Payment"><dir name="Method"><file name="Authorizenet.php" hash="aebd18a2aa07609f2fe07ea9c6033a9c"/><file name="Ccsave.php" hash="32c7844e003ed81fc36ab0f0b2984f9d"/><file name="Checkmo.php" hash="d34d3ad863b6236f67e9a5bed1167287"/><dir name="Info"><file name="Authorizenet.php" hash="3ee20e52608afff657ca7977bc9c7d8c"/><file name="Ccsave.php" hash="59281ffc690044f961490679b9eeaa83"/><file name="Checkmo.php" hash="26bee7db3c9d9ec4a2be154d298e6e80"/><file name="Free.php" hash="1928bf8c13732d359c9a3399a5697a99"/><dir name="Paypal"><file name="Abstract.php" hash="d4ca56c7e7b0434cf78f4aa745602da0"/><file name="Express.php" hash="3e5aaf65696b402ca7c44dd3656fc611"/><file name="Mecl.php" hash="2205fb1f735278fded252542545cba8d"/></dir><dir name="Pbridge"><file name="Authorizenet.php" hash="de462e278ceb51696e8e8f347860edf8"/><dir name="Paypal"><file name="Direct.php" hash="d4a745ccf3eb6234b3e6b2ac68d912e6"/></dir><dir name="Paypaluk"><file name="Direct.php" hash="cbb23c943b4dfd8f2f03bd5a6d23277c"/></dir><file name="Verisign.php" hash="936073039408b25322914bcd3e9173bc"/></dir><file name="Purchaseorder.php" hash="ebc9440844b88830d99422abb0719ee6"/></dir><file name="List.php" hash="8e648b7be94f4d9185012829207bb443"/><file name="ListApi23.php" hash="9224c0fd6a9e77031abbb064d7cf5513"/><dir name="Paypal"><file name="Direct.php" hash="099c3529fb5444c50a9d0671f910df14"/><file name="Payflow.php" hash="07be42249281b35a425f4bf15d6bd4de"/></dir><dir name="Pbridge"><file name="Abstract.php" hash="098fa28d25c3d9a27f1145820024fc0f"/><file name="Authorizenet.php" hash="23265f73b0756da01ddf9b652be7677b"/><file name="Paypal.php" hash="b70198d4d55cc58bbb1df4d756f8270e"/><file name="Paypaluk.php" hash="867d1c9e376ab55ad2f740f3a1dc0e50"/><file name="Verisign.php" hash="ef4f28a565a3c8c4eeb3582538f99ed9"/></dir><file name="Purchaseorder.php" hash="ea64ee616a535e4a79cab9ec443430a4"/></dir></dir><dir name="Pbridge"><file name="Result.php" hash="833edb3d936fba72ad611b61d55c9dc8"/></dir><dir name="Shipping"><dir name="Method"><file name="Available.php" hash="e29e91a545cd7a63e653a09be622c792"/><file name="AvailableList.php" hash="7b2eaab0e3366288483052dedf66b1f5"/></dir></dir></dir><dir name="Cms"><file name="Page.php" hash="66d86a57c216b1575b7714b94dbe7231"/></dir><file name="Configuration.php" hash="b7f7301648fdb249b7b4ad162779756a"/><dir name="Customer"><dir name="Address"><file name="Form.php" hash="0b02c6a2eebb0b4a3048eb9757dc98f8"/><file name="List.php" hash="d7c3509d0fc978f0936c04d46e9c9129"/></dir><file name="Downloads.php" hash="e1340b1f0629a9ebf651c79042e688aa"/><dir name="Form"><dir name="Renderer"><file name="Boolean.php" hash="814c293b8d543a8acc618cf4dd448ece"/><file name="Date.php" hash="63690b28d76a20d4c88915d207901c3c"/><file name="File.php" hash="a009b01dca404d38b8fe792b1895c2d4"/><file name="Image.php" hash="eb2e63a8a4cc719e72d2af1e3453354f"/><file name="Multiline.php" hash="15502166fe772ae59b139692ca6c80ca"/><file name="Multiselect.php" hash="8a42000f230d7f2674cb9e422665fa13"/><file name="Select.php" hash="e598ac63fe4ca05a6d313556251624c2"/><file name="Text.php" hash="40879381558845259cbc174a7349c6b6"/><file name="Textarea.php" hash="5da94ac937bd6565b55de6c9e2de4a6c"/></dir></dir><file name="Form.php" hash="e2c00f4ec6a0004193358a110c88cdf8"/><file name="GiftcardCheck.php" hash="b3797d939644ed5ab34f8b8b05454133"/><dir name="Order"><file name="Details.php" hash="69d7f0dd6f79fc090b7ebcfcb7387962"/><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="3f3fecde3c64e48899f8055e4c7c093b"/><file name="Default.php" hash="1c51709757db243c3bc99d4989fc11b7"/><file name="Downloadable.php" hash="3b26206355e81d315dca5e8661c06fe1"/><file name="Giftcard.php" hash="8614dd8ad1a3ba75939024726a5eab35"/><file name="Grouped.php" hash="b78c5b229a86e711e8eca236d2c769e0"/></dir></dir><file name="Items.php" hash="b6e76778d4ba432f2d0817615ad47ebc"/><file name="List.php" hash="37f0f7707c65542c14a7ea8faa3cf0fa"/><dir name="Totals"><dir name="Customerbalance"><file name="Refunded.php" hash="3ed573470f738c977a2c622a2f1c61c3"/></dir><file name="Customerbalance.php" hash="b8d4ed847d6572d761392d47ab0b92ce"/><file name="Giftcards.php" hash="6d33c6ad16511d3493b6bcb45e3f2f4b"/><file name="Tax.php" hash="6ec05ef126716a9016a4d8d5cbd79c67"/></dir><file name="Totals.php" hash="0753a87dbdb6f20f20d01110433fa2cc"/></dir><file name="Storecredit.php" hash="38a6534993df649b8980191489f85234"/></dir><file name="Home.php" hash="0171e134d103453d5efa9c28b1a5a98e"/><file name="Homebanners.php" hash="cd43276610e43cb05317be3266829b12"/><file name="Localization.php" hash="13a1440efbe0708d8745e098ff2fbde8"/><dir name="Review"><file name="Form.php" hash="719df761030dce75d34620cffbc22eef"/></dir><file name="ShoppingCart.php" hash="8740a15f227063ee93fd062439182838"/><file name="Wishlist.php" hash="c35e5cbcb2c2fc2b73f9119059004abd"/></dir><dir name="Controller"><file name="Action.php" hash="aa28af4f890fa7bd98f09c62174a7b47"/><file name="AdminAction.php" hash="c113ab27904827ac00f42c1ec56453cf"/></dir><dir name="Helper"><file name="AdminApplication.php" hash="a6a346728711a616a20ac208b97b4208"/><dir name="Adminhtml"><dir name="Dashboard"><file name="Order.php" hash="34bbd403a942aa9067add45539eba21c"/></dir></dir><file name="Android.php" hash="7b607ec61ab3d8037087a75a3dc20367"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="a1181040f6a5ae2b61155229914bad90"/></dir><dir name="Product"><file name="Image.php" hash="a580b197c858ae4f86f0c76933d09b3b"/></dir></dir><dir name="Customer"><dir name="Form"><file name="Renderer.php" hash="b5dc3f5225fdac80c05dfe8c8f02073a"/></dir><file name="Order.php" hash="2fb69e79641bca8f1ab60e71db754380"/></dir><file name="Data.php" hash="ae1445dc639814841ed7d51aeffb8c3f"/><dir name="Device"><file name="Abstract.php" hash="ab62df36a04511db7f8206b2806a5b35"/></dir><file name="Image.php" hash="e169e856e7eb7502e0afa2dd0fcb6473"/><file name="Ipad.php" hash="a1c6010a148024f6e9f9371e5a0e4514"/><file name="Iphone.php" hash="db438395e4c39ddf6b08fa6e19f58837"/><file name="OfflineCatalog.php" hash="5d4586f34454d52e702a9a2c8c79209e"/><file name="Payment.php" hash="f9e55cd314d8a84304192083c3278ba7"/><file name="Theme.php" hash="fcc83009fc28d8ec70e97ab68415cca0"/><file name="Translate.php" hash="ea693f28b867e58b8a89f94b37fa7306"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="Search"><file name="Catalog.php" hash="2e6af877121f1f6206b0dff3de4351d4"/><file name="Category.php" hash="7344300c925f43df7cd1d87885cfd3ea"/></dir><dir name="System"><dir name="Config"><dir name="Backend"><file name="Baseurl.php" hash="df19169e6a42dda126784f789d4ca489"/><dir name="Currency"><file name="Default.php" hash="3d89d67b2f6a577d1d17f9f8137df07f"/></dir></dir></dir></dir></dir><file name="Application.php" hash="30bdb5b50cb7574980a47f28485ef544"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="acd1b1cf0d949616daeabaea12ae3bab"/><dir name="Media"><file name="Config.php" hash="bfe9fdf79473026783f9307591c039b7"/></dir></dir></dir><file name="ConfigData.php" hash="1b2026535bc234c289d606884912dcac"/><file name="Configuration.php" hash="d6d8bdd4c79aaa1affa9a8c71776aa27"/><dir name="Device"><file name="Abstract.php" hash="efb12adbe5626df1f03a58e1ea761760"/><file name="Android.php" hash="3edf0f598b61a3d0bb74967473c5422a"/><file name="Ipad.php" hash="ce7f5ea81ea71feb4fee7a13e2822952"/><file name="Iphone.php" hash="a52717c33a4b25056fc3cfeb49c03db9"/></dir><file name="History.php" hash="2235f24899f77bb20019f30cd5b43461"/><file name="ImageAction.php" hash="51ead1214bd38f35c947c9a9a410199f"/><dir name="ImageLimits"><file name="Abstract.php" hash="ed2bac8df20078a88c199862988b51fd"/></dir><file name="ImageLimits.php" hash="5463b50b15bf317dadbc8853bec61a55"/><file name="Images.php" hash="2d646c61ab2f0bc751f735a0f902d517"/><dir name="Mysql4"><dir name="Application"><file name="Collection.php" hash="9d2ff8db89101e153cff566a4dcd49c2"/></dir><file name="Application.php" hash="12bb5e198d9c5dff257ee6f4e0a63165"/><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="da36e2bb02ce9b1b490a61e22825098b"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="d910362570917ba3d066239901325c50"/></dir><file name="ConfigData.php" hash="e3f2172a3bd7bb7d358905c29c9aebc5"/><dir name="Filter"><file name="Collection.php" hash="da42e91c731132e8d32bda10bee05e9b"/></dir><dir name="History"><file name="Collection.php" hash="d1d9b6735cf2aaa6cccfe5bea1cfd646"/></dir><file name="History.php" hash="5403dc5cc4d58c7d66168eb7212dff5f"/><dir name="Queue"><file name="Collection.php" hash="10f054092e5fd65e17a484dbc06adba3"/></dir><file name="Queue.php" hash="214361aa7960e141d44a525bab2b5ab6"/><file name="Setup.php" hash="ca9337c48d1a1168bbf76036f8bcf72d"/><dir name="Template"><file name="Collection.php" hash="cef8ced8e5d16bdb475b2493f8d3c12f"/></dir><file name="Template.php" hash="8722c9769dc835607e332387aa5d6bd7"/></dir><file name="Observer.php" hash="bca103d97f859a57afcb20434004bc05"/><dir name="OfflineCatalog"><file name="Abstract.php" hash="65fa4eb5b0c583d29db761e5249f9269"/><dir name="Category"><file name="Category.php" hash="28887645eee8fdda480adb926d333820"/><file name="IndexCategory.php" hash="3d7deb0329ac5580356b116048823755"/></dir><file name="Category.php" hash="c240b6e64b36d7d547b03fbff52a6004"/><file name="Config.php" hash="27e0a9b70fcf4e6f28395f2d06f551ce"/><file name="Home.php" hash="5fec268bfb2d8fa8bb5e3d3cd17df6cf"/><file name="Homebanners.php" hash="5dd2c18d679451e659e2b6ffd34cf088"/><dir name="Product"><file name="Gallery.php" hash="67b9cac501378c6256bc7876c0a8a08d"/><file name="Product.php" hash="ce4b25b1862bea8cd624f918d74df8e4"/><file name="Review.php" hash="e1c0877d850f86ff7b2adccd68ab679d"/></dir><file name="Product.php" hash="13c2f6c7dda49e3b668ba77c42af6ce3"/></dir><file name="OfflineCatalog.php" hash="3652212af08998ff06d90345e2bed0db"/><dir name="Payment"><dir name="Method"><dir name="Paypal"><file name="Config.php" hash="eba57e1172a75bac4d96dbd590bcac54"/><file name="Mecl.php" hash="c3cb6d931a124ccb1b5e1c6ec704c134"/><file name="Mep.php" hash="2c8e4f6d1150addbe76b52cab54c4ecb"/><file name="Pro.php" hash="0c6086ffcef35a99e31a92460719de07"/></dir></dir></dir><dir name="Paypal"><dir name="Mecl"><file name="Checkout.php" hash="2fe903d0a69743a3beda6dabdf7779c9"/></dir><dir name="Mep"><file name="Checkout.php" hash="8cc405987b24e6937ac106643940b352"/></dir></dir><dir name="Preview"><file name="Abstract.php" hash="d7441ed91eb8bb8264eb091405473619"/><file name="Android.php" hash="1b753f745d9a3a21ac6655b5f3c29511"/><file name="Ipad.php" hash="dd9263af5283abbe471270b204171f1c"/><file name="Iphone.php" hash="2ff9d89170d89c5e4fafacd6c2d26837"/></dir><file name="Queue.php" hash="a1e2d93c7648ab9f1a2cbecda5dc0c63"/><dir name="Resource"><dir name="Application"><file name="Collection.php" hash="8c9ebfc544abd8bbd5351e16ca71173b"/></dir><file name="Application.php" hash="1326f94db59dc30f645ec4143a7e4c88"/><dir name="CategorySearch"><file name="Collection.php" hash="09c91216af434f8333aeac96434cb4ca"/></dir><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="9784becabf9a30e8ea6eaf843d5e3866"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="a357f235f37aecf20cc5a13b59ea3239"/></dir><file name="ConfigData.php" hash="84c30e8759f80b50385bee026de963db"/><dir name="Filter"><file name="Collection.php" hash="38231b2d6de6b1a2e5d7da2c05fcee92"/></dir><dir name="History"><file name="Collection.php" hash="5ac9d983c37fdbf908272edba35da72e"/></dir><file name="History.php" hash="656be7ec06a9a0d21d02411fdaa6b878"/><dir name="Images"><file name="Collection.php" hash="1fa3ec8d6e718b0a4dc2f666317cc8af"/></dir><file name="Images.php" hash="4045d7981f9e8231a41f5073c26157c4"/><dir name="Queue"><file name="Collection.php" hash="168c85c2649c0931644ce663f6e47a6b"/></dir><file name="Queue.php" hash="86a49be4c913e256d669909a098900dc"/><file name="Setup.php" hash="e65c040707309bcfcf4afa769c41594d"/><dir name="Template"><file name="Collection.php" hash="9fefe8ef407cffe7f762ad3c5f04c1c0"/></dir><file name="Template.php" hash="df69d55cbd43c3126916b775974275c4"/></dir><dir name="Simplexml"><file name="Element.php" hash="85eda8f850af7f2b0e5bb744eb24b9ce"/><dir name="Form"><file name="Abstract.php" hash="58953feebdc7574e47cc24febdfd6cca"/><dir name="Element"><file name="Abstract.php" hash="52489a893ed654b1356d93f9bedbb7fb"/><file name="Checkbox.php" hash="734e125419a6206baa224aef5b25d507"/><file name="Collection.php" hash="786f39e9a5e2ff90ccdd7787b11cd132"/><file name="CountryListSelect.php" hash="3c36ec543a347075f139d0421a7f2e51"/><file name="Custom.php" hash="493bb8b95f70f80d4606628dd27c651c"/><file name="Date.php" hash="26bcfbd4540194dcca491a550bd9d386"/><file name="Email.php" hash="5eb3e7d979518048ec46dff03e2a74a1"/><file name="Fieldset.php" hash="8823f98606c7baa0ede0e73e21e02ac7"/><file name="File.php" hash="f50c9023c37a165e9c85d8bf8adcea22"/><file name="Image.php" hash="cdc0508a3f47729b8e65c1b29ef1d468"/><file name="Multiline.php" hash="e43a266f39214ccb359d21447aba0433"/><file name="Multiselect.php" hash="e35ee1d08e5cf3cd40fe2ac0441e16e1"/><file name="Password.php" hash="6439ab336ff5ca6c32b768cd91c38376"/><dir name="Renderer"><file name="Interface.php" hash="70e0d05d72803afe580a55ca12a5ad4a"/></dir><file name="Select.php" hash="316c403364f954a588de35021c0b1a76"/><file name="Text.php" hash="a83e5f7d24345aa97e231c51f7fdffe3"/><file name="Textarea.php" hash="d92e6646075009741222ace78ae9fe1c"/><dir name="Validator"><file name="Abstract.php" hash="5f495e595a11928ae153bca79ac2ed0a"/><file name="Rule.php" hash="ed20d66918f3718981847ad4940d3722"/></dir><file name="Validator.php" hash="d0f110a77b89d1bd9244d707bfcb8627"/></dir></dir><file name="Form.php" hash="9a38fef2158d667ac59ef58b0a2a4184"/><dir name="Message"><file name="Abstract.php" hash="632ef61eed496c67ca2c31faba088fa0"/><file name="Error.php" hash="380f13e3bbdbace690ecd7350faf0a36"/><file name="Success.php" hash="8dd8a2df3a7d0e1ac974626e98eb9ae2"/></dir><file name="Message.php" hash="e3ea79eca24bc725c9cd3df1a1fb6188"/></dir><file name="Tabs.php" hash="282fc6a6103c91b6bd5cc3ea7524adea"/><file name="Template.php" hash="063b3699e6ba48c4d301de5fedb737f8"/><file name="Theme.php" hash="541352f9b1a96673f366b980b4aaf232"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Admin"><file name="ApplicationController.php" hash="7154aabbf015aa133e6d924b2b147392"/></dir><dir name="Connect"><file name="ConfigController.php" hash="1bb1b0ef95ef191e0fcd7519aff761d1"/><file name="DashboardController.php" hash="dcb1688f5c7ce4aa5a494988e740ea31"/><file name="UserController.php" hash="265923431772ab92fa0c81f72a027c04"/></dir><file name="MobileController.php" hash="f411b283681d962e7bf56dd13d6ae681"/></dir><file name="CartController.php" hash="5adcd8840b904b088d5b9e5411b9f0ad"/><file name="CatalogController.php" hash="86362c2d85e99bb7099142f6a7d3b67f"/><file name="CheckoutController.php" hash="7599d30a4c8759aa24185d1fe597f583"/><file name="CmsController.php" hash="32143c3d9b6facc655837787df3be1fb"/><file name="ConfigurationController.php" hash="962fc5e176c6df506628ece18eac9a28"/><file name="CustomerController.php" hash="ff3e84d086739dbb6f8b13ad9377ef35"/><file name="HomebannersController.php" hash="24212153f5d52004076049d8bbd34937"/><file name="IndexController.php" hash="1aefb4fbffa158d206da6b87ee24d96f"/><file name="LocalizationController.php" hash="4c258955073f4655ff5576dcab06e548"/><file name="OfflineCatalogController.php" hash="8a1890da0f5295968ce840e59a301320"/><dir name="Paypal"><file name="MeclController.php" hash="c0d3c1197373674d20235de1a925bb76"/><file name="MepController.php" hash="e74221e124abdf52ae3093965e0313fb"/></dir><file name="PbridgeController.php" hash="c410e18aa7e5a94d12bd650b42b0a2dd"/><file name="ReviewController.php" hash="ac34d14c2f9d1640200d99876e47eb45"/><file name="WishlistController.php" hash="6ffe6b32ff7ef85feafd74e4323238db"/></dir><dir name="etc"><file name="adminhtml.xml" hash="41a0eee0ff8ccc97791fca3984583b10"/><file name="config.xml" hash="0d09a634d1207e56f851ae9f4ec763eb"/><file name="system.xml" hash="60e071b734b4cd4cad9104308d4194f2"/><dir name="themes"><file name="custom.xml" hash="14fc8ad9b2b3d7e573e71aa7d68346f6"/><file name="default.xml" hash="3176577e6bbb1366b281e9e9645540ff"/><file name="funk_leaf.xml" hash="e88f9debf8ce7d072add428589ab8dac"/><file name="hot_red.xml" hash="91256c9132bca710e3392530149d85dc"/><file name="sky_blue.xml" hash="313ba8de5835b597911d6f8307a4b886"/></dir></dir><dir name="sql"><dir name="xmlconnect_setup"><file name="install-1.6.0.0.php" hash="bfa8161a83d387752fe3304945e4f902"/><file name="mysql4-data-upgrade-1.4.0.13-1.4.0.14.php" hash="868ccb802d0827a7cbd9f44192c0d2b9"/><file name="mysql4-data-upgrade-1.5.9.9-1.6.0.0.php" hash="1bedcf73c1fa646f2ae2f1fa04df558b"/><file name="mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php" hash="48a7cc742843624292f1971985a88679"/><file name="mysql4-install-1.4.0.8.php" hash="9f9e15de94aa8973996adea3944238f5"/><file name="mysql4-upgrade-1.4.0.10-1.4.0.11.php" hash="954f56443e96a25c07e78215c7e99f12"/><file name="mysql4-upgrade-1.4.0.11-1.4.0.12.php" hash="92a411920731b922db4ab8f2af503b11"/><file name="mysql4-upgrade-1.4.0.12-1.4.0.13.php" hash="a650fba5fd52ddc46600258310771dba"/><file name="mysql4-upgrade-1.4.0.13-1.4.0.14.php" hash="41fddc2b9601a81745b918cb36126044"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.9.php" hash="dd5ca9ac54e429a22bc60cea44915985"/><file name="mysql4-upgrade-1.4.0.9-1.4.0.10.php" hash="ef96cdb8d2e38faa3b6f987ee4a683ef"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="639c80838a314daa3d591a7c7dbdf4a8"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="4634743a3374bff5a5476b27b224b67f"/></dir></dir></dir></dir></dir></target><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="fb2334dc39e13ef93f0681d4e524831e"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="centinel"><file name="authentication.phtml" hash="d91b808dd1e35943da6a98029d2473eb"/></dir><dir name="pbridge"><file name="result.phtml" hash="b1b8bbd1290f37c838fa7f444d6ecb59"/></dir></dir></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="5e24fb559ca14f2ef0a450564bcd3afc"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="edit"><dir name="tab"><file name="content.phtml" hash="56551d499302bcc380de3bb93919887f"/><dir name="design"><file name="autocomplete.phtml" hash="b44f7193e354ae434de9e27f3fa8581f"/><file name="image_edit.phtml" hash="5c4a33b3722f5080db8783b12d3d83a4"/><file name="images_android.phtml" hash="4e5080a1743b18d1c6c0a6c0be7bc62b"/><file name="images_ipad.phtml" hash="b224f7a1d06f548499c792ef006be6e0"/><file name="images_iphone.phtml" hash="137a3ee34d0bf2a5c6dc80fa557e6580"/><dir name="preview"><file name="banner_rotator.phtml" hash="9344b3fa99e7366d643375d00575af1b"/><file name="catalog_android.phtml" hash="fd8c6f2e795223829c5d6a307aec45f4"/><file name="catalog_hor_ipad.phtml" hash="e60ea7d98d03fa30ed54de3f75793c19"/><file name="catalog_ipad.phtml" hash="d721dd136eefcfc9d10dc8c84b5e85c7"/><file name="catalog_iphone.phtml" hash="5751eb24402061706e1c38d4656a0055"/><file name="home_android.phtml" hash="8bb911cb0fd3ccb0a6a37cf46c1a12c6"/><file name="home_hor_ipad.phtml" hash="90a93d056928407b20ab848b7a78bc88"/><file name="home_ipad.phtml" hash="aadde2d0a5cc1f49571b8aed8f426d14"/><file name="home_iphone.phtml" hash="41490d6e60cda7b22cdb80e0c03271bf"/><file name="productinfo_iphone.phtml" hash="d0339da69754129a8f0a657bc7ba6bd7"/><file name="tab_items_android.phtml" hash="49c3b831da3079379a1f72ccb82350ad"/><file name="tab_items_ipad.phtml" hash="52b6b823508df6eb8857298a2d256dba"/><file name="tab_items_iphone.phtml" hash="862f3e4d6b5628361853458f5567c7d0"/></dir><file name="preview_android.phtml" hash="4d46079265bdac87bd80e635614d6543"/><file name="preview_ipad.phtml" hash="d6f3605c9b92df3718f4dd746557f57e"/><file name="preview_iphone.phtml" hash="b9bdb4a39efb45f83212502bf85fb020"/></dir><file name="design.phtml" hash="5219b884a2e198a9568606d32fc5795d"/><file name="offlinecatalog.phtml" hash="46a17407498e5ac909aab2adbe8d79c0"/></dir></dir><dir name="form"><dir name="element"><file name="addrow.phtml" hash="b9970e1bee9a2999286f63fef9ce9313"/><file name="app_tabs_android.phtml" hash="2135734b73cc0548638895cf41e9d3a0"/><file name="app_tabs_ipad.phtml" hash="85def73314a97942d7c2ae7d4f9836f4"/><file name="app_tabs_iphone.phtml" hash="9699edaeb66c47cbc7155260ff8b5762"/><dir name="country"><file name="androidmarket.phtml" hash="8c61f192c7372ab4e7009abaeaa8275e"/><file name="istore.phtml" hash="2ff59da9c26acf87d240b337961a8ad5"/></dir><file name="themes.phtml" hash="b0daadcde0d8f2d00d43997bd2ff4412"/></dir></dir><dir name="mobile"><file name="notification_helper.phtml" hash="f39f0b298a81201dcbcee02465885a83"/></dir><dir name="submission"><file name="app_icons_preview.phtml" hash="28677e2cbdb2b61f4025e00477e37b57"/><file name="container.phtml" hash="9427981ebb6994de95186abff3c7d35c"/></dir><dir name="template"><file name="preview.phtml" hash="1d24efc926e5beab76c51bb7e61b17fc"/></dir></dir></dir></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_XmlConnect.xml" hash="f403b961a6f5a99ee7bfe9b1f71f2396"/></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_XmlConnect.csv" hash="50e9493da78f8e6591fd3fad1311047c"/></dir></target><target name="magemedia"><dir name="xmlconnect"><dir><dir name="custom"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="original"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="system"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="xmlconnect"><file name="boxes.css" hash="b4818201fb27765bd5aa21940ce9feab"/><file name="dropdown.css" hash="909dbc9fea8fdc9b12388427397b440b"/><dir><dir name="fonts"><file name="android_icons-webfont.eot" hash="2fc917efbfb3c933ccfddc108ef05f33"/><file name="android_icons-webfont.svg" hash="e8cb2b5ef019bbc2885c97ed0caaf2a0"/><file name="android_icons-webfont.ttf" hash="bc567dd7a381093fbb652c58cbad9430"/><file name="android_icons-webfont.woff" hash="8310b54d55bf84a8a3f3a86c22a51aef"/><file name="stars-webfont.eot" hash="019beb4b8ec19447657cf3106138bbe3"/><file name="stars-webfont.svg" hash="20cf0312c0b951d173d4531ea18abc6f"/><file name="stars-webfont.ttf" hash="d63d95e9adaf775f410437535622bf60"/><file name="stars-webfont.woff" hash="526d9756131c94139f0f1df5272197fd"/></dir></dir><file name="iestyles.css" hash="043c38df2eb106524cac069c4cbfd4fe"/><file name="mobile-android.css" hash="c93c13a2f4e8ab35a3fa4f615f82fbf6"/><file name="mobile-catalog.css" hash="644c6178ae97ca892cd0bb23037fce0e"/><file name="mobile-home.css" hash="f6afa2a72cf41176f5f80d983483036e"/><file name="mobile-ipad-catalog.css" hash="f4245ec57c89a1c17a1ba2d58a9307d1"/><file name="mobile-ipad-home.css" hash="f234af2678977a92e6575a5fd6b841e6"/><file name="remove.png" hash="b4903936d44dc498d2f32b72d9161ff0"/><file name="styles.css" hash="f71c5abb274a13b6bfeb1e0cadaeb08a"/></dir><dir name="images"><dir name="xmlconnect"><file name="btn_edit.gif" hash="e7ecc9fea5c3813957814050508507a5"/><dir><dir name="design_default"><file name="accordion_open.png" hash="4c89d903ebbc61ee295ef64a60724b10"/><file name="accordion_open_android.png" hash="7ef2f1d193990c3f4c2c90aae9ab3281"/><file name="accordion_open_android_l.png" hash="bc27688afbfd866c618477ea2c7bf0ee"/><file name="accordion_open_android_p.png" hash="2e4549cba575c12ef2a39c12e9ffe173"/><file name="accordion_open_ipad_l.png" hash="dcdda97da6556393b972d6dae8d6bac5"/><file name="accordion_open_ipad_p.png" hash="55cca08a0ab79047961858789ff8c3a7"/><file name="banner_1_2.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="banner_android.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="banner_ipad.png" hash="c1d59a6ec67da1bb76c5142453da7acf"/><file name="banner_ipad_l.png" hash="04e850d481a9ae902f33fd8c1f89cbf0"/><file name="smallIcon_1_6.png" hash="c1ce9e289eaf2c0504d502928693bd89"/></dir><dir name="mobile_preview"><file name="1.gif" hash="817fd84187db3eee00799b0acf316457"/><file name="2.gif" hash="1a842d8f3ac25cfcdeab6c86dd8fea89"/><file name="3.gif" hash="207cd55e968c284bd52c86efdcdda1c7"/><file name="actionsBackground.png" hash="11faa8baee72f3e6a9a02a83915c8658"/><file name="actionsBg.png" hash="9acccd1980f17006942d74a718ebd7da"/><dir name="android"><file name="background_home_landscape.jpg" hash="1f79a1f42ca4e2cf6010ab6c3ef66aa4"/><file name="background_portrait.jpg" hash="197b15e6455ad1a85e1bad6595371fa3"/><file name="bg_button_up.gif" hash="204f590a88933c930b7fc92963accfab"/><file name="bg_cat_item.png" hash="2859b45c387b66243d4af2ba973b2ae1"/><file name="bg_catalog_filters.png" hash="7464191ebaf576b73a3c021eb1cfcc25"/><file name="bg_catalog_filters_shadow.png" hash="5021ad60917190026d85fae1d33bdaa9"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_frame.gif" hash="7062ed9b7563fc658f49ce7cfdd34f1c"/><file name="bg_header.png" hash="d4a46c8850d1d89259921b1c28b5bce1"/><file name="bg_header_catalog.png" hash="c1080cd18a89e21da18fdc6955bf6230"/><file name="bg_header_home.png" hash="dfce0445ca7c7a45c7914a986b596ce0"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="8bc1887a0c5760cc47b77b8a7a320426"/><file name="bg_logo.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="bg_page.png" hash="d65f1d123655c2eaf3bb4a1e6035a08d"/><file name="bg_star.png" hash="fc6de6c4e0ed3478b8840e1ab81da725"/><file name="bg_star_empty.png" hash="3f0421fb8c8f6c4be6ca501168a881e8"/><file name="bg_status_bar.png" hash="52b41106451ac34672f82338bbc5370c"/><file name="ico_account.png" hash="c1fd338c74fcf483155acbd37c430807"/><file name="ico_home.png" hash="2de37f640463b354d68945320bfe3e4f"/><file name="ico_search.png" hash="8b0dd17a3e9c3328e66204fe379c66aa"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.png" hash="dd975b128ba303e0ae2adc9772e0433c"/><file name="product_image_1.jpg" hash="8994979d4dcc1f339c73cd1f44398a7d"/><file name="product_image_2.jpg" hash="26d6599bdb35d80b25a1e903b40cfa19"/><file name="product_image_3.jpg" hash="d7c6d05196a84341afe0025d01b9dc61"/><file name="product_image_4.jpg" hash="2a88ead3dbbeff1d40168db692841f2f"/></dir><file name="arrow.png" hash="837259a7c365e46034dca728bffe9070"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="background.png" hash="3717f4b4ba725701e2a0604129a3a815"/><file name="banner.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="btn-l.png" hash="92b2454528e9d39119038777cf53329c"/><file name="btn-r.png" hash="8c6aa9fd9203bc10822e0505f11e0c4d"/><file name="circle.png" hash="f4c116cb0554bf936d3b9ee38b7f3d1f"/><dir name="custom_icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="e33876648546e99d875ca92bd2cd78e9"/><file name="addToWishlist.png" hash="1018602b7c5e0e11f0427ace96fd7d52"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="buttons.gif" hash="0cd19a9d9178976906161ea100cba958"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="image-bg.png" hash="14bde5cf8b00dc5f6c60e52a0fa964dc"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="tellAFriend.png" hash="46f8ef48b29f245977d66d9312d87e70"/><file name="viewDetails.png" hash="9bacc63bcc483d3db5614a026d9391f6"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><dir name="gradients"><file name="footer.png" hash="31a2feed50ef9c8637b412c4211f8300"/><file name="header.png" hash="5386da930a944cd75562216249cce08a"/><file name="header2.png" hash="ad5a2dc6ec93914e925cfe2d43fb30a2"/><file name="header3.png" hash="920ad8c6903e90323a57fb02dca37280"/><file name="item-bg.png" hash="a14886d1f9e14284ac6b4f1b61e68646"/><file name="sort-bg.png" hash="b8053bb772e849909e5b87e4fd1ebbe4"/></dir><file name="grid.png" hash="23faa3f5572cdeb597c2bceedd93a7f8"/><dir name="icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="more.png" hash="f3662ae29923b87eba3a729192aa3df3"/><file name="page.png" hash="2291d77f21de042040bc0864be40138b"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/></dir><file name="image-bg.png" hash="a588b9cced95a25fc18e28c775d9a001"/><file name="info.png" hash="3f0d2ed85b81e8251f294457c6bfa404"/><dir name="ipad"><file name="background_home_landscape.jpg" hash="9e3ef117985113b804531142d539b60a"/><file name="background_portrait.jpg" hash="bdf9e034fd30b923086e6c622ea10451"/><file name="banner_image.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="banner_image_l.png" hash="a070a40d57610b5cc7160fe894482a1c"/><file name="bg_catalog_header_hor.png" hash="f61a67aa288e1b8a8df7b4d4527c662e"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_filter_button.png" hash="728f1cd358446881ffd863eff12204a1"/><file name="bg_filters_buttons.png" hash="02fcb0ed7a7268e9f64ebaf06235bc09"/><file name="bg_filters_tooltip.png" hash="3b05ca6e585acd3d766be01eeaa23d47"/><file name="bg_filters_wrap.png" hash="31288784fe95c67de9b45b44458b4155"/><file name="bg_header.png" hash="e2cf5a575a27e6e4533e3c85e3472a82"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="00f2fbf96d2b915dcbcd921b0301ef3f"/><file name="bg_home_header_hor.png" hash="9bfef728ece003d5b3433d2623ea168c"/><file name="bg_home_products.png" hash="ac6a8a79b959a0c8298b1f607c0f0af8"/><file name="bg_home_shadow.png" hash="c54b071ca3e97a6ee67588ef74b7b44e"/><file name="bg_home_shadow_hor.png" hash="0d21a99c5c749d0e5070e3585ff4a23f"/><file name="bg_product_image.png" hash="4da74325c1a4ee1ca19b414e5d590f75"/><file name="bg_search.png" hash="6ee08d05d0c4ef9ed64b9914b821f408"/><file name="bg_sections.jpg" hash="0ee90005663aced09a9ce6385bdbce2c"/><file name="bg_status_bar.png" hash="17124d9d392bb8e37b202c80a595df54"/><file name="bg_status_bar_hor.png" hash="bd4a9f11ecb1c896145267731d8a951d"/><file name="i_cart.png" hash="1bbe0a0e54eed5bb14b9bfcce83da758"/><file name="i_info.png" hash="3f0fda8b294b67bf698badbcaa99150b"/><file name="i_login.png" hash="deb4089bdc61582c78c90ef192d577e8"/><file name="i_remove.png" hash="4923eb5e76b3c6ba6df5c667db816a0c"/><file name="logo.png" hash="49c19f59b459b6c0b3b99daa3fe7f932"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.jpg" hash="2bb6c69129bcb18dc93e9f48605647c6"/><file name="sections_arrow.png" hash="7db7144083a31882e8a62cb9579f478f"/><file name="stars.png" hash="70d38cd9883d70e4f6b21ac4874b9868"/></dir><file name="lightStar.png" hash="b5dc40d5b793dae6a069357f49cccc24"/><file name="lightStar2.png" hash="75928926a6112540c9cb073157cb7d95"/><file name="lines-h.png" hash="ea3d95812c9838affc6df2f3a3cb1977"/><file name="lines-v.png" hash="9e3ffee29ba28477d50da9642019bc0a"/><file name="login-btn-left-alt.png" hash="71bb6c7d24252aace27bee711d7616f4"/><file name="login-btn-left.png" hash="cbbf9afc6e9fc433f57270e88b63f351"/><file name="login-btn-right.png" hash="438fcc598d012bf6d33184e95accfd24"/><file name="login-btn.png" hash="051ee2c1a8ce3f7b8de3293cd2e2ed85"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="logo_25.png" hash="ba41ed568d916175c32803b614442447"/><file name="men.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="mm-frame.gif" hash="eebf30806f1dbf2118e7ec39a016c86d"/><file name="mobile-catalog.css" hash="cfcfc3b0785a57b707731b661d4d559b"/><file name="mobile-home.css" hash="3dd556688b8c578be295b16ebba934b5"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><dir name="slider"><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="2a146be4bc63713df19cc353e030d44f"/><file name="addToWishlist.png" hash="9b23a4e0d9acfc79f314e9082f14c4de"/><file name="tellAFriend.png" hash="b7600fa2ae52bdb1d6bb86fe4d9f1773"/><file name="viewDetails.png" hash="90cf37c6dbbee1861350b4c05469e3ae"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><file name="slider.gif" hash="c6b87bf15b85b18c0515e2cbefaabe60"/><file name="smallIcon.png" hash="e76d2a6364042f41b3f35fc8cdc9c0ee"/><dir name="sort_buttons"><file name="bg_button.png" hash="87d0f1b123f01c3aea3cb8a2b146306e"/><file name="button_up.gif" hash="7ad527f99b9975d5634fb2d5cc99e6b3"/><file name="buttons.gif" hash="2f14f1a3f0fb38790779c992a58654ae"/><file name="buttons.png" hash="b4a3f17370e03bf5d2a5cdf7800c25a7"/><file name="center-active.png" hash="5903988cd458cd794f23a212d51aa725"/><file name="center-inactive.png" hash="135b46aaa5c3b131a5a7e9c45c004e06"/><file name="filters.png" hash="3837ab6fcfe959833dd998533db1ca7f"/><file name="left-active.png" hash="86e94441b96a0d27d0b0a7e5108f86ed"/><file name="left-inactive.png" hash="0ddcb75aa9971cca39a5a65b4bdff8c4"/><file name="right-active.png" hash="320740ff608187301b06a96eab2f9e8e"/><file name="right-inactive.png" hash="cac4b39ab380353ffd5fdbcedb6e0a0a"/></dir><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="t-shirt.gif" hash="7505efdaabf13c4f8e26f7cfe15c8c96"/><file name="t-shirt.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="women.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="youth.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/></dir></dir><file name="dropdown-arrow.gif" hash="332e99ca6b4d1e0d39972e04fb0b2395"/><file name="empty.png" hash="23dc9dc3c4751f83c2df7a5c42668824"/><file name="full-arrow-left.gif" hash="8ec91b60d38d1a16cba7670f2088a5c7"/><file name="full-arrow.gif" hash="36ddff0fca1c7d8900cb3633e0a30cea"/><file name="gel_green.png" hash="591959d831e8e42c9175d12a88f0bae2"/><file name="gel_red.png" hash="db442c023014df9da32b84bc1bb5a39f"/><file name="l-arrow.gif" hash="ee49f7eab64657b5131953acef0238fd"/><file name="loading.gif" hash="5d25806dac7cbee5f894b13144783866"/><file name="r-arrow.gif" hash="d0429a9781e915fc9d9ca8875c470d32"/><file name="remove.png" hash="ee9497c5f31933eaab3e9e352495ee12"/><file name="small_logo.gif" hash="d5c8be7c0f16aac2549759c0228492d6"/><file name="swatch_black.gif" hash="fd31d6a3a435c8ad1f7c43f346bb47e4"/><file name="swatch_custom.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_default.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_funk_leaf.gif" hash="f1d3ba87efb742b47da879a6f48909c4"/><file name="swatch_hot_red.gif" hash="d9363d45dc2993c2fdc3ea43c5b6f71c"/><file name="swatch_sky_blue.gif" hash="ded1455db119d09a3aedd7474fd1875a"/><file name="swatch_user_custom.gif" hash="a24f31421a1ff56d1be0845f9a7c7020"/><file name="switch-arrow.gif" hash="dc7243962b341f366cd072d486687e6a"/><file name="tab_account.png" hash="27101fbaa78a07426be4768acc4c53ff"/><file name="tab_account_android.png" hash="77605cbc87f75ca17e91a5393765ceb1"/><file name="tab_account_ipad.png" hash="2997de5402195d0720309b73c6446fab"/><file name="tab_cart.png" hash="e803f760ee81cb35183f1122f388b774"/><file name="tab_cart_android.png" hash="477e97f8d03ea8aa674e952709f86578"/><file name="tab_empty.png" hash="bdd4cc355566e8861b2c45424ad94516"/><file name="tab_home.png" hash="dfa104e4da74e4a55d3c98d6ee0f7122"/><file name="tab_home_active.png" hash="bba5eb9bb724c84c1ede9e6f4bec3575"/><file name="tab_home_android.png" hash="1fefc6b070cc21b31b43194a7d85f9d9"/><file name="tab_info_android.png" hash="67fc19d8d926f7aede482f5a7083fc71"/><file name="tab_more.png" hash="2803359cb3e795bf67457e727aa16020"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="2cf29dbe325558353621b4241543204f"/><file name="tab_search_android.png" hash="932c2c568872fd9e119367c887f0539a"/><file name="tab_shop.png" hash="f36be0d3d27f2b37626247d3f6a55e2a"/><file name="tab_shop_active.png" hash="de907d6a52d477d4319649f9b0e2e4aa"/><file name="tab_shop_android.png" hash="e119fcd20f8cba856d550a64d775ddbb"/><file name="tmp-icon.gif" hash="58b759aecf3bdae26d5aaff7a0be5c90"/><file name="xmlconnect_tab.png" hash="cd99a7e01a42a6c82d866f7684faeb95"/></dir></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="xmlconnect"><dir><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="jscolor"><file name="arrow.gif" hash="5034704a76cd55c1cbcbc58ea6bf523f"/><file name="cross.gif" hash="ba9a274b9323753cd95bc3b1eb2f4e5f"/><file name="demo.html" hash="edf71251cb2be20322d2efb00aee86a6"/><file name="hs.png" hash="fefa1a03d92ebad25c88dca94a0b63db"/><file name="hv.png" hash="990d71cada17da100653636cf8490884"/><file name="jscolor.js" hash="b65a1505390592ac6c0177d6b84774e0"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Magento_Mobile-1.9.4.1.xml b/var/package/Magento_Mobile-1.9.4.1.xml
new file mode 100644
index 0000000..67c466e
--- /dev/null
+++ b/var/package/Magento_Mobile-1.9.4.1.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Magento_Mobile</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Mobile Xml Interface</summary>
+    <description>An integration Magento with mobile applications (e.g. iPhone, Android, iPad)</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:58</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="XmlConnect"><dir><dir name="Block"><dir name="Adminhtml"><dir name="Admin"><dir name="Application"><dir name="Edit"><file name="Form.php" hash="42cbf9631bb3eef431e9398b1bffb6f9"/><dir name="Tab"><file name="Settings.php" hash="60f79bfea8f31a45f68c384c62b51a6a"/></dir><file name="Tabs.php" hash="e164c429630358b7ed08b12fba12a0bf"/></dir><file name="Edit.php" hash="da4aa415cc7f509e9c5b4ab0abedf6b7"/></dir></dir><dir name="Connect"><file name="Config.php" hash="ef6f52f638874cae27d71a60ab7f6390"/><dir name="Dashboard"><file name="BestSellers.php" hash="fd83fa0abede5e1120d9f2607728c660"/><file name="Customers.php" hash="7c15234d44f4580d4d09c9c480913fd8"/><file name="GraphAmountsData.php" hash="8651060b90056a1a73097eb675669a4c"/><file name="GraphDataAbstract.php" hash="631981805df46cc521a6d78981d62f14"/><file name="GraphInfo.php" hash="fa60ad1ecad8eebea1a814fa8f3f11fc"/><file name="GraphOrderData.php" hash="4c57f103ed14ac56374548198a3f1c0c"/><file name="GraphTotalsData.php" hash="6362d716bf62d4203c0c5e4a58fa70ae"/><file name="LastOrders.php" hash="9e4d98b91e353ace105f5dc2e8880a37"/><file name="LastSearchTerms.php" hash="da93c128090d68728518b47f1937c0e6"/><file name="MostViewedProducts.php" hash="0d2f13760e47ec747772eb4fa669a577"/><file name="NewCustomers.php" hash="71faee15fdd7933ce87a579712330629"/><file name="SalesInfo.php" hash="fb77263dc72fbb4514f59270700ee798"/><file name="StoreSwitcher.php" hash="be57a6337549e4d072ce80cbe38004d3"/><file name="TopSearchTerms.php" hash="8ab84597489faa349365e2320dc6256d"/></dir><file name="Dashboard.php" hash="4d55218423a2577e0db0e65f390a0eaa"/><file name="Loginform.php" hash="3b4b92ef534eadbaae38bbef867cea04"/></dir><dir name="History"><file name="Grid.php" hash="36511c8994308a45c6b13e753ced86cc"/></dir><file name="History.php" hash="107c69ecac1edfb0b4724c5707a0ce1e"/><dir name="Mobile"><dir name="Edit"><file name="Form.php" hash="8986f753b1c7487e8c4a372a297f700c"/><file name="Submission.php" hash="c21b6576548b2f627ea224c88ec595a6"/><dir name="Tab"><file name="Cache.php" hash="980297562509b4d08f5914d3f5fce3fd"/><file name="Content.php" hash="b39a9829604497c7c0dab3b20866882f"/><dir name="Design"><dir name="Accordion"><file name="Images.php" hash="a92f18f8c4014230ce95dd1c62a128b0"/><file name="Tabs.php" hash="1c27d76f5428dd09c64e7b2f16095f73"/><file name="Themes.php" hash="e4e0e33198c8eafe2e827463cbe9ccac"/></dir><file name="Accordion.php" hash="dc535a038a8833aeba8e0c50327e03e8"/><file name="Images.php" hash="6b5f93bba329732e91da9df1e2df5751"/><file name="Preview.php" hash="49134611eb84b29dd0b99e8b415316c8"/><file name="Themes.php" hash="6090d653f395866788358daad5698d6b"/></dir><file name="Design.php" hash="dc566d2f573e2392a5d5670deb87c40f"/><file name="Flurryanalytics.php" hash="9fa282f43ceb9c9bd0d21c2ed8a61daf"/><file name="General.php" hash="824c36bebef3952c9f576de13c8bea98"/><file name="Notification.php" hash="75b24ca6db9d117d57d11ad4a9e2b93b"/><file name="OfflineCatalog.php" hash="92ee4fb43aeea91d7b01a59bb0d63592"/><file name="Payment.php" hash="812419b60554837546a757911a9aad54"/><file name="Settings.php" hash="7fe481b44647e6b124ded33afd3006e7"/><file name="Social.php" hash="cfb2fbbc99e569c5ac1c5d9c2817470b"/><dir name="Submission"><file name="History.php" hash="7d747f93da808e60db9d1c6fc9b5615a"/></dir></dir><file name="Tabs.php" hash="477fbc0c585e4ad400cc9b857663168c"/></dir><file name="Edit.php" hash="e22b7a01bb4999c6755c8843f1595214"/><dir name="Form"><dir name="Element"><file name="Addrow.php" hash="10480a9e700140671bdf129077491079"/><file name="Color.php" hash="50129c1b65d750aeedec27ed4a7d4f43"/><file name="Country.php" hash="3920f03b1786f6421f2b35543f90ad79"/><file name="Datetime.php" hash="0faa673cc2d2333d94a68fb8f6ae1840"/><file name="Font.php" hash="01a83b1dd25de9dea96d7bd3b120eb80"/><file name="Image.php" hash="afc307c06eb3acc95a22a9f7366789ae"/><file name="Page.php" hash="d677d9ede74ac4d4205295af7aa1fb98"/><file name="Tabs.php" hash="b8a9210e9dc047cbd7d6a0678f0ef3c3"/><file name="Theme.php" hash="ad796959f3425fa9076a1bd8f41ae88e"/></dir></dir><dir name="Grid"><dir name="Renderer"><file name="Bool.php" hash="e933ea09a79b53d5128649a2c944b410"/><file name="Type.php" hash="20c0c938068768cba49b3137bd9995e0"/></dir></dir><file name="Grid.php" hash="edd7bffddc1da5a3fe1cc83ad9cf8576"/><dir name="Preview"><file name="Content.php" hash="364903e644af0f3b4d23efe14620aff0"/><file name="Tabitems.php" hash="8416116abed11a4eeb200dba0e92ce10"/></dir><dir name="Submission"><file name="Form.php" hash="72ec9817f5a562163bb62334c5be1bc8"/><dir name="Renderer"><dir name="Country"><file name="Androidmarket.php" hash="28a255a8d7bc2c80e28056146e862bb3"/><file name="Istore.php" hash="7cb3d129e63a5d7b601b8e176a56fe69"/></dir></dir><dir name="Tab"><dir name="Container"><file name="Submission.php" hash="bd162efb92f38afa814d8f811acc677d"/></dir><file name="Container.php" hash="d88f4280209e67efb62e425dfb51181f"/></dir><file name="Tabs.php" hash="273e945bcc16fe9ebf2507e9202b109a"/></dir><file name="Submission.php" hash="f5d121c59912fae01944db2a90a9e46c"/><dir name="Widget"><file name="Form.php" hash="c6596c73c3a03e55035a1435138a757c"/></dir></dir><file name="Mobile.php" hash="c4bb3627a57b2bded79ded4bf1f76ba7"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="8a69da64c633c90b815a149d418e1e60"/></dir><file name="Edit.php" hash="bac0cf8d7090e606e62fba0443a77401"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="afbdc54e2d2182d3f1ebe8867ec46f9b"/><file name="Application.php" hash="5e6d1a4cd82c8f148665280814c6a66d"/><file name="Id.php" hash="564b9860db7e21d1d9a644e276d92748"/><file name="Msgtitle.php" hash="bfa380f535758215d9c714aae53b87b9"/><file name="Pushtitle.php" hash="90ebc1553ba4d8bea1e41926e281e85c"/><file name="Status.php" hash="f7230c7dca270a2d0e1a8f7046d70f7e"/><file name="Template.php" hash="aebbc022bfb288eb5101304c8b656d37"/></dir></dir><file name="Grid.php" hash="e4ea25e1eb6515633cb933b1dc653041"/></dir><file name="Queue.php" hash="07f1dcf45efd1ca07e12bd6a8defce77"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="83997726da0b6e8d5c9123f27b59a538"/></dir><file name="Edit.php" hash="4ff833041c232ca1ea787633de5a8511"/><dir name="Grid"><dir name="Renderer"><file name="Application.php" hash="2ffba8b1be1d1942f9f0648ebe5ee077"/><file name="Name.php" hash="09e2e85e74df397c903528a853d055fb"/></dir></dir><file name="Grid.php" hash="b373a577f1c41fb9d7fed57c0c67965a"/><dir name="Preview"><file name="Form.php" hash="01e6987b191e4e3d5ceee4a2816e43a3"/></dir><file name="Preview.php" hash="45a7ec71db6beb22c54f8610e966b910"/></dir><file name="Template.php" hash="66c96b78a0d7a202268681fd84f6a6c3"/></dir><dir name="Cart"><dir name="CartTotals"><file name="Default.php" hash="aa4a54fa28ebbb5dddd92e11cf1be9be"/><file name="Grandtotal.php" hash="85c3426ab148a9e015dd07acda656532"/><dir name="Nodes"><file name="Default.php" hash="21708d567639f087d30797c810d6b5d1"/><file name="Giftcardaccount.php" hash="3ab9b8cf4b4e710258f208f03cdb09a5"/></dir><file name="Shipping.php" hash="0d0e531150a5afaa13e52ee9dede860e"/><file name="Subtotal.php" hash="47d8122cdc887d0dff9e3912eb7ceab9"/></dir><file name="CartTotals.php" hash="c1fa081e4688824455c63a429b40c7b3"/><file name="Crosssell.php" hash="22984daab011bbe59f36986f0c44f7f4"/><file name="Info.php" hash="987fc8f96cfcd31a5d57d874591c87dd"/><dir name="Item"><dir name="Renderer"><file name="Configurable.php" hash="f5670a94587490768a94816c6a7043f4"/><file name="Grouped.php" hash="d9218c9a232a947f9667deefca98f376"/></dir><file name="Renderer.php" hash="413196834f1cc45c849284764cf72ced"/></dir><file name="Items.php" hash="9ef9351b39bbb23a79843138571b5a3f"/><dir name="Paypal"><dir name="Mecl"><file name="Details.php" hash="06a1c937089063423e8f7703fbef2dd2"/><file name="OrderDetails.php" hash="0d7e04d6be3962552e65535fbcce234d"/><file name="Review.php" hash="780bde503e02e74b68ad48a4aa178d4d"/><file name="Shippingmethods.php" hash="20598482b0508e2987a5342f223ff7f7"/></dir><dir name="Mep"><file name="Totals.php" hash="42a88f97d59f3f2e8b79d255e16144ef"/></dir></dir><file name="Totals.php" hash="eb6f3381db7cd39a5f39ea195b1f5182"/></dir><file name="Cart.php" hash="fde0584dc2b2811f6bb8f26cf2ed67f7"/><dir name="Catalog"><dir name="Category"><file name="Info.php" hash="c08a92405bf045de2e81e850f849f023"/></dir><file name="Category.php" hash="1b236585d2f8ff81a588699d6085f29c"/><file name="Filters.php" hash="800c575490bceda583cb7cbf43e06b0e"/><dir name="Product"><file name="Attributes.php" hash="9b3cf0c0e19fbbfe34c3d044a1823f62"/><file name="Gallery.php" hash="0afbc24f715bf88cd1167c318427d788"/><dir name="ItemPrice"><file name="Bundle.php" hash="ade6f06324b5c32fc0bb14b3a045ccd9"/><file name="Default.php" hash="1a0927b5ad5e1f8d7ab4e7ee0d28618f"/><file name="Giftcard.php" hash="f4d4f56ef7cc963ad365040d6b156949"/></dir><file name="ItemPrice.php" hash="e953ef560e9677ac54cb36d7ed6654e0"/><file name="List.php" hash="48390c6fdb31105e9e6356b6c5952074"/><dir name="Options"><file name="Bundle.php" hash="b15512d69c62d0559935f8d01b9cf941"/><file name="Configurable.php" hash="a83c4152060bf608b17d4bc3e33ff20d"/><file name="Downloadable.php" hash="0460412f67215b73fd0d3fd495685239"/><file name="Giftcard.php" hash="7df14238d142344e8acab77e6db8c451"/><file name="Grouped.php" hash="a8d50a53444b5593a31b2845a4752719"/><file name="Simple.php" hash="fb17951ec6e37da9b59531173336061b"/><file name="Virtual.php" hash="3aa13acb5b4f778f93d145ef67bcdef1"/></dir><file name="Options.php" hash="c73a87c8f50953f13d3de6c62c2fa561"/><dir name="Price"><file name="Bundle.php" hash="19b19f708134f2efa72ae044a19e13a6"/><file name="Default.php" hash="a462cf7fca028e973afe141455727014"/><file name="Giftcard.php" hash="6d4ae9ca376e16f2ce85994187b2810d"/></dir><file name="Price.php" hash="1936b972ce882fb03c99419474c86e3a"/><file name="Related.php" hash="bf8bca72c91a15837c0bc5f2685e2609"/><dir name="Review"><file name="List.php" hash="788ceecda434b52908495b30bc1501e4"/></dir><file name="Review.php" hash="c78e32b03f67861300f36bde6a57f8b4"/></dir><file name="Product.php" hash="38e22e7743f7798fd852232aafa13215"/><dir name="Search"><file name="Suggest.php" hash="76286050a2f2355fc93ff8a3c5dd503b"/></dir><file name="Search.php" hash="c19748ad0547bfeb05ac7d29069e9b94"/></dir><file name="Catalog.php" hash="1f83bf40bc69b7a90a7e3a92e5141cc8"/><dir name="Checkout"><dir name="Address"><file name="Billing.php" hash="60f5d7fda1904c44d269e83d32b04c21"/><file name="Form.php" hash="a1f8e3ad1cdeccc275374bf300f233d7"/><file name="Shipping.php" hash="9688c172819d8642184f80f24f8ffe2c"/></dir><file name="Agreements.php" hash="1c59b6dfb81133936ce928eac880c4f4"/><dir name="Cart"><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="fbb065663009c95ee39ba735cbdb6f38"/><file name="Configurable.php" hash="32ec7bc671b88c1105c656d59e7a6097"/><file name="Downloadable.php" hash="deeb8e695aa914ead6c718936bb0caee"/><file name="Giftcard.php" hash="06adc988117d07b3402bc07d632dd1d0"/><file name="Grouped.php" hash="813b8d991c30043fc43f6d9f98c113b5"/></dir><file name="Renderer.php" hash="4e410027b4a1b0f8dc56acec9a3ef0dc"/></dir></dir><dir name="Onepage"><dir name="Address"><file name="Form.php" hash="d741113a5edf198d37034368413c0f24"/><file name="List.php" hash="7bd1944b55751bfb1d0742e8c7de15c1"/></dir><file name="Address.php" hash="65aabe67caaf3899cf51ac2b32941b74"/><file name="Review.php" hash="698a09561d3706593516b72eb68b307a"/></dir><dir name="Order"><dir name="Review"><file name="Info.php" hash="a059b6066b3736fe060886608dca1ff0"/></dir><file name="Review.php" hash="67ed1ba38387ca695ec59ec72326a0b1"/></dir><dir name="Payment"><dir name="Method"><file name="Authorizenet.php" hash="834362380417a44933542381babf2ae4"/><file name="Ccsave.php" hash="3b9620de2dd955aa5fde1dbb50ed7d45"/><file name="Checkmo.php" hash="a4e64c79441c7ed6f9f1af4768476cd1"/><dir name="Info"><file name="Authorizenet.php" hash="1205a19f9cae588ae8f6182786341ac6"/><file name="Ccsave.php" hash="f88eaa8cae31cf309919eae02c9bd1e7"/><file name="Checkmo.php" hash="a3ac5e69918948a578e4b2b45cbd6fb7"/><file name="Free.php" hash="293ba305893aa93e6c46280c270c5344"/><dir name="Paypal"><file name="Abstract.php" hash="64b61f0037e0cb6db6f02d29af5af0c8"/><file name="Express.php" hash="92dedcdce406e8a28ffd3880406f0929"/><file name="Mecl.php" hash="45458c3b1756b5370b989c6cc80a19ef"/></dir><dir name="Pbridge"><file name="Authorizenet.php" hash="c13c201ba4ca62dad0c3a87cf4a9f703"/><dir name="Paypal"><file name="Direct.php" hash="b16b116cae5073631b334fa21c977771"/></dir><dir name="Paypaluk"><file name="Direct.php" hash="097c94fce223fa8c522d800bd6cc13fe"/></dir><file name="Verisign.php" hash="5d4511d4102ab8644ffe03dd1c79977e"/></dir><file name="Purchaseorder.php" hash="e58212454a851d514a84ee42a2cde91a"/></dir><file name="List.php" hash="a3e2ce26d286aabcab0f55c032239851"/><file name="ListApi23.php" hash="9b5e71077e7a0fd02946da3f486cfbb7"/><dir name="Paypal"><file name="Direct.php" hash="d3e4408ba28a9ba8f94eab98e4e4e490"/><file name="Payflow.php" hash="972c68fbe72496667bea7de3a799cdb8"/></dir><dir name="Pbridge"><file name="Abstract.php" hash="3642dfbe2d063ce90cf0ff55179a4bae"/><file name="Authorizenet.php" hash="401dc6b998dab46602a6c2ac157a70cd"/><file name="Paypal.php" hash="c2a29305f8fc181bb6076f2ff3f1d763"/><file name="Paypaluk.php" hash="0f666eb6c38c09f523d00889a4cdbe57"/><file name="Verisign.php" hash="cf6a0ed466ad465730863ba50834cd3f"/></dir><file name="Purchaseorder.php" hash="e989e488a318c9d67110a00cfc7daa32"/></dir></dir><dir name="Pbridge"><file name="Result.php" hash="349e21d3652cc2724119ce99b98d2285"/></dir><dir name="Shipping"><dir name="Method"><file name="Available.php" hash="a79a59eaf32107633f87fb552d83567e"/><file name="AvailableList.php" hash="fd5013cf123d5b353b16c37db7da2f91"/></dir></dir></dir><dir name="Cms"><file name="Page.php" hash="e6d1e375bae972eb739373dc044acb17"/></dir><file name="Configuration.php" hash="724321f880ef2d348ce935123249bf96"/><dir name="Customer"><dir name="Address"><file name="Form.php" hash="de7c6b19495fc25240c47dde1fe61385"/><file name="List.php" hash="42546489a24f4c1bfa098026eb3482b5"/></dir><file name="Downloads.php" hash="321d9c650ddd35139815aec45d16d679"/><dir name="Form"><dir name="Renderer"><file name="Boolean.php" hash="296e8a888cfe12328d8a806b2ccebbce"/><file name="Date.php" hash="f6c9d7d8c45c40ed22b3b3aed92cdc6b"/><file name="File.php" hash="35bf591fc6d1657c8f22c284ca2ff081"/><file name="Image.php" hash="dba177ca91d49f760099dcdedc507d46"/><file name="Multiline.php" hash="8587fa80557a9ca19ccafccc076886a7"/><file name="Multiselect.php" hash="68a93aaeb54eda0af2aae6f094409f2e"/><file name="Select.php" hash="a24eec858dfb4829cf9d1ba0986ecd60"/><file name="Text.php" hash="5ccdfbb2f721bf1a55cb5c746170026f"/><file name="Textarea.php" hash="a8df2c653799ab45b88d7a93cbfc3a57"/></dir></dir><file name="Form.php" hash="e35595b42e88bd5fdbbda85a1dd1b967"/><file name="GiftcardCheck.php" hash="5502c3c64d26a729f95d49beddfda484"/><dir name="Order"><file name="Details.php" hash="d3a76a64725673fefcff223a7cbc678e"/><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="9b8ec135915a09aee481a1f5afb77ab3"/><file name="Default.php" hash="c13320e211521393b62c18446a1b19a1"/><file name="Downloadable.php" hash="0f7ab7a67658a4e63c1691774405c517"/><file name="Giftcard.php" hash="3b2e6d3a8e4d9f28c0480219da746f6b"/><file name="Grouped.php" hash="bf8405d76c72db226d4edd52cac1eb1c"/></dir></dir><file name="Items.php" hash="626d61c1f7021402743169e508d826b7"/><file name="List.php" hash="c491e8b728aa767c0ab958c31adecdbf"/><dir name="Totals"><dir name="Customerbalance"><file name="Refunded.php" hash="2db2f90238a01322af451d6cb13d0227"/></dir><file name="Customerbalance.php" hash="382c7eb584ca913e12d79b54746e7123"/><file name="Giftcards.php" hash="a530fa9d0642e595f30b14c9fb846e3e"/><file name="Tax.php" hash="f801e9b97383271e443cc41add0a36f2"/></dir><file name="Totals.php" hash="9ea5b26f3a26653dbe71803512228679"/></dir><file name="Storecredit.php" hash="14bd1d964a2f70f330b35c6a1d06e396"/></dir><file name="Home.php" hash="579d6c53346982d239e7e009e400eef6"/><file name="Homebanners.php" hash="28b0ad997a792d9ec7ebf269f0995010"/><file name="Localization.php" hash="d9e0b6f7ed0670a5da165c58d74cdf85"/><dir name="Review"><file name="Form.php" hash="a31ea24b2cb1e22708fc5226296b1267"/></dir><file name="ShoppingCart.php" hash="0fcad0c7d269914600461e82df23d42a"/><file name="Wishlist.php" hash="c90c53dac188bc6d1eb0aaadc52e4ba4"/></dir><dir name="Controller"><file name="Action.php" hash="15ca45ed36fb4242715ff316487df41b"/><file name="AdminAction.php" hash="cca66931020159b3eae2455f28f09a27"/></dir><dir name="Helper"><file name="AdminApplication.php" hash="b17105d0e66e7c686ff38d5edee5cefc"/><dir name="Adminhtml"><dir name="Dashboard"><file name="Order.php" hash="9419e418ef0c1aca45a927c6076ba0d0"/></dir></dir><file name="Android.php" hash="1ed6e9dd7ee1e1ebe7c379e30160cc4d"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="57f732135ff7734cc77f6abb4c8b2449"/></dir><dir name="Product"><file name="Image.php" hash="087532b6f1dec902b53ec28cb659f497"/></dir></dir><dir name="Customer"><dir name="Form"><file name="Renderer.php" hash="045b5ccd69deefa693d7d4c5353ce68c"/></dir><file name="Order.php" hash="de100b167840320bafacc6e93a3283cc"/></dir><file name="Data.php" hash="b896980dc209bb614eb793846c46523e"/><dir name="Device"><file name="Abstract.php" hash="9bc6f1ac0f697acffb01a11236a40401"/></dir><file name="Image.php" hash="6921779e72abaacc241b34f07ed02830"/><file name="Ipad.php" hash="1effe2957ce188b6cedfb0263adef0ce"/><file name="Iphone.php" hash="6675faef922a3cfb36d39b2b86d94cfe"/><file name="OfflineCatalog.php" hash="728a6f556f0686e6903f2b3370907a9a"/><file name="Payment.php" hash="f1012b729117d69e9ab6c8d080417022"/><file name="Theme.php" hash="8977a5214ed2ac3238e8c2419be069ab"/><file name="Translate.php" hash="01435e6bf81bbc0227659b139197639b"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="Search"><file name="Catalog.php" hash="ccb6094d28df925b20ec8c031ac51a53"/><file name="Category.php" hash="52e81d55648a8570ec4e8668d53f8b80"/></dir><dir name="System"><dir name="Config"><dir name="Backend"><file name="Baseurl.php" hash="04e9900121da0d400bf9096ca7d23cd1"/><dir name="Currency"><file name="Default.php" hash="0ce2ee64ede63a08ce1b3f360eb52084"/></dir></dir></dir></dir></dir><file name="Application.php" hash="959a3812d11730d81f67a85ac6372a0b"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="fa2f7f5e7242d935f9d5e1741f9048b4"/><dir name="Media"><file name="Config.php" hash="233724daf60fb819ff318003be19dfe8"/></dir></dir></dir><file name="ConfigData.php" hash="562df19fe23520a347f96af3bfd322b4"/><file name="Configuration.php" hash="05c4089e805717727903febc0912a005"/><dir name="Device"><file name="Abstract.php" hash="f45b3f1ac62150225bb095fc0052a6ae"/><file name="Android.php" hash="7958c43e6e197d60a8ad1f1958d48833"/><file name="Ipad.php" hash="fd91ddec607efe8cfb6a26519ec8f49b"/><file name="Iphone.php" hash="b086f46206e53a0b5123fab10a0f44a2"/></dir><file name="History.php" hash="1dc8e48c826d5d4b0b556913ea82cb65"/><file name="ImageAction.php" hash="3af7f7f5fad331edaaf66613d5688e19"/><dir name="ImageLimits"><file name="Abstract.php" hash="19d6e7017a3463dbd7d4dc4acc9d3993"/></dir><file name="ImageLimits.php" hash="8c80b771068d8ab4140720aa535088f9"/><file name="Images.php" hash="9e8dcf76a202aab0ff0cb7fa4efe3558"/><dir name="Mysql4"><dir name="Application"><file name="Collection.php" hash="20ca3e05eddb2a4db99d71b8ff3552ae"/></dir><file name="Application.php" hash="cc9679db2f16fdb328d26fc730c4cea7"/><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="3cc019e54c09e49a36338cd363cb1155"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="c5b21c467e407202bd04ca85f5211a63"/></dir><file name="ConfigData.php" hash="9768cd6b2b4a5f77d29a21dbc027d437"/><dir name="Filter"><file name="Collection.php" hash="25a4d5ed9b4f11190115a23ae234f3a6"/></dir><dir name="History"><file name="Collection.php" hash="e868422aa36ce2af614a2bc025c7e5a8"/></dir><file name="History.php" hash="2bc18554615e6aa04f8fb2f4dc43cfb8"/><dir name="Queue"><file name="Collection.php" hash="c363e0c70a3940e8d990315ed8ebadec"/></dir><file name="Queue.php" hash="9c158e0e23293c0d6a0c3853fccf6018"/><file name="Setup.php" hash="dbaeabb2554c70666ef25921e89277a6"/><dir name="Template"><file name="Collection.php" hash="4993a7470f4bd5fa3ada384737234c79"/></dir><file name="Template.php" hash="5be4d94478a10677cc3f8e0ec7f3738a"/></dir><file name="Observer.php" hash="17dbbf57381227eedca5fdac00e1e937"/><dir name="OfflineCatalog"><file name="Abstract.php" hash="fff50211793a39f51c0a0d059e769eaf"/><dir name="Category"><file name="Category.php" hash="2ee314872c6cd7e9a9b075110eb6c282"/><file name="IndexCategory.php" hash="0da913c58cb221745cd0f5f93cf9722b"/></dir><file name="Category.php" hash="84c5080d5085630afd13847204d9f76f"/><file name="Config.php" hash="165414539f36e14d54a267ff93750ad6"/><file name="Home.php" hash="3fe7a558d082dcf0525e6063b35a46fc"/><file name="Homebanners.php" hash="9bd332243faec8b27a99adf80d0276c1"/><dir name="Product"><file name="Gallery.php" hash="475088e1291fb55e55dfccc2b251964e"/><file name="Product.php" hash="5cfc4c77f8d7b7431f9b922f7fc6bd87"/><file name="Review.php" hash="a343151fe3ca1c07c3bc3835b8b3de7b"/></dir><file name="Product.php" hash="2ae833518fdfbc68291b12dd306d54f6"/></dir><file name="OfflineCatalog.php" hash="becd222a9465a2a76ec745d6dc87e73f"/><dir name="Payment"><dir name="Method"><dir name="Paypal"><file name="Config.php" hash="be507f3c7ed91dee5a5dfda94cf2a402"/><file name="Mecl.php" hash="d5e0d81cacb7daa01ba6de5e4c2a34ae"/><file name="Mep.php" hash="aadc840055d64e79797fdc8b8131e1d3"/><file name="Pro.php" hash="95f452b7a53b725e3cf46361735e4c5e"/></dir></dir></dir><dir name="Paypal"><dir name="Mecl"><file name="Checkout.php" hash="ae8b531a989747319baf9c182c831ff8"/></dir><dir name="Mep"><file name="Checkout.php" hash="ff0a95a4ccf4b634ad399dd39f749d58"/></dir></dir><dir name="Preview"><file name="Abstract.php" hash="327ed7f692c9753472c5d728996d2b2d"/><file name="Android.php" hash="f5ac4ba6b2246221403cbb204f2d46e8"/><file name="Ipad.php" hash="12d621382059de3c6b8273414aedba13"/><file name="Iphone.php" hash="afcaf2577c9fd1e0f0fc991110de36c1"/></dir><file name="Queue.php" hash="251cfb9268a1b64b835ca11839a5f4d9"/><dir name="Resource"><dir name="Application"><file name="Collection.php" hash="b19fbd256a73fa6d78aab9ee42888f84"/></dir><file name="Application.php" hash="c05f1f9873f7ecbbff20c3672e058a7c"/><dir name="CategorySearch"><file name="Collection.php" hash="35b85a98ad9c7d074b59c3525ae4eb4b"/></dir><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="334fb74e0088e436d295b40bf811980b"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="b01894e4fb13a260d780b85d73001f0a"/></dir><file name="ConfigData.php" hash="974643c62572f321cf1e70942a1f2ff2"/><dir name="Filter"><file name="Collection.php" hash="090585923738dbc5d2d3e92ac74d5fc8"/></dir><dir name="History"><file name="Collection.php" hash="24579eca5258b06809924f16aca34e8a"/></dir><file name="History.php" hash="87b18d53ac3045fdf42e0054bac99fde"/><dir name="Images"><file name="Collection.php" hash="3419fabd2f739625f03ead28a84d130e"/></dir><file name="Images.php" hash="4ccc3ec55afa49cb28d15d3f1c6ef4ee"/><dir name="Queue"><file name="Collection.php" hash="e2aeb583c914787669ef7c7cc463ddc8"/></dir><file name="Queue.php" hash="76a8caa2179a95d4d9a0d10a43369470"/><file name="Setup.php" hash="41a1d11f4a4a00e46537da93c5874926"/><dir name="Template"><file name="Collection.php" hash="5d157bdf254052b152067c7b8f9b2708"/></dir><file name="Template.php" hash="4a025a389dfda83885d3be99f673592e"/></dir><dir name="Simplexml"><file name="Element.php" hash="fd7c3598aa177f1907716cf601219aeb"/><dir name="Form"><file name="Abstract.php" hash="fbe0e291e7546f965265cb2d6504f657"/><dir name="Element"><file name="Abstract.php" hash="6377bbab9d7c7f04b73d5056537e28de"/><file name="Checkbox.php" hash="da7c40c59be8e0cfc51df1602279bb8f"/><file name="Collection.php" hash="235fc8c09ff4309c925d06f2410d1252"/><file name="CountryListSelect.php" hash="51968904d112c467dd8100a578565f44"/><file name="Custom.php" hash="c4ad54563c5fa4e66125317591d9aa8f"/><file name="Date.php" hash="71f716a28728d14c386b999e0e73964e"/><file name="Email.php" hash="120682a40beb8230de3a0c8e26da78ef"/><file name="Fieldset.php" hash="71022934e1f20bbd60b039edfc084cf2"/><file name="File.php" hash="585cf229c446581ea47490078fa19f18"/><file name="Image.php" hash="dd5919b1c52222c8dc2ebb10da3be619"/><file name="Multiline.php" hash="a5d802913e78cc43a3284ec8271721e5"/><file name="Multiselect.php" hash="f79b0a7c5b747105e2b763bfceb9a999"/><file name="Password.php" hash="a9779cce59679bd46c532233702795b4"/><dir name="Renderer"><file name="Interface.php" hash="b84d0ee6d9b66f8d9f84cc52f2867af5"/></dir><file name="Select.php" hash="c2ba59f1b627c2692c45a82ea022332e"/><file name="Text.php" hash="00d613d55512fa7279159b9b1e38e3fe"/><file name="Textarea.php" hash="3fa4f12a6f898283a6b89fb0af467f96"/><dir name="Validator"><file name="Abstract.php" hash="89c217eadb21f35369abfb681e96f482"/><file name="Rule.php" hash="33e8edb8c896b25f2a1b220a82716a7a"/></dir><file name="Validator.php" hash="be511ff573d219d60de0ba0b3f740ea6"/></dir></dir><file name="Form.php" hash="c98434080575ce5a55d076be917f1d80"/><dir name="Message"><file name="Abstract.php" hash="6587dfdcc1073929966a38f397e64236"/><file name="Error.php" hash="4fdf18c0200d1cdc03baa45a375ebe22"/><file name="Success.php" hash="1a4c003a718295df9ee5c4610001a6ab"/></dir><file name="Message.php" hash="a312abeacffcde7d58f7d34624751e7c"/></dir><file name="Tabs.php" hash="ceb9453dec3fe8dbadb9130f57fff771"/><file name="Template.php" hash="7232e9f4ce510d1986371e833082ad1e"/><file name="Theme.php" hash="3b26aad383159deb98cb9235eb134d41"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Admin"><file name="ApplicationController.php" hash="d85220bbcf83701e8c4d1339edafe1f9"/></dir><dir name="Connect"><file name="ConfigController.php" hash="181c3a7c1c8c5c7126da20e2948d7afa"/><file name="DashboardController.php" hash="98a02bb6afe602c605a75224de855536"/><file name="UserController.php" hash="d361715dd4fca6a6c8b70a50ce88d6c3"/></dir><file name="MobileController.php" hash="5265057d806f41f1c888f095a422aae8"/></dir><file name="CartController.php" hash="09a71b3690f40ead7d78e33da3fa55ac"/><file name="CatalogController.php" hash="9aba97e5852376a5b5c586ffbe633d90"/><file name="CheckoutController.php" hash="5899163c45d6687a4f55efa3eca97ee4"/><file name="CmsController.php" hash="2dc7b2e14643e26444493f05434d29cc"/><file name="ConfigurationController.php" hash="67c8bc4a5a346f10b5106189c0b9afd7"/><file name="CustomerController.php" hash="f17ae4c197b7aacb4059f232a0b0e7f2"/><file name="HomebannersController.php" hash="f8f921cb733dc3d95b43c2d115612e07"/><file name="IndexController.php" hash="a4424c3802baa3fb782a7cfca984fc11"/><file name="LocalizationController.php" hash="deec1cf96b89da98feb0d72d98c7d448"/><file name="OfflineCatalogController.php" hash="61dc9bc4d698a8a9f675500331c8bc58"/><dir name="Paypal"><file name="MeclController.php" hash="e50ebf752c625a42561e4963f85c19a6"/><file name="MepController.php" hash="6a174a59d145109495b140f64b46bbac"/></dir><file name="PbridgeController.php" hash="2cbd655210d48d2fa4a921e9bdea881a"/><file name="ReviewController.php" hash="1863fbdc0eb62ee07e4e410a129c74a1"/><file name="WishlistController.php" hash="40a7c7951ae734b2c4414d0bf6c475c2"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f2935498f8438d93ac1a0084c7fb6da2"/><file name="config.xml" hash="6c643a21e6a52ea45f058329d881cec2"/><file name="system.xml" hash="817a56b1540cc8ed651b26ed0258fef0"/><dir name="themes"><file name="custom.xml" hash="117a8bb4d666ef613f19b7221268ebd0"/><file name="default.xml" hash="aaf6d41dd756497982a3ea55e13d790f"/><file name="funk_leaf.xml" hash="8c8f9210b10d43c0d90e8d6a2367cfbe"/><file name="hot_red.xml" hash="fca3e8ca7fc3634cae1979313c9b7177"/><file name="sky_blue.xml" hash="b6add2ae0a7ca115013355e316fa0137"/></dir></dir><dir name="sql"><dir name="xmlconnect_setup"><file name="install-1.6.0.0.php" hash="32c08a2bcf373250206437333d7603e1"/><file name="mysql4-data-upgrade-1.4.0.13-1.4.0.14.php" hash="c7315a31f8cef0b7d2ae8f80fbbc3163"/><file name="mysql4-data-upgrade-1.5.9.9-1.6.0.0.php" hash="d5cc11489f9a00b93b6014e065ef5715"/><file name="mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php" hash="438ed4be093ee9c3719d409d82a2ab72"/><file name="mysql4-install-1.4.0.8.php" hash="562ee2192b6688270cb8ae67116b4b2c"/><file name="mysql4-upgrade-1.4.0.10-1.4.0.11.php" hash="47239ae89b5e9879faeade3fcc5e8dff"/><file name="mysql4-upgrade-1.4.0.11-1.4.0.12.php" hash="2682567c7edffaf8818e74b1b89cec57"/><file name="mysql4-upgrade-1.4.0.12-1.4.0.13.php" hash="323be46c94ee31f0cecbc3b4551babd7"/><file name="mysql4-upgrade-1.4.0.13-1.4.0.14.php" hash="0299bd412387a948eca34642c7aef36f"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.9.php" hash="67d93828e93566e400f15df69cd07aad"/><file name="mysql4-upgrade-1.4.0.9-1.4.0.10.php" hash="4a79e3db4382b4239759a117f3261018"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e7ac9d8d2277ffd0d2ef3443c5babd50"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="a5ab0527c9e10a82421e58cf2e7946f9"/></dir></dir></dir></dir></dir></target><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="1dc6e4389554dc766d8a1f8ce14c8880"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="centinel"><file name="authentication.phtml" hash="97d0bda33c048c75071079360a633bbc"/></dir><dir name="pbridge"><file name="result.phtml" hash="eaf8dea1c847a163c6e03a79373f13db"/></dir></dir></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="9da94b4c6b75358e208d77fa71394894"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="edit"><dir name="tab"><file name="content.phtml" hash="8e5ee302d26adf7de3c5190ba3615290"/><dir name="design"><file name="autocomplete.phtml" hash="b896b29fbee0f6a694a4c1bbd4b47239"/><file name="image_edit.phtml" hash="9446db1ebe986034e800854a6cf4a58d"/><file name="images_android.phtml" hash="41e74b4bb5f363898b9c6bbba1abf340"/><file name="images_ipad.phtml" hash="7f4e7170149376c61839b7cd0aeaa535"/><file name="images_iphone.phtml" hash="5f4d38883d8c5b23186dd67aee5c2fdb"/><dir name="preview"><file name="banner_rotator.phtml" hash="21185f73d23a35eb5c2d8947f7f2e920"/><file name="catalog_android.phtml" hash="eaefb0f45613f6300099aa7bf23f301e"/><file name="catalog_hor_ipad.phtml" hash="3f23959c59286a29cfcaa719f78a13f5"/><file name="catalog_ipad.phtml" hash="624c310ec710c971fdd7e35c2122207e"/><file name="catalog_iphone.phtml" hash="c2ce0a7ca0a71f5d02e48147cd707ea0"/><file name="home_android.phtml" hash="058ea828dbc70b1eaa89b431102d5d52"/><file name="home_hor_ipad.phtml" hash="1ba3118600cd47f3db4eace31715f007"/><file name="home_ipad.phtml" hash="1f3033ec5eab6394b1bf7a91ebd3e0a6"/><file name="home_iphone.phtml" hash="f08e7358cac7612f7029e7caf0f8f9c0"/><file name="productinfo_iphone.phtml" hash="165165a8c05b6a667fbeca353d6ec216"/><file name="tab_items_android.phtml" hash="606e607fd42a6eec6ed1ef5d3855512f"/><file name="tab_items_ipad.phtml" hash="b178a8b51482b294b183a34f784b1f1e"/><file name="tab_items_iphone.phtml" hash="296eb9ad61ed6ab61d60b8f4c3dde341"/></dir><file name="preview_android.phtml" hash="e89c6f0b5622334370eeb03dbab11f52"/><file name="preview_ipad.phtml" hash="2f60401391a74808b2906a6e8468aae7"/><file name="preview_iphone.phtml" hash="cbd3e9ce74c2d4135227b24fdbd887fa"/></dir><file name="design.phtml" hash="f99ec1e92a0f6759b781a32332fc89d5"/><file name="offlinecatalog.phtml" hash="50b4394967e3e4053ae774fd8c0365a4"/></dir></dir><dir name="form"><dir name="element"><file name="addrow.phtml" hash="742de06e43b52a50f676098f8fa4e26e"/><file name="app_tabs_android.phtml" hash="0065b3e36e67c53933b823bbfbfd2bc4"/><file name="app_tabs_ipad.phtml" hash="89e64551169dffb436cebcf1f2429e0f"/><file name="app_tabs_iphone.phtml" hash="fe56e0132269b3824592eea17dc49c78"/><dir name="country"><file name="androidmarket.phtml" hash="d3702381cf57187df6ce2fb072c76f11"/><file name="istore.phtml" hash="861c3513f38f5d1cfb9303919bcab2dc"/></dir><file name="themes.phtml" hash="d3bc3e4d2b0a66acaaceb4545b5243f7"/></dir></dir><dir name="mobile"><file name="notification_helper.phtml" hash="1eb816a7bb47c809b028e9678c68282d"/></dir><dir name="submission"><file name="app_icons_preview.phtml" hash="b2f951860b9d0be57341d0e47a3b229a"/><file name="container.phtml" hash="a2a4e92c17ac1298c5012ef28b68a458"/></dir><dir name="template"><file name="preview.phtml" hash="c2b5375cc3a30ed8250effe88a81e494"/></dir></dir></dir></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_XmlConnect.xml" hash="26dbfbfa2414f06ef6db95abde509e31"/></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_XmlConnect.csv" hash="50e9493da78f8e6591fd3fad1311047c"/></dir></target><target name="magemedia"><dir name="xmlconnect"><dir><dir name="custom"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="original"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="system"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="xmlconnect"><file name="boxes.css" hash="a5a92bc3147999c70608672cceb8d818"/><file name="dropdown.css" hash="c631ab21a370129eb5526a26df214ba5"/><dir><dir name="fonts"><file name="android_icons-webfont.eot" hash="2fc917efbfb3c933ccfddc108ef05f33"/><file name="android_icons-webfont.svg" hash="e8cb2b5ef019bbc2885c97ed0caaf2a0"/><file name="android_icons-webfont.ttf" hash="bc567dd7a381093fbb652c58cbad9430"/><file name="android_icons-webfont.woff" hash="8310b54d55bf84a8a3f3a86c22a51aef"/><file name="stars-webfont.eot" hash="019beb4b8ec19447657cf3106138bbe3"/><file name="stars-webfont.svg" hash="20cf0312c0b951d173d4531ea18abc6f"/><file name="stars-webfont.ttf" hash="d63d95e9adaf775f410437535622bf60"/><file name="stars-webfont.woff" hash="526d9756131c94139f0f1df5272197fd"/></dir></dir><file name="iestyles.css" hash="8d5df1c3013797471e228162afc411e5"/><file name="mobile-android.css" hash="cc441eb45f35bd3d29b6f0833cd3b9fc"/><file name="mobile-catalog.css" hash="78e840f9871cb34662962efc4d03a514"/><file name="mobile-home.css" hash="2c38e64a3d024616bb85439707143fc9"/><file name="mobile-ipad-catalog.css" hash="22de5fda6eb0c3f2e4700f8360d62a0c"/><file name="mobile-ipad-home.css" hash="d07bbd12056c3a87cf92595e19f7a493"/><file name="remove.png" hash="b4903936d44dc498d2f32b72d9161ff0"/><file name="styles.css" hash="fb40b0c19d8fbc44d5032f69a9ebc92b"/></dir><dir name="images"><dir name="xmlconnect"><file name="btn_edit.gif" hash="e7ecc9fea5c3813957814050508507a5"/><dir><dir name="design_default"><file name="accordion_open.png" hash="4c89d903ebbc61ee295ef64a60724b10"/><file name="accordion_open_android.png" hash="7ef2f1d193990c3f4c2c90aae9ab3281"/><file name="accordion_open_android_l.png" hash="bc27688afbfd866c618477ea2c7bf0ee"/><file name="accordion_open_android_p.png" hash="2e4549cba575c12ef2a39c12e9ffe173"/><file name="accordion_open_ipad_l.png" hash="dcdda97da6556393b972d6dae8d6bac5"/><file name="accordion_open_ipad_p.png" hash="55cca08a0ab79047961858789ff8c3a7"/><file name="banner_1_2.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="banner_android.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="banner_ipad.png" hash="c1d59a6ec67da1bb76c5142453da7acf"/><file name="banner_ipad_l.png" hash="04e850d481a9ae902f33fd8c1f89cbf0"/><file name="smallIcon_1_6.png" hash="c1ce9e289eaf2c0504d502928693bd89"/></dir><dir name="mobile_preview"><file name="1.gif" hash="817fd84187db3eee00799b0acf316457"/><file name="2.gif" hash="1a842d8f3ac25cfcdeab6c86dd8fea89"/><file name="3.gif" hash="207cd55e968c284bd52c86efdcdda1c7"/><file name="actionsBackground.png" hash="11faa8baee72f3e6a9a02a83915c8658"/><file name="actionsBg.png" hash="9acccd1980f17006942d74a718ebd7da"/><dir name="android"><file name="background_home_landscape.jpg" hash="1f79a1f42ca4e2cf6010ab6c3ef66aa4"/><file name="background_portrait.jpg" hash="197b15e6455ad1a85e1bad6595371fa3"/><file name="bg_button_up.gif" hash="204f590a88933c930b7fc92963accfab"/><file name="bg_cat_item.png" hash="2859b45c387b66243d4af2ba973b2ae1"/><file name="bg_catalog_filters.png" hash="7464191ebaf576b73a3c021eb1cfcc25"/><file name="bg_catalog_filters_shadow.png" hash="5021ad60917190026d85fae1d33bdaa9"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_frame.gif" hash="7062ed9b7563fc658f49ce7cfdd34f1c"/><file name="bg_header.png" hash="d4a46c8850d1d89259921b1c28b5bce1"/><file name="bg_header_catalog.png" hash="c1080cd18a89e21da18fdc6955bf6230"/><file name="bg_header_home.png" hash="dfce0445ca7c7a45c7914a986b596ce0"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="8bc1887a0c5760cc47b77b8a7a320426"/><file name="bg_logo.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="bg_page.png" hash="d65f1d123655c2eaf3bb4a1e6035a08d"/><file name="bg_star.png" hash="fc6de6c4e0ed3478b8840e1ab81da725"/><file name="bg_star_empty.png" hash="3f0421fb8c8f6c4be6ca501168a881e8"/><file name="bg_status_bar.png" hash="52b41106451ac34672f82338bbc5370c"/><file name="ico_account.png" hash="c1fd338c74fcf483155acbd37c430807"/><file name="ico_home.png" hash="2de37f640463b354d68945320bfe3e4f"/><file name="ico_search.png" hash="8b0dd17a3e9c3328e66204fe379c66aa"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.png" hash="dd975b128ba303e0ae2adc9772e0433c"/><file name="product_image_1.jpg" hash="8994979d4dcc1f339c73cd1f44398a7d"/><file name="product_image_2.jpg" hash="26d6599bdb35d80b25a1e903b40cfa19"/><file name="product_image_3.jpg" hash="d7c6d05196a84341afe0025d01b9dc61"/><file name="product_image_4.jpg" hash="2a88ead3dbbeff1d40168db692841f2f"/></dir><file name="arrow.png" hash="837259a7c365e46034dca728bffe9070"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="background.png" hash="3717f4b4ba725701e2a0604129a3a815"/><file name="banner.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="btn-l.png" hash="92b2454528e9d39119038777cf53329c"/><file name="btn-r.png" hash="8c6aa9fd9203bc10822e0505f11e0c4d"/><file name="circle.png" hash="f4c116cb0554bf936d3b9ee38b7f3d1f"/><dir name="custom_icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="e33876648546e99d875ca92bd2cd78e9"/><file name="addToWishlist.png" hash="1018602b7c5e0e11f0427ace96fd7d52"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="buttons.gif" hash="0cd19a9d9178976906161ea100cba958"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="image-bg.png" hash="14bde5cf8b00dc5f6c60e52a0fa964dc"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="tellAFriend.png" hash="46f8ef48b29f245977d66d9312d87e70"/><file name="viewDetails.png" hash="9bacc63bcc483d3db5614a026d9391f6"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><dir name="gradients"><file name="footer.png" hash="31a2feed50ef9c8637b412c4211f8300"/><file name="header.png" hash="5386da930a944cd75562216249cce08a"/><file name="header2.png" hash="ad5a2dc6ec93914e925cfe2d43fb30a2"/><file name="header3.png" hash="920ad8c6903e90323a57fb02dca37280"/><file name="item-bg.png" hash="a14886d1f9e14284ac6b4f1b61e68646"/><file name="sort-bg.png" hash="b8053bb772e849909e5b87e4fd1ebbe4"/></dir><file name="grid.png" hash="23faa3f5572cdeb597c2bceedd93a7f8"/><dir name="icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="more.png" hash="f3662ae29923b87eba3a729192aa3df3"/><file name="page.png" hash="2291d77f21de042040bc0864be40138b"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/></dir><file name="image-bg.png" hash="a588b9cced95a25fc18e28c775d9a001"/><file name="info.png" hash="3f0d2ed85b81e8251f294457c6bfa404"/><dir name="ipad"><file name="background_home_landscape.jpg" hash="9e3ef117985113b804531142d539b60a"/><file name="background_portrait.jpg" hash="bdf9e034fd30b923086e6c622ea10451"/><file name="banner_image.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="banner_image_l.png" hash="a070a40d57610b5cc7160fe894482a1c"/><file name="bg_catalog_header_hor.png" hash="f61a67aa288e1b8a8df7b4d4527c662e"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_filter_button.png" hash="728f1cd358446881ffd863eff12204a1"/><file name="bg_filters_buttons.png" hash="02fcb0ed7a7268e9f64ebaf06235bc09"/><file name="bg_filters_tooltip.png" hash="3b05ca6e585acd3d766be01eeaa23d47"/><file name="bg_filters_wrap.png" hash="31288784fe95c67de9b45b44458b4155"/><file name="bg_header.png" hash="e2cf5a575a27e6e4533e3c85e3472a82"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="00f2fbf96d2b915dcbcd921b0301ef3f"/><file name="bg_home_header_hor.png" hash="9bfef728ece003d5b3433d2623ea168c"/><file name="bg_home_products.png" hash="ac6a8a79b959a0c8298b1f607c0f0af8"/><file name="bg_home_shadow.png" hash="c54b071ca3e97a6ee67588ef74b7b44e"/><file name="bg_home_shadow_hor.png" hash="0d21a99c5c749d0e5070e3585ff4a23f"/><file name="bg_product_image.png" hash="4da74325c1a4ee1ca19b414e5d590f75"/><file name="bg_search.png" hash="6ee08d05d0c4ef9ed64b9914b821f408"/><file name="bg_sections.jpg" hash="0ee90005663aced09a9ce6385bdbce2c"/><file name="bg_status_bar.png" hash="17124d9d392bb8e37b202c80a595df54"/><file name="bg_status_bar_hor.png" hash="bd4a9f11ecb1c896145267731d8a951d"/><file name="i_cart.png" hash="1bbe0a0e54eed5bb14b9bfcce83da758"/><file name="i_info.png" hash="3f0fda8b294b67bf698badbcaa99150b"/><file name="i_login.png" hash="deb4089bdc61582c78c90ef192d577e8"/><file name="i_remove.png" hash="4923eb5e76b3c6ba6df5c667db816a0c"/><file name="logo.png" hash="49c19f59b459b6c0b3b99daa3fe7f932"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.jpg" hash="2bb6c69129bcb18dc93e9f48605647c6"/><file name="sections_arrow.png" hash="7db7144083a31882e8a62cb9579f478f"/><file name="stars.png" hash="70d38cd9883d70e4f6b21ac4874b9868"/></dir><file name="lightStar.png" hash="b5dc40d5b793dae6a069357f49cccc24"/><file name="lightStar2.png" hash="75928926a6112540c9cb073157cb7d95"/><file name="lines-h.png" hash="ea3d95812c9838affc6df2f3a3cb1977"/><file name="lines-v.png" hash="9e3ffee29ba28477d50da9642019bc0a"/><file name="login-btn-left-alt.png" hash="71bb6c7d24252aace27bee711d7616f4"/><file name="login-btn-left.png" hash="cbbf9afc6e9fc433f57270e88b63f351"/><file name="login-btn-right.png" hash="438fcc598d012bf6d33184e95accfd24"/><file name="login-btn.png" hash="051ee2c1a8ce3f7b8de3293cd2e2ed85"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="logo_25.png" hash="ba41ed568d916175c32803b614442447"/><file name="men.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="mm-frame.gif" hash="eebf30806f1dbf2118e7ec39a016c86d"/><file name="mobile-catalog.css" hash="c808bf7f4ef7d84e6c0848f88abef943"/><file name="mobile-home.css" hash="a4a5f38b76b58bd4d18fb50e5977b1bd"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><dir name="slider"><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="2a146be4bc63713df19cc353e030d44f"/><file name="addToWishlist.png" hash="9b23a4e0d9acfc79f314e9082f14c4de"/><file name="tellAFriend.png" hash="b7600fa2ae52bdb1d6bb86fe4d9f1773"/><file name="viewDetails.png" hash="90cf37c6dbbee1861350b4c05469e3ae"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><file name="slider.gif" hash="c6b87bf15b85b18c0515e2cbefaabe60"/><file name="smallIcon.png" hash="e76d2a6364042f41b3f35fc8cdc9c0ee"/><dir name="sort_buttons"><file name="bg_button.png" hash="87d0f1b123f01c3aea3cb8a2b146306e"/><file name="button_up.gif" hash="7ad527f99b9975d5634fb2d5cc99e6b3"/><file name="buttons.gif" hash="2f14f1a3f0fb38790779c992a58654ae"/><file name="buttons.png" hash="b4a3f17370e03bf5d2a5cdf7800c25a7"/><file name="center-active.png" hash="5903988cd458cd794f23a212d51aa725"/><file name="center-inactive.png" hash="135b46aaa5c3b131a5a7e9c45c004e06"/><file name="filters.png" hash="3837ab6fcfe959833dd998533db1ca7f"/><file name="left-active.png" hash="86e94441b96a0d27d0b0a7e5108f86ed"/><file name="left-inactive.png" hash="0ddcb75aa9971cca39a5a65b4bdff8c4"/><file name="right-active.png" hash="320740ff608187301b06a96eab2f9e8e"/><file name="right-inactive.png" hash="cac4b39ab380353ffd5fdbcedb6e0a0a"/></dir><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="t-shirt.gif" hash="7505efdaabf13c4f8e26f7cfe15c8c96"/><file name="t-shirt.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="women.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="youth.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/></dir></dir><file name="dropdown-arrow.gif" hash="332e99ca6b4d1e0d39972e04fb0b2395"/><file name="empty.png" hash="23dc9dc3c4751f83c2df7a5c42668824"/><file name="full-arrow-left.gif" hash="8ec91b60d38d1a16cba7670f2088a5c7"/><file name="full-arrow.gif" hash="36ddff0fca1c7d8900cb3633e0a30cea"/><file name="gel_green.png" hash="591959d831e8e42c9175d12a88f0bae2"/><file name="gel_red.png" hash="db442c023014df9da32b84bc1bb5a39f"/><file name="l-arrow.gif" hash="ee49f7eab64657b5131953acef0238fd"/><file name="loading.gif" hash="5d25806dac7cbee5f894b13144783866"/><file name="r-arrow.gif" hash="d0429a9781e915fc9d9ca8875c470d32"/><file name="remove.png" hash="ee9497c5f31933eaab3e9e352495ee12"/><file name="small_logo.gif" hash="d5c8be7c0f16aac2549759c0228492d6"/><file name="swatch_black.gif" hash="fd31d6a3a435c8ad1f7c43f346bb47e4"/><file name="swatch_custom.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_default.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_funk_leaf.gif" hash="f1d3ba87efb742b47da879a6f48909c4"/><file name="swatch_hot_red.gif" hash="d9363d45dc2993c2fdc3ea43c5b6f71c"/><file name="swatch_sky_blue.gif" hash="ded1455db119d09a3aedd7474fd1875a"/><file name="swatch_user_custom.gif" hash="a24f31421a1ff56d1be0845f9a7c7020"/><file name="switch-arrow.gif" hash="dc7243962b341f366cd072d486687e6a"/><file name="tab_account.png" hash="27101fbaa78a07426be4768acc4c53ff"/><file name="tab_account_android.png" hash="77605cbc87f75ca17e91a5393765ceb1"/><file name="tab_account_ipad.png" hash="2997de5402195d0720309b73c6446fab"/><file name="tab_cart.png" hash="e803f760ee81cb35183f1122f388b774"/><file name="tab_cart_android.png" hash="477e97f8d03ea8aa674e952709f86578"/><file name="tab_empty.png" hash="bdd4cc355566e8861b2c45424ad94516"/><file name="tab_home.png" hash="dfa104e4da74e4a55d3c98d6ee0f7122"/><file name="tab_home_active.png" hash="bba5eb9bb724c84c1ede9e6f4bec3575"/><file name="tab_home_android.png" hash="1fefc6b070cc21b31b43194a7d85f9d9"/><file name="tab_info_android.png" hash="67fc19d8d926f7aede482f5a7083fc71"/><file name="tab_more.png" hash="2803359cb3e795bf67457e727aa16020"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="2cf29dbe325558353621b4241543204f"/><file name="tab_search_android.png" hash="932c2c568872fd9e119367c887f0539a"/><file name="tab_shop.png" hash="f36be0d3d27f2b37626247d3f6a55e2a"/><file name="tab_shop_active.png" hash="de907d6a52d477d4319649f9b0e2e4aa"/><file name="tab_shop_android.png" hash="e119fcd20f8cba856d550a64d775ddbb"/><file name="tmp-icon.gif" hash="58b759aecf3bdae26d5aaff7a0be5c90"/><file name="xmlconnect_tab.png" hash="cd99a7e01a42a6c82d866f7684faeb95"/></dir></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="xmlconnect"><dir><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="jscolor"><file name="arrow.gif" hash="5034704a76cd55c1cbcbc58ea6bf523f"/><file name="cross.gif" hash="ba9a274b9323753cd95bc3b1eb2f4e5f"/><file name="demo.html" hash="edf71251cb2be20322d2efb00aee86a6"/><file name="hs.png" hash="fefa1a03d92ebad25c88dca94a0b63db"/><file name="hv.png" hash="990d71cada17da100653636cf8490884"/><file name="jscolor.js" hash="b65a1505390592ac6c0177d6b84774e0"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
diff --git a/var/package/Phoenix_Moneybookers-1.9.4.0.xml b/var/package/Phoenix_Moneybookers-1.9.4.0.xml
deleted file mode 100644
index 7d0fbf0..0000000
--- a/var/package/Phoenix_Moneybookers-1.9.4.0.xml
+++ /dev/null
@@ -1,35 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Phoenix_Moneybookers</name>
-    <version>1.9.4.0</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Moneybookers payment gateway integration</summary>
-    <description>Moneybookers payment gateway official integration, implemented by Phoenix Medien GmbH. Provides integration for payment options powered by Moneybookers, as separate payment methods:
-All Credit Cards / Visa, Mastercard, AMEX, JCB, Diners - International
-CartaSi - Italy
-Lastschrift (ELV) - Germany
-Dankort - Denmark
-Nordea Solo - Sweden
-eNETS - Singapore
-Carte Bleue - France
-Giropay - Germany
-iDeal - Netherlands
-Laser - Ireland
-EPS Online-&#xDC;berweisung - Austria
-POLi - Australia
-Postepay - Italy
-Przelewy24 - Poland
-Sofort&#xFC;berweisung - Germany
-Nordea Solo - Finland
-Moneybookers eWallet</description>
-    <notes>1.9.4.0</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2018-11-23</date>
-    <time>15:32:13</time>
-    <contents><target name="magecommunity"><dir name="Phoenix"><dir name="Moneybookers"><dir name="Block"><file name="Form.php" hash="eeb9f4cbf40ad3f8ea246949df42f20f"/><file name="Info.php" hash="60f403368d869fb9bf981481183caf81"/><file name="Jsinit.php" hash="57b2647a06c41529a39fbb8267304426"/><file name="Payment.php" hash="3241b0e2e8fd1044e99b26d4417fb896"/><file name="Placeform.php" hash="55cdc50e646485e6add807906edfd9bd"/><file name="Redirect.php" hash="a74bdf41523e0f5b7f112a672bc35c0f"/></dir><dir name="Helper"><file name="Data.php" hash="405dd62f4d5034fbdd50c97c5811198a"/></dir><dir name="Model"><file name="Abstract.php" hash="a2183c3e41570d18d3fb15622f849e54"/><file name="Acc.php" hash="b336c73a891716054e731cfab7f8b82f"/><file name="Csi.php" hash="6d1bc7db413067924845ede03ef471e3"/><file name="Did.php" hash="5ecd119d337421684527d4cf6325626a"/><file name="Dnk.php" hash="81b6e59112fc18529ecfae11be4c2ade"/><file name="Ebt.php" hash="0495a2003b91cf1a618539754e721e92"/><file name="Ent.php" hash="99b33941105262ea72cf542264c25299"/><file name="Event.php" hash="8b541b7549244a79b582c63ae258016d"/><file name="Gcb.php" hash="da261d1db5ad469514d64ea5294f0b44"/><file name="Gir.php" hash="ccd8d7f1156367b82de68c495f4577e7"/><file name="Idl.php" hash="420ad97f061ccccd7649dfbd173d7b58"/><file name="Lsr.php" hash="f25ec4b47251ea8169df227a476a0475"/><file name="Mae.php" hash="438caefcb78939ea0bd484103bed860b"/><file name="Npy.php" hash="a6b60d739312b6f6c3e53060c1db0fe4"/><file name="Obt.php" hash="0e54d523afa9e0638d95e76742bc475b"/><file name="Pli.php" hash="be52cfaf911d86185da583ecd2433173"/><file name="Psp.php" hash="b8dcb8feb62b25b57982bfb23fc8d17d"/><file name="Pwy.php" hash="a5fa1665f2acf05775bb8dcdca99438f"/><file name="Sft.php" hash="5330414049131f7c889b4d7f6b95f18c"/><file name="So2.php" hash="dcc30139c5758812c42d1e90b5af5c83"/><file name="Wlt.php" hash="2fa4aafc62988eb84d2764922a23a5f5"/></dir><dir name="controllers"><file name="MoneybookersController.php" hash="bcc56ba3c6792864ba14fb8908762736"/><file name="ProcessingController.php" hash="c0550d579088c6c0c082c95f7c8899e8"/></dir><dir name="etc"><file name="config.xml" hash="dac9f28a414ad9bf9cd029e5f0ad1c79"/><file name="system.xml" hash="00d8a898760e1a18870f08cec00e9342"/></dir><dir name="sql"><dir name="moneybookers_setup"><file name="install-1.6.0.0.php" hash="15cfc5aa9d469e45eb276d5eb5226116"/><file name="mysql4-upgrade-1.2-1.2.0.1.php" hash="33737aa54286d733e363cc94b12aefba"/></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Phoenix_Moneybookers.xml" hash="a0715f3a3f42397529d8952ee1c03491"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="info.phtml" hash="a630df889916a60485b8f95a034888f7"/><file name="jsinit.phtml" hash="410d8d395f085fa8d305dafc25c0593b"/><dir name="pdf"><file name="info.phtml" hash="3cb1f4ba8ba6d8fefb9f3103115a059a"/></dir></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="16ab3cdfd84ecac3bd2707d577a7625c"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="blank.phtml" hash="d9f6fea50514645e5b55ed217c58b603"/><file name="form.phtml" hash="8b2d2d8a0798aeb04584a1691f483c7c"/><file name="info.phtml" hash="54f4bed61d0540555616d3f586491503"/><file name="payment.phtml" hash="57cdfee41897ee704578d5321e0f3e6a"/><file name="placeform.phtml" hash="85abb1fb706056a43c400ee9f4a2a3fb"/><file name="redirect.phtml" hash="a17c5ed6c574f55f46e16f756b0df224"/></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="773b844ae29d9eeadbd5e16a9744084b"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Phoenix_Moneybookers.csv" hash="c92cee5c0ca36fdedfbab70e95a91983"/><dir name="template"><dir name="email"><file name="moneybookers_activateemail.html" hash="035d73b26c54c8042e03e7551df49457"/></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner_120_de.gif" hash="74815117bf378543e5b3496bb5bc4e8a"/><file name="banner_120_de.png" hash="6c3f708fcb6dac92e53472d4c2246c68"/><file name="banner_120_dk.gif" hash="2106bd994d188d40474bf2a2e8d62a8d"/><file name="banner_120_fr.gif" hash="a84241eef7bc38fb38567e7aa8ca245a"/><file name="banner_120_fr.png" hash="8994d1dc3b4f5c9e5efc67ce3f9f55a9"/><file name="banner_120_int.gif" hash="e23ddcf71e15f0a9300062ef9cdea512"/><file name="banner_120_int.png" hash="f9dfbc26041e52b34eea65348707d64f"/><file name="banner_120_pl.gif" hash="44313c7d27cdcf59c2f66708c6c5abd5"/><file name="banner_120_pl.png" hash="67d3385f93bc9113880305ee7c7da9de"/><file name="banner_120_sp.gif" hash="a003ed8db63620672ae945682b1e1e39"/><file name="banner_120_sp.png" hash="f9c4a653d6814ab3f8c535da706f5f77"/><file name="moneybookers_acc.png" hash="a3e639a68fafdffaca81e91985127735"/><file name="moneybookers_csi.gif" hash="4eec4ed7c494d01d518a3c6c691128e9"/><file name="moneybookers_did.gif" hash="6a3a3365894e9cdb199647a5b74ba35b"/><file name="moneybookers_dnk.gif" hash="7d4b8d27784f8a6fa6ef81c4e911831b"/><file name="moneybookers_ebt.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_ent.gif" hash="704e9551ed4aff82b67114242b9fba1a"/><file name="moneybookers_gcb.gif" hash="e2e7c0f501e5ab0136f859ca5f57abc2"/><file name="moneybookers_gir.gif" hash="f16e949bc60bbd812f803d5e377d47f6"/><file name="moneybookers_idl.gif" hash="fe0ad1efc12d43df6c9ff3ffdd9dd59b"/><file name="moneybookers_lsr.gif" hash="58cdadfa20b6d37aeaa19e50995e4baf"/><file name="moneybookers_mae.gif" hash="4d4b5f0cf3377939c7738fc7e416d25f"/><file name="moneybookers_npy.gif" hash="01242c5ad7bc667e7493b550b6397fab"/><file name="moneybookers_obt_de.png" hash="ce44fd2974b8d279401778292e2c4484"/><file name="moneybookers_obt_dk.png" hash="2985e8cb472d1886d584fa31d56bee92"/><file name="moneybookers_obt_ee.png" hash="cb186be1c7595544f61d3737c7bf85aa"/><file name="moneybookers_obt_en.png" hash="eee098a06e3ea34f33e276724b084774"/><file name="moneybookers_obt_fl.png" hash="6c3766df052d875ce399e62ad8a435f8"/><file name="moneybookers_obt_lt.png" hash="adf61f248fc6d5985840db3e0c23391e"/><file name="moneybookers_obt_lv.png" hash="4e7f16b4988ea30f049942d4dcdb5f78"/><file name="moneybookers_obt_pl.png" hash="fb2c43c18ba73d390e5b5f5261261f4a"/><file name="moneybookers_obt_se.png" hash="9028412e9c3f25d114bf40bb2049d225"/><file name="moneybookers_pli.gif" hash="93989e85caff760af7a61838db0300bf"/><file name="moneybookers_psp.gif" hash="7abffc2246f172625be2ce31f4315cb2"/><file name="moneybookers_pwy.gif" hash="b4a0b9db9a031855e6e3899592012fae"/><file name="moneybookers_sft.gif" hash="e9e774163c99a8ab4deb18d37feaf658"/><file name="moneybookers_so2.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_wlt.gif" hash="4b9cbc5aa5c32f3015ce7bec98da2670"/></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner.jpg" hash="382b1eea5550ce6c1b88cd4444058362"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><file name="moneybookers.js" hash="c9581fb17c9aa5d406c698788336cebd"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.0</min><max>1.9.4.0</max></package></required></dependencies>
-</package>
diff --git a/var/package/Phoenix_Moneybookers-1.9.4.1.xml b/var/package/Phoenix_Moneybookers-1.9.4.1.xml
new file mode 100644
index 0000000..6befe41
--- /dev/null
+++ b/var/package/Phoenix_Moneybookers-1.9.4.1.xml
@@ -0,0 +1,35 @@
+<?xml version="1.0"?>
+<package>
+    <name>Phoenix_Moneybookers</name>
+    <version>1.9.4.1</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Moneybookers payment gateway integration</summary>
+    <description>Moneybookers payment gateway official integration, implemented by Phoenix Medien GmbH. Provides integration for payment options powered by Moneybookers, as separate payment methods:
+All Credit Cards / Visa, Mastercard, AMEX, JCB, Diners - International
+CartaSi - Italy
+Lastschrift (ELV) - Germany
+Dankort - Denmark
+Nordea Solo - Sweden
+eNETS - Singapore
+Carte Bleue - France
+Giropay - Germany
+iDeal - Netherlands
+Laser - Ireland
+EPS Online-&#xDC;berweisung - Austria
+POLi - Australia
+Postepay - Italy
+Przelewy24 - Poland
+Sofort&#xFC;berweisung - Germany
+Nordea Solo - Finland
+Moneybookers eWallet</description>
+    <notes>1.9.4.1</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-03-20</date>
+    <time>21:53:59</time>
+    <contents><target name="magecommunity"><dir name="Phoenix"><dir name="Moneybookers"><dir name="Block"><file name="Form.php" hash="49ba46fdbc2aee011df8979b3b22f095"/><file name="Info.php" hash="58e286f9b4d26fd2900930b809141f54"/><file name="Jsinit.php" hash="ca7643a653dbca6aab7bc4543ae8a2f3"/><file name="Payment.php" hash="ee89a5a3350a9932b0e68216b5c4eb51"/><file name="Placeform.php" hash="8bfa12841f7aa2e95c8d28547dca383c"/><file name="Redirect.php" hash="6499e4dae9bbb05bce000f667d5fcef7"/></dir><dir name="Helper"><file name="Data.php" hash="1798f14aa0fd940730aae6856e3963e2"/></dir><dir name="Model"><file name="Abstract.php" hash="d551ffe2e896c4146b05f37a5f7b3bed"/><file name="Acc.php" hash="939e2da57b59227ce2c888a571f6d68d"/><file name="Csi.php" hash="0b34b7abc133fcabacab4a5e1227e784"/><file name="Did.php" hash="a77efea0f47ddc0dbcf2178ade90d7f8"/><file name="Dnk.php" hash="4ef8510289004955286cb5fc3fb9369f"/><file name="Ebt.php" hash="beb720b8a91cda6d8dd54aa2f76c43ec"/><file name="Ent.php" hash="f3c4a7ba1f698153097cd77326992c0f"/><file name="Event.php" hash="b373bd655a3a794dfcf7e6b7683a27c9"/><file name="Gcb.php" hash="10630a1d324af938fa2c7e7d732b1ec3"/><file name="Gir.php" hash="db996ac84d4a616888ab096025c649d6"/><file name="Idl.php" hash="6ec8eba6c330c0f3f6137422713d8b60"/><file name="Lsr.php" hash="4f09028709d716e0aa7e56102a54f355"/><file name="Mae.php" hash="68f7e7bcaba63d61ea5ac56ef0e07f7f"/><file name="Npy.php" hash="cde76b9858dbeb6d239b5ffa8d6e2845"/><file name="Obt.php" hash="fdd8ed79882ab27d9f679065f0812e65"/><file name="Pli.php" hash="46ccf1cc56ec503727ccf0b01ed3ecfc"/><file name="Psp.php" hash="d704c4bd3441c5dcfbc7528fe4868e26"/><file name="Pwy.php" hash="71c9af54425a98e557b7174d784da04f"/><file name="Sft.php" hash="f1bccacf2ec8a5a198d2f433cb21d7d8"/><file name="So2.php" hash="45fb61c9c13b5abeca6aa59ff69dfb7f"/><file name="Wlt.php" hash="4a8e5d3937814de9dbc3b1bca262ba8e"/></dir><dir name="controllers"><file name="MoneybookersController.php" hash="92e1ccc2a361ee8a2e5305262857a592"/><file name="ProcessingController.php" hash="c41e0232a55d4bf492adf3fdb7caa6b1"/></dir><dir name="etc"><file name="config.xml" hash="2893116b8a4f1f5aae9635b08c7ecd2c"/><file name="system.xml" hash="706c223e723559a349c18f42d78b2695"/></dir><dir name="sql"><dir name="moneybookers_setup"><file name="install-1.6.0.0.php" hash="1d9bbf3c5025ed0d7d9ad3d3c5e22bd6"/><file name="mysql4-upgrade-1.2-1.2.0.1.php" hash="29e544d8bbde79af0a3b0a60e571cbfe"/></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Phoenix_Moneybookers.xml" hash="14751dc6d49492ef809111a97c2c01bb"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="info.phtml" hash="00b41d6fb627c4e02bb5e1b3410958fa"/><file name="jsinit.phtml" hash="368eb5021a3bd3e79651d40c1ad80733"/><dir name="pdf"><file name="info.phtml" hash="67e5414f72c8c7cedd118f6c094e6c0d"/></dir></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="0c2ea969ce71386db5a2af6360073a34"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="blank.phtml" hash="2b838fe6caaf3b36c962db5935036873"/><file name="form.phtml" hash="6bfad26b37ba6f9c59020193d24618ab"/><file name="info.phtml" hash="d80f64d287917ff499636786959cf0ab"/><file name="payment.phtml" hash="bc07fbcf3816775ce4f5a41b7270b855"/><file name="placeform.phtml" hash="11d1fc3021a0bf174dc64ed14e72ba0b"/><file name="redirect.phtml" hash="c4d74978faac32659af356b87e2a2364"/></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="56bdd4771be815d661a3a01b7b3d7b20"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Phoenix_Moneybookers.csv" hash="c92cee5c0ca36fdedfbab70e95a91983"/><dir name="template"><dir name="email"><file name="moneybookers_activateemail.html" hash="035d73b26c54c8042e03e7551df49457"/></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner_120_de.gif" hash="74815117bf378543e5b3496bb5bc4e8a"/><file name="banner_120_de.png" hash="6c3f708fcb6dac92e53472d4c2246c68"/><file name="banner_120_dk.gif" hash="2106bd994d188d40474bf2a2e8d62a8d"/><file name="banner_120_fr.gif" hash="a84241eef7bc38fb38567e7aa8ca245a"/><file name="banner_120_fr.png" hash="8994d1dc3b4f5c9e5efc67ce3f9f55a9"/><file name="banner_120_int.gif" hash="e23ddcf71e15f0a9300062ef9cdea512"/><file name="banner_120_int.png" hash="f9dfbc26041e52b34eea65348707d64f"/><file name="banner_120_pl.gif" hash="44313c7d27cdcf59c2f66708c6c5abd5"/><file name="banner_120_pl.png" hash="67d3385f93bc9113880305ee7c7da9de"/><file name="banner_120_sp.gif" hash="a003ed8db63620672ae945682b1e1e39"/><file name="banner_120_sp.png" hash="f9c4a653d6814ab3f8c535da706f5f77"/><file name="moneybookers_acc.png" hash="a3e639a68fafdffaca81e91985127735"/><file name="moneybookers_csi.gif" hash="4eec4ed7c494d01d518a3c6c691128e9"/><file name="moneybookers_did.gif" hash="6a3a3365894e9cdb199647a5b74ba35b"/><file name="moneybookers_dnk.gif" hash="7d4b8d27784f8a6fa6ef81c4e911831b"/><file name="moneybookers_ebt.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_ent.gif" hash="704e9551ed4aff82b67114242b9fba1a"/><file name="moneybookers_gcb.gif" hash="e2e7c0f501e5ab0136f859ca5f57abc2"/><file name="moneybookers_gir.gif" hash="f16e949bc60bbd812f803d5e377d47f6"/><file name="moneybookers_idl.gif" hash="fe0ad1efc12d43df6c9ff3ffdd9dd59b"/><file name="moneybookers_lsr.gif" hash="58cdadfa20b6d37aeaa19e50995e4baf"/><file name="moneybookers_mae.gif" hash="4d4b5f0cf3377939c7738fc7e416d25f"/><file name="moneybookers_npy.gif" hash="01242c5ad7bc667e7493b550b6397fab"/><file name="moneybookers_obt_de.png" hash="ce44fd2974b8d279401778292e2c4484"/><file name="moneybookers_obt_dk.png" hash="2985e8cb472d1886d584fa31d56bee92"/><file name="moneybookers_obt_ee.png" hash="cb186be1c7595544f61d3737c7bf85aa"/><file name="moneybookers_obt_en.png" hash="eee098a06e3ea34f33e276724b084774"/><file name="moneybookers_obt_fl.png" hash="6c3766df052d875ce399e62ad8a435f8"/><file name="moneybookers_obt_lt.png" hash="adf61f248fc6d5985840db3e0c23391e"/><file name="moneybookers_obt_lv.png" hash="4e7f16b4988ea30f049942d4dcdb5f78"/><file name="moneybookers_obt_pl.png" hash="fb2c43c18ba73d390e5b5f5261261f4a"/><file name="moneybookers_obt_se.png" hash="9028412e9c3f25d114bf40bb2049d225"/><file name="moneybookers_pli.gif" hash="93989e85caff760af7a61838db0300bf"/><file name="moneybookers_psp.gif" hash="7abffc2246f172625be2ce31f4315cb2"/><file name="moneybookers_pwy.gif" hash="b4a0b9db9a031855e6e3899592012fae"/><file name="moneybookers_sft.gif" hash="e9e774163c99a8ab4deb18d37feaf658"/><file name="moneybookers_so2.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_wlt.gif" hash="4b9cbc5aa5c32f3015ce7bec98da2670"/></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner.jpg" hash="382b1eea5550ce6c1b88cd4444058362"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><file name="moneybookers.js" hash="bdfe32503bd325d15b085c5c4938a428"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
+</package>
